#include "monty.h"
#include "fusion_p.h"

template<typename T> struct _checked_ptr_1 
{
  T * ptr;
  size_t sz;
  _checked_ptr_1<T>(T * ptr, size_t sz) : ptr(ptr), sz(sz) {} 
  T & operator[](ptrdiff_t i) { assert(i >= 0 && i < sz); return ptr[i]; } 
  const T & operator[](ptrdiff_t i) const { assert(i >= 0 && i < sz); return ptr[i]; } 
  void update(T * ptr_, size_t sz_) { ptr = ptr_; sz = sz_; }
};

template<typename T> struct _checked_ptr_2
{
  T * ptr; 
  size_t sz0, sz1; 
  _checked_ptr_2<T>(T * ptr, size_t sz0, size_t sz1) : ptr(ptr), sz0(sz0),sz1(sz1) {} 
  T & operator()(ptrdiff_t i0, ptrdiff_t i1) { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  const T & operator()(ptrdiff_t i0, ptrdiff_t i1) const { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  void update(T * ptr_, size_t sz0_, size_t sz1_) { ptr = ptr_; sz0 = sz0_; sz1 = sz1_; }
};

// See http://www.cplusplus.com/articles/DE18T05o/
//                 A      && ( (       B      && B1 && B2      ) || (      C      &&   C1 &&   C2  ) )
// A a and b a have different signs
// B, B1, B2 a and b are both non-negative, r is less than both a and b
// C, C1, C2 a and b are both negative, r is greater than both a and b

struct InternalNumericOverflow {};

template<typename T> 
static inline T checked_add(T a, T b, bool & overflow) {
  int r = a+b;
  overflow = ((a ^ b) >= 0) && ( (( (a & b) >= 0) && r < a && r < b) || ( ((a & b) < 0) && a > r && b > r) );
  return r;
}

template<typename T>
static inline T safe_add_(T a, T b) {
  bool overflow; 
  T r = checked_add(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_add(int a, int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, int b) { return safe_add_<long long int>(a,b); }

template<typename T>
static inline T checked_mul(T a, T b, bool & overflow) {
  T r = a * b;
  overflow = b != 0 && ((a ^ b >= 0 && a > std::numeric_limits<T>::max() / b) || (a ^ b < 0 && a < std::numeric_limits<T>::min() / b));
  return r;
}

template<typename T>
static inline T safe_mul_(T a, T b) {
  bool overflow; 
  T r = checked_mul(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_mul(int a, int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, int b) { return safe_mul_<long long int>(a,b); }

std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::StatusKey val){switch (val){case StatusKey::Unknown: os << "StatusKey::Unknown"; break;case StatusKey::Basic: os << "StatusKey::Basic"; break;case StatusKey::SuperBasic: os << "StatusKey::SuperBasic"; break;case StatusKey::OnBound: os << "StatusKey::OnBound"; break;case StatusKey::Infinity: os << "StatusKey::Infinity"; break;default: os << "StatusKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionType val){switch (val){case SolutionType::Default: os << "SolutionType::Default"; break;case SolutionType::Basic: os << "SolutionType::Basic"; break;case SolutionType::Interior: os << "SolutionType::Interior"; break;case SolutionType::Integer: os << "SolutionType::Integer"; break;default: os << "SolutionType.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ProblemStatus val){switch (val){case ProblemStatus::Unknown: os << "ProblemStatus::Unknown"; break;case ProblemStatus::PrimalAndDualFeasible: os << "ProblemStatus::PrimalAndDualFeasible"; break;case ProblemStatus::PrimalFeasible: os << "ProblemStatus::PrimalFeasible"; break;case ProblemStatus::DualFeasible: os << "ProblemStatus::DualFeasible"; break;case ProblemStatus::PrimalInfeasible: os << "ProblemStatus::PrimalInfeasible"; break;case ProblemStatus::DualInfeasible: os << "ProblemStatus::DualInfeasible"; break;case ProblemStatus::PrimalAndDualInfeasible: os << "ProblemStatus::PrimalAndDualInfeasible"; break;case ProblemStatus::IllPosed: os << "ProblemStatus::IllPosed"; break;case ProblemStatus::PrimalInfeasibleOrUnbounded: os << "ProblemStatus::PrimalInfeasibleOrUnbounded"; break;default: os << "ProblemStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::AccSolutionStatus val){switch (val){case AccSolutionStatus::Anything: os << "AccSolutionStatus::Anything"; break;case AccSolutionStatus::Optimal: os << "AccSolutionStatus::Optimal"; break;case AccSolutionStatus::Feasible: os << "AccSolutionStatus::Feasible"; break;case AccSolutionStatus::Certificate: os << "AccSolutionStatus::Certificate"; break;default: os << "AccSolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionStatus val){switch (val){case SolutionStatus::Undefined: os << "SolutionStatus::Undefined"; break;case SolutionStatus::Unknown: os << "SolutionStatus::Unknown"; break;case SolutionStatus::Optimal: os << "SolutionStatus::Optimal"; break;case SolutionStatus::Feasible: os << "SolutionStatus::Feasible"; break;case SolutionStatus::Certificate: os << "SolutionStatus::Certificate"; break;case SolutionStatus::IllposedCert: os << "SolutionStatus::IllposedCert"; break;default: os << "SolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ObjectiveSense val){switch (val){case ObjectiveSense::Undefined: os << "ObjectiveSense::Undefined"; break;case ObjectiveSense::Minimize: os << "ObjectiveSense::Minimize"; break;case ObjectiveSense::Maximize: os << "ObjectiveSense::Maximize"; break;default: os << "ObjectiveSense.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::QConeKey val){switch (val){case QConeKey::InQCone: os << "QConeKey::InQCone"; break;case QConeKey::InRotatedQCone: os << "QConeKey::InRotatedQCone"; break;case QConeKey::InPExpCone: os << "QConeKey::InPExpCone"; break;case QConeKey::InPPowCone: os << "QConeKey::InPPowCone"; break;case QConeKey::InDExpCone: os << "QConeKey::InDExpCone"; break;case QConeKey::InDPowCone: os << "QConeKey::InDPowCone"; break;default: os << "QConeKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::PSDKey val){switch (val){case PSDKey::IsSymPSD: os << "PSDKey::IsSymPSD"; break;case PSDKey::IsTrilPSD: os << "PSDKey::IsTrilPSD"; break;default: os << "PSDKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::RelationKey val){switch (val){case RelationKey::EqualsTo: os << "RelationKey::EqualsTo"; break;case RelationKey::LessThan: os << "RelationKey::LessThan"; break;case RelationKey::GreaterThan: os << "RelationKey::GreaterThan"; break;case RelationKey::IsFree: os << "RelationKey::IsFree"; break;case RelationKey::InRange: os << "RelationKey::InRange"; break;default: os << "RelationKey.<invalid>"; break;}return os;}mosek::fusion::Sort::Sort(mosek::fusion::p_Sort *_impl) : _impl(_impl) { /*std::cout << "Sort() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Sort::~Sort() { delete _impl; _impl = nullptr; }mosek::fusion::p_Sort::p_Sort  (::mosek::fusion::Sort * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Sort::argTransposeSort  ( std::shared_ptr< monty::ndarray< long long,1 > > _151,    std::shared_ptr< monty::ndarray< long long,1 > > _152,    int _153,    int _154,    int _155,    std::shared_ptr< monty::ndarray< long long,1 > > _156) { mosek::fusion::p_Sort::argTransposeSort(_151,_152,_153,_154,_155,_156); }void mosek::fusion::p_Sort::argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _151,std::shared_ptr< monty::ndarray< long long,1 > > _152,int _153,int _154,int _155,std::shared_ptr< monty::ndarray< long long,1 > > _156){
  _checked_ptr_1<long long> _ptr__151(_151 ? _151->raw() : nullptr, _151 ? _151->size(0) : 0);
  _checked_ptr_1<long long> _ptr__152(_152 ? _152->raw() : nullptr, _152 ? _152->size(0) : 0);
  _checked_ptr_1<long long> _ptr__156(_156 ? _156->raw() : nullptr, _156 ? _156->size(0) : 0);
  int _6611 = (int)0;
  int _6612 = safe_add( safe_mul( _153,_155 ),(int)1 );
  for (int _157 = _6611; _157 < _6612; ++_157)
  {
    {
      _ptr__152[_157] = (int)0;
    }
  }
  int _6613 = (int)0;
  int _6614 = (int)((_156)->size(0));
  for (int _158 = _6613; _158 < _6614; ++_158)
  {
    {
      ++ _ptr__152[safe_add( safe_add( safe_mul( (_ptr__156[_ptr__151[_158]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__151[_158]] % _155) ),(int)1 )];
    }
  }
  int _6615 = (int)0;
  int _6616 = safe_mul( _153,_155 );
  for (int _159 = _6615; _159 < _6616; ++_159)
  {
    {
      _ptr__152[safe_add( _159,(int)1 )] = safe_add( _ptr__152[safe_add( _159,(int)1 )],_ptr__152[_159] );
    }
  }
  std::vector<long long> _6617;
  for (int _161 = (int)0, _6618 = (int)((_151)->size(0)); _161 < _6618 ; ++_161)
  {
    _6617.push_back(_ptr__151[_161]);
  }
  auto _6619 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6617.size()),_6617.begin(),_6617.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _160 = _6619;
  _checked_ptr_1<long long> _ptr__160(_160 ? _160->raw() : nullptr,_160 ? _160->size(0) : 0);
  long long _6620 = (long long)0;
  long long _6621 = (long long)((_156)->size(0));
  for (long long _162 = _6620; _162 < _6621; ++_162)
  {
    {
      long long _163 = safe_add( safe_mul( (_ptr__156[_ptr__160[_162]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__160[_162]] % _155) );
      _ptr__151[_ptr__152[_163]] = _ptr__160[_162];
      ++ _ptr__152[_163];
    }
  }
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _164,    std::shared_ptr< monty::ndarray< long long,1 > > _165) { mosek::fusion::p_Sort::argsort(_164,_165); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _164,std::shared_ptr< monty::ndarray< long long,1 > > _165){
  _checked_ptr_1<long long> _ptr__164(_164 ? _164->raw() : nullptr, _164 ? _164->size(0) : 0);
  _checked_ptr_1<long long> _ptr__165(_165 ? _165->raw() : nullptr, _165 ? _165->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_164,_165,(long long)((int)0),(long long)((int)((_164)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _166,    std::shared_ptr< monty::ndarray< int,1 > > _167) { mosek::fusion::p_Sort::argsort(_166,_167); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _166,std::shared_ptr< monty::ndarray< int,1 > > _167){
  _checked_ptr_1<long long> _ptr__166(_166 ? _166->raw() : nullptr, _166 ? _166->size(0) : 0);
  _checked_ptr_1<int> _ptr__167(_167 ? _167->raw() : nullptr, _167 ? _167->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_166,_167,(long long)((int)0),(long long)((int)((_166)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _168,    std::shared_ptr< monty::ndarray< long long,1 > > _169,    std::shared_ptr< monty::ndarray< long long,1 > > _170) { mosek::fusion::p_Sort::argsort(_168,_169,_170); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _168,std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< long long,1 > > _170){
  _checked_ptr_1<long long> _ptr__168(_168 ? _168->raw() : nullptr, _168 ? _168->size(0) : 0);
  _checked_ptr_1<long long> _ptr__169(_169 ? _169->raw() : nullptr, _169 ? _169->size(0) : 0);
  _checked_ptr_1<long long> _ptr__170(_170 ? _170->raw() : nullptr, _170 ? _170->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_168,_169,_170,(long long)((int)0),(long long)((int)((_168)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _171,    std::shared_ptr< monty::ndarray< int,1 > > _172,    std::shared_ptr< monty::ndarray< int,1 > > _173) { mosek::fusion::p_Sort::argsort(_171,_172,_173); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< int,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173){
  _checked_ptr_1<long long> _ptr__171(_171 ? _171->raw() : nullptr, _171 ? _171->size(0) : 0);
  _checked_ptr_1<int> _ptr__172(_172 ? _172->raw() : nullptr, _172 ? _172->size(0) : 0);
  _checked_ptr_1<int> _ptr__173(_173 ? _173->raw() : nullptr, _173 ? _173->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_171,_172,_173,(long long)((int)0),(long long)((int)((_171)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _174,    std::shared_ptr< monty::ndarray< long long,1 > > _175,    long long _176,    long long _177) { mosek::fusion::p_Sort::argsort(_174,_175,_176,_177); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,long long _176,long long _177){
  _checked_ptr_1<long long> _ptr__174(_174 ? _174->raw() : nullptr, _174 ? _174->size(0) : 0);
  _checked_ptr_1<long long> _ptr__175(_175 ? _175->raw() : nullptr, _175 ? _175->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_174,_175,_176,_177,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _178,    std::shared_ptr< monty::ndarray< int,1 > > _179,    long long _180,    long long _181) { mosek::fusion::p_Sort::argsort(_178,_179,_180,_181); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179,long long _180,long long _181){
  _checked_ptr_1<long long> _ptr__178(_178 ? _178->raw() : nullptr, _178 ? _178->size(0) : 0);
  _checked_ptr_1<int> _ptr__179(_179 ? _179->raw() : nullptr, _179 ? _179->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_178,_179,_180,_181,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _182,    std::shared_ptr< monty::ndarray< long long,1 > > _183,    std::shared_ptr< monty::ndarray< long long,1 > > _184,    long long _185,    long long _186) { mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _182,std::shared_ptr< monty::ndarray< long long,1 > > _183,std::shared_ptr< monty::ndarray< long long,1 > > _184,long long _185,long long _186){
  _checked_ptr_1<long long> _ptr__182(_182 ? _182->raw() : nullptr, _182 ? _182->size(0) : 0);
  _checked_ptr_1<long long> _ptr__183(_183 ? _183->raw() : nullptr, _183 ? _183->size(0) : 0);
  _checked_ptr_1<long long> _ptr__184(_184 ? _184->raw() : nullptr, _184 ? _184->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _187,    std::shared_ptr< monty::ndarray< int,1 > > _188,    std::shared_ptr< monty::ndarray< int,1 > > _189,    long long _190,    long long _191) { mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _187,std::shared_ptr< monty::ndarray< int,1 > > _188,std::shared_ptr< monty::ndarray< int,1 > > _189,long long _190,long long _191){
  _checked_ptr_1<long long> _ptr__187(_187 ? _187->raw() : nullptr, _187 ? _187->size(0) : 0);
  _checked_ptr_1<int> _ptr__188(_188 ? _188->raw() : nullptr, _188 ? _188->size(0) : 0);
  _checked_ptr_1<int> _ptr__189(_189 ? _189->raw() : nullptr, _189 ? _189->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _192,    std::shared_ptr< monty::ndarray< long long,1 > > _193,    long long _194,    long long _195,    bool _196) { mosek::fusion::p_Sort::argsort(_192,_193,_194,_195,_196); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _192,std::shared_ptr< monty::ndarray< long long,1 > > _193,long long _194,long long _195,bool _196){
  _checked_ptr_1<long long> _ptr__192(_192 ? _192->raw() : nullptr, _192 ? _192->size(0) : 0);
  _checked_ptr_1<long long> _ptr__193(_193 ? _193->raw() : nullptr, _193 ? _193->size(0) : 0);
  if (((!_196) || ((_195 - _194) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_192,_193,_194,_195,_196)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _197 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__197(_197 ? _197->raw() : nullptr,_197 ? _197->size(0) : 0);
      int _198 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_192,_193,nullptr,_194,_195,_197);
      if (((_ptr__197[(int)1] - _ptr__197[(int)0]) < safe_mul( _198,(_195 - _194) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_192,_193,_194,_195,_ptr__197[(int)0],_ptr__197[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _199,    std::shared_ptr< monty::ndarray< int,1 > > _200,    long long _201,    long long _202,    bool _203) { mosek::fusion::p_Sort::argsort(_199,_200,_201,_202,_203); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _199,std::shared_ptr< monty::ndarray< int,1 > > _200,long long _201,long long _202,bool _203){
  _checked_ptr_1<long long> _ptr__199(_199 ? _199->raw() : nullptr, _199 ? _199->size(0) : 0);
  _checked_ptr_1<int> _ptr__200(_200 ? _200->raw() : nullptr, _200 ? _200->size(0) : 0);
  if (((!_203) || ((_202 - _201) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_199,_200,_201,_202,_203)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _204 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__204(_204 ? _204->raw() : nullptr,_204 ? _204->size(0) : 0);
      int _205 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_199,_200,nullptr,_201,_202,_204);
      if (((_ptr__204[(int)1] - _ptr__204[(int)0]) < safe_mul( _205,(_202 - _201) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_199,_200,_201,_202,_ptr__204[(int)0],_ptr__204[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _206,    std::shared_ptr< monty::ndarray< long long,1 > > _207,    std::shared_ptr< monty::ndarray< long long,1 > > _208,    long long _209,    long long _210,    bool _211) { mosek::fusion::p_Sort::argsort(_206,_207,_208,_209,_210,_211); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _206,std::shared_ptr< monty::ndarray< long long,1 > > _207,std::shared_ptr< monty::ndarray< long long,1 > > _208,long long _209,long long _210,bool _211){
  _checked_ptr_1<long long> _ptr__206(_206 ? _206->raw() : nullptr, _206 ? _206->size(0) : 0);
  _checked_ptr_1<long long> _ptr__207(_207 ? _207->raw() : nullptr, _207 ? _207->size(0) : 0);
  _checked_ptr_1<long long> _ptr__208(_208 ? _208->raw() : nullptr, _208 ? _208->size(0) : 0);
  if (((!_211) || ((_210 - _209) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_206,_207,_208,_209,_210,_211)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _212 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__212(_212 ? _212->raw() : nullptr,_212 ? _212->size(0) : 0);
      int _213 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_206,_207,_208,_209,_210,_212);
      if ((((_ptr__212[(int)1] - _ptr__212[(int)0]) < safe_mul( _213,(_210 - _209) )) && ((_ptr__212[(int)3] - _ptr__212[(int)2]) < safe_mul( _213,(_210 - _209) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_206,_208,_209,_210,_ptr__212[(int)2],_ptr__212[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_206,_207,_209,_210,_ptr__212[(int)0],_ptr__212[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _214,    std::shared_ptr< monty::ndarray< int,1 > > _215,    std::shared_ptr< monty::ndarray< int,1 > > _216,    long long _217,    long long _218,    bool _219) { mosek::fusion::p_Sort::argsort(_214,_215,_216,_217,_218,_219); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _214,std::shared_ptr< monty::ndarray< int,1 > > _215,std::shared_ptr< monty::ndarray< int,1 > > _216,long long _217,long long _218,bool _219){
  _checked_ptr_1<long long> _ptr__214(_214 ? _214->raw() : nullptr, _214 ? _214->size(0) : 0);
  _checked_ptr_1<int> _ptr__215(_215 ? _215->raw() : nullptr, _215 ? _215->size(0) : 0);
  _checked_ptr_1<int> _ptr__216(_216 ? _216->raw() : nullptr, _216 ? _216->size(0) : 0);
  if (((!_219) || ((_218 - _217) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_214,_215,_216,_217,_218,_219)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _220 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__220(_220 ? _220->raw() : nullptr,_220 ? _220->size(0) : 0);
      int _221 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_214,_215,_216,_217,_218,_220);
      if ((((_ptr__220[(int)1] - _ptr__220[(int)0]) < safe_mul( _221,(_218 - _217) )) && ((_ptr__220[(int)3] - _ptr__220[(int)2]) < safe_mul( _221,(_218 - _217) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_214,_216,_217,_218,_ptr__220[(int)2],_ptr__220[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_214,_215,_217,_218,_ptr__220[(int)0],_ptr__220[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _222,    std::shared_ptr< monty::ndarray< long long,1 > > _223,    long long _224,    long long _225,    long long _226,    long long _227) { mosek::fusion::p_Sort::argbucketsort(_222,_223,_224,_225,_226,_227); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _222,std::shared_ptr< monty::ndarray< long long,1 > > _223,long long _224,long long _225,long long _226,long long _227){
  _checked_ptr_1<long long> _ptr__222(_222 ? _222->raw() : nullptr, _222 ? _222->size(0) : 0);
  _checked_ptr_1<long long> _ptr__223(_223 ? _223->raw() : nullptr, _223 ? _223->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_222,_224,_225,_223,_226,_227);
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _228,    std::shared_ptr< monty::ndarray< int,1 > > _229,    long long _230,    long long _231,    int _232,    int _233) { mosek::fusion::p_Sort::argbucketsort(_228,_229,_230,_231,_232,_233); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< int,1 > > _229,long long _230,long long _231,int _232,int _233){
  _checked_ptr_1<long long> _ptr__228(_228 ? _228->raw() : nullptr, _228 ? _228->size(0) : 0);
  _checked_ptr_1<int> _ptr__229(_229 ? _229->raw() : nullptr, _229 ? _229->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_228,_230,_231,_229,_232,_233);
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _234,    std::shared_ptr< monty::ndarray< long long,1 > > _235,    std::shared_ptr< monty::ndarray< long long,1 > > _236,    long long _237,    long long _238,    std::shared_ptr< monty::ndarray< long long,1 > > _239) { mosek::fusion::p_Sort::getminmax(_234,_235,_236,_237,_238,_239); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< long long,1 > > _235,std::shared_ptr< monty::ndarray< long long,1 > > _236,long long _237,long long _238,std::shared_ptr< monty::ndarray< long long,1 > > _239){
  _checked_ptr_1<long long> _ptr__234(_234 ? _234->raw() : nullptr, _234 ? _234->size(0) : 0);
  _checked_ptr_1<long long> _ptr__235(_235 ? _235->raw() : nullptr, _235 ? _235->size(0) : 0);
  _checked_ptr_1<long long> _ptr__236(_236 ? _236->raw() : nullptr, _236 ? _236->size(0) : 0);
  _checked_ptr_1<long long> _ptr__239(_239 ? _239->raw() : nullptr, _239 ? _239->size(0) : 0);
  _ptr__239[(int)0] = _ptr__235[_ptr__234[_237]];
  _ptr__239[(int)1] = _ptr__235[_ptr__234[_237]];
  long long _6622 = safe_add( _237,(int)1 );
  long long _6623 = _238;
  for (long long _240 = _6622; _240 < _6623; ++_240)
  {
    {
      if ((_ptr__239[(int)0] > _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)0] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
      if ((_ptr__239[(int)1] < _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)1] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
    }
  }
  if ((NULL != _236.get()))
  {
    {
      _ptr__239[(int)2] = _ptr__236[_ptr__234[_237]];
      _ptr__239[(int)3] = _ptr__236[_ptr__234[_237]];
      long long _6624 = safe_add( _237,(int)1 );
      long long _6625 = _238;
      for (long long _241 = _6624; _241 < _6625; ++_241)
      {
        {
          if ((_ptr__239[(int)2] > _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)2] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
          if ((_ptr__239[(int)3] < _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)3] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _242,    std::shared_ptr< monty::ndarray< int,1 > > _243,    std::shared_ptr< monty::ndarray< int,1 > > _244,    long long _245,    long long _246,    std::shared_ptr< monty::ndarray< int,1 > > _247) { mosek::fusion::p_Sort::getminmax(_242,_243,_244,_245,_246,_247); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _242,std::shared_ptr< monty::ndarray< int,1 > > _243,std::shared_ptr< monty::ndarray< int,1 > > _244,long long _245,long long _246,std::shared_ptr< monty::ndarray< int,1 > > _247){
  _checked_ptr_1<long long> _ptr__242(_242 ? _242->raw() : nullptr, _242 ? _242->size(0) : 0);
  _checked_ptr_1<int> _ptr__243(_243 ? _243->raw() : nullptr, _243 ? _243->size(0) : 0);
  _checked_ptr_1<int> _ptr__244(_244 ? _244->raw() : nullptr, _244 ? _244->size(0) : 0);
  _checked_ptr_1<int> _ptr__247(_247 ? _247->raw() : nullptr, _247 ? _247->size(0) : 0);
  _ptr__247[(int)0] = _ptr__243[_ptr__242[_245]];
  _ptr__247[(int)1] = _ptr__243[_ptr__242[_245]];
  long long _6626 = safe_add( _245,(int)1 );
  long long _6627 = _246;
  for (long long _248 = _6626; _248 < _6627; ++_248)
  {
    {
      if ((_ptr__247[(int)0] > _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)0] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
      if ((_ptr__247[(int)1] < _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)1] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
    }
  }
  if ((NULL != _244.get()))
  {
    {
      _ptr__247[(int)2] = _ptr__244[_ptr__242[_245]];
      _ptr__247[(int)3] = _ptr__244[_ptr__242[_245]];
      long long _6628 = safe_add( _245,(int)1 );
      long long _6629 = _246;
      for (long long _249 = _6628; _249 < _6629; ++_249)
      {
        {
          if ((_ptr__247[(int)2] > _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)2] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
          if ((_ptr__247[(int)3] < _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)3] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _250,    std::shared_ptr< monty::ndarray< long long,1 > > _251,    long long _252,    long long _253,    bool _254) { return mosek::fusion::p_Sort::issorted(_250,_251,_252,_253,_254); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _250,std::shared_ptr< monty::ndarray< long long,1 > > _251,long long _252,long long _253,bool _254){
  _checked_ptr_1<long long> _ptr__250(_250 ? _250->raw() : nullptr, _250 ? _250->size(0) : 0);
  _checked_ptr_1<long long> _ptr__251(_251 ? _251->raw() : nullptr, _251 ? _251->size(0) : 0);
  long long _6630 = _252;
  long long _6631 = (_253 - (int)1);
  for (long long _255 = _6630; _255 < _6631; ++_255)
  {
    {
      if ((_ptr__251[_ptr__250[_255]] > _ptr__251[_ptr__250[safe_add( _255,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _256,    std::shared_ptr< monty::ndarray< int,1 > > _257,    long long _258,    long long _259,    bool _260) { return mosek::fusion::p_Sort::issorted(_256,_257,_258,_259,_260); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< int,1 > > _257,long long _258,long long _259,bool _260){
  _checked_ptr_1<long long> _ptr__256(_256 ? _256->raw() : nullptr, _256 ? _256->size(0) : 0);
  _checked_ptr_1<int> _ptr__257(_257 ? _257->raw() : nullptr, _257 ? _257->size(0) : 0);
  long long _6632 = _258;
  long long _6633 = (_259 - (int)1);
  for (long long _261 = _6632; _261 < _6633; ++_261)
  {
    {
      if ((_ptr__257[_ptr__256[_261]] > _ptr__257[_ptr__256[safe_add( _261,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _262,    std::shared_ptr< monty::ndarray< long long,1 > > _263,    std::shared_ptr< monty::ndarray< long long,1 > > _264,    long long _265,    long long _266,    bool _267) { return mosek::fusion::p_Sort::issorted(_262,_263,_264,_265,_266,_267); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< long long,1 > > _263,std::shared_ptr< monty::ndarray< long long,1 > > _264,long long _265,long long _266,bool _267){
  _checked_ptr_1<long long> _ptr__262(_262 ? _262->raw() : nullptr, _262 ? _262->size(0) : 0);
  _checked_ptr_1<long long> _ptr__263(_263 ? _263->raw() : nullptr, _263 ? _263->size(0) : 0);
  _checked_ptr_1<long long> _ptr__264(_264 ? _264->raw() : nullptr, _264 ? _264->size(0) : 0);
  long long _6634 = _265;
  long long _6635 = (_266 - (int)1);
  for (long long _268 = _6634; _268 < _6635; ++_268)
  {
    {
      if (((_ptr__263[_ptr__262[_268]] > _ptr__263[_ptr__262[safe_add( _268,(int)1 )]]) || ((_ptr__263[_ptr__262[safe_add( _268,(int)1 )]] == _ptr__263[_ptr__262[_268]]) && (_ptr__264[_ptr__262[_268]] > _ptr__264[_ptr__262[safe_add( _268,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _269,    std::shared_ptr< monty::ndarray< int,1 > > _270,    std::shared_ptr< monty::ndarray< int,1 > > _271,    long long _272,    long long _273,    bool _274) { return mosek::fusion::p_Sort::issorted(_269,_270,_271,_272,_273,_274); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< int,1 > > _270,std::shared_ptr< monty::ndarray< int,1 > > _271,long long _272,long long _273,bool _274){
  _checked_ptr_1<long long> _ptr__269(_269 ? _269->raw() : nullptr, _269 ? _269->size(0) : 0);
  _checked_ptr_1<int> _ptr__270(_270 ? _270->raw() : nullptr, _270 ? _270->size(0) : 0);
  _checked_ptr_1<int> _ptr__271(_271 ? _271->raw() : nullptr, _271 ? _271->size(0) : 0);
  long long _6636 = _272;
  long long _6637 = (_273 - (int)1);
  for (long long _275 = _6636; _275 < _6637; ++_275)
  {
    {
      if (((_ptr__270[_ptr__269[_275]] > _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) || ((_ptr__270[_ptr__269[_275]] == _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) && (_ptr__271[_ptr__269[_275]] > _ptr__271[_ptr__269[safe_add( _275,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_Sort::destroy(){}void mosek::fusion::Sort::destroy() { mosek::fusion::p_Sort::_get_impl(this)->destroy(); }mosek::fusion::IndexCounter::IndexCounter(mosek::fusion::p_IndexCounter *_impl) : _impl(_impl) { /*std::cout << "IndexCounter() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::IndexCounter::~IndexCounter() { delete _impl; _impl = nullptr; }mosek::fusion::p_IndexCounter::p_IndexCounter  (::mosek::fusion::IndexCounter * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276){ return new mosek::fusion::IndexCounter(_276); }mosek::fusion::IndexCounter::IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_276); }void mosek::fusion::p_IndexCounter::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _276){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__276(_276 ? _276->raw() : nullptr, _276 ? _276->size(0) : 0);
    n = (int)((_276)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    start = (long long)0;
    strides = ::mosek::fusion::p_Set::strides(_276);
    std::vector<int> _6638;
    for (int _277 = (int)0, _6639 = (int)((_276)->size(0)); _277 < _6639 ; ++_277)
    {
      _6638.push_back(_ptr__276[_277]);
    }
    auto _6640 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6638.size()),_6638.begin(),_6638.end()));
    dims = _6640;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){ return new mosek::fusion::IndexCounter(_278,_279,_280); }mosek::fusion::IndexCounter::IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_278,_279,_280); }void mosek::fusion::p_IndexCounter::_initialize  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__279(_279 ? _279->raw() : nullptr, _279 ? _279->size(0) : 0);
    _checked_ptr_1<int> _ptr__280(_280 ? _280->raw() : nullptr, _280 ? _280->size(0) : 0);
    int _281 = (int)((_280)->size(0));
    n = (int)((_279)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6641 = (int)0;
    int _6642 = n;
    for (int _282 = _6641; _282 < _6642; ++_282)
    {
      {
        ((*st)(_282)) = _278;
      }
    }
    strides = ::mosek::fusion::p_Set::strides(_280);
    dims = _279;
    start = _278;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){ return new mosek::fusion::IndexCounter(_283,_284,_285); }mosek::fusion::IndexCounter::IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_283,_284,_285); }void mosek::fusion::p_IndexCounter::_initialize  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__284(_284 ? _284->raw() : nullptr, _284 ? _284->size(0) : 0);
    _checked_ptr_1<long long> _ptr__285(_285 ? _285->raw() : nullptr, _285 ? _285->size(0) : 0);
    n = (int)((_284)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6643 = (int)0;
    int _6644 = n;
    for (int _286 = _6643; _286 < _6644; ++_286)
    {
      {
        ((*st)(_286)) = _283;
      }
    }
    strides = _285;
    dims = _284;
    start = _283;
  }
}bool mosek::fusion::IndexCounter :: atEnd() { return mosek::fusion::p_IndexCounter::_get_impl(this)->atEnd(); }bool mosek::fusion::p_IndexCounter::atEnd(){
  return (((*ii)((n - (int)1))) >= ((*dims)((n - (int)1))));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::IndexCounter :: getIndex() { return mosek::fusion::p_IndexCounter::_get_impl(this)->getIndex(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_IndexCounter::getIndex(){
  return ii;
}
long long mosek::fusion::IndexCounter :: next() { return mosek::fusion::p_IndexCounter::_get_impl(this)->next(); }long long mosek::fusion::p_IndexCounter::next(){
  long long _287 = _pubthis->get();
  _pubthis->inc();
  return _287;
}
long long mosek::fusion::IndexCounter :: get() { return mosek::fusion::p_IndexCounter::_get_impl(this)->get(); }long long mosek::fusion::p_IndexCounter::get(){
  return ((*st)((int)0));
}
void mosek::fusion::IndexCounter :: inc() { mosek::fusion::p_IndexCounter::_get_impl(this)->inc(); }void mosek::fusion::p_IndexCounter::inc(){
  ++ ((*ii)((int)0));
  ((*st)((int)0)) = safe_add( ((*st)((int)0)),((*strides)((n - (int)1))) );
  int _288;
  {
    _288 = (int)0;
    for(;((_288 < (n - (int)1)) && (((*ii)(_288)) == ((*dims)(((n - _288) - (int)1)))));++ _288)
    {
      {
        ((*ii)(_288)) = (int)0;
        ++ ((*ii)(safe_add( _288,(int)1 )));
        ((*st)(safe_add( _288,(int)1 ))) = safe_add( ((*st)(safe_add( _288,(int)1 ))),((*strides)(((n - _288) - (int)2))) );
      }
    }
  }
  int _6645 = (int)0;
  int _6646 = _288;
  for (int _289 = _6645; _289 < _6646; ++_289)
  {
    {
      ((*st)(_289)) = ((*st)(_288));
    }
  }
}
void mosek::fusion::IndexCounter :: reset() { mosek::fusion::p_IndexCounter::_get_impl(this)->reset(); }void mosek::fusion::p_IndexCounter::reset(){
  st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
  int _6647 = (int)0;
  int _6648 = n;
  for (int _290 = _6647; _290 < _6648; ++_290)
  {
    {
      ((*st)(_290)) = start;
    }
  }
}
void mosek::fusion::p_IndexCounter::destroy(){dims.reset();strides.reset();st.reset();ii.reset();}void mosek::fusion::IndexCounter::destroy() { mosek::fusion::p_IndexCounter::_get_impl(this)->destroy(); }mosek::fusion::CommonTools::CommonTools(mosek::fusion::p_CommonTools *_impl) : _impl(_impl) { /*std::cout << "CommonTools() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::CommonTools::~CommonTools() { delete _impl; _impl = nullptr; }mosek::fusion::p_CommonTools::p_CommonTools  (::mosek::fusion::CommonTools * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< long long,1 > > _291,    int _292) { return mosek::fusion::p_CommonTools::resize(_291,_292); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< long long,1 > > _291,int _292){
  _checked_ptr_1<long long> _ptr__291(_291 ? _291->raw() : nullptr, _291 ? _291->size(0) : 0);
  if ((_292 == (int)((_291)->size(0))))
  {
    {
      return _291;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _293 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_292)));
      _checked_ptr_1<long long> _ptr__293(_293 ? _293->raw() : nullptr,_293 ? _293->size(0) : 0);
      if ((_292 > (int)((_291)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,(int)((_291)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,_292);
        }
      }
      return _293;
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< int,1 > > _294,    int _295) { return mosek::fusion::p_CommonTools::resize(_294,_295); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< int,1 > > _294,int _295){
  _checked_ptr_1<int> _ptr__294(_294 ? _294->raw() : nullptr, _294 ? _294->size(0) : 0);
  if ((_295 == (int)((_294)->size(0))))
  {
    {
      return _294;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _296 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_295)));
      _checked_ptr_1<int> _ptr__296(_296 ? _296->raw() : nullptr,_296 ? _296->size(0) : 0);
      if ((_295 > (int)((_294)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,(int)((_294)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,_295);
        }
      }
      return _296;
    }
  }
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< double,1 > > _297,    int _298) { return mosek::fusion::p_CommonTools::resize(_297,_298); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< double,1 > > _297,int _298){
  _checked_ptr_1<double> _ptr__297(_297 ? _297->raw() : nullptr, _297 ? _297->size(0) : 0);
  if ((_298 == (int)((_297)->size(0))))
  {
    {
      return _297;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _299 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_298)));
      _checked_ptr_1<double> _ptr__299(_299 ? _299->raw() : nullptr,_299 ? _299->size(0) : 0);
      if ((_298 > (int)((_297)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,(int)((_297)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,_298);
        }
      }
      return _299;
    }
  }
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< int,1 > > _300,    int _301) { return mosek::fusion::p_CommonTools::binarySearch(_300,_301); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301){
  _checked_ptr_1<int> _ptr__300(_300 ? _300->raw() : nullptr, _300 ? _300->size(0) : 0);
  int _302 = (int)0;
  int _303 = (int)((_300)->size(0));
  if ((_ptr__300[_302] == _301))
  {
    {
      return _302;
    }
  }
  else if((_ptr__300[(_303 - (int)1)] == _301))
  {
    {
      return (_303 - (int)1);
    }
  }
  {}
  while ( (_302 < (_303 - (int)1)) )
  {
    {
      int _304 = ((_303 - _302) / (int)2);
      if ((_301 < _ptr__300[_304]))
      {
        {
          _302 = safe_add( _304,(int)1 );
        }
      }
      else if((_301 > _ptr__300[_304]))
      {
        {
          _303 = _304;
        }
      }
      else
      {
        {
          return _304;
        }
      }
    }
  }
  return (-(int)1);
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< long long,1 > > _305,    long long _306) { return mosek::fusion::p_CommonTools::binarySearch(_305,_306); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _305,long long _306){
  _checked_ptr_1<long long> _ptr__305(_305 ? _305->raw() : nullptr, _305 ? _305->size(0) : 0);
  int _307 = ::mosek::fusion::p_CommonTools::binarySearchL(_305,_306);
  if (((_307 < (int)((_305)->size(0))) && (_ptr__305[_307] == _306)))
  {
    {
      return _307;
    }
  }
  else
  {
    {
      return (-(int)1);
    }
  }
}
int mosek::fusion::CommonTools::binarySearchR  ( std::shared_ptr< monty::ndarray< long long,1 > > _308,    long long _309) { return mosek::fusion::p_CommonTools::binarySearchR(_308,_309); }int mosek::fusion::p_CommonTools::binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309){
  _checked_ptr_1<long long> _ptr__308(_308 ? _308->raw() : nullptr, _308 ? _308->size(0) : 0);
  int _310 = (int)0;
  int _311 = (int)((_308)->size(0));
  if ((_ptr__308[_310] > _309))
  {
    {
      return _310;
    }
  }
  {}
  while ( (_310 < (_311 - (int)1)) )
  {
    {
      int _312 = (safe_add( _311,_310 ) / (int)2);
      if ((_309 >= _ptr__308[_312]))
      {
        {
          _310 = _312;
        }
      }
      else
      {
        {
          _311 = _312;
        }
      }
    }
  }
  return _311;
}
int mosek::fusion::CommonTools::binarySearchL  ( std::shared_ptr< monty::ndarray< long long,1 > > _313,    long long _314) { return mosek::fusion::p_CommonTools::binarySearchL(_313,_314); }int mosek::fusion::p_CommonTools::binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _313,long long _314){
  _checked_ptr_1<long long> _ptr__313(_313 ? _313->raw() : nullptr, _313 ? _313->size(0) : 0);
  int _315 = (int)0;
  int _316 = (int)((_313)->size(0));
  if ((_314 <= _ptr__313[_315]))
  {
    {
      return _315;
    }
  }
  {}
  while ( (_315 < (_316 - (int)1)) )
  {
    {
      int _317 = (safe_add( _316,_315 ) / (int)2);
      if ((_ptr__313[_317] < _314))
      {
        {
          _315 = _317;
        }
      }
      else
      {
        {
          _316 = _317;
        }
      }
    }
  }
  return _316;
}
void mosek::fusion::CommonTools::ndIncr  ( std::shared_ptr< monty::ndarray< int,1 > > _318,    std::shared_ptr< monty::ndarray< int,1 > > _319,    std::shared_ptr< monty::ndarray< int,1 > > _320) { mosek::fusion::p_CommonTools::ndIncr(_318,_319,_320); }void mosek::fusion::p_CommonTools::ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _318,std::shared_ptr< monty::ndarray< int,1 > > _319,std::shared_ptr< monty::ndarray< int,1 > > _320){
  _checked_ptr_1<int> _ptr__318(_318 ? _318->raw() : nullptr, _318 ? _318->size(0) : 0);
  _checked_ptr_1<int> _ptr__319(_319 ? _319->raw() : nullptr, _319 ? _319->size(0) : 0);
  _checked_ptr_1<int> _ptr__320(_320 ? _320->raw() : nullptr, _320 ? _320->size(0) : 0);
  int _321 = ((int)((_318)->size(0)) - (int)1);
  ++ _ptr__318[_321];
  while ( ((_321 > (int)0) && (_ptr__318[_321] >= _ptr__320[_321])) )
  {
    {
      _ptr__318[_321] = _ptr__319[_321];
      ++ _ptr__318[(_321 - (int)1)];
    }
  }
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _322,    std::shared_ptr< monty::ndarray< int,1 > > _323,    std::shared_ptr< monty::ndarray< double,1 > > _324,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,    long long _328,    int _329,    int _330) { mosek::fusion::p_CommonTools::transposeTriplets(_322,_323,_324,_325,_326,_327,_328,_329,_330); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323,std::shared_ptr< monty::ndarray< double,1 > > _324,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,long long _328,int _329,int _330){
  _checked_ptr_1<int> _ptr__322(_322 ? _322->raw() : nullptr, _322 ? _322->size(0) : 0);
  _checked_ptr_1<int> _ptr__323(_323 ? _323->raw() : nullptr, _323 ? _323->size(0) : 0);
  _checked_ptr_1<double> _ptr__324(_324 ? _324->raw() : nullptr, _324 ? _324->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _331 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _329,(int)2 ))));
  _checked_ptr_1<long long> _ptr__331(_331 ? _331->raw() : nullptr,_331 ? _331->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _332 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _330,(int)2 ))));
  _checked_ptr_1<long long> _ptr__332(_332 ? _332->raw() : nullptr,_332 ? _332->size(0) : 0);
  {
    long long _333 = (long long)0;
    for(;(_333 < _328);++ _333)
    {
      {
        _ptr__332[safe_add( _ptr__323[_333],(int)2 )] = safe_add( _ptr__332[safe_add( _ptr__323[_333],(int)2 )],(int)1 );
        _ptr__331[safe_add( _ptr__322[_333],(int)2 )] = safe_add( _ptr__331[safe_add( _ptr__322[_333],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _334 = (int)1;
    for(;(_334 < _329);++ _334)
    {
      {
        _ptr__331[safe_add( _334,(int)1 )] = safe_add( _ptr__331[safe_add( _334,(int)1 )],_ptr__331[_334] );
      }
    }
  }
  {
    int _335 = (int)1;
    for(;(_335 < _330);++ _335)
    {
      {
        _ptr__332[safe_add( _335,(int)1 )] = safe_add( _ptr__332[safe_add( _335,(int)1 )],_ptr__332[_335] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _336 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__336(_336 ? _336->raw() : nullptr,_336 ? _336->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _337 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__337(_337 ? _337->raw() : nullptr,_337 ? _337->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _338 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_328)));
  _checked_ptr_1<double> _ptr__338(_338 ? _338->raw() : nullptr,_338 ? _338->size(0) : 0);
  int _6649 = (int)0;
  int _6650 = _329;
  for (int _339 = _6649; _339 < _6650; ++_339)
  {
    {
      {
        long long _340 = _ptr__331[_339];
        for(;(_340 < _ptr__331[safe_add( _339,(int)1 )]);++ _340)
        {
          {
            int _341 = _ptr__323[_340];
            long long _342 = _ptr__332[_341];
            _ptr__336[_342] = _339;
            _ptr__337[_342] = _341;
            _ptr__338[_342] = _ptr__324[_340];
            _ptr__332[_341] = safe_add( _342,(int)1 );
          }
        }
      }
    }
  }
  ((*_325)((int)0)) = _337;
  ((*_326)((int)0)) = _336;
  ((*_327)((int)0)) = _338;
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _343,    std::shared_ptr< monty::ndarray< int,1 > > _344,    std::shared_ptr< monty::ndarray< double,1 > > _345,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,    long long _349,    int _350,    int _351) { mosek::fusion::p_CommonTools::transposeTriplets(_343,_344,_345,_346,_347,_348,_349,_350,_351); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _343,std::shared_ptr< monty::ndarray< int,1 > > _344,std::shared_ptr< monty::ndarray< double,1 > > _345,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,long long _349,int _350,int _351){
  _checked_ptr_1<int> _ptr__343(_343 ? _343->raw() : nullptr, _343 ? _343->size(0) : 0);
  _checked_ptr_1<int> _ptr__344(_344 ? _344->raw() : nullptr, _344 ? _344->size(0) : 0);
  _checked_ptr_1<double> _ptr__345(_345 ? _345->raw() : nullptr, _345 ? _345->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _352 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _350,(int)2 ))));
  _checked_ptr_1<long long> _ptr__352(_352 ? _352->raw() : nullptr,_352 ? _352->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _353 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _351,(int)2 ))));
  _checked_ptr_1<long long> _ptr__353(_353 ? _353->raw() : nullptr,_353 ? _353->size(0) : 0);
  {
    long long _354 = (long long)0;
    for(;(_354 < _349);++ _354)
    {
      {
        _ptr__353[safe_add( _ptr__344[_354],(int)2 )] = safe_add( _ptr__353[safe_add( _ptr__344[_354],(int)2 )],(int)1 );
        _ptr__352[safe_add( _ptr__343[_354],(int)2 )] = safe_add( _ptr__352[safe_add( _ptr__343[_354],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _355 = (int)1;
    for(;(_355 < _350);++ _355)
    {
      {
        _ptr__352[safe_add( _355,(int)1 )] = safe_add( _ptr__352[safe_add( _355,(int)1 )],_ptr__352[_355] );
      }
    }
  }
  {
    int _356 = (int)1;
    for(;(_356 < _351);++ _356)
    {
      {
        _ptr__353[safe_add( _356,(int)1 )] = safe_add( _ptr__353[safe_add( _356,(int)1 )],_ptr__353[_356] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _357 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__357(_357 ? _357->raw() : nullptr,_357 ? _357->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _358 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__358(_358 ? _358->raw() : nullptr,_358 ? _358->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _359 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_349)));
  _checked_ptr_1<double> _ptr__359(_359 ? _359->raw() : nullptr,_359 ? _359->size(0) : 0);
  {
    int _360 = (int)0;
    for(;(_360 < _350);++ _360)
    {
      {
        long long _6651 = _ptr__352[_360];
        long long _6652 = _ptr__352[safe_add( _360,(int)1 )];
        for (long long _361 = _6651; _361 < _6652; ++_361)
        {
          {
            int _362 = _ptr__344[_361];
            long long _363 = _ptr__353[_362];
            _ptr__357[_363] = _360;
            _ptr__358[_363] = _362;
            _ptr__359[_363] = _ptr__345[_361];
            _ptr__353[_362] = safe_add( _363,(int)1 );
          }
        }
      }
    }
  }
  ((*_346)((int)0)) = _358;
  ((*_347)((int)0)) = _357;
  ((*_348)((int)0)) = _359;
}
void mosek::fusion::CommonTools::tripletSort  ( std::shared_ptr< monty::ndarray< int,1 > > _364,    std::shared_ptr< monty::ndarray< int,1 > > _365,    std::shared_ptr< monty::ndarray< double,1 > > _366,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,    long long _370,    int _371,    int _372) { mosek::fusion::p_CommonTools::tripletSort(_364,_365,_366,_367,_368,_369,_370,_371,_372); }void mosek::fusion::p_CommonTools::tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _364,std::shared_ptr< monty::ndarray< int,1 > > _365,std::shared_ptr< monty::ndarray< double,1 > > _366,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,long long _370,int _371,int _372){
  _checked_ptr_1<int> _ptr__364(_364 ? _364->raw() : nullptr, _364 ? _364->size(0) : 0);
  _checked_ptr_1<int> _ptr__365(_365 ? _365->raw() : nullptr, _365 ? _365->size(0) : 0);
  _checked_ptr_1<double> _ptr__366(_366 ? _366->raw() : nullptr, _366 ? _366->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _373 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__373(_373 ? _373->raw() : nullptr,_373 ? _373->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _374 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _372,(int)2 ))));
  _checked_ptr_1<long long> _ptr__374(_374 ? _374->raw() : nullptr,_374 ? _374->size(0) : 0);
  long long _6653 = (long long)0;
  long long _6654 = _370;
  for (long long _375 = _6653; _375 < _6654; ++_375)
  {
    {
      _ptr__374[safe_add( _ptr__365[_375],(int)2 )] = safe_add( _ptr__374[safe_add( _ptr__365[_375],(int)2 )],(int)1 );
    }
  }
  int _6655 = (int)1;
  int _6656 = _372;
  for (int _376 = _6655; _376 < _6656; ++_376)
  {
    {
      _ptr__374[safe_add( _376,(int)1 )] = safe_add( _ptr__374[safe_add( _376,(int)1 )],_ptr__374[_376] );
    }
  }
  int _6657 = (int)0;
  int _6658 = (int)_370;
  for (int _377 = _6657; _377 < _6658; ++_377)
  {
    {
      int _378 = _ptr__365[_377];
      _ptr__373[_ptr__374[safe_add( _378,(int)1 )]] = _377;
      _ptr__374[safe_add( _378,(int)1 )] = safe_add( _ptr__374[safe_add( _378,(int)1 )],(int)1 );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _379 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _371,(int)2 ))));
  _checked_ptr_1<long long> _ptr__379(_379 ? _379->raw() : nullptr,_379 ? _379->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _380 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__380(_380 ? _380->raw() : nullptr,_380 ? _380->size(0) : 0);
  {
    int _381 = (int)0;
    for(;(_381 < _370);++ _381)
    {
      {
        _ptr__379[safe_add( _ptr__364[_381],(int)2 )] = safe_add( _ptr__379[safe_add( _ptr__364[_381],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _382 = (int)1;
    for(;(_382 < _371);++ _382)
    {
      {
        _ptr__379[safe_add( _382,(int)1 )] = safe_add( _ptr__379[safe_add( _382,(int)1 )],_ptr__379[_382] );
      }
    }
  }
  {
    int _383 = (int)0;
    for(;(_383 < _372);++ _383)
    {
      {
        {
          long long _384 = _ptr__374[_383];
          for(;(_384 < _ptr__374[safe_add( _383,(int)1 )]);++ _384)
          {
            {
              int _385 = _ptr__364[_ptr__373[_384]];
              _ptr__380[_ptr__379[safe_add( _385,(int)1 )]] = _ptr__373[_384];
              _ptr__379[safe_add( _385,(int)1 )] = safe_add( _ptr__379[safe_add( _385,(int)1 )],(int)1 );
            }
          }
        }
      }
    }
  }
  int _386 = (int)1;
  {
    int _387 = _ptr__364[_ptr__380[(int)0]];
    int _388 = _ptr__365[_ptr__380[(int)0]];
    {
      int _389 = (int)1;
      for(;(_389 < _370);++ _389)
      {
        {
          int _390 = _ptr__380[_389];
          if (((_387 != _ptr__364[_390]) || (_388 != _ptr__365[_390])))
          {
            {
              _387 = _ptr__364[_390];
              _388 = _ptr__365[_390];
              ++ _386;
            }
          }
          {}
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _391 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__391(_391 ? _391->raw() : nullptr,_391 ? _391->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _392 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__392(_392 ? _392->raw() : nullptr,_392 ? _392->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _393 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_386)));
  _checked_ptr_1<double> _ptr__393(_393 ? _393->raw() : nullptr,_393 ? _393->size(0) : 0);
  {
    int _394 = _ptr__380[(int)0];
    _ptr__391[(int)0] = _ptr__364[_394];
    _ptr__392[(int)0] = _ptr__365[_394];
    _ptr__393[(int)0] = _ptr__366[_394];
  }
  int _395 = (int)1;
  int _6659 = (int)1;
  long long _6660 = _370;
  for (long long _396 = _6659; _396 < _6660; ++_396)
  {
    {
      int _397 = _ptr__380[_396];
      if (((_ptr__391[(_395 - (int)1)] == _ptr__364[_397]) && (_ptr__392[(_395 - (int)1)] == _ptr__365[_397])))
      {
        {
          _ptr__393[(_395 - (int)1)] = (_ptr__393[(_395 - (int)1)] + _ptr__366[_397]);
        }
      }
      else
      {
        {
          _ptr__391[_395] = _ptr__364[_397];
          _ptr__392[_395] = _ptr__365[_397];
          _ptr__393[_395] = _ptr__366[_397];
          ++ _395;
        }
      }
    }
  }
  ((*_367)((int)0)) = _391;
  ((*_368)((int)0)) = _392;
  ((*_369)((int)0)) = _393;
}
void mosek::fusion::CommonTools::argMSort  ( std::shared_ptr< monty::ndarray< int,1 > > _398,    std::shared_ptr< monty::ndarray< int,1 > > _399) { mosek::fusion::p_CommonTools::argMSort(_398,_399); }void mosek::fusion::p_CommonTools::argMSort(std::shared_ptr< monty::ndarray< int,1 > > _398,std::shared_ptr< monty::ndarray< int,1 > > _399){
  _checked_ptr_1<int> _ptr__398(_398 ? _398->raw() : nullptr, _398 ? _398->size(0) : 0);
  _checked_ptr_1<int> _ptr__399(_399 ? _399->raw() : nullptr, _399 ? _399->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _400 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_398)->size(0)))));
  _checked_ptr_1<int> _ptr__400(_400 ? _400->raw() : nullptr,_400 ? _400->size(0) : 0);
  bool _401 = false;
  {
    int _402 = (int)1;
    for(;(_402 < (int)((_398)->size(0)));_402 *= (int)2)
    {
      {
        _401 = (!_401);
        int _6661 = (int)0;
        int _6662 = (int)((_398)->size(0));
        int _6663 = safe_mul( _402,(int)2 );
        for (int _403 = _6661; _403 < _6662; _403 += _6663)
        {
          {
            if (_401)
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_398,_400,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
            else
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_400,_398,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
          }
        }
      }
    }
  }
  if (_401)
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_400,(int)0,_398,(int)0,(int)((_398)->size(0)));
    }
  }
  {}
}
void mosek::fusion::p_CommonTools::mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405,std::shared_ptr< monty::ndarray< int,1 > > _406,int _407,int _408,int _409){
  _checked_ptr_1<int> _ptr__404(_404 ? _404->raw() : nullptr, _404 ? _404->size(0) : 0);
  _checked_ptr_1<int> _ptr__405(_405 ? _405->raw() : nullptr, _405 ? _405->size(0) : 0);
  _checked_ptr_1<int> _ptr__406(_406 ? _406->raw() : nullptr, _406 ? _406->size(0) : 0);
  int _6664;
  bool _6665 = (_409 > (int)((_404)->size(0)));
  if (_6665)
  {
    _6664 = (int)((_404)->size(0));
  }
  else
  {
    _6664 = _409;
  }
  int _410 = _6664;
  int _6666;
  bool _6667 = (_408 > _410);
  if (_6667)
  {
    _6666 = _410;
  }
  else
  {
    _6666 = _408;
  }
  int _411 = _6666;
  if ((_411 == _410))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_404,_407,_405,_407,(_411 - _407));
    }
  }
  else
  {
    {
      int _412 = _407;
      int _413 = _411;
      int _414;
      {
        _414 = _407;
        for(;((_412 < _411) && (_413 < _410));++ _414)
        {
          {
            if ((_ptr__406[_ptr__404[_412]] < _ptr__406[_ptr__404[_413]]))
            {
              {
                _ptr__405[_414] = _ptr__404[_412];
                ++ _412;
              }
            }
            else
            {
              {
                _ptr__405[_414] = _ptr__404[_413];
                ++ _413;
              }
            }
          }
        }
      }
      while ( (_412 < _411) )
      {
        {
          _ptr__405[_414] = _ptr__404[_412];
          ++ _412;
          ++ _414;
        }
      }
      while ( (_413 < _410) )
      {
        {
          _ptr__405[_414] = _ptr__404[_413];
          ++ _413;
          ++ _414;
        }
      }
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _415,    std::shared_ptr< monty::ndarray< long long,1 > > _416,    std::shared_ptr< monty::ndarray< long long,1 > > _417,    long long _418,    long long _419) { mosek::fusion::p_CommonTools::argQsort(_415,_416,_417,_418,_419); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _415,std::shared_ptr< monty::ndarray< long long,1 > > _416,std::shared_ptr< monty::ndarray< long long,1 > > _417,long long _418,long long _419){
  _checked_ptr_1<long long> _ptr__415(_415 ? _415->raw() : nullptr, _415 ? _415->size(0) : 0);
  _checked_ptr_1<long long> _ptr__416(_416 ? _416->raw() : nullptr, _416 ? _416->size(0) : 0);
  _checked_ptr_1<long long> _ptr__417(_417 ? _417->raw() : nullptr, _417 ? _417->size(0) : 0);
  if ((NULL == _417.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_418,_419);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_417,_418,_419);
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _420,    std::shared_ptr< monty::ndarray< int,1 > > _421,    std::shared_ptr< monty::ndarray< int,1 > > _422,    long long _423,    long long _424) { mosek::fusion::p_CommonTools::argQsort(_420,_421,_422,_423,_424); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _420,std::shared_ptr< monty::ndarray< int,1 > > _421,std::shared_ptr< monty::ndarray< int,1 > > _422,long long _423,long long _424){
  _checked_ptr_1<long long> _ptr__420(_420 ? _420->raw() : nullptr, _420 ? _420->size(0) : 0);
  _checked_ptr_1<int> _ptr__421(_421 ? _421->raw() : nullptr, _421 ? _421->size(0) : 0);
  _checked_ptr_1<int> _ptr__422(_422 ? _422->raw() : nullptr, _422 ? _422->size(0) : 0);
  if ((NULL == _422.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_423,_424);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_422,_423,_424);
    }
  }
}
void mosek::fusion::p_CommonTools::destroy(){}void mosek::fusion::CommonTools::destroy() { mosek::fusion::p_CommonTools::_get_impl(this)->destroy(); }mosek::fusion::SolutionStruct::SolutionStruct(mosek::fusion::p_SolutionStruct *_impl) : _impl(_impl) { /*std::cout << "SolutionStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SolutionStruct::~SolutionStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_SolutionStruct::p_SolutionStruct  (::mosek::fusion::SolutionStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_yx() { return _impl->yx; }
void mosek::fusion::SolutionStruct::set_yx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->yx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_snx() { return _impl->snx; }
void mosek::fusion::SolutionStruct::set_snx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->snx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_sux() { return _impl->sux; }
void mosek::fusion::SolutionStruct::set_sux(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->sux = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slx() { return _impl->slx; }
void mosek::fusion::SolutionStruct::set_slx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_bars() { return _impl->bars; }
void mosek::fusion::SolutionStruct::set_bars(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bars = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_barx() { return _impl->barx; }
void mosek::fusion::SolutionStruct::set_barx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->barx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_y() { return _impl->y; }
void mosek::fusion::SolutionStruct::set_y(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->y = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_suc() { return _impl->suc; }
void mosek::fusion::SolutionStruct::set_suc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->suc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slc() { return _impl->slc; }
void mosek::fusion::SolutionStruct::set_slc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xx() { return _impl->xx; }
void mosek::fusion::SolutionStruct::set_xx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xc() { return _impl->xc; }
void mosek::fusion::SolutionStruct::set_xc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xc = _val; }
double mosek::fusion::SolutionStruct::get_dobj() { return _impl->dobj; }
void mosek::fusion::SolutionStruct::set_dobj(double _val) { _impl->dobj = _val; }
double mosek::fusion::SolutionStruct::get_pobj() { return _impl->pobj; }
void mosek::fusion::SolutionStruct::set_pobj(double _val) { _impl->pobj = _val; }
mosek::fusion::ProblemStatus mosek::fusion::SolutionStruct::get_probstatus() { return _impl->probstatus; }
void mosek::fusion::SolutionStruct::set_probstatus(mosek::fusion::ProblemStatus _val) { _impl->probstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_dstatus() { return _impl->dstatus; }
void mosek::fusion::SolutionStruct::set_dstatus(mosek::fusion::SolutionStatus _val) { _impl->dstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_pstatus() { return _impl->pstatus; }
void mosek::fusion::SolutionStruct::set_pstatus(mosek::fusion::SolutionStatus _val) { _impl->pstatus = _val; }
int mosek::fusion::SolutionStruct::get_sol_numbarvar() { return _impl->sol_numbarvar; }
void mosek::fusion::SolutionStruct::set_sol_numbarvar(int _val) { _impl->sol_numbarvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcone() { return _impl->sol_numcone; }
void mosek::fusion::SolutionStruct::set_sol_numcone(int _val) { _impl->sol_numcone = _val; }
int mosek::fusion::SolutionStruct::get_sol_numvar() { return _impl->sol_numvar; }
void mosek::fusion::SolutionStruct::set_sol_numvar(int _val) { _impl->sol_numvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcon() { return _impl->sol_numcon; }
void mosek::fusion::SolutionStruct::set_sol_numcon(int _val) { _impl->sol_numcon = _val; }
mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (int _425,    int _426,    int _427,    int _428){ return new mosek::fusion::SolutionStruct(_425,_426,_427,_428); }mosek::fusion::SolutionStruct::SolutionStruct  (int _425,    int _426,    int _427,    int _428) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_425,_426,_427,_428); }void mosek::fusion::p_SolutionStruct::_initialize  (int _425,    int _426,    int _427,    int _428){monty::rc_reserve __reserve_this(_pubthis);   {
    pobj = 0.0;
    dobj = 0.0;
    pstatus = ::mosek::fusion::SolutionStatus::Unknown;
    dstatus = ::mosek::fusion::SolutionStatus::Unknown;
    probstatus = ::mosek::fusion::ProblemStatus::Unknown;
    sol_numvar = _425;
    sol_numcon = _426;
    sol_numcone = _427;
    sol_numbarvar = _428;
    slx = nullptr;
    sux = nullptr;
    xx = nullptr;
    yx = nullptr;
    slc = nullptr;
    suc = nullptr;
    y = nullptr;
    xc = nullptr;
    snx = nullptr;
    barx = nullptr;
    bars = nullptr;
    if ((_425 > (int)0))
    {
      {
        slx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        sux = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        yx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
    if ((_428 > (int)0))
    {
      {
        barx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
        bars = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
      }
    }
    {}
    if ((_426 > (int)0))
    {
      {
        slc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        suc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        y = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        xc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
      }
    }
    {}
    if ((_427 > (int)0))
    {
      {
        snx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
  }
}mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){ return new mosek::fusion::SolutionStruct(_429); }mosek::fusion::SolutionStruct::SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_429); }void mosek::fusion::p_SolutionStruct::_initialize  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){monty::rc_reserve __reserve_this(_pubthis);   {
    sol_numcon = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcon;
    sol_numvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numvar;
    sol_numcone = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcone;
    sol_numbarvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numbarvar;
    pstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pstatus;
    dstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dstatus;
    probstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->probstatus;
    pobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pobj;
    dobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dobj;
    std::shared_ptr< monty::ndarray< double,1 > > _6668;
    bool _6669 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc.get());
    if (_6669)
    {
      _6668 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc);
    }
    else
    {
      _6668 = nullptr;
    }
    xc = _6668;
    std::shared_ptr< monty::ndarray< double,1 > > _6670;
    bool _6671 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx.get());
    if (_6671)
    {
      _6670 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx);
    }
    else
    {
      _6670 = nullptr;
    }
    xx = _6670;
    std::shared_ptr< monty::ndarray< double,1 > > _6672;
    bool _6673 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx.get());
    if (_6673)
    {
      _6672 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx);
    }
    else
    {
      _6672 = nullptr;
    }
    yx = _6672;
    std::shared_ptr< monty::ndarray< double,1 > > _6674;
    bool _6675 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slc.get());
    if (_6675)
    {
      _6674 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6674 = nullptr;
    }
    slc = _6674;
    std::shared_ptr< monty::ndarray< double,1 > > _6676;
    bool _6677 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->suc.get());
    if (_6677)
    {
      _6676 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6676 = nullptr;
    }
    suc = _6676;
    std::shared_ptr< monty::ndarray< double,1 > > _6678;
    bool _6679 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->y.get());
    if (_6679)
    {
      _6678 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->y);
    }
    else
    {
      _6678 = nullptr;
    }
    y = _6678;
    barx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->barx);
    bars = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->bars);
    std::shared_ptr< monty::ndarray< double,1 > > _6680;
    bool _6681 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx.get());
    if (_6681)
    {
      _6680 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6680 = nullptr;
    }
    slx = _6680;
    std::shared_ptr< monty::ndarray< double,1 > > _6682;
    bool _6683 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux.get());
    if (_6683)
    {
      _6682 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6682 = nullptr;
    }
    sux = _6682;
    std::shared_ptr< monty::ndarray< double,1 > > _6684;
    bool _6685 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx.get());
    if (_6685)
    {
      _6684 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx);
    }
    else
    {
      _6684 = nullptr;
    }
    snx = _6684;
  }
}monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct :: __mosek_2fusion_2SolutionStruct__clone() { return mosek::fusion::p_SolutionStruct::_get_impl(this)->__mosek_2fusion_2SolutionStruct__clone(); }monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct::clone() { return __mosek_2fusion_2SolutionStruct__clone(); }
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_SolutionStruct::__mosek_2fusion_2SolutionStruct__clone(){
  return ::mosek::fusion::p_SolutionStruct::_new_SolutionStruct(::mosek::fusion::SolutionStruct::t(_pubthis));
}
void mosek::fusion::SolutionStruct :: resize(int _430,int _431,int _432,int _433) { mosek::fusion::p_SolutionStruct::_get_impl(this)->resize(_430,_431,_432,_433); }void mosek::fusion::p_SolutionStruct::resize(int _430,int _431,int _432,int _433){
  if ((_433 < (int)0))
  {
    {
    }
  }
  else if((_433 <= sol_numbarvar))
  {
    {
      sol_numbarvar = _433;
    }
  }
  else if((_433 <= (int)((barx)->size(0))))
  {
    {
    }
  }
  else
  {
    {
      int _434;
      if ((safe_mul( sol_numbarvar,(int)2 ) > safe_add( _433,(int)100 )))
      {
        {
          _434 = safe_mul( sol_numbarvar,(int)2 );
        }
      }
      else
      {
        {
          _434 = safe_add( _433,(int)100 );
        }
      }
      barx = ::mosek::fusion::p_CommonTools::resize(barx,_434);
      bars = ::mosek::fusion::p_CommonTools::resize(bars,_434);
      sol_numbarvar = _434;
    }
  }
  if ((_430 < (int)0))
  {
    {
    }
  }
  else if((_430 <= sol_numvar))
  {
    {
      sol_numvar = _430;
    }
  }
  else if((_430 <= (int)((xx)->size(0))))
  {
    {
      int _6686 = sol_numvar;
      int _6687 = _430;
      for (int _435 = _6686; _435 < _6687; ++_435)
      {
        {
          ((*slx)(_435)) = 0.0;
          ((*sux)(_435)) = 0.0;
          ((*xx)(_435)) = 0.0;
          ((*yx)(_435)) = 0.0;
        }
      }
      sol_numvar = _430;
    }
  }
  else
  {
    {
      int _436;
      if ((safe_mul( sol_numvar,(int)2 ) > safe_add( _430,(int)100 )))
      {
        {
          _436 = safe_mul( sol_numvar,(int)2 );
        }
      }
      else
      {
        {
          _436 = safe_add( _430,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _437 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__437(_437 ? _437->raw() : nullptr,_437 ? _437->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slx,(int)0,_437,(int)0,(int)((slx)->size(0)));
      slx = _437;
      std::shared_ptr< monty::ndarray< double,1 > > _438 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__438(_438 ? _438->raw() : nullptr,_438 ? _438->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(sux,(int)0,_438,(int)0,(int)((sux)->size(0)));
      sux = _438;
      std::shared_ptr< monty::ndarray< double,1 > > _439 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__439(_439 ? _439->raw() : nullptr,_439 ? _439->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xx,(int)0,_439,(int)0,(int)((xx)->size(0)));
      xx = _439;
      std::shared_ptr< monty::ndarray< double,1 > > _440 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__440(_440 ? _440->raw() : nullptr,_440 ? _440->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(yx,(int)0,_440,(int)0,(int)((yx)->size(0)));
      yx = _440;
      {
        int _441 = sol_numvar;
        for(;(_441 < _430);++ _441)
        {
          {
            ((*slx)(_441)) = 0.0;
            ((*sux)(_441)) = 0.0;
            ((*xx)(_441)) = 0.0;
          }
        }
      }
      sol_numvar = _430;
    }
  }
  if ((_431 < (int)0))
  {
    {
    }
  }
  else if((_431 <= sol_numcon))
  {
    {
      sol_numcon = _431;
    }
  }
  else if((_431 <= (int)((xx)->size(0))))
  {
    {
      int _6688 = sol_numcon;
      int _6689 = _431;
      for (int _442 = _6688; _442 < _6689; ++_442)
      {
        {
          ((*slc)(_442)) = 0.0;
          ((*suc)(_442)) = 0.0;
          ((*xc)(_442)) = 0.0;
          ((*y)(_442)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  else
  {
    {
      int _443;
      if ((safe_mul( sol_numcon,(int)2 ) > safe_add( _431,(int)100 )))
      {
        {
          _443 = safe_mul( sol_numcon,(int)2 );
        }
      }
      else
      {
        {
          _443 = safe_add( _431,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _444 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__444(_444 ? _444->raw() : nullptr,_444 ? _444->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slc,(int)0,_444,(int)0,(int)((slc)->size(0)));
      slc = _444;
      std::shared_ptr< monty::ndarray< double,1 > > _445 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__445(_445 ? _445->raw() : nullptr,_445 ? _445->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(suc,(int)0,_445,(int)0,(int)((suc)->size(0)));
      suc = _445;
      std::shared_ptr< monty::ndarray< double,1 > > _446 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__446(_446 ? _446->raw() : nullptr,_446 ? _446->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xc,(int)0,_446,(int)0,(int)((xc)->size(0)));
      xc = _446;
      std::shared_ptr< monty::ndarray< double,1 > > _447 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__447(_447 ? _447->raw() : nullptr,_447 ? _447->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(y,(int)0,_447,(int)0,(int)((y)->size(0)));
      y = _447;
      int _6690 = sol_numcon;
      int _6691 = _431;
      for (int _448 = _6690; _448 < _6691; ++_448)
      {
        {
          ((*slc)(_448)) = 0.0;
          ((*suc)(_448)) = 0.0;
          ((*xc)(_448)) = 0.0;
          ((*y)(_448)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  if ((_432 < (int)0))
  {
    {
    }
  }
  else if((_432 <= sol_numcone))
  {
    {
      sol_numcone = _432;
    }
  }
  else if((_432 <= (int)((xx)->size(0))))
  {
    {
      int _6692 = sol_numcone;
      int _6693 = _432;
      for (int _449 = _6692; _449 < _6693; ++_449)
      {
        {
          ((*snx)(_449)) = 0.0;
        }
      }
      sol_numcone = _432;
    }
  }
  else
  {
    {
      int _450;
      if ((safe_mul( sol_numcone,(int)2 ) > safe_add( _432,(int)100 )))
      {
        {
          _450 = safe_mul( sol_numcone,(int)2 );
        }
      }
      else
      {
        {
          _450 = safe_add( _432,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _451 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_450)));
      _checked_ptr_1<double> _ptr__451(_451 ? _451->raw() : nullptr,_451 ? _451->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(snx,(int)0,_451,(int)0,(int)((snx)->size(0)));
      snx = _451;
      {
        int _452 = sol_numcone;
        for(;(_452 < _432);++ _452)
        {
          {
            ((*snx)(_452)) = 0.0;
          }
        }
      }
      sol_numcone = _432;
    }
  }
}
bool mosek::fusion::SolutionStruct :: isDualAcceptable(mosek::fusion::AccSolutionStatus _453) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isDualAcceptable(_453); }bool mosek::fusion::p_SolutionStruct::isDualAcceptable(mosek::fusion::AccSolutionStatus _453){
  return isAcceptable(dstatus,_453);
}
bool mosek::fusion::SolutionStruct :: isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isPrimalAcceptable(_454); }bool mosek::fusion::p_SolutionStruct::isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454){
  return isAcceptable(pstatus,_454);
}
bool mosek::fusion::p_SolutionStruct::isAcceptable(mosek::fusion::SolutionStatus _455,mosek::fusion::AccSolutionStatus _456){
  if ((_456 == ::mosek::fusion::AccSolutionStatus::Anything))
  {
    {
      return true;
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Optimal))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Optimal);
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Feasible))
  {
    {
      return ((_455 == ::mosek::fusion::SolutionStatus::Optimal) || (_455 == ::mosek::fusion::SolutionStatus::Feasible));
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Certificate))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Certificate);
    }
  }
  {}
  return false;
}
void mosek::fusion::p_SolutionStruct::destroy(){yx.reset();snx.reset();sux.reset();slx.reset();bars.reset();barx.reset();y.reset();suc.reset();slc.reset();xx.reset();xc.reset();}void mosek::fusion::SolutionStruct::destroy() { mosek::fusion::p_SolutionStruct::_get_impl(this)->destroy(); }mosek::fusion::ConNZStruct::ConNZStruct(mosek::fusion::p_ConNZStruct *_impl) : _impl(_impl) { /*std::cout << "ConNZStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConNZStruct::~ConNZStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConNZStruct::p_ConNZStruct  (::mosek::fusion::ConNZStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barmidx() { return _impl->barmidx; }
void mosek::fusion::ConNZStruct::set_barmidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConNZStruct::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConNZStruct::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConNZStruct::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_cof() { return _impl->cof; }
void mosek::fusion::ConNZStruct::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_subj() { return _impl->subj; }
void mosek::fusion::ConNZStruct::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::ConNZStruct::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::ConNZStruct::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
mosek::fusion::ConNZStruct::t mosek::fusion::p_ConNZStruct::_new_ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){ return new mosek::fusion::ConNZStruct(_457,_458,_459,_460,_461,_462,_463); }mosek::fusion::ConNZStruct::ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463) :    ConNZStruct(new mosek::fusion::p_ConNZStruct(this)){ mosek::fusion::p_ConNZStruct::_get_impl(this)->_initialize(_457,_458,_459,_460,_461,_462,_463); }void mosek::fusion::p_ConNZStruct::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__457(_457 ? _457->raw() : nullptr, _457 ? _457->size(0) : 0);
    _checked_ptr_1<int> _ptr__458(_458 ? _458->raw() : nullptr, _458 ? _458->size(0) : 0);
    _checked_ptr_1<double> _ptr__459(_459 ? _459->raw() : nullptr, _459 ? _459->size(0) : 0);
    _checked_ptr_1<double> _ptr__460(_460 ? _460->raw() : nullptr, _460 ? _460->size(0) : 0);
    _checked_ptr_1<int> _ptr__461(_461 ? _461->raw() : nullptr, _461 ? _461->size(0) : 0);
    _checked_ptr_1<int> _ptr__462(_462 ? _462->raw() : nullptr, _462 ? _462->size(0) : 0);
    _checked_ptr_1<int> _ptr__463(_463 ? _463->raw() : nullptr, _463 ? _463->size(0) : 0);
    ptrb = _457;
    subj = _458;
    cof = _459;
    bfix = _460;
    barsubi = _461;
    barsubj = _462;
    barmidx = _463;
  }
}void mosek::fusion::p_ConNZStruct::destroy(){barmidx.reset();barsubj.reset();barsubi.reset();bfix.reset();cof.reset();subj.reset();ptrb.reset();}void mosek::fusion::ConNZStruct::destroy() { mosek::fusion::p_ConNZStruct::_get_impl(this)->destroy(); }mosek::fusion::Model::Model(mosek::fusion::p_Model *_impl) : mosek::fusion::BaseModel(_impl) { /*std::cout << "Model()" << this << std::endl; */ }mosek::fusion::Model::~Model() {  /* std::cout << "~Model()" << this << std::endl << std::flush; */ }mosek::fusion::p_Model::p_Model  (::mosek::fusion::Model * _pubthis) :     mosek::fusion::p_BaseModel(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (monty::rc_ptr< ::mosek::fusion::Model > _464){ return new mosek::fusion::Model(_464); }mosek::fusion::Model::Model  (monty::rc_ptr< ::mosek::fusion::Model > _464) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_464); }void mosek::fusion::p_Model::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _464){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_464);
    monty::rc_ptr< ::mosek::fusion::Model > _465 = ::mosek::fusion::Model::t(_pubthis);
    model_name = mosek::fusion::p_Model::_get_impl(_464)->model_name;
    acceptable_sol = mosek::fusion::p_Model::_get_impl(_464)->acceptable_sol;
    solutionptr = mosek::fusion::p_Model::_get_impl(_464)->solutionptr;
    natvarmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_blockid);
    natvarmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_idx);
    natvarmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_type);
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natvarmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6694;
    for (int _466 = (int)0, _6695 = (int)((mosek::fusion::p_Model::_get_impl(_464)->vars)->size(0)); _466 < _6695 ; ++_466)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6696;
      bool _6697 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get());
      if (_6697)
      {
        _6696 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6696 = nullptr;
      }
      _6694.push_back(_6696);
    }
    auto _6698 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6694.size()),_6694.begin(),_6694.end()));
    vars = _6698;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconemap);
    natconemap_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconemap_dim);
    natbarvar_numbarvarelm = mosek::fusion::p_Model::_get_impl(_464)->natbarvar_numbarvarelm;
    natbarvar_ptr = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_ptr);
    natbarvar_i = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_i);
    natbarvar_j = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_j);
    natbarvar_idx = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_idx);
    natbarvarmap_nblock = mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_nblock;
    natbarvar_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvar_dim);
    natbarvarmap_num = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_num);
    natbarvarmap_ptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_ptr);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6699;
    for (int _467 = (int)0, _6700 = (int)((mosek::fusion::p_Model::_get_impl(_464)->barvars)->size(0)); _467 < _6700 ; ++_467)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6701;
      bool _6702 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get());
      if (_6702)
      {
        _6701 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6701 = nullptr;
      }
      _6699.push_back(_6701);
    }
    auto _6703 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6699.size()),_6699.begin(),_6699.end()));
    barvars = _6703;
    var_map = mosek::fusion::p_Model::_get_impl(_464)->var_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    natconmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_blockid);
    natconmap_slackidx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_slackidx);
    natconmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_idx);
    natconmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_type);
    natconmap_efix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_efix);
    natconmap_lb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_lb);
    natconmap_ub = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_ub);
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6704;
    for (int _468 = (int)0, _6705 = (int)((mosek::fusion::p_Model::_get_impl(_464)->cons)->size(0)); _468 < _6705 ; ++_468)
    {
      monty::rc_ptr< ::mosek::fusion::ModelConstraint > _6706;
      bool _6707 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get());
      if (_6707)
      {
        _6706 = mosek::fusion::p_ModelConstraint::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get())->__mosek_2fusion_2ModelConstraint__clone(_465);
      }
      else
      {
        _6706 = nullptr;
      }
      _6704.push_back(_6706);
    }
    auto _6708 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6704.size()),_6704.begin(),_6704.end()));
    cons = _6708;
    con_map = mosek::fusion::p_Model::_get_impl(_464)->con_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (const std::string &  _469){ return new mosek::fusion::Model(_469); }mosek::fusion::Model::Model  (const std::string &  _469) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_469); }void mosek::fusion::p_Model::_initialize  (const std::string &  _469){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_469,std::string (""));
    model_name = _469;
    acceptable_sol = ::mosek::fusion::AccSolutionStatus::Optimal;
    solutionptr = ::mosek::fusion::SolutionType::Default;
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natvarmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6709;
    for (int _470 = (int)0, _6710 = (int)1024; _470 < _6710 ; ++_470)
    {
      _6709.push_back(nullptr);
    }
    auto _6711 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6709.size()),_6709.begin(),_6709.end()));
    vars = _6711;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconemap_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    natbarvar_ptr = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
    natbarvar_numbarvarelm = (int)0;
    natbarvar_i = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_j = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_nblock = (int)0;
    natbarvar_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_num = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_ptr = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    var_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_slackidx = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1024)));
    natconmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_efix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_lb = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_ub = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6712;
    for (int _471 = (int)0, _6713 = (int)1024; _471 < _6713 ; ++_471)
    {
      _6712.push_back(nullptr);
    }
    auto _6714 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6712.size()),_6712.begin(),_6712.end()));
    cons = _6714;
    con_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (){ return new mosek::fusion::Model(); }mosek::fusion::Model::Model  () :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(); }void mosek::fusion::p_Model::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Model::_initialize(std::string (""));
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_Model::__mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _472,std::shared_ptr< monty::ndarray< int,1 > > _473,std::shared_ptr< monty::ndarray< int,1 > > _474){
  _checked_ptr_1<int> _ptr__473(_473 ? _473->raw() : nullptr, _473 ? _473->size(0) : 0);
  _checked_ptr_1<int> _ptr__474(_474 ? _474->raw() : nullptr, _474 ? _474->size(0) : 0);
  return _472;
}
void mosek::fusion::p_Model::connames(std::shared_ptr< monty::ndarray< int,1 > > _475,const std::string & _476,std::shared_ptr< monty::ndarray< int,1 > > _477,std::shared_ptr< monty::ndarray< long long,1 > > _478){
  _checked_ptr_1<int> _ptr__475(_475 ? _475->raw() : nullptr, _475 ? _475->size(0) : 0);
  _checked_ptr_1<int> _ptr__477(_477 ? _477->raw() : nullptr, _477 ? _477->size(0) : 0);
  _checked_ptr_1<long long> _ptr__478(_478 ? _478->raw() : nullptr, _478 ? _478->size(0) : 0);
  task_format_con_names(_475,_476,_477,_478);
}
void mosek::fusion::p_Model::varnames(std::shared_ptr< monty::ndarray< int,1 > > _479,const std::string & _480,std::shared_ptr< monty::ndarray< int,1 > > _481,std::shared_ptr< monty::ndarray< long long,1 > > _482){
  _checked_ptr_1<int> _ptr__479(_479 ? _479->raw() : nullptr, _479 ? _479->size(0) : 0);
  _checked_ptr_1<int> _ptr__481(_481 ? _481->raw() : nullptr, _481 ? _481->size(0) : 0);
  _checked_ptr_1<long long> _ptr__482(_482 ? _482->raw() : nullptr, _482 ? _482->size(0) : 0);
  task_format_var_names(_479,_480,_481,_482);
}
void mosek::fusion::p_Model::varname(int _483,const std::string & _484){
  task_var_name(_483,_484);
}
void mosek::fusion::p_Model::natbarvarmap_get(int _485,std::shared_ptr< monty::ndarray< int,1 > > _486){
  _checked_ptr_1<int> _ptr__486(_486 ? _486->raw() : nullptr, _486 ? _486->size(0) : 0);
  int _487 = ((*natbarvarmap_ptr)(_485));
  int _488 = ((*natbarvarmap_num)(_485));
  int _6715 = (int)0;
  int _6716 = _488;
  for (int _489 = _6715; _489 < _6716; ++_489)
  {
    {
      _ptr__486[_489] = safe_add( _487,_489 );
    }
  }
}
void mosek::fusion::p_Model::natbarvar_get(int _490,std::shared_ptr< monty::ndarray< long long,1 > > _491){
  _checked_ptr_1<long long> _ptr__491(_491 ? _491->raw() : nullptr, _491 ? _491->size(0) : 0);
  int _492 = ((*natbarvarmap_ptr)(_490));
  int _493 = ((*natbarvarmap_num)(_490));
  int _494 = ((*natbarvar_dim)(((*natbarvarmap_ptr)(_490))));
  int _495 = (safe_mul( safe_mul( _493,_494 ),safe_add( _494,(int)1 ) ) / (int)2);
  long long _496 = ((*natbarvar_ptr)(_492));
  int _6717 = (int)0;
  int _6718 = _495;
  for (int _497 = _6717; _497 < _6718; ++_497)
  {
    {
      _ptr__491[_497] = safe_add( _496,_497 );
    }
  }
}
int mosek::fusion::p_Model::natbarvarmap_alloc(int _498,int _499){
  int _500 = (int)((natbarvar_idx)->size(0));
  int _501 = task_numbarvar();
  int _502 = (safe_mul( _499,safe_add( _499,(int)1 ) ) / (int)2);
  int _503 = safe_mul( _498,_502 );
  if ((safe_add( natbarvar_numbarvarelm,_503 ) >= _500))
  {
    {
      if ((_503 < _500))
      {
        {
          _503 = _500;
        }
      }
      {}
      natbarvar_idx = ::mosek::fusion::p_CommonTools::resize(natbarvar_idx,safe_add( _500,_503 ));
      natbarvar_i = ::mosek::fusion::p_CommonTools::resize(natbarvar_i,safe_add( _500,_503 ));
      natbarvar_j = ::mosek::fusion::p_CommonTools::resize(natbarvar_j,safe_add( _500,_503 ));
    }
  }
  {}
  if ((safe_add( natbarvarmap_nblock,(int)1 ) >= (int)((natbarvarmap_num)->size(0))))
  {
    {
      int _6719;
      bool _6720 = ((int)((natbarvarmap_num)->size(0)) > (int)0);
      if (_6720)
      {
        _6719 = safe_mul( (int)((natbarvarmap_num)->size(0)),(int)2 );
      }
      else
      {
        _6719 = (int)32;
      }
      int _504 = _6719;
      natbarvarmap_num = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_num,_504);
      natbarvarmap_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_ptr,safe_add( _504,(int)1 ));
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _505 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_504)));
      int _6721 = (int)0;
      int _6722 = (int)((barvars)->size(0));
      for (int _506 = _6721; _506 < _6722; ++_506)
      {
        {
          ((*_505)(_506)) = ((*barvars)(_506));
        }
      }
      barvars = _505;
    }
  }
  {}
  if ((safe_add( _501,_498 ) > (int)((natbarvar_dim)->size(0))))
  {
    {
      int _6723;
      bool _6724 = (safe_add( _501,_498 ) < safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 ));
      if (_6724)
      {
        _6723 = safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 );
      }
      else
      {
        _6723 = safe_add( _501,_498 );
      }
      int _507 = _6723;
      natbarvar_dim = ::mosek::fusion::p_CommonTools::resize(natbarvar_dim,_507);
    }
  }
  {}
  if ((safe_add( _501,_498 ) >= (int)((natbarvar_ptr)->size(0))))
  {
    {
      int _6725;
      bool _6726 = (_498 > (int)((natbarvar_ptr)->size(0)));
      if (_6726)
      {
        _6725 = _498;
      }
      else
      {
        _6725 = (int)((natbarvar_ptr)->size(0));
      }
      int _508 = _6725;
      natbarvar_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvar_ptr,safe_add( safe_add( (int)((natbarvar_ptr)->size(0)),_508 ),(int)1 ));
    }
  }
  {}
  int _6727 = (int)0;
  int _6728 = _498;
  for (int _509 = _6727; _509 < _6728; ++_509)
  {
    {
      ((*natbarvar_dim)(safe_add( _501,_509 ))) = _499;
    }
  }
  ((*natbarvarmap_num)(natbarvarmap_nblock)) = _498;
  ((*natbarvarmap_ptr)(safe_add( natbarvarmap_nblock,(int)1 ))) = safe_add( ((*natbarvarmap_ptr)(natbarvarmap_nblock)),_498 );
  int _510 = task_append_barvar(_499,_498);
  int _511 = ((*natbarvarmap_ptr)(natbarvarmap_nblock));
  {
    long long _512 = ((*natbarvar_ptr)(_501));
    int _6729 = (int)0;
    int _6730 = _499;
    for (int _513 = _6729; _513 < _6730; ++_513)
    {
      {
        int _6731 = _513;
        int _6732 = _499;
        for (int _514 = _6731; _514 < _6732; ++_514)
        {
          {
            int _6733 = (int)0;
            int _6734 = _498;
            for (int _515 = _6733; _515 < _6734; ++_515)
            {
              {
                ((*natbarvar_idx)(safe_add( _512,safe_mul( _515,_502 ) ))) = safe_add( _511,_515 );
                ((*natbarvar_i)(safe_add( _512,safe_mul( _515,_502 ) ))) = _514;
                ((*natbarvar_j)(safe_add( _512,safe_mul( _515,_502 ) ))) = _513;
              }
            }
            ++ _512;
          }
        }
      }
    }
    int _6735 = (int)0;
    int _6736 = _498;
    for (int _516 = _6735; _516 < _6736; ++_516)
    {
      {
        ((*natbarvar_ptr)(safe_add( safe_add( _511,_516 ),(int)1 ))) = safe_add( ((*natbarvar_ptr)(safe_add( _511,_516 ))),_502 );
      }
    }
  }
  natbarvarmap_nblock += (int)1;
  natbarvar_numbarvarelm += safe_mul( _498,_502 );
  return (natbarvarmap_nblock - (int)1);
}
int mosek::fusion::p_Model::natvarmap_alloc(int _517){
  int _518 = natvarmap->alloc(_517);
  int _519 = safe_add( natvarmap->maxidx(_518),(int)1 );
  int _520 = natvarmap->capacity();
  int _521 = natvarmap->numblocks();
  if (((int)((natvarmap_idx)->size(0)) < _520))
  {
    {
      int _522 = (int)((natvarmap_idx)->size(0));
      natvarmap_idx = ::mosek::fusion::p_CommonTools::resize(natvarmap_idx,_520);
      int _6737 = _522;
      int _6738 = _520;
      for (int _523 = _6737; _523 < _6738; ++_523)
      {
        {
          ((*natvarmap_idx)(_523)) = (-(int)1);
        }
      }
      natvarmap_blockid = ::mosek::fusion::p_CommonTools::resize(natvarmap_blockid,_520);
    }
  }
  {}
  if (((int)((vars)->size(0)) < _521))
  {
    {
      natvarmap_type = ::mosek::fusion::p_CommonTools::resize(natvarmap_type,_521);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _524 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_521)));
      int _6739 = (int)0;
      int _6740 = (int)((vars)->size(0));
      for (int _525 = _6739; _525 < _6740; ++_525)
      {
        {
          ((*_524)(_525)) = ((*vars)(_525));
        }
      }
      int _6741 = (int)((vars)->size(0));
      int _6742 = (int)((_524)->size(0));
      for (int _526 = _6741; _526 < _6742; ++_526)
      {
        {
          ((*_524)(_526)) = nullptr;
        }
      }
      vars = _524;
    }
  }
  {}
  if ((task_numvar() < _519))
  {
    {
      task_append_var((_519 - task_numvar()));
    }
  }
  {}
  return _518;
}
int mosek::fusion::p_Model::natconmap_alloc(int _527){
  int _528 = natconmap->alloc(_527);
  int _529 = safe_add( natconmap->maxidx(_528),(int)1 );
  int _530 = natconmap->capacity();
  int _531 = natconmap->numblocks();
  if (((int)((natconmap_idx)->size(0)) < _530))
  {
    {
      int _532 = (int)((natconmap_idx)->size(0));
      natconmap_idx = ::mosek::fusion::p_CommonTools::resize(natconmap_idx,_530);
      int _6743 = _532;
      int _6744 = _530;
      for (int _533 = _6743; _533 < _6744; ++_533)
      {
        {
          ((*natconmap_idx)(_533)) = (-(int)1);
        }
      }
      natconmap_efix = ::mosek::fusion::p_CommonTools::resize(natconmap_efix,_530);
      natconmap_lb = ::mosek::fusion::p_CommonTools::resize(natconmap_lb,_530);
      natconmap_ub = ::mosek::fusion::p_CommonTools::resize(natconmap_ub,_530);
      natconmap_blockid = ::mosek::fusion::p_CommonTools::resize(natconmap_blockid,_530);
      natconmap_slackidx = ::mosek::fusion::p_CommonTools::resize(natconmap_slackidx,_530);
    }
  }
  {}
  if (((int)((cons)->size(0)) < _531))
  {
    {
      natconmap_type = ::mosek::fusion::p_CommonTools::resize(natconmap_type,_531);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > _534 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_531)));
      int _6745 = (int)0;
      int _6746 = (int)((cons)->size(0));
      for (int _535 = _6745; _535 < _6746; ++_535)
      {
        {
          ((*_534)(_535)) = ((*cons)(_535));
        }
      }
      int _6747 = (int)((cons)->size(0));
      int _6748 = _531;
      for (int _536 = _6747; _536 < _6748; ++_536)
      {
        {
          ((*_534)(_536)) = nullptr;
        }
      }
      cons = _534;
    }
  }
  {}
  if ((_529 > task_numcon()))
  {
    {
      task_append_con((_529 - task_numcon()));
    }
  }
  {}
  return _528;
}
int mosek::fusion::p_Model::natconemap_alloc(int _537){
  int _538 = natconemap->alloc(_537);
  int _539 = safe_add( natconemap->maxidx(_538),(int)1 );
  if ((_539 > task_numcone()))
  {
    {
      task_append_zerocones((_539 - task_numcone()));
    }
  }
  {}
  natconemap_dim = ::mosek::fusion::p_CommonTools::resize(natconemap_dim,natconemap->numblocks());
  return _538;
}
void mosek::fusion::p_Model::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _540){
  _checked_ptr_1<long long> _ptr__540(_540 ? _540->raw() : nullptr, _540 ? _540->size(0) : 0);
  int _541 = (int)0;
  int _6749 = (int)0;
  int _6750 = (int)((_540)->size(0));
  for (int _542 = _6749; _542 < _6750; ++_542)
  {
    {
      if ((_ptr__540[_542] > (int)0))
      {
        {
          ++ _541;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _543 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_541)));
  _checked_ptr_1<int> _ptr__543(_543 ? _543->raw() : nullptr,_543 ? _543->size(0) : 0);
  int _544 = (int)0;
  int _6751 = (int)0;
  int _6752 = (int)((_540)->size(0));
  for (int _545 = _6751; _545 < _6752; ++_545)
  {
    {
      if ((_ptr__540[_545] > (int)0))
      {
        {
          _ptr__543[_544] = (int)(_ptr__540[_545] - (int)1);
          ++ _544;
        }
      }
      {}
    }
  }
  task_var_putcontlist(_543);
}
void mosek::fusion::p_Model::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _546){
  _checked_ptr_1<long long> _ptr__546(_546 ? _546->raw() : nullptr, _546 ? _546->size(0) : 0);
  int _547 = (int)0;
  int _6753 = (int)0;
  int _6754 = (int)((_546)->size(0));
  for (int _548 = _6753; _548 < _6754; ++_548)
  {
    {
      if ((_ptr__546[_548] > (int)0))
      {
        {
          ++ _547;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _549 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_547)));
  _checked_ptr_1<int> _ptr__549(_549 ? _549->raw() : nullptr,_549 ? _549->size(0) : 0);
  int _550 = (int)0;
  int _6755 = (int)0;
  int _6756 = (int)((_546)->size(0));
  for (int _551 = _6755; _551 < _6756; ++_551)
  {
    {
      if ((_ptr__546[_551] > (int)0))
      {
        {
          _ptr__549[_550] = (int)(_ptr__546[_551] - (int)1);
          ++ _550;
        }
      }
      {}
    }
  }
  task_var_putintlist(_549);
}
void mosek::fusion::Model::putlicensewait  ( bool _552) { mosek::fusion::p_Model::putlicensewait(_552); }void mosek::fusion::p_Model::putlicensewait(bool _552){
  ::mosek::fusion::p_BaseModel::env_putlicensewait(_552);
}
void mosek::fusion::Model::putlicensepath  ( const std::string & _553) { mosek::fusion::p_Model::putlicensepath(_553); }void mosek::fusion::p_Model::putlicensepath(const std::string & _553){
  ::mosek::fusion::p_BaseModel::env_putlicensepath(_553);
}
void mosek::fusion::Model::putlicensecode  ( std::shared_ptr< monty::ndarray< int,1 > > _554) { mosek::fusion::p_Model::putlicensecode(_554); }void mosek::fusion::p_Model::putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _554){
  _checked_ptr_1<int> _ptr__554(_554 ? _554->raw() : nullptr, _554 ? _554->size(0) : 0);
  ::mosek::fusion::p_BaseModel::env_putlicensecode(_554);
}
void mosek::fusion::Model :: dispose() { mosek::fusion::p_Model::_get_impl(this)->dispose(); }void mosek::fusion::p_Model::dispose(){
  int _6757 = (int)0;
  int _6758 = (int)((vars)->size(0));
  for (int _555 = _6757; _555 < _6758; ++_555)
  {
    {
      ((*vars)(_555)) = nullptr;
    }
  }
  int _6759 = (int)0;
  int _6760 = (int)((cons)->size(0));
  for (int _556 = _6759; _556 < _6760; ++_556)
  {
    {
      ((*cons)(_556)) = nullptr;
    }
  }
  ::mosek::fusion::p_BaseModel::dispose();
}
void mosek::fusion::p_Model::nativeVarToStr(int _557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _558){
  if (((_557 < (int)0) || ((_557 >= (int)((natvarmap_idx)->size(0))) || (((*natvarmap_idx)(_557)) < (int)0))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Native variable index is invalid"));
    }
  }
  {}
  ((*vars)(((*natvarmap_blockid)(_557))))->elementName((long long)(((*natvarmap_idx)(_557))),_558);
}
MSKtask_t mosek::fusion::Model :: __mosek_2fusion_2Model__getTask() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getTask(); }MSKtask_t mosek::fusion::Model::getTask() { return __mosek_2fusion_2Model__getTask(); }
MSKtask_t mosek::fusion::p_Model::__mosek_2fusion_2Model__getTask(){
  return __mosek_2fusion_2BaseModel__task_get();
}
void mosek::fusion::Model :: getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562) { mosek::fusion::p_Model::_get_impl(this)->getConstraintValues(_559,_560,_561,_562); }void mosek::fusion::p_Model::getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562){
  _checked_ptr_1<int> _ptr__560(_560 ? _560->raw() : nullptr, _560 ? _560->size(0) : 0);
  _checked_ptr_1<double> _ptr__561(_561 ? _561->raw() : nullptr, _561 ? _561->size(0) : 0);
  int _563 = (int)((_560)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6761;
  bool _6762 = _559;
  if (_6762)
  {
    _6761 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6761 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _564 = _6761;
  _checked_ptr_1<double> _ptr__564(_564 ? _564->raw() : nullptr,_564 ? _564->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6763;
  bool _6764 = _559;
  if (_6764)
  {
    _6763 = getSolution_barx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6763 = getSolution_bars(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _565 = _6763;
  _checked_ptr_1<double> _ptr__565(_565 ? _565->raw() : nullptr,_565 ? _565->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6765;
  bool _6766 = _559;
  if (_6766)
  {
    _6765 = getSolution_xc(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6765 = getSolution_y(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _566 = _6765;
  _checked_ptr_1<double> _ptr__566(_566 ? _566->raw() : nullptr,_566 ? _566->size(0) : 0);
  int _6767 = (int)0;
  int _6768 = _563;
  for (int _567 = _6767; _567 < _6768; ++_567)
  {
    {
      long long _568 = ((*natconmap_slackidx)(_ptr__560[_567]));
      if ((_568 < (int)0))
      {
        {
          long long _569 = (-safe_add( _568,(int)1 ));
          _ptr__561[safe_add( _562,_567 )] = _ptr__565[_569];
        }
      }
      else if((_568 > (int)0))
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__564[(_568 - (int)1)];
        }
      }
      else
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__566[_ptr__560[_567]];
        }
      }
    }
  }
  if (_559)
  {
    {
      int _6769 = (int)0;
      int _6770 = _563;
      for (int _570 = _6769; _570 < _6770; ++_570)
      {
        {
          _ptr__561[safe_add( _562,_570 )] += ((*natconmap_efix)(_ptr__560[_570]));
        }
      }
    }
  }
  {}
}
void mosek::fusion::Model :: getVariableDuals(bool _571,std::shared_ptr< monty::ndarray< long long,1 > > _572,std::shared_ptr< monty::ndarray< double,1 > > _573,int _574) { mosek::fusion::p_Model::_get_impl(this)->getVariableDuals(_571,_572,_573,_574); }void mosek::fusion::p_Model::getVariableDuals(bool _571,std::shared_ptr< monty::ndarray< long long,1 > > _572,std::shared_ptr< monty::ndarray< double,1 > > _573,int _574){
  _checked_ptr_1<long long> _ptr__572(_572 ? _572->raw() : nullptr, _572 ? _572->size(0) : 0);
  _checked_ptr_1<double> _ptr__573(_573 ? _573->raw() : nullptr, _573 ? _573->size(0) : 0);
  int _575 = (int)((_572)->size(0));
  if (_571)
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _576 = getSolution_slx(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__576(_576 ? _576->raw() : nullptr,_576 ? _576->size(0) : 0);
      int _6771 = (int)0;
      int _6772 = _575;
      for (int _577 = _6771; _577 < _6772; ++_577)
      {
        {
          if ((_ptr__572[_577] > (int)0))
          {
            {
              _ptr__573[safe_add( _574,_577 )] = _ptr__576[(_ptr__572[_577] - (int)1)];
            }
          }
          else
          {
            {
              _ptr__573[safe_add( _574,_577 )] = (int)0;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _578 = getSolution_sux(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__578(_578 ? _578->raw() : nullptr,_578 ? _578->size(0) : 0);
      int _6773 = (int)0;
      int _6774 = _575;
      for (int _579 = _6773; _579 < _6774; ++_579)
      {
        {
          if ((_ptr__572[_579] > (int)0))
          {
            {
              _ptr__573[safe_add( _574,_579 )] = (-_ptr__578[(_ptr__572[_579] - (int)1)]);
            }
          }
          else
          {
            {
              _ptr__573[safe_add( _574,_579 )] = (int)0;
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableValues(bool _580,std::shared_ptr< monty::ndarray< long long,1 > > _581,std::shared_ptr< monty::ndarray< double,1 > > _582,int _583) { mosek::fusion::p_Model::_get_impl(this)->getVariableValues(_580,_581,_582,_583); }void mosek::fusion::p_Model::getVariableValues(bool _580,std::shared_ptr< monty::ndarray< long long,1 > > _581,std::shared_ptr< monty::ndarray< double,1 > > _582,int _583){
  _checked_ptr_1<long long> _ptr__581(_581 ? _581->raw() : nullptr, _581 ? _581->size(0) : 0);
  _checked_ptr_1<double> _ptr__582(_582 ? _582->raw() : nullptr, _582 ? _582->size(0) : 0);
  int _584 = (int)((_581)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6775;
  bool _6776 = _580;
  if (_6776)
  {
    _6775 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6775 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _585 = _6775;
  _checked_ptr_1<double> _ptr__585(_585 ? _585->raw() : nullptr,_585 ? _585->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6777;
  bool _6778 = (natbarvar_numbarvarelm > (int)0);
  if (_6778)
  {
    std::shared_ptr< monty::ndarray< double,1 > > _6779;
    bool _6780 = _580;
    if (_6780)
    {
      _6779 = getSolution_barx(::mosek::fusion::SolutionType::Default);
    }
    else
    {
      _6779 = getSolution_bars(::mosek::fusion::SolutionType::Default);
    }
    _6777 = _6779;
  }
  else
  {
    _6777 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _586 = _6777;
  _checked_ptr_1<double> _ptr__586(_586 ? _586->raw() : nullptr,_586 ? _586->size(0) : 0);
  int _6781 = (int)0;
  int _6782 = _584;
  for (int _587 = _6781; _587 < _6782; ++_587)
  {
    {
      if ((_ptr__581[_587] > (int)0))
      {
        {
          _ptr__582[safe_add( _583,_587 )] = _ptr__585[(_ptr__581[_587] - (int)1)];
        }
      }
      else if((_ptr__581[_587] < (int)0))
      {
        {
          long long _588 = (-safe_add( _ptr__581[_587],(int)1 ));
          _ptr__582[safe_add( _583,_587 )] = _ptr__586[_588];
        }
      }
      else
      {
        {
          _ptr__582[safe_add( _583,_587 )] = (int)0;
        }
      }
    }
  }
}
void mosek::fusion::Model :: setVariableValues(bool _589,std::shared_ptr< monty::ndarray< long long,1 > > _590,std::shared_ptr< monty::ndarray< double,1 > > _591) { mosek::fusion::p_Model::_get_impl(this)->setVariableValues(_589,_590,_591); }void mosek::fusion::p_Model::setVariableValues(bool _589,std::shared_ptr< monty::ndarray< long long,1 > > _590,std::shared_ptr< monty::ndarray< double,1 > > _591){
  _checked_ptr_1<long long> _ptr__590(_590 ? _590->raw() : nullptr, _590 ? _590->size(0) : 0);
  _checked_ptr_1<double> _ptr__591(_591 ? _591->raw() : nullptr, _591 ? _591->size(0) : 0);
}
void mosek::fusion::Model :: flushNames() { mosek::fusion::p_Model::_get_impl(this)->flushNames(); }void mosek::fusion::p_Model::flushNames(){
  int _6783 = (int)0;
  int _6784 = (int)((vars)->size(0));
  for (int _592 = _6783; _592 < _6784; ++_592)
  {
    {
      if ((NULL != ((*vars)(_592)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*vars)(_592)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6785 = (int)0;
  int _6786 = (int)((barvars)->size(0));
  for (int _593 = _6785; _593 < _6786; ++_593)
  {
    {
      if ((NULL != ((*barvars)(_593)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*barvars)(_593)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6787 = (int)0;
  int _6788 = (int)((cons)->size(0));
  for (int _594 = _6787; _594 < _6788; ++_594)
  {
    {
      if ((NULL != ((*cons)(_594)).get()))
      {
        {
          mosek::fusion::p_ModelConstraint::_get_impl(((*cons)(_594)).get())->flushNames();
        }
      }
      {}
    }
  }
}
void mosek::fusion::Model :: writeTask(const std::string & _595) { mosek::fusion::p_Model::_get_impl(this)->writeTask(_595); }void mosek::fusion::p_Model::writeTask(const std::string & _595){
  _pubthis->flushNames();
  task_write(_595);
}
long long mosek::fusion::Model :: getSolverLIntInfo(const std::string & _596) { return mosek::fusion::p_Model::_get_impl(this)->getSolverLIntInfo(_596); }long long mosek::fusion::p_Model::getSolverLIntInfo(const std::string & _596){
  return task_get_liinf(_596);
}
int mosek::fusion::Model :: getSolverIntInfo(const std::string & _597) { return mosek::fusion::p_Model::_get_impl(this)->getSolverIntInfo(_597); }int mosek::fusion::p_Model::getSolverIntInfo(const std::string & _597){
  return task_get_iinf(_597);
}
double mosek::fusion::Model :: getSolverDoubleInfo(const std::string & _598) { return mosek::fusion::p_Model::_get_impl(this)->getSolverDoubleInfo(_598); }double mosek::fusion::p_Model::getSolverDoubleInfo(const std::string & _598){
  return task_get_dinf(_598);
}
void mosek::fusion::Model :: setCallbackHandler(mosek::cbhandler_t _599) { mosek::fusion::p_Model::_get_impl(this)->setCallbackHandler(_599); }void mosek::fusion::p_Model::setCallbackHandler(mosek::cbhandler_t _599){
  task_setCallbackHandler(_599);
}
void mosek::fusion::Model :: setDataCallbackHandler(mosek::datacbhandler_t _600) { mosek::fusion::p_Model::_get_impl(this)->setDataCallbackHandler(_600); }void mosek::fusion::p_Model::setDataCallbackHandler(mosek::datacbhandler_t _600){
  task_setDataCallbackHandler(_600);
}
void mosek::fusion::Model :: setLogHandler(mosek::msghandler_t _601) { mosek::fusion::p_Model::_get_impl(this)->setLogHandler(_601); }void mosek::fusion::p_Model::setLogHandler(mosek::msghandler_t _601){
  task_setLogHandler(_601);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _602,double _603) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_602,_603); }void mosek::fusion::p_Model::setSolverParam(const std::string & _602,double _603){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_602,_603);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _604,int _605) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_604,_605); }void mosek::fusion::p_Model::setSolverParam(const std::string & _604,int _605){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_604,_605);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _606,const std::string & _607) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_606,_607); }void mosek::fusion::p_Model::setSolverParam(const std::string & _606,const std::string & _607){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_606,_607);
}
void mosek::fusion::Model :: breakSolver() { mosek::fusion::p_Model::_get_impl(this)->breakSolver(); }void mosek::fusion::p_Model::breakSolver(){
  task_break_solve();
}
void mosek::fusion::Model :: solve() { mosek::fusion::p_Model::_get_impl(this)->solve(); }void mosek::fusion::p_Model::solve(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
  task_solve();
}
void mosek::fusion::Model :: flushSolutions() { mosek::fusion::p_Model::_get_impl(this)->flushSolutions(); }void mosek::fusion::p_Model::flushSolutions(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
}
void mosek::fusion::p_Model::flush_initsol(mosek::fusion::SolutionType _608){
  if ((NULL != initsol_xx.get()))
  {
    {
      try
      {
        {
          monty::rc_ptr< ::mosek::fusion::SolutionStruct > _610 = __mosek_2fusion_2Model__get_sol_cache(_608,true);
          if ((NULL != mosek::fusion::p_SolutionStruct::_get_impl(_610)->xx.get()))
          {
            {
              int _6789 = (int)0;
              int _6790 = (int)((initsol_xx)->size(0));
              for (int _611 = _6789; _611 < _6790; ++_611)
              {
                {
                  if ((!((*initsol_xx_flag)(_611))))
                  {
                    {
                      ((*initsol_xx)(_611)) = ((*mosek::fusion::p_SolutionStruct::_get_impl(_610)->xx)(_611));
                    }
                  }
                  {}
                }
              }
            }
          }
          else
          {
            {
              int _6791 = (int)0;
              int _6792 = (int)((initsol_xx)->size(0));
              for (int _612 = _6791; _612 < _6792; ++_612)
              {
                {
                  if ((!((*initsol_xx_flag)(_612))))
                  {
                    {
                      ((*initsol_xx)(_612)) = 0.0;
                    }
                  }
                  {}
                }
              }
            }
          }
        }
      }
      catch (mosek::fusion::SolutionError _609)
      {
        {
          int _6793 = (int)0;
          int _6794 = (int)((initsol_xx)->size(0));
          for (int _613 = _6793; _613 < _6794; ++_613)
          {
            {
              if ((!((*initsol_xx_flag)(_613))))
              {
                {
                  ((*initsol_xx)(_613)) = 0.0;
                }
              }
              {}
            }
          }
        }
      }
      task_putxx_slice(_608,(int)0,(int)((initsol_xx)->size(0)),initsol_xx);
    }
  }
  {}
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(){
  return _pubthis->getDualSolutionStatus(solutionptr);
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus() { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(){
  return _pubthis->getProblemStatus(solutionptr);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(){
  return _pubthis->getPrimalSolutionStatus(solutionptr);
}
double mosek::fusion::Model :: dualObjValue() { return mosek::fusion::p_Model::_get_impl(this)->dualObjValue(); }double mosek::fusion::p_Model::dualObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,false))->dobj;
}
double mosek::fusion::Model :: primalObjValue() { return mosek::fusion::p_Model::_get_impl(this)->primalObjValue(); }double mosek::fusion::p_Model::primalObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,true))->pobj;
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _614,bool _615,bool _616){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _617 = nullptr;
  mosek::fusion::SolutionType _618 = _614;
  if ((_618 == ::mosek::fusion::SolutionType::Default))
  {
    {
      _618 = solutionptr;
    }
  }
  {}
  if ((_618 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _617 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _617 = sol_bas;
        }
      }
      else
      {
        {
          _617 = sol_itr;
        }
      }
    }
  }
  else if((_618 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _617 = sol_itr;
    }
  }
  else if((_618 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _617 = sol_bas;
    }
  }
  else if((_618 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _617 = sol_itg;
    }
  }
  {}
  if ((NULL == _617.get()))
  {
    {
      throw ::mosek::fusion::SolutionError(std::string ("Solution not available"));
    }
  }
  else
  {
    {
      if ((_616 || ((_615 && _617->isPrimalAcceptable(acceptable_sol)) || ((!_615) && _617->isDualAcceptable(acceptable_sol)))))
      {
        {
          return _617;
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _619 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          mosek::fusion::SolutionStatus _620 = mosek::fusion::p_SolutionStruct::_get_impl(_617)->pstatus;
          if ((!_615))
          {
            {
              _620 = mosek::fusion::p_SolutionStruct::_get_impl(_617)->dstatus;
            }
          }
          {}
          _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Solution status is "));
          if ((_620 == ::mosek::fusion::SolutionStatus::Undefined))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Undefined"));
            }
          }
          else if((_620 == ::mosek::fusion::SolutionStatus::Unknown))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_620 == ::mosek::fusion::SolutionStatus::Optimal))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((_620 == ::mosek::fusion::SolutionStatus::Feasible))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((_620 == ::mosek::fusion::SolutionStatus::Certificate))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" but at least "));
          if ((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Anything))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Anything"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Optimal))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Feasible))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Certificate))
          {
            {
              _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" is expected"));
          throw ::mosek::fusion::SolutionError(_619->toString());
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _621,bool _622){
  return __mosek_2fusion_2Model__get_sol_cache(_621,_622,false);
}
void mosek::fusion::p_Model::setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _623,std::shared_ptr< monty::ndarray< double,1 > > _624){
  _checked_ptr_1<int> _ptr__623(_623 ? _623->raw() : nullptr, _623 ? _623->size(0) : 0);
  _checked_ptr_1<double> _ptr__624(_624 ? _624->raw() : nullptr, _624 ? _624->size(0) : 0);
  ensure_initsol_xx();
  int _6795 = (int)0;
  int _6796 = (int)((_623)->size(0));
  for (int _625 = _6795; _625 < _6796; ++_625)
  {
    {
      ((*initsol_xx)(_ptr__623[_625])) = _ptr__624[_625];
      ((*initsol_xx_flag)(_ptr__623[_625])) = true;
    }
  }
}
void mosek::fusion::p_Model::ensure_initsol_xx(){
  int _626 = (int)((natvarmap_idx)->size(0));
  if ((NULL == initsol_xx.get()))
  {
    {
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_626)));
      std::vector<bool> _6797;
      for (int _627 = (int)0, _6798 = _626; _627 < _6798 ; ++_627)
      {
        _6797.push_back(false);
      }
      auto _6799 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_6797.size()),_6797.begin(),_6797.end()));
      initsol_xx_flag = _6799;
    }
  }
  else if(((int)((initsol_xx)->size(0)) < _626))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _628 = initsol_xx;
      _checked_ptr_1<double> _ptr__628(_628 ? _628->raw() : nullptr,_628 ? _628->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _629 = initsol_xx_flag;
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_626)));
      initsol_xx_flag = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_626)));
      ::mosek::fusion::Utils::Tools::arraycopy(_628,(int)0,initsol_xx,(int)0,_626);
      int _6800 = (int)0;
      int _6801 = _626;
      for (int _630 = _6800; _630 < _6801; ++_630)
      {
        {
          ((*initsol_xx_flag)(_630)) = ((*_629)(_630));
        }
      }
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_bars(mosek::fusion::SolutionType _631){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_631,false))->bars;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_barx(mosek::fusion::SolutionType _632){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_632,false))->barx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_y(mosek::fusion::SolutionType _633){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_633,false))->y;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xc(mosek::fusion::SolutionType _634){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_634,true))->xc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_snx(mosek::fusion::SolutionType _635){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_635,false))->snx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_suc(mosek::fusion::SolutionType _636){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_636,false))->suc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slc(mosek::fusion::SolutionType _637){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_637,false))->slc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_sux(mosek::fusion::SolutionType _638){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_638,false))->sux;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slx(mosek::fusion::SolutionType _639){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_639,false))->slx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_yx(mosek::fusion::SolutionType _640){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_640,true))->yx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xx(mosek::fusion::SolutionType _641){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_641,true))->xx;
}
void mosek::fusion::Model :: selectedSolution(mosek::fusion::SolutionType _642) { mosek::fusion::p_Model::_get_impl(this)->selectedSolution(_642); }void mosek::fusion::p_Model::selectedSolution(mosek::fusion::SolutionType _642){
  solutionptr = _642;
}
mosek::fusion::AccSolutionStatus mosek::fusion::Model :: getAcceptedSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getAcceptedSolutionStatus(); }mosek::fusion::AccSolutionStatus mosek::fusion::p_Model::getAcceptedSolutionStatus(){
  return acceptable_sol;
}
void mosek::fusion::Model :: acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _643) { mosek::fusion::p_Model::_get_impl(this)->acceptedSolutionStatus(_643); }void mosek::fusion::p_Model::acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _643){
  acceptable_sol = _643;
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus(mosek::fusion::SolutionType _644) { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(_644); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(mosek::fusion::SolutionType _644){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _645 = nullptr;
  if ((_644 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _645 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _645 = sol_bas;
        }
      }
      else
      {
        {
          _645 = sol_itr;
        }
      }
    }
  }
  else if((_644 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _645 = sol_itr;
    }
  }
  else if((_644 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _645 = sol_bas;
    }
  }
  else if((_644 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _645 = sol_itg;
    }
  }
  {}
  if ((NULL == _645.get()))
  {
    {
      return ::mosek::fusion::ProblemStatus::Unknown;
    }
  }
  else
  {
    {
      return mosek::fusion::p_SolutionStruct::_get_impl(_645)->probstatus;
    }
  }
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus(mosek::fusion::SolutionType _646) { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(_646); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(mosek::fusion::SolutionType _646){
  return getSolutionStatus(_646,false);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus(mosek::fusion::SolutionType _647) { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(_647); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(mosek::fusion::SolutionType _647){
  return getSolutionStatus(_647,true);
}
mosek::fusion::SolutionStatus mosek::fusion::p_Model::getSolutionStatus(mosek::fusion::SolutionType _648,bool _649){
  try
  {
    {
      monty::rc_ptr< ::mosek::fusion::SolutionStruct > _651 = __mosek_2fusion_2Model__get_sol_cache(_648,_649,true);
      if (_649)
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_651)->pstatus;
        }
      }
      else
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_651)->dstatus;
        }
      }
    }
  }
  catch (mosek::fusion::SolutionError _650)
  {
    {
      return ::mosek::fusion::SolutionStatus::Undefined;
    }
  }
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _652,monty::rc_ptr< ::mosek::fusion::Expression > _653){
  _checked_ptr_1<int> _ptr__652(_652 ? _652->raw() : nullptr, _652 ? _652->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_653)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _654 = ws->popi32();
  int _655 = ws->popi32(_654);
  int _656 = ws->popi32();
  int _657 = ws->popi32();
  bool _658 = ((int)0 != ws->popi32());
  int _659 = ws->popi32(safe_add( _656,(int)1 ));
  int _6802;
  bool _6803 = _658;
  if (_6803)
  {
    _6802 = ws->popi64(_656);
  }
  else
  {
    _6802 = (int)0;
  }
  int _660 = _6802;
  int _661 = ws->popi64(_657);
  int _662 = ws->popf64(_656);
  int _663 = ws->popf64(_657);
  std::shared_ptr< monty::ndarray< int,1 > > _664 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__664(_664 ? _664->raw() : nullptr,_664 ? _664->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _665 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__665(_665 ? _665->raw() : nullptr,_665 ? _665->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _666 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__666(_666 ? _666->raw() : nullptr,_666 ? _666->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _667 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _656,(int)1 ))));
  _checked_ptr_1<long long> _ptr__667(_667 ? _667->raw() : nullptr,_667 ? _667->size(0) : 0);
  int _6804 = (int)0;
  int _6805 = _656;
  for (int _668 = _6804; _668 < _6805; ++_668)
  {
    {
      int _6806 = _ptr__664[safe_add( _659,_668 )];
      int _6807 = _ptr__664[safe_add( safe_add( _659,_668 ),(int)1 )];
      for (int _669 = _6806; _669 < _6807; ++_669)
      {
        {
          if ((_ptr__665[safe_add( _661,_669 )] > (int)0))
          {
            {
              ++ _ptr__667[safe_add( _668,(int)1 )];
            }
          }
          {}
        }
      }
    }
  }
  long long _670 = _ptr__667[_656];
  std::shared_ptr< monty::ndarray< int,1 > > _671 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_670)));
  _checked_ptr_1<int> _ptr__671(_671 ? _671->raw() : nullptr,_671 ? _671->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _672 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_670)));
  _checked_ptr_1<double> _ptr__672(_672 ? _672->raw() : nullptr,_672 ? _672->size(0) : 0);
  int _6808 = (int)0;
  int _6809 = _656;
  for (int _673 = _6808; _673 < _6809; ++_673)
  {
    {
      _ptr__667[safe_add( _673,(int)1 )] += _ptr__667[_673];
    }
  }
  int _674 = (int)0;
  int _6810 = (int)0;
  int _6811 = _656;
  for (int _675 = _6810; _675 < _6811; ++_675)
  {
    {
      int _6812 = _ptr__664[safe_add( _659,_675 )];
      int _6813 = _ptr__664[safe_add( safe_add( _659,_675 ),(int)1 )];
      for (int _676 = _6812; _676 < _6813; ++_676)
      {
        {
          if ((_ptr__665[safe_add( _661,_676 )] > (int)0))
          {
            {
              _ptr__671[_674] = (int)_ptr__665[safe_add( _661,_676 )];
              _ptr__672[_674] = _ptr__666[safe_add( _663,_676 )];
            }
          }
          {}
        }
      }
    }
  }
  task_putarowlist(_652,_667,_671,_672);
  int _677 = (int)0;
  int _6814 = (int)0;
  int _6815 = _656;
  for (int _678 = _6814; _678 < _6815; ++_678)
  {
    {
      if ((((*natconmap_slackidx)(_ptr__652[_678])) > (int)0))
      {
        {
          ++ _677;
        }
      }
      {}
    }
  }
  if ((_677 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _679 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_677)));
      _checked_ptr_1<int> _ptr__679(_679 ? _679->raw() : nullptr,_679 ? _679->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _680 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_677)));
      _checked_ptr_1<int> _ptr__680(_680 ? _680->raw() : nullptr,_680 ? _680->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _681 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_677)));
      _checked_ptr_1<double> _ptr__681(_681 ? _681->raw() : nullptr,_681 ? _681->size(0) : 0);
      int _682 = (int)0;
      int _6816 = (int)0;
      int _6817 = _656;
      for (int _683 = _6816; _683 < _6817; ++_683)
      {
        {
          if ((((*natconmap_slackidx)(_ptr__652[_683])) > (int)0))
          {
            {
              _ptr__679[_682] = _ptr__652[_683];
              _ptr__680[_682] = (int)(((*natconmap_slackidx)(_ptr__652[_683])) - (int)1);
              _ptr__681[_682] = (-1.0);
              ++ _682;
            }
          }
          {}
        }
      }
      task_putaijlist(_679,_680,_681,(long long)(_677));
    }
  }
  {}
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _684,monty::rc_ptr< ::mosek::fusion::Expression > _685,std::shared_ptr< monty::ndarray< int,1 > > _686){
  _checked_ptr_1<int> _ptr__684(_684 ? _684->raw() : nullptr, _684 ? _684->size(0) : 0);
  _checked_ptr_1<int> _ptr__686(_686 ? _686->raw() : nullptr, _686 ? _686->size(0) : 0);
  int _687 = safe_mul( (int)((_684)->size(0)),(int)((_686)->size(0)) );
  std::shared_ptr< monty::ndarray< double,1 > > _688 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_687)));
  _checked_ptr_1<double> _ptr__688(_688 ? _688->raw() : nullptr,_688 ? _688->size(0) : 0);
  std::vector<int> _6818;
  for (int _690 = (int)0, _6819 = (int)((_684)->size(0)); _690 < _6819 ; ++_690)
  {
    for (int _691 = (int)0, _6820 = (int)((_686)->size(0)); _691 < _6820 ; ++_691)
    {
      _6818.push_back(_ptr__684[_690]);
    }
  }
  auto _6821 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6818.size()),_6818.begin(),_6818.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _689 = _6821;
  _checked_ptr_1<int> _ptr__689(_689 ? _689->raw() : nullptr,_689 ? _689->size(0) : 0);
  std::vector<int> _6822;
  for (int _693 = (int)0, _6823 = (int)((_684)->size(0)); _693 < _6823 ; ++_693)
  {
    for (int _694 = (int)0, _6824 = (int)((_686)->size(0)); _694 < _6824 ; ++_694)
    {
      _6822.push_back(_ptr__686[_694]);
    }
  }
  auto _6825 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6822.size()),_6822.begin(),_6822.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _692 = _6825;
  _checked_ptr_1<int> _ptr__692(_692 ? _692->raw() : nullptr,_692 ? _692->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_685)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _695 = ws->popi32();
  int _696 = ws->popi32(_695);
  int _697 = ws->popi32();
  int _698 = ws->popi32();
  bool _699 = ((int)0 != ws->popi32());
  int _700 = ws->popi32(safe_add( _697,(int)1 ));
  int _6826;
  bool _6827 = _699;
  if (_6827)
  {
    _6826 = ws->popi64(_697);
  }
  else
  {
    _6826 = (int)0;
  }
  int _701 = _6826;
  int _702 = ws->popi64(_698);
  int _703 = ws->popf64(_697);
  int _704 = ws->popf64(_698);
  std::shared_ptr< monty::ndarray< int,1 > > _705 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__705(_705 ? _705->raw() : nullptr,_705 ? _705->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _706 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__706(_706 ? _706->raw() : nullptr,_706 ? _706->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _707 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__707(_707 ? _707->raw() : nullptr,_707 ? _707->size(0) : 0);
  int _708 = (int)0;
  int _6828 = (int)0;
  int _6829 = _697;
  for (int _709 = _6828; _709 < _6829; ++_709)
  {
    {
      int _710 = _ptr__705[safe_add( _700,_709 )];
      int _711 = _ptr__705[safe_add( safe_add( _700,_709 ),(int)1 )];
      int _712 = _710;
      int _713 = (int)0;
      while ( ((_713 < (int)((_686)->size(0))) && (_712 < _711)) )
      {
        {
          if ((_ptr__686[_713] < (_ptr__706[safe_add( _702,_712 )] - (int)1)))
          {
            {
              ++ _713;
            }
          }
          else if((_ptr__686[_713] > (_ptr__706[safe_add( _702,_712 )] - (int)1)))
          {
            {
              ++ _712;
            }
          }
          else
          {
            {
              _ptr__688[safe_add( _708,_713 )] = _ptr__707[safe_add( _704,_712 )];
              ++ _713;
              ++ _712;
            }
          }
        }
      }
      _708 += (int)((_686)->size(0));
    }
  }
  task_putaijlist(_689,_692,_688,(long long)(_687));
}
void mosek::fusion::Model :: updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _714,monty::rc_ptr< ::mosek::fusion::Variable > _715) { mosek::fusion::p_Model::_get_impl(this)->updateObjective(_714,_715); }void mosek::fusion::p_Model::updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _714,monty::rc_ptr< ::mosek::fusion::Variable > _715){
  if ((_714->getSize() != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _716 = _715->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _717 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_716)));
  _checked_ptr_1<long long> _ptr__717(_717 ? _717->raw() : nullptr,_717 ? _717->size(0) : 0);
  if ((_716 < _715->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _718 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_716)));
      _checked_ptr_1<long long> _ptr__718(_718 ? _718->raw() : nullptr,_718 ? _718->size(0) : 0);
      _715->inst((int)0,_718,(int)0,_717);
    }
  }
  else
  {
    {
      _715->inst((int)0,_717);
    }
  }
  int _6830 = (int)0;
  int _6831 = _716;
  for (int _719 = _6830; _719 < _6831; ++_719)
  {
    {
      if ((_ptr__717[_719] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  bool _720 = true;
  int _6832 = (int)0;
  int _6833 = (_716 - (int)1);
  for (int _721 = _6832; _721 < _6833; ++_721)
  {
    {
      _720 = (_720 && (_ptr__717[_721] < _ptr__717[(_721 - (int)1)]));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _722 = nullptr;
  _checked_ptr_1<int> _ptr__722(_722 ? _722->raw() : nullptr,_722 ? _722->size(0) : 0);
  if (_720)
  {
    {
      std::vector<int> _6834;
      for (int _723 = (int)0, _6835 = _716; _723 < _6835 ; ++_723)
      {
        _6834.push_back((int)(_ptr__717[_723] - (int)1));
      }
      auto _6836 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6834.size()),_6834.begin(),_6834.end()));
      _722 = _6836;
      _ptr__722.update(_722 ? _722->raw() : nullptr, _722 ? _722->size(0) : 0);
    }
  }
  else
  {
    {
      std::vector<long long> _6837;
      for (int _725 = (-(int)1), _6838 = _716; _725 < _6838 ; ++_725)
      {
        _6837.push_back(_725);
      }
      auto _6839 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6837.size()),_6837.begin(),_6837.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _724 = _6839;
      _checked_ptr_1<long long> _ptr__724(_724 ? _724->raw() : nullptr,_724 ? _724->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_724,_717,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_716));
      std::vector<int> _6840;
      for (int _726 = (int)0, _6841 = _716; _726 < _6841 ; ++_726)
      {
        _6840.push_back((int)(_ptr__717[_ptr__724[_726]] - (int)1));
      }
      auto _6842 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6840.size()),_6840.begin(),_6840.end()));
      _722 = _6842;
      _ptr__722.update(_722 ? _722->raw() : nullptr, _722 ? _722->size(0) : 0);
    }
  }
  int _727 = (int)((_722)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _728 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_727)));
  _checked_ptr_1<double> _ptr__728(_728 ? _728->raw() : nullptr,_728 ? _728->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _729 = _722;
  _checked_ptr_1<int> _ptr__729(_729 ? _729->raw() : nullptr,_729 ? _729->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_714)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _730 = ws->popi32();
  int _731 = ws->popi32(_730);
  int _732 = ws->popi32();
  int _733 = ws->popi32();
  bool _734 = ((int)0 != ws->popi32());
  int _735 = ws->popi32(safe_add( _732,(int)1 ));
  int _6843;
  bool _6844 = _734;
  if (_6844)
  {
    _6843 = ws->popi64(_732);
  }
  else
  {
    _6843 = (int)0;
  }
  int _736 = _6843;
  int _737 = ws->popi64(_733);
  int _738 = ws->popf64(_732);
  int _739 = ws->popf64(_733);
  std::shared_ptr< monty::ndarray< int,1 > > _740 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__740(_740 ? _740->raw() : nullptr,_740 ? _740->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _741 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__741(_741 ? _741->raw() : nullptr,_741 ? _741->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _742 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__742(_742 ? _742->raw() : nullptr,_742 ? _742->size(0) : 0);
  int _743 = (int)0;
  int _6845 = (int)0;
  int _6846 = _732;
  for (int _744 = _6845; _744 < _6846; ++_744)
  {
    {
      int _745 = _ptr__740[safe_add( _735,_744 )];
      int _746 = _ptr__740[safe_add( safe_add( _735,_744 ),(int)1 )];
      int _747 = _745;
      int _748 = (int)0;
      while ( ((_748 < (int)((_722)->size(0))) && (_747 < _746)) )
      {
        {
          if ((_ptr__722[_748] < (_ptr__741[safe_add( _737,_747 )] - (int)1)))
          {
            {
              ++ _748;
            }
          }
          else if((_ptr__722[_748] > (_ptr__741[safe_add( _737,_747 )] - (int)1)))
          {
            {
              ++ _747;
            }
          }
          else
          {
            {
              _ptr__728[safe_add( _743,_748 )] = _ptr__742[safe_add( _739,_747 )];
              ++ _748;
              ++ _747;
            }
          }
        }
      }
      _743 += (int)((_722)->size(0));
    }
  }
  task_putclist(_729,_728);
}
void mosek::fusion::p_Model::objective_(const std::string & _749,mosek::fusion::ObjectiveSense _750,monty::rc_ptr< ::mosek::fusion::Expression > _751){
  task_putobjectivename(_749);
  monty::rc_ptr< ::mosek::fusion::WorkStack > _752 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _753 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_751)).as<::mosek::fusion::Expression>())->eval(_752,_753,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _754 = mosek::fusion::p_WorkStack::_get_impl(_752)->i32;
  _checked_ptr_1<int> _ptr__754(_754 ? _754->raw() : nullptr,_754 ? _754->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _755 = mosek::fusion::p_WorkStack::_get_impl(_752)->i64;
  _checked_ptr_1<long long> _ptr__755(_755 ? _755->raw() : nullptr,_755 ? _755->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _756 = mosek::fusion::p_WorkStack::_get_impl(_752)->f64;
  _checked_ptr_1<double> _ptr__756(_756 ? _756->raw() : nullptr,_756 ? _756->size(0) : 0);
  int _757 = _752->popi32();
  int _758 = (int)1;
  int _6847 = (int)0;
  int _6848 = _757;
  for (int _759 = _6847; _759 < _6848; ++_759)
  {
    {
      _757 *= _752->popi32();
    }
  }
  if ((_758 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _760 = _752->popi32();
  if ((_760 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression for objective"));
    }
  }
  {}
  int _761 = _752->popi32();
  bool _762 = (_752->popi32() != (int)0);
  int _763 = _752->popi32(safe_add( _760,(int)1 ));
  int _764 = _752->popi64(_761);
  int _765 = _752->popf64(_760);
  int _766 = _752->popf64(_761);
  int _767 = (int)0;
  int _768 = (int)0;
  int _6849 = (int)0;
  int _6850 = _761;
  for (int _769 = _6849; _769 < _6850; ++_769)
  {
    {
      if ((_ptr__755[safe_add( _764,_769 )] < (int)0))
      {
        {
          ++ _768;
        }
      }
      else if((_ptr__755[safe_add( _764,_769 )] > (int)0))
      {
        {
          ++ _767;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _770 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_767)));
  _checked_ptr_1<int> _ptr__770(_770 ? _770->raw() : nullptr,_770 ? _770->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _771 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_767)));
  _checked_ptr_1<double> _ptr__771(_771 ? _771->raw() : nullptr,_771 ? _771->size(0) : 0);
  {
    int _772 = (int)0;
    int _6851 = (int)0;
    int _6852 = _761;
    for (int _773 = _6851; _773 < _6852; ++_773)
    {
      {
        if ((_ptr__755[safe_add( _764,_773 )] > (int)0))
        {
          {
            _ptr__770[_772] = (int)(_ptr__755[safe_add( _764,_773 )] - (int)1);
            _ptr__771[_772] = _ptr__756[safe_add( _766,_773 )];
            ++ _772;
          }
        }
        {}
      }
    }
  }
  task_putobjective((_750 == ::mosek::fusion::ObjectiveSense::Maximize),_770,_771,_ptr__756[_765]);
  if ((_768 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _774 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_768)));
      _checked_ptr_1<int> _ptr__774(_774 ? _774->raw() : nullptr,_774 ? _774->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _775 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_768)));
      _checked_ptr_1<int> _ptr__775(_775 ? _775->raw() : nullptr,_775 ? _775->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _776 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_768)));
      _checked_ptr_1<int> _ptr__776(_776 ? _776->raw() : nullptr,_776 ? _776->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _777 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_768)));
      _checked_ptr_1<double> _ptr__777(_777 ? _777->raw() : nullptr,_777 ? _777->size(0) : 0);
      int _6853 = (int)0;
      int _6854 = _768;
      for (int _778 = _6853; _778 < _6854; ++_778)
      {
        {
          long long _779 = (-safe_add( _ptr__755[safe_add( _764,_778 )],(int)1 ));
          _ptr__774[_778] = ((*natbarvar_idx)(_779));
          _ptr__775[_778] = ((*natbarvar_i)(_779));
          _ptr__776[_778] = ((*natbarvar_j)(_779));
          double _6855;
          bool _6856 = (_ptr__775[_778] == _ptr__776[_778]);
          if (_6856)
          {
            _6855 = _ptr__756[safe_add( _766,_778 )];
          }
          else
          {
            _6855 = (0.5 * _ptr__756[safe_add( _766,_778 )]);
          }
          _ptr__777[_778] = _6855;
        }
      }
      task_putbarc(_774,_775,_776,_777);
    }
  }
  {}
}
void mosek::fusion::Model :: objective(double _780) { mosek::fusion::p_Model::_get_impl(this)->objective(_780); }void mosek::fusion::p_Model::objective(double _780){
  objective_(std::string (""),::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_780));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _781,double _782) { mosek::fusion::p_Model::_get_impl(this)->objective(_781,_782); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _781,double _782){
  objective_(std::string (""),_781,::mosek::fusion::p_Expr::constTerm(_782));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _783,monty::rc_ptr< ::mosek::fusion::Expression > _784) { mosek::fusion::p_Model::_get_impl(this)->objective(_783,_784); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _783,monty::rc_ptr< ::mosek::fusion::Expression > _784){
  objective_(std::string (""),_783,_784);
}
void mosek::fusion::Model :: objective(const std::string & _785,double _786) { mosek::fusion::p_Model::_get_impl(this)->objective(_785,_786); }void mosek::fusion::p_Model::objective(const std::string & _785,double _786){
  objective_(_785,::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_786));
}
void mosek::fusion::Model :: objective(const std::string & _787,mosek::fusion::ObjectiveSense _788,double _789) { mosek::fusion::p_Model::_get_impl(this)->objective(_787,_788,_789); }void mosek::fusion::p_Model::objective(const std::string & _787,mosek::fusion::ObjectiveSense _788,double _789){
  objective_(_787,_788,::mosek::fusion::p_Expr::constTerm(_789));
}
void mosek::fusion::Model :: objective(const std::string & _790,mosek::fusion::ObjectiveSense _791,monty::rc_ptr< ::mosek::fusion::Expression > _792) { mosek::fusion::p_Model::_get_impl(this)->objective(_790,_791,_792); }void mosek::fusion::p_Model::objective(const std::string & _790,mosek::fusion::ObjectiveSense _791,monty::rc_ptr< ::mosek::fusion::Expression > _792){
  objective_(_790,_791,_792);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _793,monty::rc_ptr< ::mosek::fusion::ConeDomain > _794) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_793,_794); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _793,monty::rc_ptr< ::mosek::fusion::ConeDomain > _794) { return __mosek_2fusion_2Model__constraint(_793,_794); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _793,monty::rc_ptr< ::mosek::fusion::ConeDomain > _794){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_793,_794);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _795,monty::rc_ptr< ::mosek::fusion::Expression > _796,monty::rc_ptr< ::mosek::fusion::ConeDomain > _797) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_795,_796,_797); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _795,monty::rc_ptr< ::mosek::fusion::Expression > _796,monty::rc_ptr< ::mosek::fusion::ConeDomain > _797) { return __mosek_2fusion_2Model__constraint(_795,_796,_797); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _795,monty::rc_ptr< ::mosek::fusion::Expression > _796,monty::rc_ptr< ::mosek::fusion::ConeDomain > _797){
  return __mosek_2fusion_2Model__constraint_(_795,_796,_797);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _798,monty::rc_ptr< ::mosek::fusion::RangeDomain > _799) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_798,_799); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _798,monty::rc_ptr< ::mosek::fusion::RangeDomain > _799) { return __mosek_2fusion_2Model__constraint(_798,_799); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _798,monty::rc_ptr< ::mosek::fusion::RangeDomain > _799){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_798,_799);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _800,monty::rc_ptr< ::mosek::fusion::Expression > _801,monty::rc_ptr< ::mosek::fusion::RangeDomain > _802) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_800,_801,_802); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _800,monty::rc_ptr< ::mosek::fusion::Expression > _801,monty::rc_ptr< ::mosek::fusion::RangeDomain > _802) { return __mosek_2fusion_2Model__constraint(_800,_801,_802); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _800,monty::rc_ptr< ::mosek::fusion::Expression > _801,monty::rc_ptr< ::mosek::fusion::RangeDomain > _802){
  return __mosek_2fusion_2Model__constraint_(_800,_801,_802);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _803,monty::rc_ptr< ::mosek::fusion::LinearDomain > _804) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_803,_804); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _803,monty::rc_ptr< ::mosek::fusion::LinearDomain > _804) { return __mosek_2fusion_2Model__constraint(_803,_804); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _803,monty::rc_ptr< ::mosek::fusion::LinearDomain > _804){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_803,_804);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _805,monty::rc_ptr< ::mosek::fusion::Expression > _806,monty::rc_ptr< ::mosek::fusion::LinearDomain > _807) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_805,_806,_807); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _805,monty::rc_ptr< ::mosek::fusion::Expression > _806,monty::rc_ptr< ::mosek::fusion::LinearDomain > _807) { return __mosek_2fusion_2Model__constraint(_805,_806,_807); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _805,monty::rc_ptr< ::mosek::fusion::Expression > _806,monty::rc_ptr< ::mosek::fusion::LinearDomain > _807){
  return __mosek_2fusion_2Model__constraint_(_805,_806,_807);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _809) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_808,_809); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _809) { return __mosek_2fusion_2Model__constraint(_808,_809); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _808,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _809){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_808,_809);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _810,monty::rc_ptr< ::mosek::fusion::Expression > _811,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _812) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_810,_811,_812); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _810,monty::rc_ptr< ::mosek::fusion::Expression > _811,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _812) { return __mosek_2fusion_2Model__constraint(_810,_811,_812); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _810,monty::rc_ptr< ::mosek::fusion::Expression > _811,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _812){
  return __mosek_2fusion_2Model__constraint_(_810,_811,_812);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::PSDDomain > _814) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_813,_814); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::PSDDomain > _814) { return __mosek_2fusion_2Model__constraint(_813,_814); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::PSDDomain > _814){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_813,_814);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _815,monty::rc_ptr< ::mosek::fusion::Expression > _816,monty::rc_ptr< ::mosek::fusion::PSDDomain > _817) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_815,_816,_817); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _815,monty::rc_ptr< ::mosek::fusion::Expression > _816,monty::rc_ptr< ::mosek::fusion::PSDDomain > _817) { return __mosek_2fusion_2Model__constraint(_815,_816,_817); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _815,monty::rc_ptr< ::mosek::fusion::Expression > _816,monty::rc_ptr< ::mosek::fusion::PSDDomain > _817){
  return __mosek_2fusion_2Model__constraint_(_815,_816,_817);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _818) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_818); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _818) { return __mosek_2fusion_2Model__variable(_818); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _818){
  return __mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_LinPSDDomain::_get_impl(_818)->shape,_818);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _819,int _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_819,_820,_821); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _819,int _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821) { return __mosek_2fusion_2Model__variable(_819,_820,_821); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _819,int _820,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _821){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_819),(int)(_819),(int)(_820)}),_821);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_822,_823); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) { return __mosek_2fusion_2Model__variable(_822,_823); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_822),(int)(_822)}),_823);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _824,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _825) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_824,_825); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _824,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _825) { return __mosek_2fusion_2Model__variable(_824,_825); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _824,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _825){
  return __mosek_2fusion_2Model__variable_(_824,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_825);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _826,int _827,int _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_826,_827,_828,_829); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _826,int _827,int _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return __mosek_2fusion_2Model__variable(_826,_827,_828,_829); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _826,int _827,int _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829){
  return __mosek_2fusion_2Model__variable_(_826,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_827),(int)(_827),(int)(_828)}),_829);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_830,_831,_832); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) { return __mosek_2fusion_2Model__variable(_830,_831,_832); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832){
  return __mosek_2fusion_2Model__variable_(_830,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_831),(int)(_831)}),_832);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _833,std::shared_ptr< monty::ndarray< int,1 > > _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_833,_834,_835); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _833,std::shared_ptr< monty::ndarray< int,1 > > _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) { return __mosek_2fusion_2Model__variable(_833,_834,_835); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _833,std::shared_ptr< monty::ndarray< int,1 > > _834,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835){
  _checked_ptr_1<int> _ptr__834(_834 ? _834->raw() : nullptr, _834 ? _834->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_833,_834,_835);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _836) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_836); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _836) { return __mosek_2fusion_2Model__variable(_836); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _836){
  return (__mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_PSDDomain::_get_impl(_836)->shape,_836)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _837,int _838,monty::rc_ptr< ::mosek::fusion::PSDDomain > _839) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_837,_838,_839); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _837,int _838,monty::rc_ptr< ::mosek::fusion::PSDDomain > _839) { return __mosek_2fusion_2Model__variable(_837,_838,_839); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _837,int _838,monty::rc_ptr< ::mosek::fusion::PSDDomain > _839){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_837),(int)(_837),(int)(_838)}),_839)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _840,monty::rc_ptr< ::mosek::fusion::PSDDomain > _841) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_840,_841); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _840,monty::rc_ptr< ::mosek::fusion::PSDDomain > _841) { return __mosek_2fusion_2Model__variable(_840,_841); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _840,monty::rc_ptr< ::mosek::fusion::PSDDomain > _841){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_840),(int)(_840)}),_841)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _842,monty::rc_ptr< ::mosek::fusion::PSDDomain > _843) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_842,_843); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _842,monty::rc_ptr< ::mosek::fusion::PSDDomain > _843) { return __mosek_2fusion_2Model__variable(_842,_843); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _842,monty::rc_ptr< ::mosek::fusion::PSDDomain > _843){
  return (__mosek_2fusion_2Model__variable_(_842,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_843)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _844,int _845,int _846,monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_844,_845,_846,_847); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _844,int _845,int _846,monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) { return __mosek_2fusion_2Model__variable(_844,_845,_846,_847); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _844,int _845,int _846,monty::rc_ptr< ::mosek::fusion::PSDDomain > _847){
  return (__mosek_2fusion_2Model__variable_(_844,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_845),(int)(_845),(int)(_846)}),_847)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_848,_849,_850); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) { return __mosek_2fusion_2Model__variable(_848,_849,_850); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850){
  return (__mosek_2fusion_2Model__variable_(_848,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_849),(int)(_849)}),_850)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _851,std::shared_ptr< monty::ndarray< int,1 > > _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_851,_852,_853); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _851,std::shared_ptr< monty::ndarray< int,1 > > _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) { return __mosek_2fusion_2Model__variable(_851,_852,_853); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _851,std::shared_ptr< monty::ndarray< int,1 > > _852,monty::rc_ptr< ::mosek::fusion::PSDDomain > _853){
  _checked_ptr_1<int> _ptr__852(_852 ? _852->raw() : nullptr, _852 ? _852->size(0) : 0);
  return (__mosek_2fusion_2Model__variable_(_851,_852,_853)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _854) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_854); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _854) { return __mosek_2fusion_2Model__variable(_854); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _854){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_854);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _855) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_855); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _855) { return __mosek_2fusion_2Model__variable(_855); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _855){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_855);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _856) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_856); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _856) { return __mosek_2fusion_2Model__variable(_856); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _856){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_856);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _857,monty::rc_ptr< ::mosek::fusion::ConeDomain > _858) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_857,_858); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _857,monty::rc_ptr< ::mosek::fusion::ConeDomain > _858) { return __mosek_2fusion_2Model__variable(_857,_858); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _857,monty::rc_ptr< ::mosek::fusion::ConeDomain > _858){
  _checked_ptr_1<int> _ptr__857(_857 ? _857->raw() : nullptr, _857 ? _857->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_857,_858);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _859,monty::rc_ptr< ::mosek::fusion::RangeDomain > _860) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_859,_860); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _859,monty::rc_ptr< ::mosek::fusion::RangeDomain > _860) { return __mosek_2fusion_2Model__variable(_859,_860); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _859,monty::rc_ptr< ::mosek::fusion::RangeDomain > _860){
  _checked_ptr_1<int> _ptr__859(_859 ? _859->raw() : nullptr, _859 ? _859->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),_859,_860);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _861,monty::rc_ptr< ::mosek::fusion::LinearDomain > _862) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_861,_862); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _861,monty::rc_ptr< ::mosek::fusion::LinearDomain > _862) { return __mosek_2fusion_2Model__variable(_861,_862); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _861,monty::rc_ptr< ::mosek::fusion::LinearDomain > _862){
  _checked_ptr_1<int> _ptr__861(_861 ? _861->raw() : nullptr, _861 ? _861->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_861,_862);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _863) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_863); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _863) { return __mosek_2fusion_2Model__variable(_863); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _863){
  _checked_ptr_1<int> _ptr__863(_863 ? _863->raw() : nullptr, _863 ? _863->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_863,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _864,monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_864,_865); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _864,monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) { return __mosek_2fusion_2Model__variable(_864,_865); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _864,monty::rc_ptr< ::mosek::fusion::ConeDomain > _865){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_864)}),_865);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _866,monty::rc_ptr< ::mosek::fusion::RangeDomain > _867) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_866,_867); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _866,monty::rc_ptr< ::mosek::fusion::RangeDomain > _867) { return __mosek_2fusion_2Model__variable(_866,_867); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _866,monty::rc_ptr< ::mosek::fusion::RangeDomain > _867){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_866)}),_867);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _868,monty::rc_ptr< ::mosek::fusion::LinearDomain > _869) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_868,_869); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _868,monty::rc_ptr< ::mosek::fusion::LinearDomain > _869) { return __mosek_2fusion_2Model__variable(_868,_869); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _868,monty::rc_ptr< ::mosek::fusion::LinearDomain > _869){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_868)}),_869);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _870) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_870); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _870) { return __mosek_2fusion_2Model__variable(_870); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _870){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_870)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable() { return __mosek_2fusion_2Model__variable(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _871,monty::rc_ptr< ::mosek::fusion::ConeDomain > _872) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_871,_872); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _871,monty::rc_ptr< ::mosek::fusion::ConeDomain > _872) { return __mosek_2fusion_2Model__variable(_871,_872); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _871,monty::rc_ptr< ::mosek::fusion::ConeDomain > _872){
  return __mosek_2fusion_2Model__variable_(_871,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_872);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _873,monty::rc_ptr< ::mosek::fusion::RangeDomain > _874) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_873,_874); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _873,monty::rc_ptr< ::mosek::fusion::RangeDomain > _874) { return __mosek_2fusion_2Model__variable(_873,_874); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _873,monty::rc_ptr< ::mosek::fusion::RangeDomain > _874){
  return __mosek_2fusion_2Model__ranged_variable(_873,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_874);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _875,monty::rc_ptr< ::mosek::fusion::LinearDomain > _876) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_875,_876); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _875,monty::rc_ptr< ::mosek::fusion::LinearDomain > _876) { return __mosek_2fusion_2Model__variable(_875,_876); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _875,monty::rc_ptr< ::mosek::fusion::LinearDomain > _876){
  return __mosek_2fusion_2Model__variable_(_875,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_876);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _877,std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::ConeDomain > _879) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_877,_878,_879); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _877,std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::ConeDomain > _879) { return __mosek_2fusion_2Model__variable(_877,_878,_879); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _877,std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::ConeDomain > _879){
  _checked_ptr_1<int> _ptr__878(_878 ? _878->raw() : nullptr, _878 ? _878->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_877,_878,_879);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _880,std::shared_ptr< monty::ndarray< int,1 > > _881,monty::rc_ptr< ::mosek::fusion::RangeDomain > _882) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_880,_881,_882); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _880,std::shared_ptr< monty::ndarray< int,1 > > _881,monty::rc_ptr< ::mosek::fusion::RangeDomain > _882) { return __mosek_2fusion_2Model__variable(_880,_881,_882); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _880,std::shared_ptr< monty::ndarray< int,1 > > _881,monty::rc_ptr< ::mosek::fusion::RangeDomain > _882){
  _checked_ptr_1<int> _ptr__881(_881 ? _881->raw() : nullptr, _881 ? _881->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(_880,_881,_882);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _883,std::shared_ptr< monty::ndarray< int,1 > > _884,monty::rc_ptr< ::mosek::fusion::LinearDomain > _885) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_883,_884,_885); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _883,std::shared_ptr< monty::ndarray< int,1 > > _884,monty::rc_ptr< ::mosek::fusion::LinearDomain > _885) { return __mosek_2fusion_2Model__variable(_883,_884,_885); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _883,std::shared_ptr< monty::ndarray< int,1 > > _884,monty::rc_ptr< ::mosek::fusion::LinearDomain > _885){
  _checked_ptr_1<int> _ptr__884(_884 ? _884->raw() : nullptr, _884 ? _884->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_883,_884,_885);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _886,std::shared_ptr< monty::ndarray< int,1 > > _887) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_886,_887); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _886,std::shared_ptr< monty::ndarray< int,1 > > _887) { return __mosek_2fusion_2Model__variable(_886,_887); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _886,std::shared_ptr< monty::ndarray< int,1 > > _887){
  _checked_ptr_1<int> _ptr__887(_887 ? _887->raw() : nullptr, _887 ? _887->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_886,_887,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _888,int _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_888,_889,_890); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _888,int _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) { return __mosek_2fusion_2Model__variable(_888,_889,_890); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _888,int _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890){
  return __mosek_2fusion_2Model__variable_(_888,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_889)}),_890);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _891,int _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_891,_892,_893); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _891,int _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) { return __mosek_2fusion_2Model__variable(_891,_892,_893); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _891,int _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893){
  return __mosek_2fusion_2Model__ranged_variable(_891,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_892)}),_893);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _894,int _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_894,_895,_896); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _894,int _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) { return __mosek_2fusion_2Model__variable(_894,_895,_896); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _894,int _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896){
  return __mosek_2fusion_2Model__variable_(_894,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_895)}),_896);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _897,int _898) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_897,_898); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _897,int _898) { return __mosek_2fusion_2Model__variable(_897,_898); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _897,int _898){
  return __mosek_2fusion_2Model__variable_(_897,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_898)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _899) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_899); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _899) { return __mosek_2fusion_2Model__variable(_899); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _899){
  return __mosek_2fusion_2Model__variable_(_899,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__ranged_variable(const std::string & _900,std::shared_ptr< monty::ndarray< int,1 > > _901,monty::rc_ptr< ::mosek::fusion::RangeDomain > _902){
  _checked_ptr_1<int> _ptr__901(_901 ? _901->raw() : nullptr, _901 ? _901->size(0) : 0);
  if ((((int)((_900).size()) > (int)0) && hasVariable(_900)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_900)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6857;
  bool _6858 = (NULL != _901.get());
  if (_6858)
  {
    _6857 = _901;
  }
  else
  {
    _6857 = mosek::fusion::p_RangeDomain::_get_impl(_902)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _903 = _6857;
  _checked_ptr_1<int> _ptr__903(_903 ? _903->raw() : nullptr,_903 ? _903->size(0) : 0);
  if (((NULL != mosek::fusion::p_RangeDomain::_get_impl(_902)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_RangeDomain::_get_impl(_902)->shape,_903))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _903.get()))
  {
    {
      _903 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__903.update(_903 ? _903->raw() : nullptr, _903 ? _903->size(0) : 0);
    }
  }
  {}
  int _904 = (int)((_903)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _905 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_904)));
  _checked_ptr_1<int> _ptr__905(_905 ? _905->raw() : nullptr,_905 ? _905->size(0) : 0);
  if ((_904 > (int)0))
  {
    {
      _ptr__905[(_904 - (int)1)] = (int)1;
      int _6859 = (int)1;
      int _6860 = _904;
      for (int _906 = _6859; _906 < _6860; ++_906)
      {
        {
          _ptr__905[((_904 - _906) - (int)1)] = safe_mul( _ptr__905[(_904 - _906)],_ptr__903[(_904 - _906)] );
        }
      }
    }
  }
  {}
  int _907 = (int)1;
  int _6861 = (int)0;
  int _6862 = (int)((_903)->size(0));
  for (int _908 = _6861; _908 < _6862; ++_908)
  {
    {
      _907 *= _ptr__903[_908];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _909 = nullptr;
  _checked_ptr_1<long long> _ptr__909(_909 ? _909->raw() : nullptr,_909 ? _909->size(0) : 0);
  if ((NULL != _909.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(1)) != _904))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      _909 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(0)))));
      _ptr__909.update(_909 ? _909->raw() : nullptr, _909 ? _909->size(0) : 0);
      int _6863 = (int)0;
      int _6864 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(0));
      for (int _910 = _6863; _910 < _6864; ++_910)
      {
        {
          int _6865 = (int)0;
          int _6866 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(1));
          for (int _911 = _6865; _911 < _6866; ++_911)
          {
            {
              if (((((*mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)(_910,_911)) < (int)0) || (((*mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)(_910,_911)) >= _ptr__903[_911])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
                }
              }
              {}
            }
          }
          long long _912 = (int)0;
          int _6867 = (int)0;
          int _6868 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)->size(1));
          for (int _913 = _6867; _913 < _6868; ++_913)
          {
            {
              _912 += safe_mul( _ptr__905[_913],((*mosek::fusion::p_RangeDomain::_get_impl(_902)->sparsity)(_910,_913)) );
            }
          }
          _ptr__909[_910] = _912;
        }
      }
    }
  }
  {}
  int _6869;
  bool _6870 = (NULL != _909.get());
  if (_6870)
  {
    _6869 = (int)((_909)->size(0));
  }
  else
  {
    _6869 = _907;
  }
  int _914 = _6869;
  std::shared_ptr< monty::ndarray< double,1 > > _915;
  _checked_ptr_1<double> _ptr__915(_915 ? _915->raw() : nullptr,_915 ? _915->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _916;
  _checked_ptr_1<double> _ptr__916(_916 ? _916->raw() : nullptr,_916 ? _916->size(0) : 0);
  if (mosek::fusion::p_RangeDomain::_get_impl(_902)->scalable)
  {
    {
      std::vector<double> _6871;
      for (int _917 = (int)0, _6872 = _914; _917 < _6872 ; ++_917)
      {
        _6871.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_902)->lb)((int)0)));
      }
      auto _6873 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6871.size()),_6871.begin(),_6871.end()));
      _915 = _6873;
      _ptr__915.update(_915 ? _915->raw() : nullptr, _915 ? _915->size(0) : 0);
      std::vector<double> _6874;
      for (int _918 = (int)0, _6875 = _914; _918 < _6875 ; ++_918)
      {
        _6874.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_902)->ub)((int)0)));
      }
      auto _6876 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6874.size()),_6874.begin(),_6874.end()));
      _916 = _6876;
      _ptr__916.update(_916 ? _916->raw() : nullptr, _916 ? _916->size(0) : 0);
    }
  }
  else
  {
    {
      _915 = mosek::fusion::p_RangeDomain::_get_impl(_902)->lb;
      _ptr__915.update(_915 ? _915->raw() : nullptr, _915 ? _915->size(0) : 0);
      _916 = mosek::fusion::p_RangeDomain::_get_impl(_902)->ub;
      _ptr__916.update(_916 ? _916->raw() : nullptr, _916 ? _916->size(0) : 0);
    }
  }
  int _919 = natvarmap_alloc(_914);
  std::shared_ptr< monty::ndarray< int,1 > > _920 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_919))));
  _checked_ptr_1<int> _ptr__920(_920 ? _920->raw() : nullptr,_920 ? _920->size(0) : 0);
  natvarmap->get(_919,_920,(int)0);
  int _6877 = (int)0;
  int _6878 = _914;
  for (int _921 = _6877; _921 < _6878; ++_921)
  {
    {
      ((*natvarmap_idx)(_ptr__920[_921])) = _919;
    }
  }
  task_var_putboundlist_ra(_920,_915,_916);
  monty::rc_ptr< ::mosek::fusion::RangedVariable > _922 = ::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::Model::t(_pubthis),_900,(long long)(_919),_903,_909,_920);
  if (mosek::fusion::p_RangeDomain::_get_impl(_902)->cardinal_flag)
  {
    {
      task_var_putintlist(_920);
    }
  }
  {}
  ((*vars)(_919)) = (_922).as<::mosek::fusion::ModelVariable>();
  if (((int)((_900).size()) > (int)0))
  {
    {
      var_map->setItem(_900,_919);
    }
  }
  {}
  return (_922).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _923,std::shared_ptr< monty::ndarray< int,1 > > _924,monty::rc_ptr< ::mosek::fusion::ConeDomain > _925){
  _checked_ptr_1<int> _ptr__924(_924 ? _924->raw() : nullptr, _924 ? _924->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6879;
  bool _6880 = (NULL != _924.get());
  if (_6880)
  {
    _6879 = _924;
  }
  else
  {
    _6879 = mosek::fusion::p_ConeDomain::_get_impl(_925)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _926 = _6879;
  _checked_ptr_1<int> _ptr__926(_926 ? _926->raw() : nullptr,_926 ? _926->size(0) : 0);
  if ((((int)((_923).size()) > (int)0) && hasVariable(_923)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_923)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((NULL == _926.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape"));
    }
  }
  else if(((NULL != mosek::fusion::p_ConeDomain::_get_impl(_925)->shape.get()) && (!::mosek::fusion::p_Set::match(_926,mosek::fusion::p_ConeDomain::_get_impl(_925)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  else if((_925->getAxis() >= (int)((_926)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone dimension"));
    }
  }
  {}
  int _6881;
  bool _6882 = (NULL != mosek::fusion::p_ConeDomain::_get_impl(_925)->shape.get());
  if (_6882)
  {
    _6881 = _925->getAxis();
  }
  else
  {
    _6881 = ((int)((_926)->size(0)) - (int)1);
  }
  int _927 = _6881;
  int _928 = _ptr__926[_927];
  int _929 = (int)((_926)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _930 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_929)));
  _checked_ptr_1<int> _ptr__930(_930 ? _930->raw() : nullptr,_930 ? _930->size(0) : 0);
  _ptr__930[(_929 - (int)1)] = (int)1;
  int _6883 = (int)1;
  int _6884 = _929;
  for (int _931 = _6883; _931 < _6884; ++_931)
  {
    {
      _ptr__930[((_929 - _931) - (int)1)] = safe_mul( _ptr__930[(_929 - _931)],_ptr__926[(_929 - _931)] );
    }
  }
  int _932 = _ptr__926[(int)0];
  int _6885 = (int)1;
  int _6886 = (int)((_926)->size(0));
  for (int _933 = _6885; _933 < _6886; ++_933)
  {
    {
      _932 *= _ptr__926[_933];
    }
  }
  int _934 = (int)1;
  int _6887 = (int)0;
  int _6888 = _927;
  for (int _935 = _6887; _935 < _6888; ++_935)
  {
    {
      _934 *= _ptr__926[_935];
    }
  }
  int _936 = (int)1;
  int _6889 = safe_add( _927,(int)1 );
  int _6890 = _929;
  for (int _937 = _6889; _937 < _6890; ++_937)
  {
    {
      _936 *= _ptr__926[_937];
    }
  }
  int _938 = safe_mul( _934,_936 );
  if ((((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InQCone) && (_928 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_928 < (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_928 != (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_928 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_928 != (int)3)) || ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_928 < (int)2))))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for cone"));
    }
  }
  {}
  int _939 = natvarmap_alloc(_932);
  int _940 = natconemap_alloc(_938);
  ((*natvarmap_type)(_939)) = safe_add( _940,(int)6 );
  std::shared_ptr< monty::ndarray< int,1 > > _941 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_939))));
  _checked_ptr_1<int> _ptr__941(_941 ? _941->raw() : nullptr,_941 ? _941->size(0) : 0);
  natvarmap->get(_939,_941,(int)0);
  int _6891 = (int)0;
  int _6892 = _932;
  for (int _942 = _6891; _942 < _6892; ++_942)
  {
    {
      ((*natvarmap_idx)(_ptr__941[_942])) = _939;
    }
  }
  task_var_putboundlist_fr(_941);
  if (mosek::fusion::p_ConeDomain::_get_impl(_925)->int_flag)
  {
    {
      task_var_putintlist(_941);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _943 = _941;
  _checked_ptr_1<int> _ptr__943(_943 ? _943->raw() : nullptr,_943 ? _943->size(0) : 0);
  if ((_927 < ((int)((_926)->size(0)) - (int)1)))
  {
    {
      _943 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_941)->size(0)))));
      _ptr__943.update(_943 ? _943->raw() : nullptr, _943 ? _943->size(0) : 0);
      int _944 = (int)0;
      int _6893 = (int)0;
      int _6894 = _934;
      for (int _945 = _6893; _945 < _6894; ++_945)
      {
        {
          int _6895 = (int)0;
          int _6896 = _936;
          for (int _946 = _6895; _946 < _6896; ++_946)
          {
            {
              int _6897 = (int)0;
              int _6898 = _928;
              for (int _947 = _6897; _947 < _6898; ++_947)
              {
                {
                  _ptr__943[_944] = _ptr__941[safe_add( safe_mul( safe_add( safe_mul( _945,_928 ),_947 ),_936 ),_946 )];
                  ++ _944;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _948 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_938)));
  _checked_ptr_1<int> _ptr__948(_948 ? _948->raw() : nullptr,_948 ? _948->size(0) : 0);
  natconemap->get(_940,_948,(int)0);
  ((*natconemap_dim)(_940)) = _928;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_948,_928,_938,_943);
    }
  }
  else
  {
    {
      if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
      {
        {
          task_put_rquadcones(_948,_928,_938,_943);
        }
      }
      else
      {
        {
          if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InPExpCone))
          {
            {
              task_put_pexpcones(_948,_928,_938,_943);
            }
          }
          else
          {
            {
              if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InPPowCone))
              {
                {
                  std::vector<double> _6899;
                  for (int _949 = (int)0, _6900 = _938; _949 < _6900 ; ++_949)
                  {
                    _6899.push_back(mosek::fusion::p_ConeDomain::_get_impl(_925)->alpha);
                  }
                  auto _6901 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6899.size()),_6899.begin(),_6899.end()));
                  task_put_ppowcones(_948,_928,_938,_943,_6901);
                }
              }
              else
              {
                {
                  if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InDExpCone))
                  {
                    {
                      task_put_dexpcones(_948,_928,_938,_943);
                    }
                  }
                  else
                  {
                    {
                      if ((mosek::fusion::p_ConeDomain::_get_impl(_925)->key == ::mosek::fusion::QConeKey::InDPowCone))
                      {
                        {
                          std::vector<double> _6902;
                          for (int _950 = (int)0, _6903 = _938; _950 < _6903 ; ++_950)
                          {
                            _6902.push_back(mosek::fusion::p_ConeDomain::_get_impl(_925)->alpha);
                          }
                          auto _6904 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6902.size()),_6902.begin(),_6902.end()));
                          task_put_dpowcones(_948,_928,_938,_943,_6904);
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _6905 = (int)0;
  int _6906 = (int)((_948)->size(0));
  for (int _951 = _6905; _951 < _6906; ++_951)
  {
    {
      task_cone_name(_ptr__948[_951],::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__948[_951])->toString());
    }
  }
  monty::rc_ptr< ::mosek::fusion::ConicVariable > _952 = ::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::Model::t(_pubthis),_923,_939,_926,_941);
  ((*vars)(_939)) = (_952).as<::mosek::fusion::ModelVariable>();
  if (((int)((_923).size()) > (int)0))
  {
    {
      var_map->setItem(_923,_939);
    }
  }
  {}
  return (_952).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _953,std::shared_ptr< monty::ndarray< int,1 > > _954,monty::rc_ptr< ::mosek::fusion::LinearDomain > _955){
  _checked_ptr_1<int> _ptr__954(_954 ? _954->raw() : nullptr, _954 ? _954->size(0) : 0);
  if ((((int)((_953).size()) > (int)0) && hasVariable(_953)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_953)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6907;
  bool _6908 = (NULL != _954.get());
  if (_6908)
  {
    _6907 = _954;
  }
  else
  {
    _6907 = mosek::fusion::p_LinearDomain::_get_impl(_955)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _956 = _6907;
  _checked_ptr_1<int> _ptr__956(_956 ? _956->raw() : nullptr,_956 ? _956->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_955)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_LinearDomain::_get_impl(_955)->shape,_956))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _956.get()))
  {
    {
      _956 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__956.update(_956 ? _956->raw() : nullptr, _956 ? _956->size(0) : 0);
    }
  }
  {}
  int _957 = (int)((_956)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _958 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_957)));
  _checked_ptr_1<int> _ptr__958(_958 ? _958->raw() : nullptr,_958 ? _958->size(0) : 0);
  if ((_957 > (int)0))
  {
    {
      _ptr__958[(_957 - (int)1)] = (int)1;
      int _6909 = (int)1;
      int _6910 = _957;
      for (int _959 = _6909; _959 < _6910; ++_959)
      {
        {
          _ptr__958[((_957 - _959) - (int)1)] = safe_mul( _ptr__958[(_957 - _959)],_ptr__956[(_957 - _959)] );
        }
      }
    }
  }
  {}
  int _960 = (int)1;
  int _6911 = (int)0;
  int _6912 = (int)((_956)->size(0));
  for (int _961 = _6911; _961 < _6912; ++_961)
  {
    {
      _960 *= _ptr__956[_961];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _962 = nullptr;
  _checked_ptr_1<long long> _ptr__962(_962 ? _962->raw() : nullptr,_962 ? _962->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _963 = nullptr;
  _checked_ptr_1<int> _ptr__963(_963 ? _963->raw() : nullptr,_963 ? _963->size(0) : 0);
  if ((NULL != mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)->size(1)) != _957))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      int _964 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)->size(0));
      _962 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_964)));
      _ptr__962.update(_962 ? _962->raw() : nullptr, _962 ? _962->size(0) : 0);
      int _6913 = (int)0;
      int _6914 = _964;
      for (int _965 = _6913; _965 < _6914; ++_965)
      {
        {
          int _6915 = (int)0;
          int _6916 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)->size(1));
          for (int _966 = _6915; _966 < _6916; ++_966)
          {
            {
              if (((((*mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)(_965,_966)) < (int)0) || (((*mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)(_965,_966)) >= _ptr__956[_966])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
                }
              }
              {}
            }
          }
          long long _967 = (int)0;
          int _6917 = (int)0;
          int _6918 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)->size(1));
          for (int _968 = _6917; _968 < _6918; ++_968)
          {
            {
              _967 += safe_mul( _ptr__958[_968],((*mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity)(_965,_968)) );
            }
          }
          _ptr__962[_965] = _967;
        }
      }
      std::shared_ptr< monty::ndarray< int,2 > > _969 = mosek::fusion::p_LinearDomain::_get_impl(_955)->sparsity;
      int _970 = (int)0;
      int _6919 = (int)0;
      int _6920 = _957;
      for (int _971 = _6919; _971 < _6920; ++_971)
      {
        {
          if ((_970 < _ptr__956[_971]))
          {
            {
              _970 = _ptr__956[_971];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _972 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_964)));
      _checked_ptr_1<int> _ptr__972(_972 ? _972->raw() : nullptr,_972 ? _972->size(0) : 0);
      int _6921 = (int)0;
      int _6922 = _964;
      for (int _973 = _6921; _973 < _6922; ++_973)
      {
        {
          _ptr__972[_973] = _973;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _974 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_964)));
      _checked_ptr_1<int> _ptr__974(_974 ? _974->raw() : nullptr,_974 ? _974->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _975 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _970,(int)1 ))));
      _checked_ptr_1<int> _ptr__975(_975 ? _975->raw() : nullptr,_975 ? _975->size(0) : 0);
      int _6923 = (int)0;
      int _6924 = _957;
      for (int _976 = _6923; _976 < _6924; ++_976)
      {
        {
          int _977 = ((_957 - _976) - (int)1);
          int _6925 = (int)0;
          int _6926 = safe_add( _ptr__956[_977],(int)1 );
          for (int _978 = _6925; _978 < _6926; ++_978)
          {
            {
              _ptr__975[_978] = (int)0;
            }
          }
          int _6927 = (int)0;
          int _6928 = _964;
          for (int _979 = _6927; _979 < _6928; ++_979)
          {
            {
              ++ _ptr__975[safe_add( ((*_969)(_979,_977)),(int)1 )];
            }
          }
          int _6929 = (int)0;
          int _6930 = _ptr__956[_977];
          for (int _980 = _6929; _980 < _6930; ++_980)
          {
            {
              _ptr__975[safe_add( _980,(int)1 )] += _ptr__975[_980];
            }
          }
          int _6931 = (int)0;
          int _6932 = _964;
          for (int _981 = _6931; _981 < _6932; ++_981)
          {
            {
              int _982 = _ptr__972[_981];
              _ptr__974[_ptr__975[((*_969)(_982,_977))]] = _982;
              ++ _ptr__975[((*_969)(_982,_977))];
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _983 = _972;
          _checked_ptr_1<int> _ptr__983(_983 ? _983->raw() : nullptr,_983 ? _983->size(0) : 0);
          _972 = _974;
          _ptr__972.update(_972 ? _972->raw() : nullptr, _972 ? _972->size(0) : 0);
          _974 = _983;
          _ptr__974.update(_974 ? _974->raw() : nullptr, _974 ? _974->size(0) : 0);
        }
      }
      int _6933 = (int)0;
      int _6934 = _964;
      for (int _984 = _6933; _984 < _6934; ++_984)
      {
        {
          int _985 = _ptr__972[_984];
          long long _986 = (int)0;
          int _6935 = (int)0;
          int _6936 = _957;
          for (int _987 = _6935; _987 < _6936; ++_987)
          {
            {
              _986 += safe_mul( _ptr__958[_987],((*_969)(_985,_987)) );
            }
          }
          _ptr__962[_984] = _986;
        }
      }
    }
  }
  {}
  int _6937;
  bool _6938 = (NULL != _962.get());
  if (_6938)
  {
    _6937 = (int)((_962)->size(0));
  }
  else
  {
    _6937 = _960;
  }
  int _988 = _6937;
  std::shared_ptr< monty::ndarray< double,1 > > _989 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_988)));
  _checked_ptr_1<double> _ptr__989(_989 ? _989->raw() : nullptr,_989 ? _989->size(0) : 0);
  if ((NULL != mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd)->size(0)) == (int)1))
      {
        {
          int _6939 = (int)0;
          int _6940 = _988;
          for (int _990 = _6939; _990 < _6940; ++_990)
          {
            {
              _ptr__989[_990] = ((*mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd)((int)0));
            }
          }
        }
      }
      else if(((int)((mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd)->size(0)) == _988))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinearDomain::_get_impl(_955)->bnd,(int)0,_989,(int)0,_988);
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid right hand side shape in domain"));
        }
      }
    }
  }
  {}
  int _991 = natvarmap_alloc(_988);
  std::shared_ptr< monty::ndarray< int,1 > > _992 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_991))));
  _checked_ptr_1<int> _ptr__992(_992 ? _992->raw() : nullptr,_992 ? _992->size(0) : 0);
  natvarmap->get(_991,_992,(int)0);
  int _6941 = (int)0;
  int _6942 = _988;
  for (int _993 = _6941; _993 < _6942; ++_993)
  {
    {
      ((*natvarmap_idx)(_ptr__992[_993])) = _991;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_955)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      task_var_putboundlist_fr(_992);
      ((*natvarmap_type)(_991)) = (int)1;
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_955)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      task_var_putboundlist_up(_992,_989);
      ((*natvarmap_type)(_991)) = (int)3;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_955)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      task_var_putboundlist_lo(_992,_989);
      ((*natvarmap_type)(_991)) = (int)2;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_955)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      task_var_putboundlist_fx(_992,_989);
      ((*natvarmap_type)(_991)) = (int)5;
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearVariable > _994 = ::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::Model::t(_pubthis),_953,(long long)(_991),_956,_962,_992);
  if (mosek::fusion::p_LinearDomain::_get_impl(_955)->cardinal_flag)
  {
    {
      task_var_putintlist(_992);
    }
  }
  {}
  ((*vars)(_991)) = (_994).as<::mosek::fusion::ModelVariable>();
  if (((int)((_953).size()) > (int)0))
  {
    {
      var_map->setItem(_953,_991);
    }
  }
  {}
  return (_994).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _995,std::shared_ptr< monty::ndarray< int,1 > > _996,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _997){
  _checked_ptr_1<int> _ptr__996(_996 ? _996->raw() : nullptr, _996 ? _996->size(0) : 0);
  if ((((int)((_995).size()) > (int)0) && hasVariable(_995)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_995)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6943;
  bool _6944 = (NULL != _996.get());
  if (_6944)
  {
    _6943 = _996;
  }
  else
  {
    _6943 = mosek::fusion::p_LinPSDDomain::_get_impl(_997)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _998 = _6943;
  _checked_ptr_1<int> _ptr__998(_998 ? _998->raw() : nullptr,_998 ? _998->size(0) : 0);
  if ((NULL == _998.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  else if((!::mosek::fusion::p_Set::match(mosek::fusion::p_LinPSDDomain::_get_impl(_997)->shape,_998)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  int _999 = (int)((_998)->size(0));
  int _1000 = mosek::fusion::p_LinPSDDomain::_get_impl(_997)->conedim;
  if (((_1000 < (int)0) || (_1000 >= _999)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone direction dimension"));
    }
  }
  {}
  int _1001 = _ptr__998[_1000];
  int _1002 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1001 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1002,safe_add( _1002,(int)1 ) ) / (int)2) != _1001))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1003 = (int)1;
  int _1004 = _ptr__998[_1000];
  int _1005 = (int)1;
  int _6945 = (int)0;
  int _6946 = _1000;
  for (int _1006 = _6945; _1006 < _6946; ++_1006)
  {
    {
      _1005 *= _ptr__998[_1006];
    }
  }
  int _6947 = safe_add( _1000,(int)1 );
  int _6948 = _999;
  for (int _1007 = _6947; _1007 < _6948; ++_1007)
  {
    {
      _1003 *= _ptr__998[_1007];
    }
  }
  int _1008 = safe_mul( _1005,_1003 );
  int _1009 = safe_mul( _1008,_1001 );
  int _1010 = natbarvarmap_alloc(_1008,_1002);
  std::shared_ptr< monty::ndarray< int,1 > > _1011 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1009)));
  _checked_ptr_1<int> _ptr__1011(_1011 ? _1011->raw() : nullptr,_1011 ? _1011->size(0) : 0);
  natbarvarmap_get(_1010,_1011);
  std::shared_ptr< monty::ndarray< long long,1 > > _1012 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1008,_1004 ))));
  _checked_ptr_1<long long> _ptr__1012(_1012 ? _1012->raw() : nullptr,_1012 ? _1012->size(0) : 0);
  {
    int _1013 = (int)0;
    int _6949 = (int)0;
    int _6950 = _1005;
    for (int _1014 = _6949; _1014 < _6950; ++_1014)
    {
      {
        int _6951 = (int)0;
        int _6952 = _1004;
        for (int _1015 = _6951; _1015 < _6952; ++_1015)
        {
          {
            int _6953 = (int)0;
            int _6954 = safe_add( _1015,(int)1 );
            for (int _1016 = _6953; _1016 < _6954; ++_1016)
            {
              {
                int _6955 = (int)0;
                int _6956 = _1003;
                for (int _1017 = _6955; _1017 < _6956; ++_1017)
                {
                  {
                    _ptr__1012[_1013] = safe_add( ((*natbarvar_ptr)(safe_add( safe_mul( _1014,_1003 ),_1017 ))),safe_add( (safe_mul( _1015,((safe_mul( (int)2,_1002 ) - _1015) - (int)1) ) / (int)2),_1016 ) );
                    ++ _1013;
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1018 = ::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::Model::t(_pubthis),_995,_1010,_998,_1000,_1012);
  ((*barvars)(_1010)) = (_1018).as<::mosek::fusion::ModelVariable>();
  if (((int)((_995).size()) > (int)0))
  {
    {
      var_map->setItem(_995,(-safe_add( _1010,(int)1 )));
    }
  }
  {}
  return (_1018).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::SymmetricVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1019,std::shared_ptr< monty::ndarray< int,1 > > _1020,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1021){
  _checked_ptr_1<int> _ptr__1020(_1020 ? _1020->raw() : nullptr, _1020 ? _1020->size(0) : 0);
  if ((((int)((_1019).size()) > (int)0) && hasVariable(_1019)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1019)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1022 = _1020;
  _checked_ptr_1<int> _ptr__1022(_1022 ? _1022->raw() : nullptr,_1022 ? _1022->size(0) : 0);
  if ((NULL == _1022.get()))
  {
    {
      _1022 = mosek::fusion::p_PSDDomain::_get_impl(_1021)->shape;
      _ptr__1022.update(_1022 ? _1022->raw() : nullptr, _1022 ? _1022->size(0) : 0);
    }
  }
  {}
  if ((NULL == _1022.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  {}
  int _1023 = mosek::fusion::p_PSDDomain::_get_impl(_1021)->conedim1;
  int _1024 = mosek::fusion::p_PSDDomain::_get_impl(_1021)->conedim2;
  int _1025 = (int)((_1022)->size(0));
  int _1026 = _ptr__1022[_1023];
  if ((_1023 > _1024))
  {
    {
      int _1027 = _1023;
      _1023 = _1024;
      _1024 = _1027;
    }
  }
  {}
  if (((_1023 == _1024) || ((_1023 < (int)0) || (_1024 >= _1025))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone order dimensions for semidefinite variables"));
    }
  }
  {}
  if ((_ptr__1022[_1023] != _ptr__1022[_1024]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape in cone order dimensions"));
    }
  }
  {}
  int _1028 = (int)1;
  int _6957 = (int)0;
  int _6958 = _1023;
  for (int _1029 = _6957; _1029 < _6958; ++_1029)
  {
    {
      _1028 *= _ptr__1022[_1029];
    }
  }
  int _6959 = safe_add( _1023,(int)1 );
  int _6960 = _1024;
  for (int _1030 = _6959; _1030 < _6960; ++_1030)
  {
    {
      _1028 *= _ptr__1022[_1030];
    }
  }
  int _6961 = safe_add( _1024,(int)1 );
  int _6962 = _1025;
  for (int _1031 = _6961; _1031 < _6962; ++_1031)
  {
    {
      _1028 *= _ptr__1022[_1031];
    }
  }
  int _1032 = (safe_mul( safe_mul( _1028,_1026 ),safe_add( _1026,(int)1 ) ) / (int)2);
  int _1033 = natbarvarmap_alloc(_1028,_1026);
  std::shared_ptr< monty::ndarray< long long,1 > > _1034 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1032)));
  _checked_ptr_1<long long> _ptr__1034(_1034 ? _1034->raw() : nullptr,_1034 ? _1034->size(0) : 0);
  natbarvar_get(_1033,_1034);
  monty::rc_ptr< ::mosek::fusion::PSDVariable > _1035 = ::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::Model::t(_pubthis),_1019,_1033,_1022,mosek::fusion::p_PSDDomain::_get_impl(_1021)->conedim1,mosek::fusion::p_PSDDomain::_get_impl(_1021)->conedim2,_1034);
  ((*barvars)(_1033)) = (_1035).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1019).size()) > (int)0))
  {
    {
      var_map->setItem(_1019,(-safe_add( _1033,(int)1 )));
    }
  }
  {}
  return (_1035).as<::mosek::fusion::SymmetricVariable>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1036,monty::rc_ptr< ::mosek::fusion::Expression > _1037,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1038){
  if ((((int)((_1036).size()) > (int)0) && hasConstraint(_1036)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1036)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1039 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1037)).as<::mosek::fusion::Expression>());
  _1039->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1040 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1040(_1040 ? _1040->raw() : nullptr,_1040 ? _1040->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1041 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1041(_1041 ? _1041->raw() : nullptr,_1041 ? _1041->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1042 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1042(_1042 ? _1042->raw() : nullptr,_1042 ? _1042->size(0) : 0);
  int _1043 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1044 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1045 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1046 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1047 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1048 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1049 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1050 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1051 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  if ((NULL != mosek::fusion::p_RangeDomain::_get_impl(_1038)->shape.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_1038)->shape)->size(0)) != _1043))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
        }
      }
      else
      {
        {
          int _6963 = (int)0;
          int _6964 = _1043;
          for (int _1052 = _6963; _1052 < _6964; ++_1052)
          {
            {
              if ((((*mosek::fusion::p_RangeDomain::_get_impl(_1038)->shape)(_1052)) != _ptr__1040[safe_add( _1044,_1052 )]))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
                }
              }
              {}
            }
          }
        }
      }
    }
  }
  {}
  int _1053 = (int)1;
  int _6965 = (int)0;
  int _6966 = _1043;
  for (int _1054 = _6965; _1054 < _6966; ++_1054)
  {
    {
      _1053 *= _ptr__1040[safe_add( _1044,_1054 )];
    }
  }
  int _1055 = natconmap_alloc(_1053);
  std::shared_ptr< monty::ndarray< int,1 > > _1056 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1053)));
  _checked_ptr_1<int> _ptr__1056(_1056 ? _1056->raw() : nullptr,_1056 ? _1056->size(0) : 0);
  natconmap->get(_1055,_1056,(int)0);
  int _6967 = (int)0;
  int _6968 = _1053;
  for (int _1057 = _6967; _1057 < _6968; ++_1057)
  {
    {
      ((*natconmap_idx)(_ptr__1056[_1057])) = _1055;
      ((*natconmap_slackidx)(_ptr__1056[_1057])) = (int)0;
    }
  }
  ((*natconmap_type)(_1055)) = (int)4;
  putarows(_1056,rs,_1045,_1046,_1048,_1049,_1051);
  std::shared_ptr< monty::ndarray< double,1 > > _1058 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1053)));
  _checked_ptr_1<double> _ptr__1058(_1058 ? _1058->raw() : nullptr,_1058 ? _1058->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1059 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1053)));
  _checked_ptr_1<double> _ptr__1059(_1059 ? _1059->raw() : nullptr,_1059 ? _1059->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1060 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->lb;
  _checked_ptr_1<double> _ptr__1060(_1060 ? _1060->raw() : nullptr,_1060 ? _1060->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1061 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->ub;
  _checked_ptr_1<double> _ptr__1061(_1061 ? _1061->raw() : nullptr,_1061 ? _1061->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _1062 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->sparsity;
  bool _1063 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->scalable;
  std::shared_ptr< monty::ndarray< int,2 > > _1064 = mosek::fusion::p_RangeDomain::_get_impl(_1038)->sparsity;
  {
    if (_1063)
    {
      {
        int _6969 = (int)0;
        int _6970 = _1053;
        for (int _1065 = _6969; _1065 < _6970; ++_1065)
        {
          {
            _ptr__1058[_1065] = (((*mosek::fusion::p_RangeDomain::_get_impl(_1038)->lb)((int)0)) - _ptr__1042[safe_add( _1050,_1065 )]);
            _ptr__1059[_1065] = (((*mosek::fusion::p_RangeDomain::_get_impl(_1038)->ub)((int)0)) - _ptr__1042[safe_add( _1050,_1065 )]);
          }
        }
      }
    }
    else if((NULL != _1064.get()))
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1066 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1043)));
        _checked_ptr_1<int> _ptr__1066(_1066 ? _1066->raw() : nullptr,_1066 ? _1066->size(0) : 0);
        _ptr__1066[(_1043 - (int)1)] = (int)1;
        int _6971 = (int)1;
        int _6972 = _1043;
        for (int _1067 = _6971; _1067 < _6972; ++_1067)
        {
          {
            _ptr__1066[((_1043 - _1067) - (int)1)] = safe_mul( _ptr__1066[(_1043 - _1067)],_ptr__1040[(safe_add( _1044,_1043 ) - _1067)] );
          }
        }
        int _6973 = (int)0;
        int _6974 = _1053;
        for (int _1068 = _6973; _1068 < _6974; ++_1068)
        {
          {
            _ptr__1058[_1068] = (-_ptr__1042[safe_add( _1050,_1068 )]);
            _ptr__1059[_1068] = (-_ptr__1042[safe_add( _1050,_1068 )]);
          }
        }
        int _6975 = (int)0;
        int _6976 = (int)((_1060)->size(0));
        for (int _1069 = _6975; _1069 < _6976; ++_1069)
        {
          {
            int _1070 = (int)0;
            int _6977 = (int)0;
            int _6978 = _1043;
            for (int _1071 = _6977; _1071 < _6978; ++_1071)
            {
              {
                _1070 += safe_mul( _ptr__1066[_1071],((*_1064)(_1069,_1071)) );
              }
            }
            _ptr__1058[_1070] += _ptr__1060[_1069];
            _ptr__1059[_1070] += _ptr__1061[_1069];
          }
        }
      }
    }
    {}
  }
  task_con_putboundlist_ra(_1056,_1058,_1059);
  std::vector<int> _6979;
  for (int _1073 = (int)0, _6980 = _1043; _1073 < _6980 ; ++_1073)
  {
    _6979.push_back(_ptr__1040[safe_add( _1044,_1073 )]);
  }
  auto _6981 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6979.size()),_6979.begin(),_6979.end()));
  monty::rc_ptr< ::mosek::fusion::RangedConstraint > _1072 = ::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::Model::t(_pubthis),_1036,_6981,_1056);
  ((*cons)(_1055)) = (_1072).as<::mosek::fusion::ModelConstraint>();
  return (_1072).as<::mosek::fusion::Constraint>();
}
void mosek::fusion::p_Model::update_constr_expr(std::shared_ptr< monty::ndarray< int,1 > > _1074,std::shared_ptr< monty::ndarray< double,1 > > _1075){
  _checked_ptr_1<int> _ptr__1074(_1074 ? _1074->raw() : nullptr, _1074 ? _1074->size(0) : 0);
  _checked_ptr_1<double> _ptr__1075(_1075 ? _1075->raw() : nullptr, _1075 ? _1075->size(0) : 0);
  int _1076 = (int)((_1074)->size(0));
  int _6982 = (int)0;
  int _6983 = _1076;
  for (int _1077 = _6982; _1077 < _6983; ++_1077)
  {
    {
      ((*natconmap_efix)(_ptr__1074[_1077])) += _ptr__1075[_1077];
    }
  }
  std::vector<double> _6984;
  for (int _1079 = (int)0, _6985 = _1076; _1079 < _6985 ; ++_1079)
  {
    _6984.push_back((((*natconmap_lb)(_ptr__1074[_1079])) - ((*natconmap_efix)(_ptr__1074[_1079]))));
  }
  auto _6986 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6984.size()),_6984.begin(),_6984.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1078 = _6986;
  _checked_ptr_1<double> _ptr__1078(_1078 ? _1078->raw() : nullptr,_1078 ? _1078->size(0) : 0);
  std::vector<double> _6987;
  for (int _1081 = (int)0, _6988 = _1076; _1081 < _6988 ; ++_1081)
  {
    _6987.push_back((((*natconmap_ub)(_ptr__1074[_1081])) - ((*natconmap_efix)(_ptr__1074[_1081]))));
  }
  auto _6989 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6987.size()),_6987.begin(),_6987.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1080 = _6989;
  _checked_ptr_1<double> _ptr__1080(_1080 ? _1080->raw() : nullptr,_1080 ? _1080->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Model.add_constr_expr"));
}
void mosek::fusion::p_Model::putarows(std::shared_ptr< monty::ndarray< int,1 > > _1082,monty::rc_ptr< ::mosek::fusion::WorkStack > _1083,int _1084,int _1085,int _1086,int _1087,int _1088){
  _checked_ptr_1<int> _ptr__1082(_1082 ? _1082->raw() : nullptr, _1082 ? _1082->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1089 = mosek::fusion::p_WorkStack::_get_impl(_1083)->i32;
  _checked_ptr_1<int> _ptr__1089(_1089 ? _1089->raw() : nullptr,_1089 ? _1089->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1090 = mosek::fusion::p_WorkStack::_get_impl(_1083)->i64;
  _checked_ptr_1<long long> _ptr__1090(_1090 ? _1090->raw() : nullptr,_1090 ? _1090->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1091 = mosek::fusion::p_WorkStack::_get_impl(_1083)->f64;
  _checked_ptr_1<double> _ptr__1091(_1091 ? _1091->raw() : nullptr,_1091 ? _1091->size(0) : 0);
  int _1092 = (int)0;
  int _1093 = (int)0;
  int _1094 = (int)0;
  int _6990 = (int)0;
  int _6991 = _1084;
  for (int _1095 = _6990; _1095 < _6991; ++_1095)
  {
    {
      int _1096 = _ptr__1089[safe_add( _1086,_1095 )];
      int _1097 = _ptr__1089[safe_add( safe_add( _1086,_1095 ),(int)1 )];
      int _1098 = _1096;
      while ( ((_1098 < _1097) && (_ptr__1090[safe_add( _1087,_1098 )] < (int)0)) )
      {
        {
          int _1099 = ((*natbarvar_idx)((-safe_add( _ptr__1090[safe_add( _1087,_1098 )],(int)1 ))));
          int _1100 = _1098;
          ++ _1098;
          while ( ((_1098 < _1097) && ((_ptr__1090[safe_add( _1087,_1098 )] < (int)0) && (_1099 == ((*natbarvar_idx)((-safe_add( _ptr__1090[safe_add( _1087,_1098 )],(int)1 ))))))) )
          {
            {
              ++ _1098;
            }
          }
          ++ _1093;
        }
      }
      _1094 += (_1098 - _1096);
      _1092 += (_1097 - _1098);
    }
  }
  int _1101 = (int)((_1082)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1102 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1101,(int)1 ))));
  _checked_ptr_1<long long> _ptr__1102(_1102 ? _1102->raw() : nullptr,_1102 ? _1102->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1103 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1092)));
  _checked_ptr_1<int> _ptr__1103(_1103 ? _1103->raw() : nullptr,_1103 ? _1103->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1104 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1092)));
  _checked_ptr_1<double> _ptr__1104(_1104 ? _1104->raw() : nullptr,_1104 ? _1104->size(0) : 0);
  {
    int _1105 = (int)0;
    int _6992 = (int)0;
    int _6993 = _1084;
    for (int _1106 = _6992; _1106 < _6993; ++_1106)
    {
      {
        int _1107 = (int)0;
        int _6994 = _ptr__1089[safe_add( _1086,_1106 )];
        int _6995 = _ptr__1089[safe_add( safe_add( _1086,_1106 ),(int)1 )];
        for (int _1108 = _6994; _1108 < _6995; ++_1108)
        {
          {
            if ((_ptr__1090[safe_add( _1087,_1108 )] > (int)0))
            {
              {
                _ptr__1103[safe_add( _1105,_1107 )] = (int)(_ptr__1090[safe_add( _1087,_1108 )] - (int)1);
                _ptr__1104[safe_add( _1105,_1107 )] = _ptr__1091[safe_add( _1088,_1108 )];
                ++ _1107;
              }
            }
            {}
          }
        }
        _ptr__1102[safe_add( _1106,(int)1 )] = safe_add( _ptr__1102[_1106],_1107 );
        _1105 += _1107;
      }
    }
  }
  task_putarowlist(_1082,_1102,_1103,_1104);
  if ((_1093 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1109 = _1082;
      _checked_ptr_1<int> _ptr__1109(_1109 ? _1109->raw() : nullptr,_1109 ? _1109->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1110 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1101,(int)1 ))));
      _checked_ptr_1<long long> _ptr__1110(_1110 ? _1110->raw() : nullptr,_1110 ? _1110->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1111 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1093)));
      _checked_ptr_1<int> _ptr__1111(_1111 ? _1111->raw() : nullptr,_1111 ? _1111->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1112 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1093)));
      _checked_ptr_1<int> _ptr__1112(_1112 ? _1112->raw() : nullptr,_1112 ? _1112->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1113 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1093)));
      _checked_ptr_1<long long> _ptr__1113(_1113 ? _1113->raw() : nullptr,_1113 ? _1113->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1114 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1094)));
      _checked_ptr_1<int> _ptr__1114(_1114 ? _1114->raw() : nullptr,_1114 ? _1114->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1115 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1094)));
      _checked_ptr_1<int> _ptr__1115(_1115 ? _1115->raw() : nullptr,_1115 ? _1115->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _1116 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1094)));
      _checked_ptr_1<double> _ptr__1116(_1116 ? _1116->raw() : nullptr,_1116 ? _1116->size(0) : 0);
      int _1117 = (int)0;
      int _1118 = (int)0;
      int _6996 = (int)0;
      int _6997 = _1101;
      for (int _1119 = _6996; _1119 < _6997; ++_1119)
      {
        {
          int _1120 = _ptr__1089[safe_add( _1086,_1119 )];
          int _1121 = _ptr__1089[safe_add( safe_add( _1086,_1119 ),(int)1 )];
          while ( ((_1120 < _1121) && (_ptr__1090[safe_add( _1087,_1120 )] < (int)0)) )
          {
            {
              int _1122 = _1120;
              int _1123 = ((*natbarvar_idx)((-safe_add( _ptr__1090[safe_add( _1087,_1120 )],(int)1 ))));
              while ( ((_1120 < _1121) && ((_ptr__1090[safe_add( _1087,_1120 )] < (int)0) && (((*natbarvar_idx)((-safe_add( _ptr__1090[safe_add( _1087,_1120 )],(int)1 )))) == _1123))) )
              {
                {
                  _ptr__1114[_1118] = ((*natbarvar_i)((-safe_add( _ptr__1090[safe_add( _1087,_1120 )],(int)1 ))));
                  _ptr__1115[_1118] = ((*natbarvar_j)((-safe_add( _ptr__1090[safe_add( _1087,_1120 )],(int)1 ))));
                  if ((_ptr__1114[_1118] == _ptr__1115[_1118]))
                  {
                    {
                      _ptr__1116[_1118] = _ptr__1091[safe_add( _1088,_1120 )];
                    }
                  }
                  else
                  {
                    {
                      _ptr__1116[_1118] = (0.5 * _ptr__1091[safe_add( _1088,_1120 )]);
                    }
                  }
                  ++ _1118;
                  ++ _1120;
                }
              }
              _ptr__1111[_1117] = _1123;
              _ptr__1112[_1117] = ((*natbarvar_dim)(_1123));
              _ptr__1113[_1117] = (_1120 - _1122);
              ++ _1117;
            }
          }
          _1120 = _1121;
          _ptr__1110[safe_add( _1119,(int)1 )] = _1117;
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1124 = task_appendsymmatlist(_1112,_1113,_1114,_1115,_1116);
      _checked_ptr_1<long long> _ptr__1124(_1124 ? _1124->raw() : nullptr,_1124 ? _1124->size(0) : 0);
      task_putbararowlist(_1109,_1110,_1111,_1124);
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1125,monty::rc_ptr< ::mosek::fusion::Expression > _1126,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1127){
  std::shared_ptr< monty::ndarray< int,1 > > _1128 = _1126->getShape();
  _checked_ptr_1<int> _ptr__1128(_1128 ? _1128->raw() : nullptr,_1128 ? _1128->size(0) : 0);
  if (((NULL != mosek::fusion::p_PSDDomain::_get_impl(_1127)->shape.get()) && (!::mosek::fusion::p_Set::match(_1128,mosek::fusion::p_PSDDomain::_get_impl(_1127)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  bool _1129;
  int _1130;
  int _1131;
  if (mosek::fusion::p_PSDDomain::_get_impl(_1127)->axisIsSet)
  {
    {
      _1129 = (mosek::fusion::p_PSDDomain::_get_impl(_1127)->conedim1 < mosek::fusion::p_PSDDomain::_get_impl(_1127)->conedim2);
      int _6998;
      bool _6999 = _1129;
      if (_6999)
      {
        _6998 = mosek::fusion::p_PSDDomain::_get_impl(_1127)->conedim1;
      }
      else
      {
        _6998 = mosek::fusion::p_PSDDomain::_get_impl(_1127)->conedim2;
      }
      _1131 = _6998;
      int _7000;
      bool _7001 = _1129;
      if (_7001)
      {
        _7000 = mosek::fusion::p_PSDDomain::_get_impl(_1127)->conedim2;
      }
      else
      {
        _7000 = mosek::fusion::p_PSDDomain::_get_impl(_1127)->conedim1;
      }
      _1130 = _7000;
    }
  }
  else
  {
    {
      _1129 = true;
      _1131 = ((int)((_1128)->size(0)) - (int)2);
      _1130 = ((int)((_1128)->size(0)) - (int)1);
    }
  }
  if (((_1130 >= (int)((_1128)->size(0))) || (_ptr__1128[_1131] != _ptr__1128[_1130])))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Expression > _7002;
  bool _7003 = (mosek::fusion::p_PSDDomain::_get_impl(_1127)->key == ::mosek::fusion::PSDKey::IsSymPSD);
  if (_7003)
  {
    _7002 = ::mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize(_1131,_1130,_1126).as<::mosek::fusion::Expression>();
  }
  else
  {
    _7002 = _1126;
  }
  monty::rc_ptr< ::mosek::fusion::ExprCompress > _1132 = ::mosek::fusion::p_ExprCompress::_new_ExprCompress((::mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril(_1131,_1130,_7002)).as<::mosek::fusion::Expression>());
  _1132->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1133 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1133(_1133 ? _1133->raw() : nullptr,_1133 ? _1133->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1134 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1134(_1134 ? _1134->raw() : nullptr,_1134 ? _1134->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1135 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1135(_1135 ? _1135->raw() : nullptr,_1135 ? _1135->size(0) : 0);
  int _1136 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1137 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1136)));
  _checked_ptr_1<int> _ptr__1137(_1137 ? _1137->raw() : nullptr,_1137 ? _1137->size(0) : 0);
  rs->popi32(_1136,_1137,(int)0);
  int _1138 = rs->popi32();
  int _1139 = rs->popi32();
  bool _1140 = (rs->popi32() != (int)0);
  int _1141 = rs->popi32(safe_add( _1138,(int)1 ));
  int _7004;
  bool _7005 = _1140;
  if (_7005)
  {
    _7004 = rs->popi64(_1138);
  }
  else
  {
    _7004 = (-(int)99999);
  }
  int _1142 = _7004;
  int _1143 = rs->popi64(_1139);
  int _1144 = rs->popf64(_1138);
  int _1145 = rs->popf64(_1139);
  int _1146 = _ptr__1137[_1130];
  int _1147 = (safe_mul( _1146,safe_add( _1146,(int)1 ) ) / (int)2);
  int _7006 = (int)0;
  int _7007 = _1136;
  for (int _1148 = _7006; _1148 < _7007; ++_1148)
  {
    {
      if (((_1148 != _1131) && (_1148 != _1130)))
      {
        {
          _1147 *= _ptr__1137[_1148];
        }
      }
      {}
    }
  }
  int _1149 = natconmap_alloc(_1147);
  std::shared_ptr< monty::ndarray< int,1 > > _1150 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1147)));
  _checked_ptr_1<int> _ptr__1150(_1150 ? _1150->raw() : nullptr,_1150 ? _1150->size(0) : 0);
  natconmap->get(_1149,_1150,(int)0);
  putarows(_1150,rs,_1138,_1139,_1141,_1143,_1145);
  std::shared_ptr< monty::ndarray< int,1 > > _1151 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__1151(_1151 ? _1151->raw() : nullptr,_1151 ? _1151->size(0) : 0);
  int _7008 = (int)0;
  int _7009 = _1131;
  for (int _1152 = _7008; _1152 < _7009; ++_1152)
  {
    {
      _ptr__1151[(int)0] *= _ptr__1137[_1152];
    }
  }
  _ptr__1151[(int)1] = _ptr__1137[_1131];
  int _7010 = safe_add( _1131,(int)1 );
  int _7011 = _1130;
  for (int _1153 = _7010; _1153 < _7011; ++_1153)
  {
    {
      _ptr__1151[(int)2] *= _ptr__1137[_1153];
    }
  }
  _ptr__1151[(int)3] = _ptr__1137[_1130];
  int _7012 = safe_add( _1130,(int)1 );
  int _7013 = _1136;
  for (int _1154 = _7012; _1154 < _7013; ++_1154)
  {
    {
      _ptr__1151[(int)4] *= _ptr__1137[_1154];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1155 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__1155(_1155 ? _1155->raw() : nullptr,_1155 ? _1155->size(0) : 0);
  _ptr__1155[(int)4] = (int)1;
  int _7014 = (int)1;
  int _7015 = (int)5;
  for (int _1156 = _7014; _1156 < _7015; ++_1156)
  {
    {
      _ptr__1155[(((int)5 - _1156) - (int)1)] = safe_mul( _ptr__1155[((int)5 - _1156)],_ptr__1151[((int)5 - _1156)] );
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1157 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1147)));
  _checked_ptr_1<double> _ptr__1157(_1157 ? _1157->raw() : nullptr,_1157 ? _1157->size(0) : 0);
  if ((_1142 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Unexpected case!"));
    }
  }
  else
  {
    {
      int _7016 = (int)0;
      int _7017 = _1138;
      for (int _1158 = _7016; _1158 < _7017; ++_1158)
      {
        {
          ((*natconmap_efix)(_ptr__1150[_1158])) = _ptr__1135[safe_add( _1144,_1158 )];
          ((*natconmap_lb)(_ptr__1150[_1158])) = (int)0;
          ((*natconmap_ub)(_ptr__1150[_1158])) = (int)0;
          _ptr__1157[_1158] = (-_ptr__1135[safe_add( _1144,_1158 )]);
        }
      }
    }
  }
  task_con_putboundlist_fx(_1150,_1157);
  int _1159 = safe_mul( safe_mul( _ptr__1151[(int)0],_ptr__1151[(int)2] ),_ptr__1151[(int)4] );
  int _1160 = _ptr__1151[(int)1];
  int _1161 = natbarvarmap_alloc(_1159,_1160);
  std::shared_ptr< monty::ndarray< int,1 > > _1162 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1159)));
  _checked_ptr_1<int> _ptr__1162(_1162 ? _1162->raw() : nullptr,_1162 ? _1162->size(0) : 0);
  natbarvarmap_get(_1161,_1162);
  std::vector<int> _7018;
  for (int _1164 = (int)0, _7019 = (safe_mul( _1160,safe_add( _1160,(int)1 ) ) / (int)2); _1164 < _7019 ; ++_1164)
  {
    _7018.push_back(_1160);
  }
  auto _7020 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7018.size()),_7018.begin(),_7018.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1163 = _7020;
  _checked_ptr_1<int> _ptr__1163(_1163 ? _1163->raw() : nullptr,_1163 ? _1163->size(0) : 0);
  std::vector<long long> _7021;
  for (int _1166 = (int)0, _7022 = (safe_mul( _1160,safe_add( _1160,(int)1 ) ) / (int)2); _1166 < _7022 ; ++_1166)
  {
    _7021.push_back((int)1);
  }
  auto _7023 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7021.size()),_7021.begin(),_7021.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1165 = _7023;
  _checked_ptr_1<long long> _ptr__1165(_1165 ? _1165->raw() : nullptr,_1165 ? _1165->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1167 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1160,safe_add( _1160,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1167(_1167 ? _1167->raw() : nullptr,_1167 ? _1167->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1168 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1160,safe_add( _1160,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1168(_1168 ? _1168->raw() : nullptr,_1168 ? _1168->size(0) : 0);
  std::vector<double> _7024;
  for (int _1170 = (int)0, _7025 = (safe_mul( _1160,safe_add( _1160,(int)1 ) ) / (int)2); _1170 < _7025 ; ++_1170)
  {
    _7024.push_back((-1.0));
  }
  auto _7026 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7024.size()),_7024.begin(),_7024.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1169 = _7026;
  _checked_ptr_1<double> _ptr__1169(_1169 ? _1169->raw() : nullptr,_1169 ? _1169->size(0) : 0);
  {
    int _1171 = (int)0;
    int _7027 = (int)0;
    int _7028 = _1160;
    for (int _1172 = _7027; _1172 < _7028; ++_1172)
    {
      {
        int _7029 = (int)0;
        int _7030 = safe_add( _1172,(int)1 );
        for (int _1173 = _7029; _1173 < _7030; ++_1173)
        {
          {
            _ptr__1167[_1171] = _1172;
            _ptr__1168[_1171] = _1173;
            ++ _1171;
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1174 = task_appendsymmatlist(_1163,_1165,_1167,_1168,_1169);
  _checked_ptr_1<long long> _ptr__1174(_1174 ? _1174->raw() : nullptr,_1174 ? _1174->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1175 = _1150;
  _checked_ptr_1<int> _ptr__1175(_1175 ? _1175->raw() : nullptr,_1175 ? _1175->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1176 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1147)));
  _checked_ptr_1<int> _ptr__1176(_1176 ? _1176->raw() : nullptr,_1176 ? _1176->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1177 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1147)));
  _checked_ptr_1<long long> _ptr__1177(_1177 ? _1177->raw() : nullptr,_1177 ? _1177->size(0) : 0);
  {
    int _1178 = (int)0;
    if (_1129)
    {
      {
        int _7031 = (int)0;
        int _7032 = _ptr__1151[(int)0];
        for (int _1179 = _7031; _1179 < _7032; ++_1179)
        {
          {
            int _7033 = (int)0;
            int _7034 = _ptr__1151[(int)1];
            for (int _1180 = _7033; _1180 < _7034; ++_1180)
            {
              {
                int _7035 = (int)0;
                int _7036 = _ptr__1151[(int)2];
                for (int _1181 = _7035; _1181 < _7036; ++_1181)
                {
                  {
                    int _7037 = (int)0;
                    int _7038 = safe_add( _1180,(int)1 );
                    for (int _1182 = _7037; _1182 < _7038; ++_1182)
                    {
                      {
                        int _7039 = (int)0;
                        int _7040 = _ptr__1151[(int)4];
                        for (int _1183 = _7039; _1183 < _7040; ++_1183)
                        {
                          {
                            _ptr__1177[_1178] = _ptr__1174[safe_add( (safe_mul( _1180,safe_add( _1180,(int)1 ) ) / (int)2),_1182 )];
                            _ptr__1176[_1178] = _ptr__1162[safe_add( safe_mul( safe_add( safe_mul( _1179,_ptr__1151[(int)2] ),_1181 ),_ptr__1151[(int)4] ),_1183 )];
                            ((*natconmap_slackidx)(_ptr__1150[_1178])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1176[_1178])),(safe_mul( _1182,((safe_mul( (int)2,_ptr__1151[(int)1] ) - _1182) - (int)1) ) / (int)2) ),_1180 );
                            ++ _1178;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        int _7041 = (int)0;
        int _7042 = _ptr__1151[(int)0];
        for (int _1184 = _7041; _1184 < _7042; ++_1184)
        {
          {
            int _7043 = (int)0;
            int _7044 = _ptr__1151[(int)1];
            for (int _1185 = _7043; _1185 < _7044; ++_1185)
            {
              {
                int _7045 = (int)0;
                int _7046 = _ptr__1151[(int)2];
                for (int _1186 = _7045; _1186 < _7046; ++_1186)
                {
                  {
                    int _7047 = _1185;
                    int _7048 = _ptr__1151[(int)1];
                    for (int _1187 = _7047; _1187 < _7048; ++_1187)
                    {
                      {
                        int _7049 = (int)0;
                        int _7050 = _ptr__1151[(int)4];
                        for (int _1188 = _7049; _1188 < _7050; ++_1188)
                        {
                          {
                            _ptr__1177[_1178] = _ptr__1174[safe_add( (safe_mul( _1187,safe_add( _1187,(int)1 ) ) / (int)2),_1185 )];
                            _ptr__1176[_1178] = _ptr__1162[safe_add( safe_mul( safe_add( safe_mul( _1184,_ptr__1151[(int)2] ),_1186 ),_ptr__1151[(int)4] ),_1188 )];
                            ((*natconmap_slackidx)(_ptr__1150[_1178])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1176[_1178])),(safe_mul( _1185,((safe_mul( (int)2,_ptr__1151[(int)1] ) - _1185) - (int)1) ) / (int)2) ),_1187 );
                            ++ _1178;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  task_putbaraijlist(_1175,_1176,_1177);
  ((*natconmap_type)(_1149)) = (-safe_add( _1161,(int)1 ));
  std::vector<long long> _7051;
  for (int _1190 = (int)0, _7052 = _1147; _1190 < _7052 ; ++_1190)
  {
    _7051.push_back(((*natconmap_slackidx)(_ptr__1150[_1190])));
  }
  auto _7053 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7051.size()),_7051.begin(),_7051.end()));
  monty::rc_ptr< ::mosek::fusion::PSDConstraint > _1189 = ::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::Model::t(_pubthis),_1125,_1149,_1137,_1131,_1130,_7053,_1150);
  ((*cons)(_1149)) = (_1189).as<::mosek::fusion::ModelConstraint>();
  return (_1189).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1191,monty::rc_ptr< ::mosek::fusion::Expression > _1192,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1193){
  if ((((int)((_1191).size()) > (int)0) && hasConstraint(_1191)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1191)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1191).size()) > (int)0) && hasConstraint(_1191)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1191)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1194 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1192)).as<::mosek::fusion::Expression>());
  _1194->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1195 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1195(_1195 ? _1195->raw() : nullptr,_1195 ? _1195->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1196 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1196(_1196 ? _1196->raw() : nullptr,_1196 ? _1196->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1197 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1197(_1197 ? _1197->raw() : nullptr,_1197 ? _1197->size(0) : 0);
  int _1198 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1199 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1198)));
  _checked_ptr_1<int> _ptr__1199(_1199 ? _1199->raw() : nullptr,_1199 ? _1199->size(0) : 0);
  rs->popi32(_1198,_1199,(int)0);
  int _1200 = rs->popi32();
  int _1201 = rs->popi32();
  bool _1202 = (rs->popi32() != (int)0);
  int _1203 = rs->popi32(safe_add( _1200,(int)1 ));
  int _1204 = rs->popi64(_1201);
  int _1205 = rs->popf64(_1200);
  int _1206 = rs->popf64(_1201);
  if (((NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1193)->shape.get()) && (!::mosek::fusion::p_Set::match(_1199,mosek::fusion::p_LinPSDDomain::_get_impl(_1193)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1207 = (int)1;
  int _7054 = (int)0;
  int _7055 = _1198;
  for (int _1208 = _7054; _1208 < _7055; ++_1208)
  {
    {
      _1207 *= _ptr__1199[_1208];
    }
  }
  int _1209 = mosek::fusion::p_LinPSDDomain::_get_impl(_1193)->conedim;
  int _1210 = _ptr__1199[_1209];
  int _1211 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1210 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1211,safe_add( _1211,(int)1 ) ) / (int)2) != _1210))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1212 = (int)1;
  int _7056 = (int)0;
  int _7057 = _1209;
  for (int _1213 = _7056; _1213 < _7057; ++_1213)
  {
    {
      _1212 *= _ptr__1199[_1213];
    }
  }
  int _1214 = (int)1;
  int _7058 = safe_add( _1209,(int)1 );
  int _7059 = _1198;
  for (int _1215 = _7058; _1215 < _7059; ++_1215)
  {
    {
      _1214 *= _ptr__1199[_1215];
    }
  }
  int _1216 = safe_mul( _1212,_1214 );
  int _1217 = natconmap_alloc(_1207);
  std::shared_ptr< monty::ndarray< int,1 > > _1218 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1207)));
  _checked_ptr_1<int> _ptr__1218(_1218 ? _1218->raw() : nullptr,_1218 ? _1218->size(0) : 0);
  natconmap->get(_1217,_1218,(int)0);
  putarows(_1218,rs,_1200,_1201,_1203,_1204,_1206);
  int _1219 = natbarvarmap_alloc(_1216,_1211);
  std::shared_ptr< monty::ndarray< int,1 > > _1220 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1216)));
  _checked_ptr_1<int> _ptr__1220(_1220 ? _1220->raw() : nullptr,_1220 ? _1220->size(0) : 0);
  natbarvarmap_get(_1219,_1220);
  ((*barvars)(_1219)) = nullptr;
  int _1221 = safe_mul( safe_mul( _1210,_1212 ),_1214 );
  std::vector<int> _7060;
  for (int _1223 = (int)0, _7061 = _1210; _1223 < _7061 ; ++_1223)
  {
    _7060.push_back(_1223);
  }
  auto _7062 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7060.size()),_7060.begin(),_7060.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1222 = _7062;
  _checked_ptr_1<int> _ptr__1222(_1222 ? _1222->raw() : nullptr,_1222 ? _1222->size(0) : 0);
  std::vector<long long> _7063;
  for (int _1225 = (int)0, _7064 = _1210; _1225 < _7064 ; ++_1225)
  {
    _7063.push_back((int)1);
  }
  auto _7065 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7063.size()),_7063.begin(),_7063.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1224 = _7065;
  _checked_ptr_1<long long> _ptr__1224(_1224 ? _1224->raw() : nullptr,_1224 ? _1224->size(0) : 0);
  std::vector<double> _7066;
  for (int _1227 = (int)0, _7067 = _1210; _1227 < _7067 ; ++_1227)
  {
    _7066.push_back((-1.0));
  }
  auto _7068 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7066.size()),_7066.begin(),_7066.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1226 = _7068;
  _checked_ptr_1<double> _ptr__1226(_1226 ? _1226->raw() : nullptr,_1226 ? _1226->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1228 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1210)));
  _checked_ptr_1<int> _ptr__1228(_1228 ? _1228->raw() : nullptr,_1228 ? _1228->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1229 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1210)));
  _checked_ptr_1<int> _ptr__1229(_1229 ? _1229->raw() : nullptr,_1229 ? _1229->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1230 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1221)));
  _checked_ptr_1<int> _ptr__1230(_1230 ? _1230->raw() : nullptr,_1230 ? _1230->size(0) : 0);
  {
    int _1231 = (int)0;
    int _7069 = (int)0;
    int _7070 = _1212;
    for (int _1232 = _7069; _1232 < _7070; ++_1232)
    {
      {
        int _7071 = (int)0;
        int _7072 = _1211;
        for (int _1233 = _7071; _1233 < _7072; ++_1233)
        {
          {
            int _7073 = (int)0;
            int _7074 = safe_add( _1233,(int)1 );
            for (int _1234 = _7073; _1234 < _7074; ++_1234)
            {
              {
                int _7075 = (int)0;
                int _7076 = _1214;
                for (int _1235 = _7075; _1235 < _7076; ++_1235)
                {
                  {
                    _ptr__1230[_1231] = safe_add( safe_mul( _1232,_1214 ),_1235 );
                    _ptr__1228[_1231] = _1233;
                    _ptr__1229[_1231] = _1234;
                    ++ _1231;
                  }
                }
              }
            }
          }
        }
      }
    }
    ((*natconmap_type)(_1217)) = (-safe_add( _1219,(int)1 ));
    int _7077 = (int)0;
    int _7078 = _1207;
    for (int _1236 = _7077; _1236 < _7078; ++_1236)
    {
      {
        ((*natconmap_blockid)(_ptr__1218[_1236])) = _1217;
        ((*natconmap_idx)(_ptr__1218[_1236])) = _1236;
        ((*natconmap_efix)(_ptr__1218[_1236])) = _ptr__1197[safe_add( _1205,_1236 )];
        ((*natconmap_lb)(_ptr__1218[_1236])) = (int)0;
        ((*natconmap_ub)(_ptr__1218[_1236])) = (int)0;
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1237 = task_appendsymmatlist(_1222,_1224,_1228,_1229,_1226);
  _checked_ptr_1<long long> _ptr__1237(_1237 ? _1237->raw() : nullptr,_1237 ? _1237->size(0) : 0);
  task_putbaraijlist(_1218,_1230,_1237);
  std::vector<double> _7079;
  for (int _1239 = (int)0, _7080 = _1207; _1239 < _7080 ; ++_1239)
  {
    _7079.push_back((-_ptr__1197[safe_add( _1205,_1239 )]));
  }
  auto _7081 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7079.size()),_7079.begin(),_7079.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1238 = _7081;
  _checked_ptr_1<double> _ptr__1238(_1238 ? _1238->raw() : nullptr,_1238 ? _1238->size(0) : 0);
  task_con_putboundlist_fx(_1218,_1238);
  std::vector<long long> _7082;
  for (int _1241 = (int)0, _7083 = _1207; _1241 < _7083 ; ++_1241)
  {
    _7082.push_back(((*natconmap_slackidx)(_ptr__1218[_1241])));
  }
  auto _7084 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7082.size()),_7082.begin(),_7082.end()));
  monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _1240 = ::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::Model::t(_pubthis),_1191,_1217,_1199,_1209,_1218,_7084);
  ((*cons)(_1217)) = (_1240).as<::mosek::fusion::ModelConstraint>();
  return (_1240).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1242,monty::rc_ptr< ::mosek::fusion::Expression > _1243,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1244){
  if ((((int)((_1242).size()) > (int)0) && hasConstraint(_1242)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1242)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1242).size()) > (int)0) && hasConstraint(_1242)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1242)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1245 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1243)).as<::mosek::fusion::Expression>());
  _1245->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1246 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1246(_1246 ? _1246->raw() : nullptr,_1246 ? _1246->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1247 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1247(_1247 ? _1247->raw() : nullptr,_1247 ? _1247->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1248 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1248(_1248 ? _1248->raw() : nullptr,_1248 ? _1248->size(0) : 0);
  int _1249 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1250 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1251 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1252 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1253 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1254 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1255 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1256 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1257 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7085;
  for (int _1259 = (int)0, _7086 = _1249; _1259 < _7086 ; ++_1259)
  {
    _7085.push_back(_ptr__1246[safe_add( _1250,_1259 )]);
  }
  auto _7087 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7085.size()),_7085.begin(),_7085.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1258 = _7087;
  _checked_ptr_1<int> _ptr__1258(_1258 ? _1258->raw() : nullptr,_1258 ? _1258->size(0) : 0);
  if (((NULL != mosek::fusion::p_ConeDomain::_get_impl(_1244)->shape.get()) && (!::mosek::fusion::p_Set::match(_1258,mosek::fusion::p_ConeDomain::_get_impl(_1244)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _7088;
  bool _7089 = _1244->axisIsSet();
  if (_7089)
  {
    _7088 = _1244->getAxis();
  }
  else
  {
    _7088 = (_1249 - (int)1);
  }
  int _1260 = _7088;
  int _1261 = _ptr__1258[_1260];
  int _1262 = (int)1;
  int _1263 = (int)1;
  int _1264 = (int)1;
  {
    int _7090 = (int)0;
    int _7091 = _1249;
    for (int _1265 = _7090; _1265 < _7091; ++_1265)
    {
      {
        _1264 *= _ptr__1258[_1265];
      }
    }
    int _7092 = (int)0;
    int _7093 = _1260;
    for (int _1266 = _7092; _1266 < _7093; ++_1266)
    {
      {
        _1263 *= _ptr__1258[_1266];
      }
    }
    int _7094 = safe_add( _1260,(int)1 );
    int _7095 = _1249;
    for (int _1267 = _7094; _1267 < _7095; ++_1267)
    {
      {
        _1262 *= _ptr__1258[_1267];
      }
    }
  }
  int _1268 = safe_mul( _1263,_1262 );
  if (((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InQCone) && (_1261 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1261)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_1261 < (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1261)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for rotated quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_1261 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1261)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_1261 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1261)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for power cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_1261 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1261)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_1261 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1261)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual power cone"))->toString());
    }
  }
  {}
  int _1269 = natvarmap_alloc(_1264);
  std::shared_ptr< monty::ndarray< int,1 > > _1270 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1264)));
  _checked_ptr_1<int> _ptr__1270(_1270 ? _1270->raw() : nullptr,_1270 ? _1270->size(0) : 0);
  natvarmap->get(_1269,_1270,(int)0);
  int _1271 = natconemap_alloc(_1268);
  int _7096 = (int)0;
  int _7097 = _1264;
  for (int _1272 = _7096; _1272 < _7097; ++_1272)
  {
    {
      ((*natvarmap_idx)(_ptr__1270[_1272])) = _1269;
    }
  }
  task_var_putboundlist_fr(_1270);
  std::shared_ptr< monty::ndarray< int,1 > > _7098;
  bool _7099 = (_1260 < ((int)((_1258)->size(0)) - (int)1));
  if (_7099)
  {
    _7098 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_1270)->size(0)))));
  }
  else
  {
    _7098 = _1270;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1273 = _7098;
  _checked_ptr_1<int> _ptr__1273(_1273 ? _1273->raw() : nullptr,_1273 ? _1273->size(0) : 0);
  if ((_1260 < ((int)((_1258)->size(0)) - (int)1)))
  {
    {
      int _1274 = (int)0;
      int _7100 = (int)0;
      int _7101 = _1263;
      for (int _1275 = _7100; _1275 < _7101; ++_1275)
      {
        {
          int _7102 = (int)0;
          int _7103 = _1262;
          for (int _1276 = _7102; _1276 < _7103; ++_1276)
          {
            {
              int _7104 = (int)0;
              int _7105 = _1261;
              for (int _1277 = _7104; _1277 < _7105; ++_1277)
              {
                {
                  _ptr__1273[_1274] = _ptr__1270[safe_add( safe_mul( safe_add( safe_mul( _1275,_1261 ),_1277 ),_1262 ),_1276 )];
                  ++ _1274;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1278 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1268)));
  _checked_ptr_1<int> _ptr__1278(_1278 ? _1278->raw() : nullptr,_1278 ? _1278->size(0) : 0);
  natconemap->get(_1271,_1278,(int)0);
  ((*natconemap_dim)(_1271)) = _1261;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_1278,_1261,_1268,_1273);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
  {
    {
      task_put_rquadcones(_1278,_1261,_1268,_1273);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InPExpCone))
  {
    {
      task_put_pexpcones(_1278,_1261,_1268,_1273);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InPPowCone))
  {
    {
      std::vector<double> _7106;
      for (int _1279 = (int)0, _7107 = _1268; _1279 < _7107 ; ++_1279)
      {
        _7106.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1244)->alpha);
      }
      auto _7108 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7106.size()),_7106.begin(),_7106.end()));
      task_put_ppowcones(_1278,_1261,_1268,_1273,_7108);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InDExpCone))
  {
    {
      task_put_dexpcones(_1278,_1261,_1268,_1273);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1244)->key == ::mosek::fusion::QConeKey::InDPowCone))
  {
    {
      std::vector<double> _7109;
      for (int _1280 = (int)0, _7110 = _1268; _1280 < _7110 ; ++_1280)
      {
        _7109.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1244)->alpha);
      }
      auto _7111 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7109.size()),_7109.begin(),_7109.end()));
      task_put_dpowcones(_1278,_1261,_1268,_1273,_7111);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal error: Invalid cone type"));
    }
  }
  ((*vars)(_1269)) = nullptr;
  std::shared_ptr< monty::ndarray< double,1 > > _1281 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1264)));
  _checked_ptr_1<double> _ptr__1281(_1281 ? _1281->raw() : nullptr,_1281 ? _1281->size(0) : 0);
  int _1282 = natconmap_alloc(_1264);
  std::shared_ptr< monty::ndarray< int,1 > > _1283 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1264)));
  _checked_ptr_1<int> _ptr__1283(_1283 ? _1283->raw() : nullptr,_1283 ? _1283->size(0) : 0);
  natconmap->get(_1282,_1283,(int)0);
  ((*natconmap_type)(_1282)) = safe_add( _1269,(int)6 );
  {
    int _7112 = (int)0;
    int _7113 = _1264;
    for (int _1284 = _7112; _1284 < _7113; ++_1284)
    {
      {
        ((*natconmap_efix)(_ptr__1283[_1284])) = _ptr__1248[safe_add( _1256,_1284 )];
      }
    }
    int _7114 = (int)0;
    int _7115 = _1264;
    for (int _1285 = _7114; _1285 < _7115; ++_1285)
    {
      {
        ((*natconmap_lb)(_ptr__1283[_1285])) = (int)0;
      }
    }
    int _7116 = (int)0;
    int _7117 = _1264;
    for (int _1286 = _7116; _1286 < _7117; ++_1286)
    {
      {
        ((*natconmap_ub)(_ptr__1283[_1286])) = (int)0;
      }
    }
    int _7118 = (int)0;
    int _7119 = _1264;
    for (int _1287 = _7118; _1287 < _7119; ++_1287)
    {
      {
        _ptr__1281[_1287] = (-_ptr__1248[safe_add( _1256,_1287 )]);
      }
    }
    int _7120 = (int)0;
    int _7121 = _1264;
    for (int _1288 = _7120; _1288 < _7121; ++_1288)
    {
      {
        ((*natconmap_slackidx)(_ptr__1283[_1288])) = safe_add( _ptr__1270[_1288],(int)1 );
      }
    }
    int _7122 = (int)0;
    int _7123 = _1264;
    for (int _1289 = _7122; _1289 < _7123; ++_1289)
    {
      {
        ((*natconmap_blockid)(_ptr__1283[_1289])) = _1282;
      }
    }
    int _7124 = (int)0;
    int _7125 = _1264;
    for (int _1290 = _7124; _1290 < _7125; ++_1290)
    {
      {
        ((*natconmap_idx)(_ptr__1283[_1290])) = _1290;
      }
    }
  }
  putarows(_1283,rs,_1251,_1252,_1254,_1255,_1257);
  task_con_putboundlist_fx(_1283,_1281);
  std::vector<double> _7126;
  for (int _1291 = (int)0, _7127 = (int)((_1283)->size(0)); _1291 < _7127 ; ++_1291)
  {
    _7126.push_back((-1.0));
  }
  auto _7128 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7126.size()),_7126.begin(),_7126.end()));
  task_putaijlist(_1283,_1270,_7128,(long long)((int)((_1283)->size(0))));
  monty::rc_ptr< ::mosek::fusion::ConicConstraint > _1292 = ::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::Model::t(_pubthis),_1242,_1244,_1258,_1282,_1283,_1270);
  ((*cons)(_1282)) = (_1292).as<::mosek::fusion::ModelConstraint>();
  return (_1292).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1293,monty::rc_ptr< ::mosek::fusion::Expression > _1294,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1295){
  if ((((int)((_1293).size()) > (int)0) && hasConstraint(_1293)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1293)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1296 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1294)).as<::mosek::fusion::Expression>());
  _1296->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1297 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1297(_1297 ? _1297->raw() : nullptr,_1297 ? _1297->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1298 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1298(_1298 ? _1298->raw() : nullptr,_1298 ? _1298->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1299 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1299(_1299 ? _1299->raw() : nullptr,_1299 ? _1299->size(0) : 0);
  int _1300 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1301 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1302 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1303 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1304 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1305 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1306 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1307 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1308 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7129;
  for (int _1310 = (int)0, _7130 = _1300; _1310 < _7130 ; ++_1310)
  {
    _7129.push_back(_ptr__1297[safe_add( _1301,_1310 )]);
  }
  auto _7131 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7129.size()),_7129.begin(),_7129.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1309 = _7131;
  _checked_ptr_1<int> _ptr__1309(_1309 ? _1309->raw() : nullptr,_1309 ? _1309->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1295)->shape.get()) && (!::mosek::fusion::p_Set::match(_1309,mosek::fusion::p_LinearDomain::_get_impl(_1295)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1311 = (int)1;
  int _7132 = (int)0;
  int _7133 = _1300;
  for (int _1312 = _7132; _1312 < _7133; ++_1312)
  {
    {
      _1311 *= _ptr__1309[_1312];
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1313;
  _checked_ptr_1<double> _ptr__1313(_1313 ? _1313->raw() : nullptr,_1313 ? _1313->size(0) : 0);
  int _1314 = natconmap_alloc(_1311);
  std::shared_ptr< monty::ndarray< int,1 > > _1315 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1311)));
  _checked_ptr_1<int> _ptr__1315(_1315 ? _1315->raw() : nullptr,_1315 ? _1315->size(0) : 0);
  natconmap->get(_1314,_1315,(int)0);
  putarows(_1315,rs,_1302,_1303,_1305,_1306,_1308);
  {
    std::shared_ptr< monty::ndarray< int,2 > > _1316 = mosek::fusion::p_LinearDomain::_get_impl(_1295)->sparsity;
    std::shared_ptr< monty::ndarray< double,1 > > _1317 = mosek::fusion::p_LinearDomain::_get_impl(_1295)->bnd;
    _checked_ptr_1<double> _ptr__1317(_1317 ? _1317->raw() : nullptr,_1317 ? _1317->size(0) : 0);
    bool _1318 = mosek::fusion::p_LinearDomain::_get_impl(_1295)->scalable;
    std::shared_ptr< monty::ndarray< double,1 > > _1319 = natconmap_efix;
    _checked_ptr_1<double> _ptr__1319(_1319 ? _1319->raw() : nullptr,_1319 ? _1319->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1320 = natconmap_lb;
    _checked_ptr_1<double> _ptr__1320(_1320 ? _1320->raw() : nullptr,_1320 ? _1320->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1321 = natconmap_ub;
    _checked_ptr_1<double> _ptr__1321(_1321 ? _1321->raw() : nullptr,_1321 ? _1321->size(0) : 0);
    {
      int _7134 = (int)0;
      int _7135 = _1302;
      for (int _1322 = _7134; _1322 < _7135; ++_1322)
      {
        {
          _ptr__1319[_ptr__1315[_1322]] = _ptr__1299[safe_add( _1307,_1322 )];
        }
      }
      if ((NULL == _1317.get()))
      {
        {
          int _7136 = (int)0;
          int _7137 = _1302;
          for (int _1323 = _7136; _1323 < _7137; ++_1323)
          {
            {
              _ptr__1320[_ptr__1315[_1323]] = (int)0;
              _ptr__1321[_ptr__1315[_1323]] = (int)0;
            }
          }
        }
      }
      else if(_1318)
      {
        {
          int _7138 = (int)0;
          int _7139 = _1302;
          for (int _1324 = _7138; _1324 < _7139; ++_1324)
          {
            {
              _ptr__1320[_ptr__1315[_1324]] = _ptr__1317[(int)0];
              _ptr__1321[_ptr__1315[_1324]] = _ptr__1317[(int)0];
            }
          }
        }
      }
      else if((NULL != _1316.get()))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1325 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1300)));
          _checked_ptr_1<int> _ptr__1325(_1325 ? _1325->raw() : nullptr,_1325 ? _1325->size(0) : 0);
          _ptr__1325[(_1300 - (int)1)] = (int)1;
          int _7140 = (int)1;
          int _7141 = _1300;
          for (int _1326 = _7140; _1326 < _7141; ++_1326)
          {
            {
              _ptr__1325[((_1300 - _1326) - (int)1)] = safe_mul( _ptr__1325[(_1300 - _1326)],_ptr__1309[(_1300 - _1326)] );
            }
          }
          int _7142 = (int)0;
          int _7143 = (int)((_1316)->size(0));
          for (int _1327 = _7142; _1327 < _7143; ++_1327)
          {
            {
              int _1328 = (int)0;
              int _7144 = (int)0;
              int _7145 = _1300;
              for (int _1329 = _7144; _1329 < _7145; ++_1329)
              {
                {
                  _1328 += safe_mul( _ptr__1325[_1329],((*_1316)(_1327,_1329)) );
                }
              }
              _ptr__1320[_ptr__1315[_1328]] = _ptr__1317[_1327];
              _ptr__1321[_ptr__1315[_1328]] = _ptr__1317[_1327];
            }
          }
        }
      }
      else
      {
        {
          int _7146 = (int)0;
          int _7147 = _1302;
          for (int _1330 = _7146; _1330 < _7147; ++_1330)
          {
            {
              _ptr__1320[_ptr__1315[_1330]] = _ptr__1317[_1330];
              _ptr__1321[_ptr__1315[_1330]] = _ptr__1317[_1330];
            }
          }
        }
      }
    }
    std::vector<double> _7148;
    for (int _1331 = (int)0, _7149 = (int)((_1315)->size(0)); _1331 < _7149 ; ++_1331)
    {
      _7148.push_back((_ptr__1320[_ptr__1315[_1331]] - _ptr__1319[_ptr__1315[_1331]]));
    }
    auto _7150 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7148.size()),_7148.begin(),_7148.end()));
    _1313 = _7150;
    _ptr__1313.update(_1313 ? _1313->raw() : nullptr, _1313 ? _1313->size(0) : 0);
  }
  int _7151 = (int)0;
  int _7152 = _1311;
  for (int _1332 = _7151; _1332 < _7152; ++_1332)
  {
    {
      ((*natconmap_idx)(_ptr__1315[_1332])) = _1314;
      ((*natconmap_slackidx)(_ptr__1315[_1332])) = (int)0;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1295)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      ((*natconmap_type)(_1314)) = (int)1;
      task_con_putboundlist_fr(_1315);
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1295)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      ((*natconmap_type)(_1314)) = (int)3;
      task_con_putboundlist_up(_1315,_1313);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1295)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      ((*natconmap_type)(_1314)) = (int)2;
      task_con_putboundlist_lo(_1315,_1313);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1295)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      ((*natconmap_type)(_1314)) = (int)5;
      task_con_putboundlist_fx(_1315,_1313);
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearConstraint > _1333 = ::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::Model::t(_pubthis),_1293,_1314,_1309,_1315);
  ((*cons)(_1314)) = (_1333).as<::mosek::fusion::ModelConstraint>();
  return (_1333).as<::mosek::fusion::Constraint>();
}
bool mosek::fusion::Model :: hasConstraint(const std::string & _1334) { return mosek::fusion::p_Model::_get_impl(this)->hasConstraint(_1334); }bool mosek::fusion::p_Model::hasConstraint(const std::string & _1334){
  return con_map->hasItem(_1334);
}
bool mosek::fusion::Model :: hasVariable(const std::string & _1335) { return mosek::fusion::p_Model::_get_impl(this)->hasVariable(_1335); }bool mosek::fusion::p_Model::hasVariable(const std::string & _1335){
  return var_map->hasItem(_1335);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(int _1336) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1336); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(int _1336) { return __mosek_2fusion_2Model__getConstraint(_1336); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(int _1336){
  return (((*cons)(_1336))).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(const std::string & _1337) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1337); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(const std::string &  _1337) { return __mosek_2fusion_2Model__getConstraint(_1337); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(const std::string & _1337){
  monty::rc_ptr< ::mosek::fusion::ModelConstraint > _7153;
  bool _7154 = con_map->hasItem(_1337);
  if (_7154)
  {
    _7153 = ((*cons)(con_map->getItem(_1337)));
  }
  else
  {
    _7153 = nullptr;
  }
  return (_7153).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(int _1338) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1338); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(int _1338) { return __mosek_2fusion_2Model__getVariable(_1338); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(int _1338){
  return (((*vars)(_1338))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(const std::string & _1339) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1339); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(const std::string &  _1339) { return __mosek_2fusion_2Model__getVariable(_1339); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(const std::string & _1339){
  if (var_map->hasItem(_1339))
  {
    {
      int _1340 = var_map->getItem(_1339);
      if ((_1340 < (int)0))
      {
        {
          return (((*barvars)((-safe_add( _1340,(int)1 ))))).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          return (((*vars)(_1340))).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
  else
  {
    {
      return nullptr;
    }
  }
}
std::string mosek::fusion::Model :: getName() { return mosek::fusion::p_Model::_get_impl(this)->getName(); }std::string mosek::fusion::p_Model::getName(){
  return model_name;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model :: __mosek_2fusion_2Model__clone() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__clone(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model::clone() { return __mosek_2fusion_2Model__clone(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Model::__mosek_2fusion_2Model__clone(){
  return ::mosek::fusion::p_Model::_new_Model(::mosek::fusion::Model::t(_pubthis));
}
void mosek::fusion::p_Model::destroy(){xs.reset();ws.reset();rs.reset();con_map.reset();cons.reset();natconmap_type.reset();natconmap_ub.reset();natconmap_lb.reset();natconmap_efix.reset();natconmap_idx.reset();natconmap_slackidx.reset();natconmap_blockid.reset();natconmap.reset();initsol_xx_flag.reset();initsol_xx.reset();var_map.reset();barvars.reset();natbarvarmap_ptr.reset();natbarvarmap_num.reset();natbarvar_dim.reset();natbarvar_ptr.reset();natbarvar_j.reset();natbarvar_i.reset();natbarvar_idx.reset();natvarmap_type.reset();natconemap_dim.reset();natconemap.reset();vars.reset();natvarmap_idx.reset();natvarmap_blockid.reset();natvarmap.reset();}void mosek::fusion::Model::destroy() { mosek::fusion::p_Model::_get_impl(this)->destroy(); }mosek::fusion::SliceVariable::SliceVariable(mosek::fusion::p_SliceVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "SliceVariable()" << this << std::endl; */ }mosek::fusion::SliceVariable::~SliceVariable() {  /* std::cout << "~SliceVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceVariable::p_SliceVariable  (::mosek::fusion::SliceVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceVariable::t mosek::fusion::p_SliceVariable::_new_SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1341,    std::shared_ptr< monty::ndarray< int,1 > > _1342,    std::shared_ptr< monty::ndarray< long long,1 > > _1343,    std::shared_ptr< monty::ndarray< long long,1 > > _1344){ return new mosek::fusion::SliceVariable(_1341,_1342,_1343,_1344); }mosek::fusion::SliceVariable::SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1341,    std::shared_ptr< monty::ndarray< int,1 > > _1342,    std::shared_ptr< monty::ndarray< long long,1 > > _1343,    std::shared_ptr< monty::ndarray< long long,1 > > _1344) :    SliceVariable(new mosek::fusion::p_SliceVariable(this)){ mosek::fusion::p_SliceVariable::_get_impl(this)->_initialize(_1341,_1342,_1343,_1344); }void mosek::fusion::p_SliceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1341,    std::shared_ptr< monty::ndarray< int,1 > > _1342,    std::shared_ptr< monty::ndarray< long long,1 > > _1343,    std::shared_ptr< monty::ndarray< long long,1 > > _1344){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1342(_1342 ? _1342->raw() : nullptr, _1342 ? _1342->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1343(_1343 ? _1343->raw() : nullptr, _1343 ? _1343->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1344(_1344 ? _1344->raw() : nullptr, _1344 ? _1344->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1341,_1342,_1343,_1344);
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->nativeidxs = _1344;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->sparsity = _1343;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->shape = _1342;
  }
}void mosek::fusion::p_SliceVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::SliceVariable::destroy() { mosek::fusion::p_SliceVariable::_get_impl(this)->destroy(); }mosek::fusion::SymRangedVariable::SymRangedVariable(mosek::fusion::p_SymRangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymRangedVariable()" << this << std::endl; */ }mosek::fusion::SymRangedVariable::~SymRangedVariable() {  /* std::cout << "~SymRangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymRangedVariable::p_SymRangedVariable  (::mosek::fusion::SymRangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1345,    monty::rc_ptr< ::mosek::fusion::Model > _1346){ return new mosek::fusion::SymRangedVariable(_1345,_1346); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1345,    monty::rc_ptr< ::mosek::fusion::Model > _1346) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1345,_1346); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1345,    monty::rc_ptr< ::mosek::fusion::Model > _1346){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1345,_1346);
    names_flushed = mosek::fusion::p_SymRangedVariable::_get_impl(_1345)->names_flushed;
    name = mosek::fusion::p_SymRangedVariable::_get_impl(_1345)->name;
    sparsity = mosek::fusion::p_SymRangedVariable::_get_impl(_1345)->sparsity;
    nativeidxs = mosek::fusion::p_SymRangedVariable::_get_impl(_1345)->nativeidxs;
    dim = mosek::fusion::p_SymRangedVariable::_get_impl(_1345)->dim;
  }
}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1347,    const std::string &  _1348,    long long _1349,    int _1350,    std::shared_ptr< monty::ndarray< long long,1 > > _1351,    std::shared_ptr< monty::ndarray< int,1 > > _1352){ return new mosek::fusion::SymRangedVariable(_1347,_1348,_1349,_1350,_1351,_1352); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1347,    const std::string &  _1348,    long long _1349,    int _1350,    std::shared_ptr< monty::ndarray< long long,1 > > _1351,    std::shared_ptr< monty::ndarray< int,1 > > _1352) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1347,_1348,_1349,_1350,_1351,_1352); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1347,    const std::string &  _1348,    long long _1349,    int _1350,    std::shared_ptr< monty::ndarray< long long,1 > > _1351,    std::shared_ptr< monty::ndarray< int,1 > > _1352){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1351(_1351 ? _1351->raw() : nullptr, _1351 ? _1351->size(0) : 0);
    _checked_ptr_1<int> _ptr__1352(_1352 ? _1352->raw() : nullptr, _1352 ? _1352->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1347,_1348,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1350),(int)(_1350)}),_1349,::mosek::fusion::p_SymRangedVariable::mirror_sp(_1350,_1351),::mosek::fusion::p_SymRangedVariable::mirror_idxs(_1350,_1351,_1352));
    names_flushed = false;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->name = _1348;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->nativeidxs = _1352;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->sparsity = _1351;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->dim = _1350;
  }
}void mosek::fusion::p_SymRangedVariable::dual_u(int _1353,std::shared_ptr< monty::ndarray< double,1 > > _1354){
  _checked_ptr_1<double> _ptr__1354(_1354 ? _1354->raw() : nullptr, _1354 ? _1354->size(0) : 0);
  dual_lu(_1353,_1354,false);
}
void mosek::fusion::p_SymRangedVariable::dual_l(int _1355,std::shared_ptr< monty::ndarray< double,1 > > _1356){
  _checked_ptr_1<double> _ptr__1356(_1356 ? _1356->raw() : nullptr, _1356 ? _1356->size(0) : 0);
  dual_lu(_1355,_1356,true);
}
void mosek::fusion::p_SymRangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1357 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7155 = (int)0;
          int _7156 = (int)((nativeidxs)->size(0));
          for (int _1358 = _7155; _1358 < _7156; ++_1358)
          {
            {
              std::string _7157;
              bool _7158 = ((int)((name).size()) == (int)0);
              if (_7158)
              {
                _7157 = std::string ("");
              }
              else
              {
                _7157 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1358 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1358 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1357.get())->varname(((*nativeidxs)(_1358)),_7157);
            }
          }
        }
      }
      else
      {
        {
          int _7159 = (int)0;
          int _7160 = (int)((sparsity)->size(0));
          for (int _1359 = _7159; _1359 < _7160; ++_1359)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1357.get())->varname(((*nativeidxs)(_1359)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1359)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1359)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymRangedVariable::__mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1360){
  return (::mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable(::mosek::fusion::SymRangedVariable::t(_pubthis),_1360)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_idxs(int _1361,std::shared_ptr< monty::ndarray< long long,1 > > _1362,std::shared_ptr< monty::ndarray< int,1 > > _1363){
  _checked_ptr_1<long long> _ptr__1362(_1362 ? _1362->raw() : nullptr, _1362 ? _1362->size(0) : 0);
  _checked_ptr_1<int> _ptr__1363(_1363 ? _1363->raw() : nullptr, _1363 ? _1363->size(0) : 0);
  if ((NULL == _1362.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1364 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1361,_1361 ))));
      _checked_ptr_1<long long> _ptr__1364(_1364 ? _1364->raw() : nullptr,_1364 ? _1364->size(0) : 0);
      int _1365 = (int)0;
      {
        int _7161 = (int)0;
        int _7162 = _1361;
        for (int _1366 = _7161; _1366 < _7162; ++_1366)
        {
          {
            _ptr__1364[safe_add( safe_mul( _1366,_1361 ),_1366 )] = safe_add( _ptr__1363[_1365],(int)1 );
            ++ _1365;
            int _7163 = safe_add( _1366,(int)1 );
            int _7164 = _1361;
            for (int _1367 = _7163; _1367 < _7164; ++_1367)
            {
              {
                _ptr__1364[safe_add( safe_mul( _1366,_1361 ),_1367 )] = safe_add( _ptr__1363[_1365],(int)1 );
                _ptr__1364[safe_add( safe_mul( _1367,_1361 ),_1366 )] = safe_add( _ptr__1363[_1365],(int)1 );
                ++ _1365;
              }
            }
          }
        }
      }
      return _1364;
    }
  }
  else
  {
    {
      int _1368 = (int)0;
      {
        int _7165 = (int)0;
        int _7166 = (int)((_1362)->size(0));
        for (int _1369 = _7165; _1369 < _7166; ++_1369)
        {
          {
            int _7167;
            bool _7168 = ((_ptr__1362[_1369] % safe_add( _1361,(int)1 )) == (int)0);
            if (_7168)
            {
              _7167 = (int)1;
            }
            else
            {
              _7167 = (int)2;
            }
            _1368 += _7167;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1370 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1368)));
      _checked_ptr_1<long long> _ptr__1370(_1370 ? _1370->raw() : nullptr,_1370 ? _1370->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1371 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1368)));
      _checked_ptr_1<long long> _ptr__1371(_1371 ? _1371->raw() : nullptr,_1371 ? _1371->size(0) : 0);
      {
        int _1372 = (int)0;
        int _7169 = (int)0;
        int _7170 = (int)((_1362)->size(0));
        for (int _1373 = _7169; _1373 < _7170; ++_1373)
        {
          {
            long long _1374 = (_ptr__1362[_1373] / _1361);
            long long _1375 = (_ptr__1362[_1373] % _1361);
            _ptr__1370[_1372] = _ptr__1362[_1373];
            _ptr__1371[_1372] = safe_add( _ptr__1363[_1373],(int)1 );
            ++ _1372;
            if ((_1374 != _1375))
            {
              {
                _ptr__1370[_1372] = safe_add( safe_mul( _1375,_1361 ),_1374 );
                _ptr__1371[_1372] = safe_add( _ptr__1363[_1373],(int)1 );
                ++ _1372;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7171;
      for (int _1377 = (int)0, _7172 = _1368; _1377 < _7172 ; ++_1377)
      {
        _7171.push_back(_1377);
      }
      auto _7173 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7171.size()),_7171.begin(),_7171.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1376 = _7173;
      _checked_ptr_1<long long> _ptr__1376(_1376 ? _1376->raw() : nullptr,_1376 ? _1376->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1376,_1370,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1368));
      std::vector<long long> _7174;
      for (int _1378 = (int)0, _7175 = _1368; _1378 < _7175 ; ++_1378)
      {
        _7174.push_back(_ptr__1371[_ptr__1376[_1378]]);
      }
      auto _7176 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7174.size()),_7174.begin(),_7174.end()));
      return _7176;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_sp(int _1379,std::shared_ptr< monty::ndarray< long long,1 > > _1380){
  _checked_ptr_1<long long> _ptr__1380(_1380 ? _1380->raw() : nullptr, _1380 ? _1380->size(0) : 0);
  if ((NULL == _1380.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1381 = (int)0;
      {
        int _7177 = (int)0;
        int _7178 = (int)((_1380)->size(0));
        for (int _1382 = _7177; _1382 < _7178; ++_1382)
        {
          {
            int _7179;
            bool _7180 = ((_ptr__1380[_1382] % safe_add( _1379,(int)1 )) == (int)0);
            if (_7180)
            {
              _7179 = (int)1;
            }
            else
            {
              _7179 = (int)2;
            }
            _1381 += _7179;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1383 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1381)));
      _checked_ptr_1<long long> _ptr__1383(_1383 ? _1383->raw() : nullptr,_1383 ? _1383->size(0) : 0);
      {
        int _1384 = (int)0;
        int _7181 = (int)0;
        int _7182 = (int)((_1380)->size(0));
        for (int _1385 = _7181; _1385 < _7182; ++_1385)
        {
          {
            long long _1386 = (_ptr__1380[_1385] / _1379);
            long long _1387 = (_ptr__1380[_1385] % _1379);
            _ptr__1383[_1384] = _ptr__1380[_1385];
            ++ _1384;
            if ((_1386 != _1387))
            {
              {
                _ptr__1383[_1384] = safe_add( safe_mul( _1387,_1379 ),_1386 );
                ++ _1384;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7183;
      for (int _1389 = (int)0, _7184 = _1381; _1389 < _7184 ; ++_1389)
      {
        _7183.push_back(_1389);
      }
      auto _7185 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7183.size()),_7183.begin(),_7183.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1388 = _7185;
      _checked_ptr_1<long long> _ptr__1388(_1388 ? _1388->raw() : nullptr,_1388 ? _1388->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1388,_1383,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1381));
      std::vector<long long> _7186;
      for (int _1390 = (int)0, _7187 = _1381; _1390 < _7187 ; ++_1390)
      {
        _7186.push_back(_ptr__1383[_ptr__1388[_1390]]);
      }
      auto _7188 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7186.size()),_7186.begin(),_7186.end()));
      return _7188;
    }
  }
}
void mosek::fusion::p_SymRangedVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymRangedVariable::destroy() { mosek::fusion::p_SymRangedVariable::_get_impl(this)->destroy(); }mosek::fusion::RangedVariable::RangedVariable(mosek::fusion::p_RangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "RangedVariable()" << this << std::endl; */ }mosek::fusion::RangedVariable::~RangedVariable() {  /* std::cout << "~RangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedVariable::p_RangedVariable  (::mosek::fusion::RangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1391,    monty::rc_ptr< ::mosek::fusion::Model > _1392){ return new mosek::fusion::RangedVariable(_1391,_1392); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1391,    monty::rc_ptr< ::mosek::fusion::Model > _1392) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1391,_1392); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1391,    monty::rc_ptr< ::mosek::fusion::Model > _1392){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1391,_1392);
    name = mosek::fusion::p_RangedVariable::_get_impl(_1391)->name;
    nativeidxs = mosek::fusion::p_RangedVariable::_get_impl(_1391)->nativeidxs;
    sparsity = mosek::fusion::p_RangedVariable::_get_impl(_1391)->sparsity;
    names_flushed = mosek::fusion::p_RangedVariable::_get_impl(_1391)->names_flushed;
    shape = mosek::fusion::p_RangedVariable::_get_impl(_1391)->shape;
  }
}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1393,    const std::string &  _1394,    long long _1395,    std::shared_ptr< monty::ndarray< int,1 > > _1396,    std::shared_ptr< monty::ndarray< long long,1 > > _1397,    std::shared_ptr< monty::ndarray< int,1 > > _1398){ return new mosek::fusion::RangedVariable(_1393,_1394,_1395,_1396,_1397,_1398); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1393,    const std::string &  _1394,    long long _1395,    std::shared_ptr< monty::ndarray< int,1 > > _1396,    std::shared_ptr< monty::ndarray< long long,1 > > _1397,    std::shared_ptr< monty::ndarray< int,1 > > _1398) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1393,_1394,_1395,_1396,_1397,_1398); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1393,    const std::string &  _1394,    long long _1395,    std::shared_ptr< monty::ndarray< int,1 > > _1396,    std::shared_ptr< monty::ndarray< long long,1 > > _1397,    std::shared_ptr< monty::ndarray< int,1 > > _1398){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1396(_1396 ? _1396->raw() : nullptr, _1396 ? _1396->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1397(_1397 ? _1397->raw() : nullptr, _1397 ? _1397->size(0) : 0);
    _checked_ptr_1<int> _ptr__1398(_1398 ? _1398->raw() : nullptr, _1398 ? _1398->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1393,_1394,_1396,_1395,_1397,::mosek::fusion::p_RangedVariable::globalNativeIndexes(_1398));
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->nativeidxs = _1398;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->sparsity = _1397;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->name = _1394;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->shape = _1396;
    names_flushed = false;
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable :: __mosek_2fusion_2RangedVariable__elementDesc(long long _1399,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1400) { return mosek::fusion::p_RangedVariable::_get_impl(this)->__mosek_2fusion_2RangedVariable__elementDesc(_1399,_1400); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable::elementDesc(long long _1399,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1400) { return __mosek_2fusion_2RangedVariable__elementDesc(_1399,_1400); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__elementDesc(long long _1399,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1400){
  _pubthis->elementName(_1399,_1400);
  _1400->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : in range"));
  return _1400;
}
void mosek::fusion::p_RangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1401 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1402 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1402->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1402->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7189 = (int)1;
          int _7190 = _pubthis->getND();
          for (int _1403 = _7189; _1403 < _7190; ++_1403)
          {
            {
              _1402->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1403);
            }
          }
        }
      }
      {}
      _1402->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      mosek::fusion::p_Model::_get_impl(_1401.get())->varnames(nativeidxs,_1402->toString(),_pubthis->getShape(),sparsity);
      names_flushed = true;
    }
  }
  {}
}
void mosek::fusion::p_RangedVariable::dual_u(int _1404,std::shared_ptr< monty::ndarray< double,1 > > _1405){
  _checked_ptr_1<double> _ptr__1405(_1405 ? _1405->raw() : nullptr, _1405 ? _1405->size(0) : 0);
  dual_lu(_1404,_1405,false);
}
void mosek::fusion::p_RangedVariable::dual_l(int _1406,std::shared_ptr< monty::ndarray< double,1 > > _1407){
  _checked_ptr_1<double> _ptr__1407(_1407 ? _1407->raw() : nullptr, _1407 ? _1407->size(0) : 0);
  dual_lu(_1406,_1407,true);
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1408){
  return (::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::RangedVariable::t(_pubthis),_1408)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_RangedVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1409){
  _checked_ptr_1<int> _ptr__1409(_1409 ? _1409->raw() : nullptr, _1409 ? _1409->size(0) : 0);
  std::vector<long long> _7191;
  for (int _1410 = (int)0, _7192 = (int)((_1409)->size(0)); _1410 < _7192 ; ++_1410)
  {
    _7191.push_back(safe_add( _ptr__1409[_1410],(int)1 ));
  }
  auto _7193 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7191.size()),_7191.begin(),_7191.end()));
  return _7193;
}
void mosek::fusion::p_RangedVariable::destroy(){shape.reset();nativeidxs.reset();sparsity.reset();}void mosek::fusion::RangedVariable::destroy() { mosek::fusion::p_RangedVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDVariable::LinearPSDVariable(mosek::fusion::p_LinearPSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearPSDVariable()" << this << std::endl; */ }mosek::fusion::LinearPSDVariable::~LinearPSDVariable() {  /* std::cout << "~LinearPSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDVariable::p_LinearPSDVariable  (::mosek::fusion::LinearPSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1411,    monty::rc_ptr< ::mosek::fusion::Model > _1412){ return new mosek::fusion::LinearPSDVariable(_1411,_1412); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1411,    monty::rc_ptr< ::mosek::fusion::Model > _1412) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1411,_1412); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1411,    monty::rc_ptr< ::mosek::fusion::Model > _1412){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1411,_1412);
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = mosek::fusion::p_LinearPSDVariable::_get_impl(_1411)->conedim;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = mosek::fusion::p_LinearPSDVariable::_get_impl(_1411)->varid;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = mosek::fusion::p_LinearPSDVariable::_get_impl(_1411)->name;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = mosek::fusion::p_LinearPSDVariable::_get_impl(_1411)->shape;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = mosek::fusion::p_LinearPSDVariable::_get_impl(_1411)->nativeidxs;
  }
}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1413,    const std::string &  _1414,    int _1415,    std::shared_ptr< monty::ndarray< int,1 > > _1416,    int _1417,    std::shared_ptr< monty::ndarray< long long,1 > > _1418){ return new mosek::fusion::LinearPSDVariable(_1413,_1414,_1415,_1416,_1417,_1418); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1413,    const std::string &  _1414,    int _1415,    std::shared_ptr< monty::ndarray< int,1 > > _1416,    int _1417,    std::shared_ptr< monty::ndarray< long long,1 > > _1418) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1413,_1414,_1415,_1416,_1417,_1418); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1413,    const std::string &  _1414,    int _1415,    std::shared_ptr< monty::ndarray< int,1 > > _1416,    int _1417,    std::shared_ptr< monty::ndarray< long long,1 > > _1418){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1416(_1416 ? _1416->raw() : nullptr, _1416 ? _1416->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1418(_1418 ? _1418->raw() : nullptr, _1418 ? _1418->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1413,_1414,_1416,_1415,nullptr,::mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(_1418));
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = _1414;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = _1417;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = _1415;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = _1416;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = _1418;
  }
}void mosek::fusion::p_LinearPSDVariable::flushNames(){
}
std::string mosek::fusion::LinearPSDVariable :: toString() { return mosek::fusion::p_LinearPSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearPSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1419 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1419->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1419->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1419->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7194 = (int)1;
  int _7195 = (int)((shape)->size(0));
  for (int _1420 = _7194; _1420 < _7195; ++_1420)
  {
    {
      _1419->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1420)));
    }
  }
  _1419->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1419->toString();
}
void mosek::fusion::LinearPSDVariable :: make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1421) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_continuous(_1421); }void mosek::fusion::p_LinearPSDVariable::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1421){
  _checked_ptr_1<long long> _ptr__1421(_1421 ? _1421->raw() : nullptr, _1421 ? _1421->size(0) : 0);
}
void mosek::fusion::LinearPSDVariable :: make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1422) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_integer(_1422); }void mosek::fusion::p_LinearPSDVariable::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1422){
  _checked_ptr_1<long long> _ptr__1422(_1422 ? _1422->raw() : nullptr, _1422 ? _1422->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Cannot make PSDVariable elements integer"));
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearPSDVariable::__mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1423){
  return (::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::LinearPSDVariable::t(_pubthis),_1423)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1424){
  _checked_ptr_1<long long> _ptr__1424(_1424 ? _1424->raw() : nullptr, _1424 ? _1424->size(0) : 0);
  std::vector<long long> _7196;
  for (int _1425 = (int)0, _7197 = (int)((_1424)->size(0)); _1425 < _7197 ; ++_1425)
  {
    _7196.push_back((-safe_add( _ptr__1424[_1425],(int)1 )));
  }
  auto _7198 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7196.size()),_7196.begin(),_7196.end()));
  return _7198;
}
void mosek::fusion::p_LinearPSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDVariable::destroy() { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->destroy(); }mosek::fusion::PSDVariable::PSDVariable(mosek::fusion::p_PSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "PSDVariable()" << this << std::endl; */ }mosek::fusion::PSDVariable::~PSDVariable() {  /* std::cout << "~PSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDVariable::p_PSDVariable  (::mosek::fusion::PSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1426,    monty::rc_ptr< ::mosek::fusion::Model > _1427){ return new mosek::fusion::PSDVariable(_1426,_1427); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1426,    monty::rc_ptr< ::mosek::fusion::Model > _1427) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1426,_1427); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1426,    monty::rc_ptr< ::mosek::fusion::Model > _1427){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1426,_1427);
    varid = mosek::fusion::p_PSDVariable::_get_impl(_1426)->varid;
    nativeidxs = mosek::fusion::p_PSDVariable::_get_impl(_1426)->nativeidxs;
    name = mosek::fusion::p_PSDVariable::_get_impl(_1426)->name;
    shape = mosek::fusion::p_PSDVariable::_get_impl(_1426)->shape;
    conedim1 = mosek::fusion::p_PSDVariable::_get_impl(_1426)->conedim1;
    conedim2 = mosek::fusion::p_PSDVariable::_get_impl(_1426)->conedim2;
  }
}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1428,    const std::string &  _1429,    int _1430,    std::shared_ptr< monty::ndarray< int,1 > > _1431,    int _1432,    int _1433,    std::shared_ptr< monty::ndarray< long long,1 > > _1434){ return new mosek::fusion::PSDVariable(_1428,_1429,_1430,_1431,_1432,_1433,_1434); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1428,    const std::string &  _1429,    int _1430,    std::shared_ptr< monty::ndarray< int,1 > > _1431,    int _1432,    int _1433,    std::shared_ptr< monty::ndarray< long long,1 > > _1434) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1428,_1429,_1430,_1431,_1432,_1433,_1434); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1428,    const std::string &  _1429,    int _1430,    std::shared_ptr< monty::ndarray< int,1 > > _1431,    int _1432,    int _1433,    std::shared_ptr< monty::ndarray< long long,1 > > _1434){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1431(_1431 ? _1431->raw() : nullptr, _1431 ? _1431->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1434(_1434 ? _1434->raw() : nullptr, _1434 ? _1434->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1428,_1429,_1431,_1430,nullptr,::mosek::fusion::p_PSDVariable::fullnativeidxs(_1431,_1432,_1433,_1434));
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->varid = _1430;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->nativeidxs = _1434;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->name = _1429;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->shape = _1431;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim1 = _1432;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim2 = _1433;
  }
}void mosek::fusion::p_PSDVariable::flushNames(){
}
std::string mosek::fusion::PSDVariable :: toString() { return mosek::fusion::p_PSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1435 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1435->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1435->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1435->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7199 = (int)1;
  int _7200 = (int)((shape)->size(0));
  for (int _1436 = _7199; _1436 < _7200; ++_1436)
  {
    {
      _1435->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1436)));
    }
  }
  _1435->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1435->toString();
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable :: __mosek_2fusion_2PSDVariable__elementDesc(long long _1437,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1438) { return mosek::fusion::p_PSDVariable::_get_impl(this)->__mosek_2fusion_2PSDVariable__elementDesc(_1437,_1438); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable::elementDesc(long long _1437,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1438) { return __mosek_2fusion_2PSDVariable__elementDesc(_1437,_1438); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__elementDesc(long long _1437,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1438){
  _pubthis->elementName(_1437,_1438);
  _1438->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element in positive semidefinite cone"));
  return _1438;
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1439){
  return (::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::PSDVariable::t(_pubthis),_1439)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_PSDVariable::fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1440,int _1441,int _1442,std::shared_ptr< monty::ndarray< long long,1 > > _1443){
  _checked_ptr_1<int> _ptr__1440(_1440 ? _1440->raw() : nullptr, _1440 ? _1440->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1443(_1443 ? _1443->raw() : nullptr, _1443 ? _1443->size(0) : 0);
  int _1444 = (int)((_1440)->size(0));
  bool _1445 = (_1441 < _1442);
  int _7201;
  bool _7202 = _1445;
  if (_7202)
  {
    _7201 = _1441;
  }
  else
  {
    _7201 = _1442;
  }
  int _1446 = _7201;
  int _7203;
  bool _7204 = (!_1445);
  if (_7204)
  {
    _7203 = _1441;
  }
  else
  {
    _7203 = _1442;
  }
  int _1447 = _7203;
  int _1448 = (int)1;
  int _7205 = (int)0;
  int _7206 = _1446;
  for (int _1449 = _7205; _1449 < _7206; ++_1449)
  {
    {
      _1448 *= _ptr__1440[_1449];
    }
  }
  int _1450 = _ptr__1440[_1446];
  int _1451 = (int)1;
  int _7207 = safe_add( _1446,(int)1 );
  int _7208 = _1447;
  for (int _1452 = _7207; _1452 < _7208; ++_1452)
  {
    {
      _1451 *= _ptr__1440[_1452];
    }
  }
  int _1453 = _ptr__1440[_1447];
  int _1454 = (int)1;
  int _7209 = safe_add( _1447,(int)1 );
  int _7210 = _1444;
  for (int _1455 = _7209; _1455 < _7210; ++_1455)
  {
    {
      _1454 *= _ptr__1440[_1455];
    }
  }
  int _1456 = safe_mul( safe_mul( safe_mul( safe_mul( _1448,_1450 ),_1451 ),_1453 ),_1454 );
  std::shared_ptr< monty::ndarray< long long,1 > > _1457 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1456)));
  _checked_ptr_1<long long> _ptr__1457(_1457 ? _1457->raw() : nullptr,_1457 ? _1457->size(0) : 0);
  int _1458 = _1454;
  int _1459 = safe_mul( _1458,_1453 );
  int _1460 = safe_mul( _1459,_1451 );
  int _1461 = safe_mul( _1460,_1460 );
  {
    int _1462 = (int)0;
    int _7211 = (int)0;
    int _7212 = _1448;
    for (int _1463 = _7211; _1463 < _7212; ++_1463)
    {
      {
        int _7213 = (int)0;
        int _7214 = _1453;
        for (int _1464 = _7213; _1464 < _7214; ++_1464)
        {
          {
            int _7215 = (int)0;
            int _7216 = _1451;
            for (int _1465 = _7215; _1465 < _7216; ++_1465)
            {
              {
                int _7217 = _1464;
                int _7218 = _1450;
                for (int _1466 = _7217; _1466 < _7218; ++_1466)
                {
                  {
                    int _7219 = (int)0;
                    int _7220 = _1454;
                    for (int _1467 = _7219; _1467 < _7220; ++_1467)
                    {
                      {
                        _ptr__1457[safe_add( safe_add( safe_add( safe_add( safe_mul( _1463,_1461 ),safe_mul( _1466,_1460 ) ),safe_mul( _1465,_1459 ) ),safe_mul( _1464,_1458 ) ),_1467 )] = (-safe_add( _ptr__1443[_1462],(int)1 ));
                        _ptr__1457[safe_add( safe_add( safe_add( safe_add( safe_mul( _1463,_1461 ),safe_mul( _1464,_1460 ) ),safe_mul( _1465,_1459 ) ),safe_mul( _1466,_1458 ) ),_1467 )] = (-safe_add( _ptr__1443[_1462],(int)1 ));
                        ++ _1462;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _1457;
}
void mosek::fusion::p_PSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::PSDVariable::destroy() { mosek::fusion::p_PSDVariable::_get_impl(this)->destroy(); }mosek::fusion::SymLinearVariable::SymLinearVariable(mosek::fusion::p_SymLinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymLinearVariable()" << this << std::endl; */ }mosek::fusion::SymLinearVariable::~SymLinearVariable() {  /* std::cout << "~SymLinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymLinearVariable::p_SymLinearVariable  (::mosek::fusion::SymLinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1468,    monty::rc_ptr< ::mosek::fusion::Model > _1469){ return new mosek::fusion::SymLinearVariable(_1468,_1469); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1468,    monty::rc_ptr< ::mosek::fusion::Model > _1469) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1468,_1469); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1468,    monty::rc_ptr< ::mosek::fusion::Model > _1469){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1468,_1469);
    names_flushed = mosek::fusion::p_SymLinearVariable::_get_impl(_1468)->names_flushed;
    name = mosek::fusion::p_SymLinearVariable::_get_impl(_1468)->name;
    sparsity = mosek::fusion::p_SymLinearVariable::_get_impl(_1468)->sparsity;
    nativeidxs = mosek::fusion::p_SymLinearVariable::_get_impl(_1468)->nativeidxs;
    dim = mosek::fusion::p_SymLinearVariable::_get_impl(_1468)->dim;
  }
}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1470,    const std::string &  _1471,    long long _1472,    int _1473,    std::shared_ptr< monty::ndarray< long long,1 > > _1474,    std::shared_ptr< monty::ndarray< int,1 > > _1475){ return new mosek::fusion::SymLinearVariable(_1470,_1471,_1472,_1473,_1474,_1475); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1470,    const std::string &  _1471,    long long _1472,    int _1473,    std::shared_ptr< monty::ndarray< long long,1 > > _1474,    std::shared_ptr< monty::ndarray< int,1 > > _1475) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1470,_1471,_1472,_1473,_1474,_1475); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1470,    const std::string &  _1471,    long long _1472,    int _1473,    std::shared_ptr< monty::ndarray< long long,1 > > _1474,    std::shared_ptr< monty::ndarray< int,1 > > _1475){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1474(_1474 ? _1474->raw() : nullptr, _1474 ? _1474->size(0) : 0);
    _checked_ptr_1<int> _ptr__1475(_1475 ? _1475->raw() : nullptr, _1475 ? _1475->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1470,_1471,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1473),(int)(_1473)}),_1472,::mosek::fusion::p_SymLinearVariable::mirror_sp(_1473,_1474),::mosek::fusion::p_SymLinearVariable::mirror_idxs(_1473,_1474,_1475));
    names_flushed = false;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->name = _1471;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->nativeidxs = _1475;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->sparsity = _1474;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->dim = _1473;
  }
}void mosek::fusion::p_SymLinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1476 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7221 = (int)0;
          int _7222 = (int)((nativeidxs)->size(0));
          for (int _1477 = _7221; _1477 < _7222; ++_1477)
          {
            {
              std::string _7223;
              bool _7224 = ((int)((name).size()) == (int)0);
              if (_7224)
              {
                _7223 = std::string ("");
              }
              else
              {
                _7223 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1477 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1477 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1476.get())->varname(((*nativeidxs)(_1477)),_7223);
            }
          }
        }
      }
      else
      {
        {
          int _7225 = (int)0;
          int _7226 = (int)((sparsity)->size(0));
          for (int _1478 = _7225; _1478 < _7226; ++_1478)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1476.get())->varname(((*nativeidxs)(_1478)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1478)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1478)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymLinearVariable::__mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1479){
  return (::mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable(::mosek::fusion::SymLinearVariable::t(_pubthis),_1479)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_idxs(int _1480,std::shared_ptr< monty::ndarray< long long,1 > > _1481,std::shared_ptr< monty::ndarray< int,1 > > _1482){
  _checked_ptr_1<long long> _ptr__1481(_1481 ? _1481->raw() : nullptr, _1481 ? _1481->size(0) : 0);
  _checked_ptr_1<int> _ptr__1482(_1482 ? _1482->raw() : nullptr, _1482 ? _1482->size(0) : 0);
  if ((NULL == _1481.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1483 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1480,_1480 ))));
      _checked_ptr_1<long long> _ptr__1483(_1483 ? _1483->raw() : nullptr,_1483 ? _1483->size(0) : 0);
      int _1484 = (int)0;
      {
        int _7227 = (int)0;
        int _7228 = _1480;
        for (int _1485 = _7227; _1485 < _7228; ++_1485)
        {
          {
            _ptr__1483[safe_add( safe_mul( _1485,_1480 ),_1485 )] = safe_add( _ptr__1482[_1484],(int)1 );
            ++ _1484;
            int _7229 = safe_add( _1485,(int)1 );
            int _7230 = _1480;
            for (int _1486 = _7229; _1486 < _7230; ++_1486)
            {
              {
                _ptr__1483[safe_add( safe_mul( _1485,_1480 ),_1486 )] = safe_add( _ptr__1482[_1484],(int)1 );
                _ptr__1483[safe_add( safe_mul( _1486,_1480 ),_1485 )] = safe_add( _ptr__1482[_1484],(int)1 );
                ++ _1484;
              }
            }
          }
        }
      }
      return _1483;
    }
  }
  else
  {
    {
      int _1487 = (int)0;
      {
        int _7231 = (int)0;
        int _7232 = (int)((_1481)->size(0));
        for (int _1488 = _7231; _1488 < _7232; ++_1488)
        {
          {
            int _7233;
            bool _7234 = ((_ptr__1481[_1488] % safe_add( _1480,(int)1 )) == (int)0);
            if (_7234)
            {
              _7233 = (int)1;
            }
            else
            {
              _7233 = (int)2;
            }
            _1487 += _7233;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1489 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1487)));
      _checked_ptr_1<long long> _ptr__1489(_1489 ? _1489->raw() : nullptr,_1489 ? _1489->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1490 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1487)));
      _checked_ptr_1<long long> _ptr__1490(_1490 ? _1490->raw() : nullptr,_1490 ? _1490->size(0) : 0);
      {
        int _1491 = (int)0;
        int _7235 = (int)0;
        int _7236 = (int)((_1481)->size(0));
        for (int _1492 = _7235; _1492 < _7236; ++_1492)
        {
          {
            long long _1493 = (_ptr__1481[_1492] / _1480);
            long long _1494 = (_ptr__1481[_1492] % _1480);
            _ptr__1489[_1491] = _ptr__1481[_1492];
            _ptr__1490[_1491] = safe_add( _ptr__1482[_1492],(int)1 );
            ++ _1491;
            if ((_1493 != _1494))
            {
              {
                _ptr__1489[_1491] = safe_add( safe_mul( _1494,_1480 ),_1493 );
                _ptr__1490[_1491] = safe_add( _ptr__1482[_1492],(int)1 );
                ++ _1491;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7237;
      for (int _1496 = (int)0, _7238 = _1487; _1496 < _7238 ; ++_1496)
      {
        _7237.push_back(_1496);
      }
      auto _7239 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7237.size()),_7237.begin(),_7237.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1495 = _7239;
      _checked_ptr_1<long long> _ptr__1495(_1495 ? _1495->raw() : nullptr,_1495 ? _1495->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1495,_1489,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1487));
      std::vector<long long> _7240;
      for (int _1497 = (int)0, _7241 = _1487; _1497 < _7241 ; ++_1497)
      {
        _7240.push_back(_ptr__1490[_ptr__1495[_1497]]);
      }
      auto _7242 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7240.size()),_7240.begin(),_7240.end()));
      return _7242;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_sp(int _1498,std::shared_ptr< monty::ndarray< long long,1 > > _1499){
  _checked_ptr_1<long long> _ptr__1499(_1499 ? _1499->raw() : nullptr, _1499 ? _1499->size(0) : 0);
  if ((NULL == _1499.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1500 = (int)0;
      {
        int _7243 = (int)0;
        int _7244 = (int)((_1499)->size(0));
        for (int _1501 = _7243; _1501 < _7244; ++_1501)
        {
          {
            int _7245;
            bool _7246 = ((_ptr__1499[_1501] % safe_add( _1498,(int)1 )) == (int)0);
            if (_7246)
            {
              _7245 = (int)1;
            }
            else
            {
              _7245 = (int)2;
            }
            _1500 += _7245;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1502 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1500)));
      _checked_ptr_1<long long> _ptr__1502(_1502 ? _1502->raw() : nullptr,_1502 ? _1502->size(0) : 0);
      {
        int _1503 = (int)0;
        int _7247 = (int)0;
        int _7248 = (int)((_1499)->size(0));
        for (int _1504 = _7247; _1504 < _7248; ++_1504)
        {
          {
            long long _1505 = (_ptr__1499[_1504] / _1498);
            long long _1506 = (_ptr__1499[_1504] % _1498);
            _ptr__1502[_1503] = _ptr__1499[_1504];
            ++ _1503;
            if ((_1505 != _1506))
            {
              {
                _ptr__1502[_1503] = safe_add( safe_mul( _1506,_1498 ),_1505 );
                ++ _1503;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7249;
      for (int _1508 = (int)0, _7250 = _1500; _1508 < _7250 ; ++_1508)
      {
        _7249.push_back(_1508);
      }
      auto _7251 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7249.size()),_7249.begin(),_7249.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1507 = _7251;
      _checked_ptr_1<long long> _ptr__1507(_1507 ? _1507->raw() : nullptr,_1507 ? _1507->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1507,_1502,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1500));
      std::vector<long long> _7252;
      for (int _1509 = (int)0, _7253 = _1500; _1509 < _7253 ; ++_1509)
      {
        _7252.push_back(_ptr__1502[_ptr__1507[_1509]]);
      }
      auto _7254 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7252.size()),_7252.begin(),_7252.end()));
      return _7254;
    }
  }
}
void mosek::fusion::p_SymLinearVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymLinearVariable::destroy() { mosek::fusion::p_SymLinearVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearVariable::LinearVariable(mosek::fusion::p_LinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearVariable()" << this << std::endl; */ }mosek::fusion::LinearVariable::~LinearVariable() {  /* std::cout << "~LinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearVariable::p_LinearVariable  (::mosek::fusion::LinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1510,    monty::rc_ptr< ::mosek::fusion::Model > _1511){ return new mosek::fusion::LinearVariable(_1510,_1511); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1510,    monty::rc_ptr< ::mosek::fusion::Model > _1511) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1510,_1511); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1510,    monty::rc_ptr< ::mosek::fusion::Model > _1511){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1510,_1511);
    names_flushed = mosek::fusion::p_LinearVariable::_get_impl(_1510)->names_flushed;
    nativeidxs = mosek::fusion::p_LinearVariable::_get_impl(_1510)->nativeidxs;
    sparsity = mosek::fusion::p_LinearVariable::_get_impl(_1510)->sparsity;
    shape = mosek::fusion::p_LinearVariable::_get_impl(_1510)->shape;
    name = mosek::fusion::p_LinearVariable::_get_impl(_1510)->name;
  }
}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1512,    const std::string &  _1513,    long long _1514,    std::shared_ptr< monty::ndarray< int,1 > > _1515,    std::shared_ptr< monty::ndarray< long long,1 > > _1516,    std::shared_ptr< monty::ndarray< int,1 > > _1517){ return new mosek::fusion::LinearVariable(_1512,_1513,_1514,_1515,_1516,_1517); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1512,    const std::string &  _1513,    long long _1514,    std::shared_ptr< monty::ndarray< int,1 > > _1515,    std::shared_ptr< monty::ndarray< long long,1 > > _1516,    std::shared_ptr< monty::ndarray< int,1 > > _1517) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1512,_1513,_1514,_1515,_1516,_1517); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1512,    const std::string &  _1513,    long long _1514,    std::shared_ptr< monty::ndarray< int,1 > > _1515,    std::shared_ptr< monty::ndarray< long long,1 > > _1516,    std::shared_ptr< monty::ndarray< int,1 > > _1517){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1515(_1515 ? _1515->raw() : nullptr, _1515 ? _1515->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1516(_1516 ? _1516->raw() : nullptr, _1516 ? _1516->size(0) : 0);
    _checked_ptr_1<int> _ptr__1517(_1517 ? _1517->raw() : nullptr, _1517 ? _1517->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1512,_1513,_1515,_1514,_1516,::mosek::fusion::p_LinearVariable::globalNativeIndexes(_1517));
    names_flushed = false;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->name = _1513;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->nativeidxs = _1517;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->sparsity = _1516;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->shape = _1515;
  }
}std::string mosek::fusion::LinearVariable :: toString() { return mosek::fusion::p_LinearVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1518 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1518->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearVariable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1518->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7255 = (int)1;
      int _7256 = (int)((shape)->size(0));
      for (int _1519 = _7255; _1519 < _7256; ++_1519)
      {
        {
          _1518->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1519)));
        }
      }
    }
  }
  {}
  _1518->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1518->toString();
}
void mosek::fusion::p_LinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1520 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1521 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1521->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1521->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7257 = (int)1;
          int _7258 = _pubthis->getND();
          for (int _1522 = _7257; _1522 < _7258; ++_1522)
          {
            {
              _1521->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1522);
            }
          }
        }
      }
      {}
      _1521->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7259;
      bool _7260 = (_pubthis->getND() > (int)0);
      if (_7260)
      {
        _7259 = _pubthis->getShape();
      }
      else
      {
        _7259 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
      }
      mosek::fusion::p_Model::_get_impl(_1520.get())->varnames(nativeidxs,_1521->toString(),_7259,sparsity);
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearVariable::__mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1523){
  return (::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::LinearVariable::t(_pubthis),_1523)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1524){
  _checked_ptr_1<int> _ptr__1524(_1524 ? _1524->raw() : nullptr, _1524 ? _1524->size(0) : 0);
  std::vector<long long> _7261;
  for (int _1525 = (int)0, _7262 = (int)((_1524)->size(0)); _1525 < _7262 ; ++_1525)
  {
    _7261.push_back(safe_add( _ptr__1524[_1525],(int)1 ));
  }
  auto _7263 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7261.size()),_7261.begin(),_7261.end()));
  return _7263;
}
void mosek::fusion::p_LinearVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::LinearVariable::destroy() { mosek::fusion::p_LinearVariable::_get_impl(this)->destroy(); }mosek::fusion::ConicVariable::ConicVariable(mosek::fusion::p_ConicVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "ConicVariable()" << this << std::endl; */ }mosek::fusion::ConicVariable::~ConicVariable() {  /* std::cout << "~ConicVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicVariable::p_ConicVariable  (::mosek::fusion::ConicVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1526,    monty::rc_ptr< ::mosek::fusion::Model > _1527){ return new mosek::fusion::ConicVariable(_1526,_1527); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1526,    monty::rc_ptr< ::mosek::fusion::Model > _1527) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1526,_1527); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1526,    monty::rc_ptr< ::mosek::fusion::Model > _1527){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1526,_1527);
    names_flushed = mosek::fusion::p_ConicVariable::_get_impl(_1526)->names_flushed;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1526)->shape;
    nativeidxs = mosek::fusion::p_ConicVariable::_get_impl(_1526)->nativeidxs;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1526)->shape;
    varid = mosek::fusion::p_ConicVariable::_get_impl(_1526)->varid;
    name = mosek::fusion::p_ConicVariable::_get_impl(_1526)->name;
  }
}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1528,    const std::string &  _1529,    int _1530,    std::shared_ptr< monty::ndarray< int,1 > > _1531,    std::shared_ptr< monty::ndarray< int,1 > > _1532){ return new mosek::fusion::ConicVariable(_1528,_1529,_1530,_1531,_1532); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1528,    const std::string &  _1529,    int _1530,    std::shared_ptr< monty::ndarray< int,1 > > _1531,    std::shared_ptr< monty::ndarray< int,1 > > _1532) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1528,_1529,_1530,_1531,_1532); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1528,    const std::string &  _1529,    int _1530,    std::shared_ptr< monty::ndarray< int,1 > > _1531,    std::shared_ptr< monty::ndarray< int,1 > > _1532){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1531(_1531 ? _1531->raw() : nullptr, _1531 ? _1531->size(0) : 0);
    _checked_ptr_1<int> _ptr__1532(_1532 ? _1532->raw() : nullptr, _1532 ? _1532->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1528,_1529,_1531,_1530,nullptr,::mosek::fusion::p_ConicVariable::globalNativeIndexes(_1532));
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->name = _1529;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->varid = _1530;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->shape = _1531;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->nativeidxs = _1532;
  }
}std::string mosek::fusion::ConicVariable :: toString() { return mosek::fusion::p_ConicVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1533 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1533->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicVariable( "));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1533->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1533->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("));
  _1533->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7264 = (int)1;
  int _7265 = (int)((shape)->size(0));
  for (int _1534 = _7264; _1534 < _7265; ++_1534)
  {
    {
      _1533->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1534)));
    }
  }
  _1533->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _1533->toString();
}
void mosek::fusion::p_ConicVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1535 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1536 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1536->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      _1536->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
      int _7266 = (int)1;
      int _7267 = _pubthis->getND();
      for (int _1537 = _7266; _1537 < _7267; ++_1537)
      {
        {
          _1536->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1537);
        }
      }
      _1536->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7268;
      bool _7269 = (_pubthis->getND() > (int)0);
      if (_7269)
      {
        _7268 = _pubthis->getShape();
      }
      else
      {
        _7268 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
      }
      mosek::fusion::p_Model::_get_impl(_1535.get())->varnames(nativeidxs,_1536->toString(),_7268,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_ConicVariable::__mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1538){
  return (::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::ConicVariable::t(_pubthis),_1538)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ConicVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1539){
  _checked_ptr_1<int> _ptr__1539(_1539 ? _1539->raw() : nullptr, _1539 ? _1539->size(0) : 0);
  std::vector<long long> _7270;
  for (int _1540 = (int)0, _7271 = (int)((_1539)->size(0)); _1540 < _7271 ; ++_1540)
  {
    _7270.push_back(safe_add( _ptr__1539[_1540],(int)1 ));
  }
  auto _7272 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7270.size()),_7270.begin(),_7270.end()));
  return _7272;
}
void mosek::fusion::p_ConicVariable::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::ConicVariable::destroy() { mosek::fusion::p_ConicVariable::_get_impl(this)->destroy(); }mosek::fusion::ModelVariable::ModelVariable(mosek::fusion::p_ModelVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "ModelVariable()" << this << std::endl; */ }mosek::fusion::ModelVariable::~ModelVariable() {  /* std::cout << "~ModelVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelVariable::p_ModelVariable  (::mosek::fusion::ModelVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelVariable > _1541,    monty::rc_ptr< ::mosek::fusion::Model > _1542){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseVariable::_initialize(_1541,_1542);
    name = mosek::fusion::p_ModelVariable::_get_impl(_1541)->name;
    varid = mosek::fusion::p_ModelVariable::_get_impl(_1541)->varid;
    nativeidxs = mosek::fusion::p_ModelVariable::_get_impl(_1541)->nativeidxs;
    shape = mosek::fusion::p_ModelVariable::_get_impl(_1541)->shape;
    sparsity = mosek::fusion::p_ModelVariable::_get_impl(_1541)->sparsity;
  }
}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1543,    const std::string &  _1544,    std::shared_ptr< monty::ndarray< int,1 > > _1545,    long long _1546,    std::shared_ptr< monty::ndarray< long long,1 > > _1547,    std::shared_ptr< monty::ndarray< long long,1 > > _1548){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1545(_1545 ? _1545->raw() : nullptr, _1545 ? _1545->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1547(_1547 ? _1547->raw() : nullptr, _1547 ? _1547->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1548(_1548 ? _1548->raw() : nullptr, _1548 ? _1548->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1543,_1545,_1547,_1548);
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->name = _1544;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->varid = _1546;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->shape = _1545;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->sparsity = _1547;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->nativeidxs = _1548;
  }
}void mosek::fusion::ModelVariable :: elementName(long long _1549,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1550) { mosek::fusion::p_ModelVariable::_get_impl(this)->elementName(_1549,_1550); }void mosek::fusion::p_ModelVariable::elementName(long long _1549,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1550){
  std::string _7273;
  bool _7274 = ((int)((name).size()) == (int)0);
  if (_7274)
  {
    _7273 = std::string ("_");
  }
  else
  {
    _7273 = name;
  }
  _1550->__mosek_2fusion_2Utils_2StringBuffer__a(_7273)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,_1549))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
}
void mosek::fusion::p_ModelVariable::destroy(){sparsity.reset();shape.reset();nativeidxs.reset();}void mosek::fusion::ModelVariable::destroy() { mosek::fusion::p_ModelVariable::_get_impl(this)->destroy(); }mosek::fusion::NilVariable::NilVariable(mosek::fusion::p_NilVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "NilVariable()" << this << std::endl; */ }mosek::fusion::NilVariable::~NilVariable() {  /* std::cout << "~NilVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_NilVariable::p_NilVariable  (::mosek::fusion::NilVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1552){ return new mosek::fusion::NilVariable(_1552); }mosek::fusion::NilVariable::NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1552) :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(_1552); }void mosek::fusion::p_NilVariable::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _1552){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1552(_1552 ? _1552->raw() : nullptr, _1552 ? _1552->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(nullptr,::mosek::fusion::Utils::Tools::arraycopy(_1552),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))));
    std::vector<int> _7275;
    for (int _1553 = (int)0, _7276 = (int)((_1552)->size(0)); _1553 < _7276 ; ++_1553)
    {
      _7275.push_back(_ptr__1552[_1553]);
    }
    auto _7277 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7275.size()),_7275.begin(),_7275.end()));
    mosek::fusion::p_NilVariable::_get_impl(::mosek::fusion::NilVariable::t(_pubthis))->shape = _7277;
  }
}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (){ return new mosek::fusion::NilVariable(); }mosek::fusion::NilVariable::NilVariable  () :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(); }void mosek::fusion::p_NilVariable::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_NilVariable::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)}));
  }
}void mosek::fusion::p_NilVariable::flushNames(){
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__elementDesc(long long _1554,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1555) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__elementDesc(_1554,_1555); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable::elementDesc(long long _1554,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1555) { return __mosek_2fusion_2NilVariable__elementDesc(_1554,_1555); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__elementDesc(long long _1554,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1555){
  return _1555;
}
void mosek::fusion::NilVariable :: elementName(long long _1556,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1557) { mosek::fusion::p_NilVariable::_get_impl(this)->elementName(_1556,_1557); }void mosek::fusion::p_NilVariable::elementName(long long _1556,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1557){
}
int mosek::fusion::NilVariable :: numInst() { return mosek::fusion::p_NilVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_NilVariable::numInst(){
  return (int)0;
}
int mosek::fusion::NilVariable :: inst(int _1558,std::shared_ptr< monty::ndarray< long long,1 > > _1559,std::shared_ptr< monty::ndarray< long long,1 > > _1560) { return mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1558,_1559,_1560); }int mosek::fusion::p_NilVariable::inst(int _1558,std::shared_ptr< monty::ndarray< long long,1 > > _1559,std::shared_ptr< monty::ndarray< long long,1 > > _1560){
  _checked_ptr_1<long long> _ptr__1559(_1559 ? _1559->raw() : nullptr, _1559 ? _1559->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1560(_1560 ? _1560->raw() : nullptr, _1560 ? _1560->size(0) : 0);
  return (int)0;
}
void mosek::fusion::NilVariable :: inst(int _1561,std::shared_ptr< monty::ndarray< long long,1 > > _1562) { mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1561,_1562); }void mosek::fusion::p_NilVariable::inst(int _1561,std::shared_ptr< monty::ndarray< long long,1 > > _1562){
  _checked_ptr_1<long long> _ptr__1562(_1562 ? _1562->raw() : nullptr, _1562 ? _1562->size(0) : 0);
}
void mosek::fusion::NilVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1563,bool _1564) { mosek::fusion::p_NilVariable::_get_impl(this)->set_values(_1563,_1564); }void mosek::fusion::p_NilVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1563,bool _1564){
  _checked_ptr_1<double> _ptr__1563(_1563 ? _1563->raw() : nullptr, _1563 ? _1563->size(0) : 0);
}
void mosek::fusion::NilVariable :: values(int _1565,std::shared_ptr< monty::ndarray< double,1 > > _1566,bool _1567) { mosek::fusion::p_NilVariable::_get_impl(this)->values(_1565,_1566,_1567); }void mosek::fusion::p_NilVariable::values(int _1565,std::shared_ptr< monty::ndarray< double,1 > > _1566,bool _1567){
  _checked_ptr_1<double> _ptr__1566(_1566 ? _1566->raw() : nullptr, _1566 ? _1566->size(0) : 0);
}
void mosek::fusion::NilVariable :: make_continuous() { mosek::fusion::p_NilVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_NilVariable::make_continuous(){
}
void mosek::fusion::NilVariable :: make_integer() { mosek::fusion::p_NilVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_NilVariable::make_integer(){
}
std::string mosek::fusion::NilVariable :: toString() { return mosek::fusion::p_NilVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_NilVariable::toString(){
  return std::string ("NilVariable");
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1568) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1568); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1568) { return __mosek_2fusion_2NilVariable__index(_1568); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1568) { return __mosek_2fusion_2NilVariable__index(_1568); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1568) { return __mosek_2fusion_2NilVariable__index(_1568); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1568){
  _checked_ptr_1<int> _ptr__1568(_1568 ? _1568->raw() : nullptr, _1568 ? _1568->size(0) : 0);
  std::vector<int> _7278;
  for (int _1569 = (int)0, _7279 = (int)((shape)->size(0)); _1569 < _7279 ; ++_1569)
  {
    _7278.push_back((int)1);
  }
  auto _7280 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7278.size()),_7278.begin(),_7278.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7280)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(int _1570) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1570); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(int _1570) { return __mosek_2fusion_2NilVariable__index(_1570); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(int _1570) { return __mosek_2fusion_2NilVariable__index(_1570); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(int _1570) { return __mosek_2fusion_2NilVariable__index(_1570); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(int _1570){
  std::vector<int> _7281;
  for (int _1571 = (int)0, _7282 = (int)((shape)->size(0)); _1571 < _7282 ; ++_1571)
  {
    _7281.push_back((int)1);
  }
  auto _7283 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7281.size()),_7281.begin(),_7281.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7283)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1572,std::shared_ptr< monty::ndarray< int,1 > > _1573) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1572,_1573); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1572,std::shared_ptr< monty::ndarray< int,1 > > _1573) { return __mosek_2fusion_2NilVariable__slice(_1572,_1573); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1572,std::shared_ptr< monty::ndarray< int,1 > > _1573) { return __mosek_2fusion_2NilVariable__slice(_1572,_1573); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1572,std::shared_ptr< monty::ndarray< int,1 > > _1573) { return __mosek_2fusion_2NilVariable__slice(_1572,_1573); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1572,std::shared_ptr< monty::ndarray< int,1 > > _1573){
  _checked_ptr_1<int> _ptr__1572(_1572 ? _1572->raw() : nullptr, _1572 ? _1572->size(0) : 0);
  _checked_ptr_1<int> _ptr__1573(_1573 ? _1573->raw() : nullptr, _1573 ? _1573->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)((_1572)->size(0))) || ((int)((shape)->size(0)) != (int)((_1573)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  {}
  int _7284 = (int)0;
  int _7285 = (int)((_1572)->size(0));
  for (int _1574 = _7284; _1574 < _7285; ++_1574)
  {
    {
      if (((_ptr__1573[_1574] > _ptr__1572[_1574]) || ((_ptr__1572[_1574] < (int)0) || (_ptr__1573[_1574] >= ((*shape)(_1574))))))
      {
        {
          throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _7286;
  for (int _1575 = (int)0, _7287 = (int)((shape)->size(0)); _1575 < _7287 ; ++_1575)
  {
    _7286.push_back((_ptr__1573[_1575] - _ptr__1572[_1575]));
  }
  auto _7288 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7286.size()),_7286.begin(),_7286.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7288)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(int _1576,int _1577) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1576,_1577); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(int _1576,int _1577) { return __mosek_2fusion_2NilVariable__slice(_1576,_1577); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(int _1576,int _1577) { return __mosek_2fusion_2NilVariable__slice(_1576,_1577); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(int _1576,int _1577) { return __mosek_2fusion_2NilVariable__slice(_1576,_1577); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(int _1576,int _1577){
  if (((_1577 > _1576) || ((_1576 < (int)0) || (_1577 > ((*shape)((int)0))))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_1577 - _1576))}))).as<::mosek::fusion::Variable>();
    }
  }
}
void mosek::fusion::p_NilVariable::destroy(){shape.reset();}void mosek::fusion::NilVariable::destroy() { mosek::fusion::p_NilVariable::_get_impl(this)->destroy(); }mosek::fusion::BaseVariable::BaseVariable(mosek::fusion::p_BaseVariable *_impl) : _impl(_impl) { /*std::cout << "BaseVariable() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseVariable::~BaseVariable() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseVariable::p_BaseVariable  (::mosek::fusion::BaseVariable * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::BaseVariable > _1578,    monty::rc_ptr< ::mosek::fusion::Model > _1579){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _1579;
    shape = mosek::fusion::p_BaseVariable::_get_impl(_1578)->shape;
    sparsity = mosek::fusion::p_BaseVariable::_get_impl(_1578)->sparsity;
    nativeidxs = mosek::fusion::p_BaseVariable::_get_impl(_1578)->nativeidxs;
  }
}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1580,    std::shared_ptr< monty::ndarray< int,1 > > _1581,    std::shared_ptr< monty::ndarray< long long,1 > > _1582,    std::shared_ptr< monty::ndarray< long long,1 > > _1583){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1581(_1581 ? _1581->raw() : nullptr, _1581 ? _1581->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1582(_1582 ? _1582->raw() : nullptr, _1582 ? _1582->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1583(_1583 ? _1583->raw() : nullptr, _1583 ? _1583->size(0) : 0);
    model = _1580;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->shape = _1581;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity = _1582;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs = _1583;
  }
}std::string mosek::fusion::BaseVariable :: toString() { return mosek::fusion::p_BaseVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1584 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1584->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1584->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7289 = (int)1;
      int _7290 = (int)((shape)->size(0));
      for (int _1585 = _7289; _1585 < _7290; ++_1585)
      {
        {
          _1584->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1585)));
        }
      }
    }
  }
  {}
  _1584->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1584->toString();
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__eval() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::eval() { return __mosek_2fusion_2BaseVariable__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__eval(){
  return _pubthis->__mosek_2fusion_2BaseVariable__asExpr()->__mosek_2fusion_2Expression__eval();
}
void mosek::fusion::BaseVariable :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1586,monty::rc_ptr< ::mosek::fusion::WorkStack > _1587,monty::rc_ptr< ::mosek::fusion::WorkStack > _1588) { mosek::fusion::p_BaseVariable::_get_impl(this)->eval(_1586,_1587,_1588); }void mosek::fusion::p_BaseVariable::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1586,monty::rc_ptr< ::mosek::fusion::WorkStack > _1587,monty::rc_ptr< ::mosek::fusion::WorkStack > _1588){
  int _1589 = (int)((nativeidxs)->size(0));
  int _1590 = _1589;
  int _1591 = (int)((shape)->size(0));
  bool _1592 = (NULL != sparsity.get());
  _1586->alloc_expr(_1591,_1590,_1589,_1592);
  int _1593 = mosek::fusion::p_WorkStack::_get_impl(_1586)->ptr_base;
  int _1594 = mosek::fusion::p_WorkStack::_get_impl(_1586)->nidxs_base;
  int _1595 = mosek::fusion::p_WorkStack::_get_impl(_1586)->sp_base;
  int _1596 = mosek::fusion::p_WorkStack::_get_impl(_1586)->cof_base;
  int _1597 = mosek::fusion::p_WorkStack::_get_impl(_1586)->bfix_base;
  int _1598 = mosek::fusion::p_WorkStack::_get_impl(_1586)->shape_base;
  std::shared_ptr< monty::ndarray< int,1 > > _1599 = mosek::fusion::p_WorkStack::_get_impl(_1586)->i32;
  _checked_ptr_1<int> _ptr__1599(_1599 ? _1599->raw() : nullptr,_1599 ? _1599->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1600 = mosek::fusion::p_WorkStack::_get_impl(_1586)->i64;
  _checked_ptr_1<long long> _ptr__1600(_1600 ? _1600->raw() : nullptr,_1600 ? _1600->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1601 = mosek::fusion::p_WorkStack::_get_impl(_1586)->f64;
  _checked_ptr_1<double> _ptr__1601(_1601 ? _1601->raw() : nullptr,_1601 ? _1601->size(0) : 0);
  int _7291 = (int)0;
  int _7292 = _1591;
  for (int _1602 = _7291; _1602 < _7292; ++_1602)
  {
    {
      _ptr__1599[safe_add( _1598,_1602 )] = ((*shape)(_1602));
    }
  }
  {
    int _7293 = (int)0;
    int _7294 = safe_add( _1589,(int)1 );
    for (int _1603 = _7293; _1603 < _7294; ++_1603)
    {
      {
        _ptr__1599[safe_add( _1593,_1603 )] = _1603;
      }
    }
    int _7295 = (int)0;
    int _7296 = _1589;
    for (int _1604 = _7295; _1604 < _7296; ++_1604)
    {
      {
        _ptr__1600[safe_add( _1594,_1604 )] = ((*nativeidxs)(_1604));
      }
    }
    if (_1592)
    {
      {
        int _7297 = (int)0;
        int _7298 = _1589;
        for (int _1605 = _7297; _1605 < _7298; ++_1605)
        {
          {
            _ptr__1600[safe_add( _1595,_1605 )] = ((*sparsity)(_1605));
          }
        }
      }
    }
    {}
    int _7299 = (int)0;
    int _7300 = _1589;
    for (int _1606 = _7299; _1606 < _7300; ++_1606)
    {
      {
        _ptr__1601[safe_add( _1596,_1606 )] = 1.0;
      }
    }
    int _7301 = (int)0;
    int _7302 = _1589;
    for (int _1607 = _7301; _1607 < _7302; ++_1607)
    {
      {
        _ptr__1601[safe_add( _1597,_1607 )] = 0.0;
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1608) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1608); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1608) { return __mosek_2fusion_2BaseVariable__reshape(_1608); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1608) { return __mosek_2fusion_2BaseVariable__reshape(_1608); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1608){
  _checked_ptr_1<int> _ptr__1608(_1608 ? _1608->raw() : nullptr, _1608 ? _1608->size(0) : 0);
  long long _1609 = (int)1;
  int _7303 = (int)0;
  int _7304 = (int)((_1608)->size(0));
  for (int _1610 = _7303; _1610 < _7304; ++_1610)
  {
    {
      if ((_ptr__1608[_1610] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
      _1609 *= _ptr__1608[_1610];
    }
  }
  if ((_1609 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Shape size does not match variable size"));
    }
  }
  {}
  std::vector<int> _7305;
  for (int _1611 = (int)0, _7306 = (int)((_1608)->size(0)); _1611 < _7306 ; ++_1611)
  {
    _7305.push_back(_ptr__1608[_1611]);
  }
  auto _7307 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7305.size()),_7305.begin(),_7305.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_7307,sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
}
void mosek::fusion::BaseVariable :: setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1612) { mosek::fusion::p_BaseVariable::_get_impl(this)->setLevel(_1612); }void mosek::fusion::p_BaseVariable::setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1612){
  _checked_ptr_1<double> _ptr__1612(_1612 ? _1612->raw() : nullptr, _1612 ? _1612->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      if (((int)((_1612)->size(0)) != (int)((nativeidxs)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      model->setVariableValues(true,nativeidxs,_1612);
    }
  }
  else
  {
    {
      if (((int)((_1612)->size(0)) != _pubthis->getSize()))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      std::vector<double> _7308;
      for (int _1614 = (int)0, _7309 = (int)((nativeidxs)->size(0)); _1614 < _7309 ; ++_1614)
      {
        _7308.push_back(_ptr__1612[((*sparsity)(_1614))]);
      }
      auto _7310 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7308.size()),_7308.begin(),_7308.end()));
      std::shared_ptr< monty::ndarray< double,1 > > _1613 = _7310;
      _checked_ptr_1<double> _ptr__1613(_1613 ? _1613->raw() : nullptr,_1613 ? _1613->size(0) : 0);
      model->setVariableValues(true,nativeidxs,_1613);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__getModel() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__getModel(){
  return model;
}
int mosek::fusion::BaseVariable :: getND() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getND(); }int mosek::fusion::p_BaseVariable::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseVariable :: getDim(int _1615) { return mosek::fusion::p_BaseVariable::_get_impl(this)->getDim(_1615); }int mosek::fusion::p_BaseVariable::getDim(int _1615){
  return ((*shape)(_1615));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseVariable :: getShape() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseVariable::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
long long mosek::fusion::BaseVariable :: getSize() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseVariable::getSize(){
  long long _1616 = (long long)1;
  int _7311 = (int)0;
  int _7312 = (int)((shape)->size(0));
  for (int _1617 = _7311; _1617 < _7312; ++_1617)
  {
    {
      _1616 *= ((*shape)(_1617));
    }
  }
  return _1616;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: dual() { return mosek::fusion::p_BaseVariable::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _1618 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1618(_1618 ? _1618->raw() : nullptr,_1618 ? _1618->size(0) : 0);
  model->getVariableValues(false,nativeidxs,_1618,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1619 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1619(_1619 ? _1619->raw() : nullptr,_1619 ? _1619->size(0) : 0);
      int _7313 = (int)0;
      int _7314 = (int)((nativeidxs)->size(0));
      for (int _1620 = _7313; _1620 < _7314; ++_1620)
      {
        {
          _ptr__1619[((*sparsity)(_1620))] = _ptr__1618[_1620];
        }
      }
      _1618 = _1619;
      _ptr__1618.update(_1618 ? _1618->raw() : nullptr, _1618 ? _1618->size(0) : 0);
    }
  }
  {}
  return _1618;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: level() { return mosek::fusion::p_BaseVariable::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _1621 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1621(_1621 ? _1621->raw() : nullptr,_1621 ? _1621->size(0) : 0);
  model->getVariableValues(true,nativeidxs,_1621,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1622 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1622(_1622 ? _1622->raw() : nullptr,_1622 ? _1622->size(0) : 0);
      int _7315 = (int)0;
      int _7316 = (int)((nativeidxs)->size(0));
      for (int _1623 = _7315; _1623 < _7316; ++_1623)
      {
        {
          _ptr__1622[((*sparsity)(_1623))] = _ptr__1621[_1623];
        }
      }
      _1621 = _1622;
      _ptr__1621.update(_1621 ? _1621->raw() : nullptr, _1621 ? _1621->size(0) : 0);
    }
  }
  {}
  return _1621;
}
void mosek::fusion::BaseVariable :: makeContinuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeContinuous(); }void mosek::fusion::p_BaseVariable::makeContinuous(){
  _pubthis->make_continuous();
}
void mosek::fusion::BaseVariable :: makeInteger() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeInteger(); }void mosek::fusion::p_BaseVariable::makeInteger(){
  _pubthis->make_integer();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__transpose() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__transpose(){
  if (((int)((shape)->size(0)) == (int)1))
  {
    {
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(((*shape)((int)0)))}),sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((shape)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid shape for operation"));
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1624 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      _checked_ptr_1<long long> _ptr__1624(_1624 ? _1624->raw() : nullptr,_1624 ? _1624->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _7317;
      bool _7318 = (NULL == sparsity.get());
      if (_7318)
      {
        _7317 = nullptr;
      }
      else
      {
        _7317 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1625 = _7317;
      _checked_ptr_1<long long> _ptr__1625(_1625 ? _1625->raw() : nullptr,_1625 ? _1625->size(0) : 0);
      if ((NULL == sparsity.get()))
      {
        {
          int _1626 = (int)0;
          int _7319 = (int)0;
          int _7320 = ((*shape)((int)1));
          for (int _1627 = _7319; _1627 < _7320; ++_1627)
          {
            {
              int _7321 = (int)0;
              int _7322 = ((*shape)((int)0));
              for (int _1628 = _7321; _1628 < _7322; ++_1628)
              {
                {
                  _ptr__1624[_1626] = ((*nativeidxs)(safe_add( safe_mul( _1628,((*shape)((int)1)) ),_1627 )));
                  ++ _1626;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1629 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( ((*shape)((int)1)),(int)1 ))));
          _checked_ptr_1<int> _ptr__1629(_1629 ? _1629->raw() : nullptr,_1629 ? _1629->size(0) : 0);
          int _1630 = ((*shape)((int)0));
          int _1631 = ((*shape)((int)1));
          int _7323 = (int)0;
          int _7324 = (int)((sparsity)->size(0));
          for (int _1632 = _7323; _1632 < _7324; ++_1632)
          {
            {
              ++ _ptr__1629[safe_add( (((*sparsity)(_1632)) % _1631),(int)1 )];
            }
          }
          int _7325 = (int)0;
          int _7326 = _1631;
          for (int _1633 = _7325; _1633 < _7326; ++_1633)
          {
            {
              _ptr__1629[safe_add( _1633,(int)1 )] += _ptr__1629[_1633];
            }
          }
          int _7327 = (int)0;
          int _7328 = (int)((sparsity)->size(0));
          for (int _1634 = _7327; _1634 < _7328; ++_1634)
          {
            {
              long long _1635 = (((*sparsity)(_1634)) % _1631);
              _ptr__1624[_ptr__1629[_1635]] = ((*nativeidxs)(_1634));
              _ptr__1625[_ptr__1629[_1635]] = safe_add( (((*sparsity)(_1634)) / _1631),safe_mul( (((*sparsity)(_1634)) % _1631),_1630 ) );
              ++ _ptr__1629[_1635];
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*shape)((int)1))),(int)(((*shape)((int)0)))}),_1625,_1624)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1636,int _1637,int _1638) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1636,_1637,_1638); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1636,int _1637,int _1638) { return __mosek_2fusion_2BaseVariable__index(_1636,_1637,_1638); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1636,int _1637,int _1638) { return __mosek_2fusion_2BaseVariable__index(_1636,_1637,_1638); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1636,int _1637,int _1638){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1636),(int)(_1637),(int)(_1638)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1639,int _1640) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1639,_1640); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1639,int _1640) { return __mosek_2fusion_2BaseVariable__index(_1639,_1640); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1639,int _1640) { return __mosek_2fusion_2BaseVariable__index(_1639,_1640); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1639,int _1640){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1639),(int)(_1640)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1641) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1641); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1641) { return __mosek_2fusion_2BaseVariable__index(_1641); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1641) { return __mosek_2fusion_2BaseVariable__index(_1641); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1641){
  _checked_ptr_1<int> _ptr__1641(_1641 ? _1641->raw() : nullptr, _1641 ? _1641->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _1642 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_1641)->size(0)))));
  int _7329 = (int)0;
  int _7330 = (int)((_1641)->size(0));
  for (int _1643 = _7329; _1643 < _7330; ++_1643)
  {
    {
      ((*_1642)((int)0,_1643)) = _ptr__1641[_1643];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1642)->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1644) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1644); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1644) { return __mosek_2fusion_2BaseVariable__index(_1644); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1644) { return __mosek_2fusion_2BaseVariable__index(_1644); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1644){
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1644)}))->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1645,std::shared_ptr< monty::ndarray< int,1 > > _1646,std::shared_ptr< monty::ndarray< int,1 > > _1647) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1645,_1646,_1647); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1645,std::shared_ptr< monty::ndarray< int,1 > > _1646,std::shared_ptr< monty::ndarray< int,1 > > _1647) { return __mosek_2fusion_2BaseVariable__pick(_1645,_1646,_1647); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1645,std::shared_ptr< monty::ndarray< int,1 > > _1646,std::shared_ptr< monty::ndarray< int,1 > > _1647) { return __mosek_2fusion_2BaseVariable__pick(_1645,_1646,_1647); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1645,std::shared_ptr< monty::ndarray< int,1 > > _1646,std::shared_ptr< monty::ndarray< int,1 > > _1647){
  _checked_ptr_1<int> _ptr__1645(_1645 ? _1645->raw() : nullptr, _1645 ? _1645->size(0) : 0);
  _checked_ptr_1<int> _ptr__1646(_1646 ? _1646->raw() : nullptr, _1646 ? _1646->size(0) : 0);
  _checked_ptr_1<int> _ptr__1647(_1647 ? _1647->raw() : nullptr, _1647 ? _1647->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)3))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  if ((((int)((_1645)->size(0)) != (int)((_1646)->size(0))) || ((int)((_1645)->size(0)) != (int)((_1647)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching argument lengths"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1648 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1645)->size(0)),(int)3)));
  int _7331 = (int)0;
  int _7332 = (int)((_1645)->size(0));
  for (int _1649 = _7331; _1649 < _7332; ++_1649)
  {
    {
      ((*_1648)(_1649,(int)0)) = _ptr__1645[_1649];
      ((*_1648)(_1649,(int)1)) = _ptr__1646[_1649];
      ((*_1648)(_1649,(int)2)) = _ptr__1647[_1649];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1648);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1650,std::shared_ptr< monty::ndarray< int,1 > > _1651) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1650,_1651); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1650,std::shared_ptr< monty::ndarray< int,1 > > _1651) { return __mosek_2fusion_2BaseVariable__pick(_1650,_1651); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1650,std::shared_ptr< monty::ndarray< int,1 > > _1651) { return __mosek_2fusion_2BaseVariable__pick(_1650,_1651); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1650,std::shared_ptr< monty::ndarray< int,1 > > _1651){
  _checked_ptr_1<int> _ptr__1650(_1650 ? _1650->raw() : nullptr, _1650 ? _1650->size(0) : 0);
  _checked_ptr_1<int> _ptr__1651(_1651 ? _1651->raw() : nullptr, _1651 ? _1651->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)2) || ((int)((_1650)->size(0)) != (int)((_1651)->size(0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1652 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1650)->size(0)),(int)2)));
  int _7333 = (int)0;
  int _7334 = (int)((_1650)->size(0));
  for (int _1653 = _7333; _1653 < _7334; ++_1653)
  {
    {
      ((*_1652)(_1653,(int)0)) = _ptr__1650[_1653];
      ((*_1652)(_1653,(int)1)) = _ptr__1651[_1653];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1652);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1654) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1654); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1654) { return __mosek_2fusion_2BaseVariable__pick(_1654); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1654) { return __mosek_2fusion_2BaseVariable__pick(_1654); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1654){
  if (((int)((shape)->size(0)) != (int)((_1654)->size(1))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _7335 = (int)0;
  int _7336 = (int)((_1654)->size(0));
  for (int _1655 = _7335; _1655 < _7336; ++_1655)
  {
    {
      int _7337 = (int)0;
      int _7338 = (int)((_1654)->size(1));
      for (int _1656 = _7337; _1656 < _7338; ++_1656)
      {
        {
          if (((((*_1654)(_1655,_1656)) < (int)0) || (((*_1654)(_1655,_1656)) >= ((*shape)(_1656)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
            }
          }
          {}
        }
      }
    }
  }
  int _1657 = (int)((shape)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1658 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1657)));
  _checked_ptr_1<long long> _ptr__1658(_1658 ? _1658->raw() : nullptr,_1658 ? _1658->size(0) : 0);
  _ptr__1658[(_1657 - (int)1)] = (int)1;
  int _7339 = (int)1;
  int _7340 = _1657;
  for (int _1659 = _7339; _1659 < _7340; ++_1659)
  {
    {
      _ptr__1658[((_1657 - _1659) - (int)1)] = safe_mul( _ptr__1658[(_1657 - _1659)],((*shape)((_1657 - _1659))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1660 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1654)->size(0)))});
  _checked_ptr_1<int> _ptr__1660(_1660 ? _1660->raw() : nullptr,_1660 ? _1660->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1661;
  _checked_ptr_1<long long> _ptr__1661(_1661 ? _1661->raw() : nullptr,_1661 ? _1661->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1662 = nullptr;
  _checked_ptr_1<long long> _ptr__1662(_1662 ? _1662->raw() : nullptr,_1662 ? _1662->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _1661 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1654)->size(0)))));
      _ptr__1661.update(_1661 ? _1661->raw() : nullptr, _1661 ? _1661->size(0) : 0);
      {
        int _7341 = (int)0;
        int _7342 = (int)((_1654)->size(0));
        for (int _1663 = _7341; _1663 < _7342; ++_1663)
        {
          {
            long long _1664 = (long long)0;
            int _7343 = (int)0;
            int _7344 = _1657;
            for (int _1665 = _7343; _1665 < _7344; ++_1665)
            {
              {
                _1664 += safe_mul( _ptr__1658[_1665],((*_1654)(_1663,_1665)) );
              }
            }
            _ptr__1661[_1663] = ((*nativeidxs)(_1664));
          }
        }
      }
    }
  }
  else
  {
    {
      int _1666 = (int)0;
      int _7345 = (int)0;
      int _7346 = (int)((_1654)->size(0));
      for (int _1667 = _7345; _1667 < _7346; ++_1667)
      {
        {
          long long _1668 = (long long)0;
          int _7347 = (int)0;
          int _7348 = _1657;
          for (int _1669 = _7347; _1669 < _7348; ++_1669)
          {
            {
              _1668 += safe_mul( _ptr__1658[_1669],((*_1654)(_1667,_1669)) );
            }
          }
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1668) >= (int)0))
          {
            {
              ++ _1666;
            }
          }
          {}
        }
      }
      _1661 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1666)));
      _ptr__1661.update(_1661 ? _1661->raw() : nullptr, _1661 ? _1661->size(0) : 0);
      _1662 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1666)));
      _ptr__1662.update(_1662 ? _1662->raw() : nullptr, _1662 ? _1662->size(0) : 0);
      {
        int _1670 = (int)0;
        int _7349 = (int)0;
        int _7350 = (int)((_1654)->size(0));
        for (int _1671 = _7349; _1671 < _7350; ++_1671)
        {
          {
            long long _1672 = (long long)0;
            int _7351 = (int)0;
            int _7352 = _1657;
            for (int _1673 = _7351; _1673 < _7352; ++_1673)
            {
              {
                _1672 += safe_mul( _ptr__1658[_1673],((*_1654)(_1671,_1673)) );
              }
            }
            int _1674 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1672);
            if ((_1674 >= (int)0))
            {
              {
                _ptr__1661[_1670] = ((*nativeidxs)(_1674));
                _ptr__1662[_1670] = _1671;
                ++ _1670;
              }
            }
            {}
          }
        }
      }
      if ((_1666 == (int)((_1654)->size(0))))
      {
        {
          _1662 = nullptr;
          _ptr__1662.update(_1662 ? _1662->raw() : nullptr, _1662 ? _1662->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1660,_1662,_1661)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1675) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1675); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1675) { return __mosek_2fusion_2BaseVariable__pick(_1675); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1675) { return __mosek_2fusion_2BaseVariable__pick(_1675); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1675){
  _checked_ptr_1<int> _ptr__1675(_1675 ? _1675->raw() : nullptr, _1675 ? _1675->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _7353 = (int)0;
  int _7354 = (int)((_1675)->size(0));
  for (int _1676 = _7353; _1676 < _7354; ++_1676)
  {
    {
      if (((_ptr__1675[_1676] < (int)0) || (_ptr__1675[_1676] >= ((*shape)((int)0)))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1677;
  _checked_ptr_1<long long> _ptr__1677(_1677 ? _1677->raw() : nullptr,_1677 ? _1677->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1678 = nullptr;
  _checked_ptr_1<long long> _ptr__1678(_1678 ? _1678->raw() : nullptr,_1678 ? _1678->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      std::vector<long long> _7355;
      for (int _1679 = (int)0, _7356 = (int)((_1675)->size(0)); _1679 < _7356 ; ++_1679)
      {
        _7355.push_back(((*nativeidxs)(_ptr__1675[_1679])));
      }
      auto _7357 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7355.size()),_7355.begin(),_7355.end()));
      _1677 = _7357;
      _ptr__1677.update(_1677 ? _1677->raw() : nullptr, _1677 ? _1677->size(0) : 0);
    }
  }
  else
  {
    {
      int _1680 = (int)0;
      int _7358 = (int)0;
      int _7359 = (int)((_1675)->size(0));
      for (int _1681 = _7358; _1681 < _7359; ++_1681)
      {
        {
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1675[_1681])) >= (int)0))
          {
            {
              ++ _1680;
            }
          }
          {}
        }
      }
      _1677 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1680)));
      _ptr__1677.update(_1677 ? _1677->raw() : nullptr, _1677 ? _1677->size(0) : 0);
      _1678 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1680)));
      _ptr__1678.update(_1678 ? _1678->raw() : nullptr, _1678 ? _1678->size(0) : 0);
      int _1682 = (int)0;
      int _7360 = (int)0;
      int _7361 = (int)((_1675)->size(0));
      for (int _1683 = _7360; _1683 < _7361; ++_1683)
      {
        {
          int _1684 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1675[_1683]));
          if ((_1684 >= (int)0))
          {
            {
              _ptr__1678[_1682] = _1683;
              _ptr__1677[_1682] = ((*nativeidxs)(_1684));
              ++ _1682;
            }
          }
          {}
        }
      }
      if ((_1680 == (int)((_1675)->size(0))))
      {
        {
          _1678 = nullptr;
          _ptr__1678.update(_1678 ? _1678->raw() : nullptr, _1678 ? _1678->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1675)->size(0)))}),_1678,_1677)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag(int _1685) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(_1685); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag(int _1685) { return __mosek_2fusion_2BaseVariable__antidiag(_1685); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag(int _1685) { return __mosek_2fusion_2BaseVariable__antidiag(_1685); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(int _1685){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  else if(((_1685 >= ((*shape)((int)1))) || ((-_1685) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1685 >= (int)0))
  {
    {
      int _7362;
      bool _7363 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1685));
      if (_7363)
      {
        _7362 = ((*shape)((int)0));
      }
      else
      {
        _7362 = (((*shape)((int)1)) - _1685);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(((((*shape)((int)1)) - (int)1) - _1685))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7362);
    }
  }
  else
  {
    {
      int _7364;
      bool _7365 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1685 ));
      if (_7365)
      {
        _7364 = ((*shape)((int)1));
      }
      else
      {
        _7364 = safe_add( ((*shape)((int)0)),_1685 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1685)),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7364);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7366;
  bool _7367 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7367)
  {
    _7366 = ((*shape)((int)0));
  }
  else
  {
    _7366 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7366);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag(int _1686) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(_1686); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag(int _1686) { return __mosek_2fusion_2BaseVariable__diag(_1686); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag(int _1686) { return __mosek_2fusion_2BaseVariable__diag(_1686); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(int _1686){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  else if(((_1686 >= ((*shape)((int)1))) || ((-_1686) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1686 >= (int)0))
  {
    {
      int _7368;
      bool _7369 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1686));
      if (_7369)
      {
        _7368 = ((*shape)((int)0));
      }
      else
      {
        _7368 = (((*shape)((int)1)) - _1686);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(_1686)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7368);
    }
  }
  else
  {
    {
      int _7370;
      bool _7371 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1686 ));
      if (_7371)
      {
        _7370 = ((*shape)((int)1));
      }
      else
      {
        _7370 = safe_add( ((*shape)((int)0)),_1686 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1686)),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7370);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag() { return __mosek_2fusion_2BaseVariable__diag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7372;
  bool _7373 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7373)
  {
    _7372 = ((*shape)((int)0));
  }
  else
  {
    _7372 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7372);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1687,std::shared_ptr< monty::ndarray< int,1 > > _1688,int _1689){
  _checked_ptr_1<int> _ptr__1687(_1687 ? _1687->raw() : nullptr, _1687 ? _1687->size(0) : 0);
  _checked_ptr_1<int> _ptr__1688(_1688 ? _1688->raw() : nullptr, _1688 ? _1688->size(0) : 0);
  int _1690 = (int)((shape)->size(0));
  if (((_1690 != (int)((_1687)->size(0))) || (_1690 != (int)((_1688)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid start or step definition"));
    }
  }
  {}
  int _7374 = (int)0;
  int _7375 = _1690;
  for (int _1691 = _7374; _1691 < _7375; ++_1691)
  {
    {
      if (((_ptr__1687[_1691] < (int)0) || (_ptr__1687[_1691] >= ((*shape)(_1691)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Start element is out of bounds"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1692 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1690)));
  _checked_ptr_1<long long> _ptr__1692(_1692 ? _1692->raw() : nullptr,_1692 ? _1692->size(0) : 0);
  _ptr__1692[(_1690 - (int)1)] = (int)1;
  int _7376 = (int)1;
  int _7377 = _1690;
  for (int _1693 = _7376; _1693 < _7377; ++_1693)
  {
    {
      _ptr__1692[((_1690 - _1693) - (int)1)] = safe_mul( _ptr__1692[(_1690 - _1693)],((*shape)((_1690 - _1693))) );
    }
  }
  long long _1694 = (long long)0;
  int _7378 = (int)0;
  int _7379 = (int)((_1688)->size(0));
  for (int _1695 = _7378; _1695 < _7379; ++_1695)
  {
    {
      _1694 += safe_mul( _ptr__1687[_1695],_ptr__1692[_1695] );
    }
  }
  long long _1696 = (long long)0;
  int _7380 = (int)0;
  int _7381 = (int)((_1688)->size(0));
  for (int _1697 = _7380; _1697 < _7381; ++_1697)
  {
    {
      _1696 += safe_mul( _ptr__1688[_1697],_ptr__1692[_1697] );
    }
  }
  if ((NULL == sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1698 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1689)));
      _checked_ptr_1<long long> _ptr__1698(_1698 ? _1698->raw() : nullptr,_1698 ? _1698->size(0) : 0);
      int _7382 = (int)0;
      int _7383 = _1689;
      for (int _1699 = _7382; _1699 < _7383; ++_1699)
      {
        {
          _ptr__1698[_1699] = ((*nativeidxs)(safe_add( _1694,safe_mul( _1696,_1699 ) )));
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1689)}),nullptr,_1698)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1700 = (int)0;
      int _7384 = (int)0;
      int _7385 = _1689;
      for (int _1701 = _7384; _1701 < _7385; ++_1701)
      {
        {
          long long _1702 = safe_add( _1694,safe_mul( _1696,_1701 ) );
          int _1703 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1702);
          if ((_1703 >= (int)0))
          {
            {
              ++ _1700;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1704 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1700)));
      _checked_ptr_1<long long> _ptr__1704(_1704 ? _1704->raw() : nullptr,_1704 ? _1704->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1705 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1700)));
      _checked_ptr_1<long long> _ptr__1705(_1705 ? _1705->raw() : nullptr,_1705 ? _1705->size(0) : 0);
      int _1706 = (int)0;
      int _7386 = (int)0;
      int _7387 = _1689;
      for (int _1707 = _7386; _1707 < _7387; ++_1707)
      {
        {
          _ptr__1704[_1707] = ((*nativeidxs)(safe_add( _1694,safe_mul( _1696,_1707 ) )));
          long long _1708 = safe_add( _1694,safe_mul( _1696,_1707 ) );
          int _1709 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1708);
          if ((_1709 >= (int)0))
          {
            {
              _ptr__1705[_1706] = _1707;
              _ptr__1704[_1706] = ((*nativeidxs)(_1709));
              ++ _1706;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1689)}),_1705,_1704)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1710,std::shared_ptr< monty::ndarray< int,1 > > _1711) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1710,_1711); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1710,std::shared_ptr< monty::ndarray< int,1 > > _1711) { return __mosek_2fusion_2BaseVariable__slice(_1710,_1711); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1710,std::shared_ptr< monty::ndarray< int,1 > > _1711) { return __mosek_2fusion_2BaseVariable__slice(_1710,_1711); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1710,std::shared_ptr< monty::ndarray< int,1 > > _1711){
  _checked_ptr_1<int> _ptr__1710(_1710 ? _1710->raw() : nullptr, _1710 ? _1710->size(0) : 0);
  _checked_ptr_1<int> _ptr__1711(_1711 ? _1711->raw() : nullptr, _1711 ? _1711->size(0) : 0);
  if (((int)((_1710)->size(0)) != (int)((_1711)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if(((int)((_1710)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7388 = (int)0;
      int _7389 = (int)((shape)->size(0));
      for (int _1712 = _7388; _1712 < _7389; ++_1712)
      {
        {
          if (((_ptr__1710[_1712] < (int)0) || (_ptr__1711[_1712] > ((*shape)(_1712)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
            }
          }
          else if((_ptr__1710[_1712] > _ptr__1711[_1712]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
            }
          }
          {}
        }
      }
      int _1713 = (int)((shape)->size(0));
      std::vector<int> _7390;
      for (int _1715 = (int)0, _7391 = _1713; _1715 < _7391 ; ++_1715)
      {
        _7390.push_back((_ptr__1711[_1715] - _ptr__1710[_1715]));
      }
      auto _7392 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7390.size()),_7390.begin(),_7390.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1714 = _7392;
      _checked_ptr_1<int> _ptr__1714(_1714 ? _1714->raw() : nullptr,_1714 ? _1714->size(0) : 0);
      int _1716 = (int)1;
      int _7393 = (int)0;
      int _7394 = _1713;
      for (int _1717 = _7393; _1717 < _7394; ++_1717)
      {
        {
          _1716 *= (_ptr__1711[_1717] - _ptr__1710[_1717]);
        }
      }
      if ((_1716 == (int)0))
      {
        {
          return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
        }
      }
      else if((NULL != sparsity.get()))
      {
        {
          int _1718 = (int)0;
          std::shared_ptr< monty::ndarray< int,1 > > _1719 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1713)));
          _checked_ptr_1<int> _ptr__1719(_1719 ? _1719->raw() : nullptr,_1719 ? _1719->size(0) : 0);
          int _7395 = (int)0;
          int _7396 = (int)((sparsity)->size(0));
          for (int _1720 = _7395; _1720 < _7396; ++_1720)
          {
            {
              long long _1721 = ((*sparsity)(_1720));
              int _7397 = (int)1;
              int _7398 = _1713;
              for (int _1722 = _7397; _1722 < _7398; ++_1722)
              {
                {
                  _ptr__1719[(_1713 - _1722)] = (int)(_1721 % ((*shape)((_1713 - _1722))));
                  _1721 /= ((*shape)((_1713 - _1722)));
                }
              }
              _ptr__1719[(int)0] = (int)_1721;
              int _1723 = (int)0;
              while ( ((_ptr__1719[_1723] >= _ptr__1710[_1723]) && (_ptr__1719[_1723] < _ptr__1711[_1723])) )
              {
                {
                  ++ _1723;
                }
              }
              if ((_1723 == _1713))
              {
                {
                  ++ _1718;
                }
              }
              {}
            }
          }
          int _1724 = (int)0;
          std::shared_ptr< monty::ndarray< long long,1 > > _1725 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1718)));
          _checked_ptr_1<long long> _ptr__1725(_1725 ? _1725->raw() : nullptr,_1725 ? _1725->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1726 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1718)));
          _checked_ptr_1<long long> _ptr__1726(_1726 ? _1726->raw() : nullptr,_1726 ? _1726->size(0) : 0);
          int _7399 = (int)0;
          int _7400 = (int)((sparsity)->size(0));
          for (int _1727 = _7399; _1727 < _7400; ++_1727)
          {
            {
              long long _1728 = ((*sparsity)(_1727));
              int _7401 = (int)1;
              int _7402 = _1713;
              for (int _1729 = _7401; _1729 < _7402; ++_1729)
              {
                {
                  _ptr__1719[(_1713 - _1729)] = (int)(_1728 % ((*shape)((_1713 - _1729))));
                  _1728 /= ((*shape)((_1713 - _1729)));
                }
              }
              _ptr__1719[(int)0] = (int)_1728;
              int _1730 = (int)0;
              while ( ((_ptr__1719[_1730] >= _ptr__1710[_1730]) && (_ptr__1719[_1730] < _ptr__1711[_1730])) )
              {
                {
                  ++ _1730;
                }
              }
              if ((_1730 == _1713))
              {
                {
                  _ptr__1725[_1724] = ((*nativeidxs)(_1727));
                  int _1731 = (int)0;
                  int _7403 = (int)0;
                  int _7404 = _1713;
                  for (int _1732 = _7403; _1732 < _7404; ++_1732)
                  {
                    {
                      _1731 = safe_add( safe_mul( _1731,_ptr__1714[_1732] ),(_ptr__1719[_1732] - _ptr__1710[_1732]) );
                    }
                  }
                  _ptr__1726[_1724] = _1731;
                  ++ _1724;
                }
              }
              {}
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1714,_1726,_1725)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1733 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1716)));
          _checked_ptr_1<long long> _ptr__1733(_1733 ? _1733->raw() : nullptr,_1733 ? _1733->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _1734 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1713)));
            _checked_ptr_1<int> _ptr__1734(_1734 ? _1734->raw() : nullptr,_1734 ? _1734->size(0) : 0);
            _ptr__1734[(_1713 - (int)1)] = (int)1;
            int _7405 = (int)1;
            int _7406 = _1713;
            for (int _1735 = _7405; _1735 < _7406; ++_1735)
            {
              {
                _ptr__1734[((_1713 - _1735) - (int)1)] = safe_mul( _ptr__1734[(_1713 - _1735)],((*shape)((_1713 - _1735))) );
              }
            }
            int _1736 = (int)0;
            int _7407 = (int)0;
            int _7408 = _1713;
            for (int _1737 = _7407; _1737 < _7408; ++_1737)
            {
              {
                _1736 += safe_mul( _ptr__1710[_1737],_ptr__1734[_1737] );
              }
            }
            std::vector<int> _7409;
            for (int _1739 = (int)0, _7410 = _1713; _1739 < _7410 ; ++_1739)
            {
              _7409.push_back(_1736);
            }
            auto _7411 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7409.size()),_7409.begin(),_7409.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1738 = _7411;
            _checked_ptr_1<int> _ptr__1738(_1738 ? _1738->raw() : nullptr,_1738 ? _1738->size(0) : 0);
            std::vector<int> _7412;
            for (int _1741 = (int)0, _7413 = _1713; _1741 < _7413 ; ++_1741)
            {
              _7412.push_back(_ptr__1710[_1741]);
            }
            auto _7414 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7412.size()),_7412.begin(),_7412.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1740 = _7414;
            _checked_ptr_1<int> _ptr__1740(_1740 ? _1740->raw() : nullptr,_1740 ? _1740->size(0) : 0);
            int _7415 = (int)0;
            int _7416 = _1716;
            for (int _1742 = _7415; _1742 < _7416; ++_1742)
            {
              {
                _ptr__1733[_1742] = ((*nativeidxs)(_ptr__1738[(_1713 - (int)1)]));
                _ptr__1740[(_1713 - (int)1)] += (int)1;
                _ptr__1738[(_1713 - (int)1)] += _ptr__1734[(_1713 - (int)1)];
                if ((_ptr__1740[(_1713 - (int)1)] >= _ptr__1711[(_1713 - (int)1)]))
                {
                  {
                    int _1743 = (_1713 - (int)1);
                    while ( ((_1743 > (int)0) && (_ptr__1740[_1743] >= _ptr__1711[_1743])) )
                    {
                      {
                        _ptr__1740[_1743] = _ptr__1710[_1743];
                        _ptr__1740[(_1743 - (int)1)] += (int)1;
                        _ptr__1738[(_1743 - (int)1)] += _ptr__1734[(_1743 - (int)1)];
                        -- _1743;
                      }
                    }
                    int _7417 = safe_add( _1743,(int)1 );
                    int _7418 = _1713;
                    for (int _1744 = _7417; _1744 < _7418; ++_1744)
                    {
                      {
                        _ptr__1738[_1744] = _ptr__1738[_1743];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1714,nullptr,_1733)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(int _1745,int _1746) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1745,_1746); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(int _1745,int _1746) { return __mosek_2fusion_2BaseVariable__slice(_1745,_1746); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(int _1745,int _1746) { return __mosek_2fusion_2BaseVariable__slice(_1745,_1746); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(int _1745,int _1746){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_1745 == (int)0) && (_1746 == ((*shape)((int)0)))))
  {
    {
      return (::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((_1745 < (int)0) || (_1746 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_1745 > _1746))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if((_1745 == _1746))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((NULL != sparsity.get()))
  {
    {
      int _1747 = (_1746 - _1745);
      int _1748 = (int)0;
      int _1749 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1745));
      int _1750 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1746));
      std::vector<long long> _7419;
      for (int _1751 = _1749, _7420 = _1750; _1751 < _7420 ; ++_1751)
      {
        _7419.push_back((((*sparsity)(_1751)) - _1745));
      }
      auto _7421 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7419.size()),_7419.begin(),_7419.end()));
      std::vector<long long> _7422;
      for (int _1752 = _1749, _7423 = _1750; _1752 < _7423 ; ++_1752)
      {
        _7422.push_back(((*nativeidxs)(_1752)));
      }
      auto _7424 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7422.size()),_7422.begin(),_7422.end()));
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1747)}),_7421,_7424)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1753 = (_1746 - _1745);
      std::shared_ptr< monty::ndarray< long long,1 > > _1754 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1753)));
      _checked_ptr_1<long long> _ptr__1754(_1754 ? _1754->raw() : nullptr,_1754 ? _1754->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(nativeidxs,_1745,_1754,(int)0,_1753);
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1753)}),nullptr,_1754)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__asExpr() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__asExpr(){
  return (::mosek::fusion::p_ExprFromVar::_new_ExprFromVar((::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>())).as<::mosek::fusion::Expression>();
}
int mosek::fusion::BaseVariable :: inst(int _1755,std::shared_ptr< monty::ndarray< long long,1 > > _1756,int _1757,std::shared_ptr< monty::ndarray< long long,1 > > _1758) { return mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1755,_1756,_1757,_1758); }int mosek::fusion::p_BaseVariable::inst(int _1755,std::shared_ptr< monty::ndarray< long long,1 > > _1756,int _1757,std::shared_ptr< monty::ndarray< long long,1 > > _1758){
  _checked_ptr_1<long long> _ptr__1756(_1756 ? _1756->raw() : nullptr, _1756 ? _1756->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1758(_1758 ? _1758->raw() : nullptr, _1758 ? _1758->size(0) : 0);
  if ((NULL == mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity.get()))
  {
    {
      int _7425 = (int)0;
      int _7426 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
      for (int _1759 = _7425; _1759 < _7426; ++_1759)
      {
        {
          _ptr__1756[safe_add( _1759,_1755 )] = _1759;
          _ptr__1758[safe_add( _1759,_1757 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)(_1759));
        }
      }
    }
  }
  else
  {
    {
      int _7427 = (int)0;
      int _7428 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)->size(0));
      for (int _1760 = _7427; _1760 < _7428; ++_1760)
      {
        {
          _ptr__1756[safe_add( _1755,_1760 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)(_1760));
          _ptr__1758[safe_add( _1760,_1757 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)(_1760));
        }
      }
    }
  }
  return (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
}
int mosek::fusion::BaseVariable :: numInst() { return mosek::fusion::p_BaseVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_BaseVariable::numInst(){
  return (int)((nativeidxs)->size(0));
}
void mosek::fusion::BaseVariable :: inst(int _1761,std::shared_ptr< monty::ndarray< long long,1 > > _1762) { mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1761,_1762); }void mosek::fusion::p_BaseVariable::inst(int _1761,std::shared_ptr< monty::ndarray< long long,1 > > _1762){
  _checked_ptr_1<long long> _ptr__1762(_1762 ? _1762->raw() : nullptr, _1762 ? _1762->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      int _7429 = (int)0;
      int _7430 = (int)((nativeidxs)->size(0));
      for (int _1763 = _7429; _1763 < _7430; ++_1763)
      {
        {
          _ptr__1762[safe_add( _1761,_1763 )] = ((*nativeidxs)(_1763));
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1764 = _pubthis->getShape();
      _checked_ptr_1<int> _ptr__1764(_1764 ? _1764->raw() : nullptr,_1764 ? _1764->size(0) : 0);
      int _1765 = (int)1;
      int _7431 = (int)0;
      int _7432 = (int)((_1764)->size(0));
      for (int _1766 = _7431; _1766 < _7432; ++_1766)
      {
        {
          _1765 *= _ptr__1764[_1766];
        }
      }
      int _7433 = (int)0;
      int _7434 = _1765;
      for (int _1767 = _7433; _1767 < _7434; ++_1767)
      {
        {
          _ptr__1762[safe_add( _1761,_1767 )] = (int)0;
        }
      }
      int _7435 = (int)0;
      int _7436 = (int)((sparsity)->size(0));
      for (int _1768 = _7435; _1768 < _7436; ++_1768)
      {
        {
          _ptr__1762[safe_add( _1761,((*sparsity)(_1768)) )] = ((*nativeidxs)(_1768));
        }
      }
    }
  }
}
void mosek::fusion::BaseVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1769,bool _1770) { mosek::fusion::p_BaseVariable::_get_impl(this)->set_values(_1769,_1770); }void mosek::fusion::p_BaseVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1769,bool _1770){
  _checked_ptr_1<double> _ptr__1769(_1769 ? _1769->raw() : nullptr, _1769 ? _1769->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1770,nativeidxs,_1769);
    }
  }
  else
  {
    {
      int _1771 = (int)1;
      int _7437 = (int)0;
      int _7438 = (int)((shape)->size(0));
      for (int _1772 = _7437; _1772 < _7438; ++_1772)
      {
        {
          _1771 *= ((*shape)(_1772));
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1773 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1771)));
      _checked_ptr_1<long long> _ptr__1773(_1773 ? _1773->raw() : nullptr,_1773 ? _1773->size(0) : 0);
      int _7439 = (int)0;
      int _7440 = (int)((nativeidxs)->size(0));
      for (int _1774 = _7439; _1774 < _7440; ++_1774)
      {
        {
          _ptr__1773[((*sparsity)(_1774))] = ((*nativeidxs)(_1774));
        }
      }
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1770,_1773,_1769);
    }
  }
}
void mosek::fusion::p_BaseVariable::dual_lu(int _1775,std::shared_ptr< monty::ndarray< double,1 > > _1776,bool _1777){
  _checked_ptr_1<double> _ptr__1776(_1776 ? _1776->raw() : nullptr, _1776 ? _1776->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableDuals(_1777,nativeidxs,_1776,_1775);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1778 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1778(_1778 ? _1778->raw() : nullptr,_1778 ? _1778->size(0) : 0);
      int _7441 = (int)0;
      int _7442 = (int)((sparsity)->size(0));
      for (int _1779 = _7441; _1779 < _7442; ++_1779)
      {
        {
          _ptr__1778[((*sparsity)(_1779))] = ((*nativeidxs)(_1779));
        }
      }
      model->getVariableDuals(_1777,_1778,_1776,_1775);
    }
  }
}
void mosek::fusion::BaseVariable :: values(int _1780,std::shared_ptr< monty::ndarray< double,1 > > _1781,bool _1782) { mosek::fusion::p_BaseVariable::_get_impl(this)->values(_1780,_1781,_1782); }void mosek::fusion::p_BaseVariable::values(int _1780,std::shared_ptr< monty::ndarray< double,1 > > _1781,bool _1782){
  _checked_ptr_1<double> _ptr__1781(_1781 ? _1781->raw() : nullptr, _1781 ? _1781->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableValues(_1782,nativeidxs,_1781,_1780);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1783 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1783(_1783 ? _1783->raw() : nullptr,_1783 ? _1783->size(0) : 0);
      int _7443 = (int)0;
      int _7444 = (int)((sparsity)->size(0));
      for (int _1784 = _7443; _1784 < _7444; ++_1784)
      {
        {
          _ptr__1783[((*sparsity)(_1784))] = ((*nativeidxs)(_1784));
        }
      }
      model->getVariableValues(_1782,_1783,_1781,_1780);
    }
  }
}
void mosek::fusion::BaseVariable :: make_continuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_BaseVariable::make_continuous(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_continuous(nativeidxs);
}
void mosek::fusion::BaseVariable :: make_integer() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_BaseVariable::make_integer(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_integer(nativeidxs);
}
void mosek::fusion::p_BaseVariable::destroy(){sparsity.reset();nativeidxs.reset();model.reset();shape.reset();}void mosek::fusion::BaseVariable::destroy() { mosek::fusion::p_BaseVariable::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Model > mosek::fusion::Variable::getModel() { return __mosek_2fusion_2Variable__getModel(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1792) { return __mosek_2fusion_2Variable__reshape(_1792); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::transpose() { return __mosek_2fusion_2Variable__transpose(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1798,std::shared_ptr< monty::ndarray< int,1 > > _1799,std::shared_ptr< monty::ndarray< int,1 > > _1800) { return __mosek_2fusion_2Variable__pick(_1798,_1799,_1800); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1801,std::shared_ptr< monty::ndarray< int,1 > > _1802) { return __mosek_2fusion_2Variable__pick(_1801,_1802); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _1803) { return __mosek_2fusion_2Variable__pick(_1803); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1803) { return __mosek_2fusion_2Variable__pick(_1803); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _1804) { return __mosek_2fusion_2Variable__pick(_1804); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1804) { return __mosek_2fusion_2Variable__pick(_1804); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag() { return __mosek_2fusion_2Variable__antidiag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag(int _1805) { return __mosek_2fusion_2Variable__antidiag(_1805); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag() { return __mosek_2fusion_2Variable__diag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag(int _1806) { return __mosek_2fusion_2Variable__diag(_1806); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _1807) { return __mosek_2fusion_2Variable__index(_1807); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(std::shared_ptr< monty::ndarray< int,1 > > _1807) { return __mosek_2fusion_2Variable__index(_1807); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1808,int _1809,int _1810) { return __mosek_2fusion_2Variable__index(_1808,_1809,_1810); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1811,int _1812) { return __mosek_2fusion_2Variable__index(_1811,_1812); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(int _1813) { return __mosek_2fusion_2Variable__index(_1813); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1813) { return __mosek_2fusion_2Variable__index(_1813); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _1814,std::shared_ptr< monty::ndarray< int,1 > > _1815) { return __mosek_2fusion_2Variable__slice(_1814,_1815); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1814,std::shared_ptr< monty::ndarray< int,1 > > _1815) { return __mosek_2fusion_2Variable__slice(_1814,_1815); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(int _1816,int _1817) { return __mosek_2fusion_2Variable__slice(_1816,_1817); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(int _1816,int _1817) { return __mosek_2fusion_2Variable__slice(_1816,_1817); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::asExpr() { return __mosek_2fusion_2Variable__asExpr(); }
mosek::fusion::Var::Var(mosek::fusion::p_Var *_impl) : _impl(_impl) { /*std::cout << "Var() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Var::~Var() { delete _impl; _impl = nullptr; }mosek::fusion::p_Var::p_Var  (::mosek::fusion::Var * _pubthis) :     _pubthis(_pubthis){}monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::empty  ( std::shared_ptr< monty::ndarray< int,1 > > _1818) { return mosek::fusion::p_Var::empty(_1818); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::empty(std::shared_ptr< monty::ndarray< int,1 > > _1818){
  _checked_ptr_1<int> _ptr__1818(_1818 ? _1818->raw() : nullptr, _1818 ? _1818->size(0) : 0);
  int _7445 = (int)0;
  int _7446 = (int)((_1818)->size(0));
  for (int _1819 = _7445; _1819 < _7446; ++_1819)
  {
    {
      if ((_ptr__1818[_1819] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_1818)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::compress  ( monty::rc_ptr< ::mosek::fusion::Variable > _1820) { return mosek::fusion::p_Var::compress(_1820); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::compress(monty::rc_ptr< ::mosek::fusion::Variable > _1820){
  std::shared_ptr< monty::ndarray< int,1 > > _1821 = _1820->getShape();
  _checked_ptr_1<int> _ptr__1821(_1821 ? _1821->raw() : nullptr,_1821 ? _1821->size(0) : 0);
  int _1822 = (int)((_1821)->size(0));
  int _1823 = (int)0;
  int _7447 = (int)0;
  int _7448 = _1822;
  for (int _1824 = _7447; _1824 < _7448; ++_1824)
  {
    {
      if ((_ptr__1821[_1824] != (int)1))
      {
        {
          ++ _1823;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1825 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1823)));
  _checked_ptr_1<int> _ptr__1825(_1825 ? _1825->raw() : nullptr,_1825 ? _1825->size(0) : 0);
  {
    int _1826 = (int)0;
    int _7449 = (int)0;
    int _7450 = _1822;
    for (int _1827 = _7449; _1827 < _7450; ++_1827)
    {
      {
        if ((_ptr__1821[_1827] != (int)1))
        {
          {
            _ptr__1825[_1826] = _ptr__1821[_1827];
            ++ _1826;
          }
        }
        {}
      }
    }
  }
  return ::mosek::fusion::p_Var::reshape(_1820,_1825);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1828,    int _1829) { return mosek::fusion::p_Var::reshape(_1828,_1829); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1828,int _1829){
  return ::mosek::fusion::p_Var::reshape(_1828,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1829)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1830,    int _1831,    int _1832) { return mosek::fusion::p_Var::reshape(_1830,_1831,_1832); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1830,int _1831,int _1832){
  return ::mosek::fusion::p_Var::reshape(_1830,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1831),(int)(_1832)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::flatten  ( monty::rc_ptr< ::mosek::fusion::Variable > _1833) { return mosek::fusion::p_Var::flatten(_1833); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1833){
  return ::mosek::fusion::p_Var::reshape(_1833,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)::mosek::fusion::p_Set::size(_1833->getShape()))}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1834,    std::shared_ptr< monty::ndarray< int,1 > > _1835) { return mosek::fusion::p_Var::reshape(_1834,_1835); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1834,std::shared_ptr< monty::ndarray< int,1 > > _1835){
  _checked_ptr_1<int> _ptr__1835(_1835 ? _1835->raw() : nullptr, _1835 ? _1835->size(0) : 0);
  return _1834->__mosek_2fusion_2Variable__reshape(_1835);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1836,std::shared_ptr< monty::ndarray< int,1 > > _1837){
  _checked_ptr_1<int> _ptr__1837(_1837 ? _1837->raw() : nullptr, _1837 ? _1837->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1838;
  _checked_ptr_1<long long> _ptr__1838(_1838 ? _1838->raw() : nullptr,_1838 ? _1838->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1839;
  _checked_ptr_1<long long> _ptr__1839(_1839 ? _1839->raw() : nullptr,_1839 ? _1839->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1840 = _1836->getShape();
  _checked_ptr_1<int> _ptr__1840(_1840 ? _1840->raw() : nullptr,_1840 ? _1840->size(0) : 0);
  int _1841 = (int)((_1840)->size(0));
  int _1842 = (int)1;
  int _7451 = (int)0;
  int _7452 = _1841;
  for (int _1843 = _7451; _1843 < _7452; ++_1843)
  {
    {
      _1842 *= _ptr__1840[_1843];
    }
  }
  int _1844 = _1836->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _1845 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1841)));
  _checked_ptr_1<long long> _ptr__1845(_1845 ? _1845->raw() : nullptr,_1845 ? _1845->size(0) : 0);
  _ptr__1845[(_1841 - (int)1)] = (int)1;
  int _7453 = (int)1;
  int _7454 = _1841;
  for (int _1846 = _7453; _1846 < _7454; ++_1846)
  {
    {
      _ptr__1845[((_1841 - _1846) - (int)1)] = safe_mul( _ptr__1845[(_1841 - _1846)],_ptr__1840[_ptr__1837[(_1841 - _1846)]] );
    }
  }
  if ((_1844 < _1842))
  {
    {
      _1838 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1844)));
      _ptr__1838.update(_1838 ? _1838->raw() : nullptr, _1838 ? _1838->size(0) : 0);
      _1839 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1844)));
      _ptr__1839.update(_1839 ? _1839->raw() : nullptr, _1839 ? _1839->size(0) : 0);
      _1836->inst((int)0,_1838,(int)0,_1839);
    }
  }
  else
  {
    {
      _1838 = nullptr;
      _ptr__1838.update(_1838 ? _1838->raw() : nullptr, _1838 ? _1838->size(0) : 0);
      _1839 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1844)));
      _ptr__1839.update(_1839 ? _1839->raw() : nullptr, _1839 ? _1839->size(0) : 0);
      _1836->inst((int)0,_1839);
    }
  }
  if ((NULL == _1838.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1847 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1844)));
      _checked_ptr_1<long long> _ptr__1847(_1847 ? _1847->raw() : nullptr,_1847 ? _1847->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1848 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1841)));
        _checked_ptr_1<int> _ptr__1848(_1848 ? _1848->raw() : nullptr,_1848 ? _1848->size(0) : 0);
        int _7455 = (int)0;
        int _7456 = _1844;
        for (int _1849 = _7455; _1849 < _7456; ++_1849)
        {
          {
            int _1850 = _1849;
            int _7457 = (int)0;
            int _7458 = _1841;
            for (int _1851 = _7457; _1851 < _7458; ++_1851)
            {
              {
                _ptr__1848[((_1841 - _1849) - (int)1)] = (_1850 % _ptr__1840[((_1841 - _1849) - (int)1)]);
                _1850 /= _ptr__1840[((_1841 - _1849) - (int)1)];
              }
            }
            int _1852 = (int)0;
            int _7459 = (int)0;
            int _7460 = _1841;
            for (int _1853 = _7459; _1853 < _7460; ++_1853)
            {
              {
                _1852 += (int)safe_mul( _ptr__1848[_ptr__1837[_1853]],_ptr__1845[_1853] );
              }
            }
            _ptr__1847[_1852] = _ptr__1839[_1849];
          }
        }
      }
      _1839 = _1847;
      _ptr__1839.update(_1839 ? _1839->raw() : nullptr, _1839 ? _1839->size(0) : 0);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1854 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1844)));
      _checked_ptr_1<long long> _ptr__1854(_1854 ? _1854->raw() : nullptr,_1854 ? _1854->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1855 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1841)));
        _checked_ptr_1<int> _ptr__1855(_1855 ? _1855->raw() : nullptr,_1855 ? _1855->size(0) : 0);
        int _7461 = (int)0;
        int _7462 = _1844;
        for (int _1856 = _7461; _1856 < _7462; ++_1856)
        {
          {
            int _1857 = _1856;
            int _7463 = (int)0;
            int _7464 = _1841;
            for (int _1858 = _7463; _1858 < _7464; ++_1858)
            {
              {
                _ptr__1855[((_1841 - _1856) - (int)1)] = (_1857 % _ptr__1840[((_1841 - _1856) - (int)1)]);
                _1857 /= _ptr__1840[((_1841 - _1856) - (int)1)];
              }
            }
            int _1859 = (int)0;
            int _7465 = (int)0;
            int _7466 = _1841;
            for (int _1860 = _7465; _1860 < _7466; ++_1860)
            {
              {
                _1859 += (int)safe_mul( _ptr__1855[_ptr__1837[_1860]],_ptr__1845[_1860] );
              }
            }
            _ptr__1854[_1856] = _1859;
          }
        }
      }
      std::vector<long long> _7467;
      for (int _1862 = (int)0, _7468 = _1844; _1862 < _7468 ; ++_1862)
      {
        _7467.push_back(_1862);
      }
      auto _7469 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7467.size()),_7467.begin(),_7467.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1861 = _7469;
      _checked_ptr_1<long long> _ptr__1861(_1861 ? _1861->raw() : nullptr,_1861 ? _1861->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1861,_1854,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1844));
      std::vector<long long> _7470;
      for (int _1863 = (int)0, _7471 = _1844; _1863 < _7471 ; ++_1863)
      {
        _7470.push_back(_ptr__1838[_ptr__1861[_1863]]);
      }
      auto _7472 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7470.size()),_7470.begin(),_7470.end()));
      _1838 = _7472;
      _ptr__1838.update(_1838 ? _1838->raw() : nullptr, _1838 ? _1838->size(0) : 0);
      std::vector<long long> _7473;
      for (int _1864 = (int)0, _7474 = _1844; _1864 < _7474 ; ++_1864)
      {
        _7473.push_back(_ptr__1839[_ptr__1861[_1864]]);
      }
      auto _7475 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7473.size()),_7473.begin(),_7473.end()));
      _1839 = _7475;
      _ptr__1839.update(_1839 ? _1839->raw() : nullptr, _1839 ? _1839->size(0) : 0);
    }
  }
  std::vector<int> _7476;
  for (int _1865 = (int)0, _7477 = _1841; _1865 < _7477 ; ++_1865)
  {
    _7476.push_back(_ptr__1840[_ptr__1837[_1865]]);
  }
  auto _7478 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7476.size()),_7476.begin(),_7476.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1836->__mosek_2fusion_2Variable__getModel(),_7478,_1838,_1839)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1866,    int _1867) { return mosek::fusion::p_Var::hrepeat(_1866,_1867); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1866,int _1867){
  return ::mosek::fusion::p_Var::drepeat(_1866,(int)1,_1867);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1868,    int _1869) { return mosek::fusion::p_Var::vrepeat(_1868,_1869); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1868,int _1869){
  return ::mosek::fusion::p_Var::drepeat(_1868,(int)0,_1869);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1870,    int _1871) { return mosek::fusion::p_Var::repeat(_1870,_1871); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1870,int _1871){
  return ::mosek::fusion::p_Var::drepeat(_1870,(int)0,_1871);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1872,    int _1873,    int _1874) { return mosek::fusion::p_Var::repeat(_1872,_1873,_1874); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1872,int _1873,int _1874){
  return ::mosek::fusion::p_Var::drepeat(_1872,_1873,_1874);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1875,int _1876,int _1877){
  if ((_1877 < (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot repeat less than 0 times"));
    }
  }
  else if((_1877 == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((_1877 == (int)1))
  {
    {
      return _1875;
    }
  }
  else
  {
    {
      monty::rc_ptr< ::mosek::fusion::Model > _1878 = _1875->__mosek_2fusion_2Variable__getModel();
      std::shared_ptr< monty::ndarray< int,1 > > _1879 = _1875->getShape();
      _checked_ptr_1<int> _ptr__1879(_1879 ? _1879->raw() : nullptr,_1879 ? _1879->size(0) : 0);
      int _1880 = (int)((_1879)->size(0));
      if (((_1876 < (int)0) || (_1876 > _1880)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      long long _1881 = ::mosek::fusion::p_Set::size(_1879);
      int _1882 = _1875->numInst();
      int _1883 = safe_mul( _1882,_1877 );
      int _1884 = (int)1;
      int _7479 = (int)0;
      int _7480 = _1876;
      for (int _1885 = _7479; _1885 < _7480; ++_1885)
      {
        {
          _1884 *= _ptr__1879[_1885];
        }
      }
      int _7481;
      bool _7482 = (_1876 < _1880);
      if (_7482)
      {
        _7481 = _ptr__1879[_1876];
      }
      else
      {
        _7481 = (int)1;
      }
      int _1886 = _7481;
      int _1887 = safe_mul( _1886,_1877 );
      int _1888 = (int)1;
      int _7483 = safe_add( _1876,(int)1 );
      int _7484 = _1880;
      for (int _1889 = _7483; _1889 < _7484; ++_1889)
      {
        {
          _1888 *= _ptr__1879[_1889];
        }
      }
      int _7485;
      bool _7486 = (_1876 < _1880);
      if (_7486)
      {
        _7485 = _1880;
      }
      else
      {
        _7485 = safe_add( _1876,(int)1 );
      }
      int _1890 = _7485;
      std::shared_ptr< monty::ndarray< int,1 > > _1891 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1890)));
      _checked_ptr_1<int> _ptr__1891(_1891 ? _1891->raw() : nullptr,_1891 ? _1891->size(0) : 0);
      int _7487 = (int)0;
      int _7488 = _1880;
      for (int _1892 = _7487; _1892 < _7488; ++_1892)
      {
        {
          _ptr__1891[_1892] = _ptr__1879[_1892];
        }
      }
      int _7489 = _1880;
      int _7490 = _1890;
      for (int _1893 = _7489; _1893 < _7490; ++_1893)
      {
        {
          _ptr__1891[_1893] = (int)1;
        }
      }
      _ptr__1891[_1876] = _1887;
      if ((_1882 < _1881))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1894 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1882)));
          _checked_ptr_1<long long> _ptr__1894(_1894 ? _1894->raw() : nullptr,_1894 ? _1894->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1895 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1882)));
          _checked_ptr_1<long long> _ptr__1895(_1895 ? _1895->raw() : nullptr,_1895 ? _1895->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1896 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1883)));
          _checked_ptr_1<long long> _ptr__1896(_1896 ? _1896->raw() : nullptr,_1896 ? _1896->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1897 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1883)));
          _checked_ptr_1<long long> _ptr__1897(_1897 ? _1897->raw() : nullptr,_1897 ? _1897->size(0) : 0);
          _1875->inst((int)0,_1895,(int)0,_1894);
          {
            int _1898 = safe_mul( _1887,_1888 );
            int _1899 = safe_mul( _1886,_1888 );
            int _1900 = _1888;
            if ((_1876 == (int)0))
            {
              {
                int _1901 = (int)0;
                int _7491 = (int)0;
                int _7492 = _1877;
                for (int _1902 = _7491; _1902 < _7492; ++_1902)
                {
                  {
                    int _7493 = (int)0;
                    int _7494 = _1882;
                    for (int _1903 = _7493; _1903 < _7494; ++_1903)
                    {
                      {
                        _ptr__1897[_1901] = safe_add( _ptr__1895[_1903],safe_mul( _1902,_1881 ) );
                        _ptr__1896[_1901] = _ptr__1894[_1903];
                        ++ _1901;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1878,_1891,_1897,_1896)).as<::mosek::fusion::Variable>();
              }
            }
            else if((_1876 >= _1880))
            {
              {
                int _1904 = (int)0;
                int _7495 = (int)0;
                int _7496 = _1882;
                for (int _1905 = _7495; _1905 < _7496; ++_1905)
                {
                  {
                    int _7497 = (int)0;
                    int _7498 = _1877;
                    for (int _1906 = _7497; _1906 < _7498; ++_1906)
                    {
                      {
                        _ptr__1897[_1904] = safe_add( safe_mul( _ptr__1895[_1905],_1877 ),_1906 );
                        _ptr__1896[_1904] = _ptr__1894[_1905];
                        ++ _1904;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1878,_1891,_1897,_1896)).as<::mosek::fusion::Variable>();
              }
            }
            else
            {
              {
                int _1907 = (int)0;
                int _7499 = (int)0;
                int _7500 = _1882;
                for (int _1908 = _7499; _1908 < _7500; ++_1908)
                {
                  {
                    long long _1909 = (_ptr__1895[_1908] / _1899);
                    long long _1910 = ((_ptr__1895[_1908] / _1900) % _1886);
                    long long _1911 = (_ptr__1895[_1908] % _1888);
                    int _7501 = (int)0;
                    int _7502 = _1877;
                    for (int _1912 = _7501; _1912 < _7502; ++_1912)
                    {
                      {
                        _ptr__1897[_1907] = safe_add( safe_add( safe_mul( _1909,_1898 ),safe_mul( safe_add( _1910,safe_mul( _1886,_1912 ) ),_1888 ) ),_1911 );
                        _ptr__1896[_1907] = _ptr__1894[_1908];
                        ++ _1907;
                      }
                    }
                  }
                }
                int _1913 = (int)1;
                int _7503 = (int)0;
                int _7504 = _1890;
                for (int _1914 = _7503; _1914 < _7504; ++_1914)
                {
                  {
                    if ((_1913 < _ptr__1891[_1914]))
                    {
                      {
                        _1913 = _ptr__1891[_1914];
                      }
                    }
                    {}
                  }
                }
                std::shared_ptr< monty::ndarray< int,1 > > _1915 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1883)));
                _checked_ptr_1<int> _ptr__1915(_1915 ? _1915->raw() : nullptr,_1915 ? _1915->size(0) : 0);
                std::shared_ptr< monty::ndarray< int,1 > > _1916 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1883)));
                _checked_ptr_1<int> _ptr__1916(_1916 ? _1916->raw() : nullptr,_1916 ? _1916->size(0) : 0);
                {
                  std::shared_ptr< monty::ndarray< int,1 > > _1917 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _1913,(int)1 ))));
                  _checked_ptr_1<int> _ptr__1917(_1917 ? _1917->raw() : nullptr,_1917 ? _1917->size(0) : 0);
                  std::shared_ptr< monty::ndarray< long long,1 > > _1918 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1890)));
                  _checked_ptr_1<long long> _ptr__1918(_1918 ? _1918->raw() : nullptr,_1918 ? _1918->size(0) : 0);
                  _ptr__1918[(_1890 - (int)1)] = (int)1;
                  int _7505 = (int)1;
                  int _7506 = _1890;
                  for (int _1919 = _7505; _1919 < _7506; ++_1919)
                  {
                    {
                      _ptr__1918[((_1890 - _1919) - (int)1)] = safe_mul( _ptr__1918[(_1890 - _1919)],_ptr__1891[(_1890 - _1919)] );
                    }
                  }
                  int _7507 = (int)0;
                  int _7508 = _1883;
                  for (int _1920 = _7507; _1920 < _7508; ++_1920)
                  {
                    {
                      _ptr__1915[_1920] = _1920;
                    }
                  }
                  int _7509 = (int)0;
                  int _7510 = _1890;
                  for (int _1921 = _7509; _1921 < _7510; ++_1921)
                  {
                    {
                      int _1922 = ((_1890 - _1921) - (int)1);
                      int _7511 = (int)0;
                      int _7512 = safe_add( _ptr__1891[_1922],(int)1 );
                      for (int _1923 = _7511; _1923 < _7512; ++_1923)
                      {
                        {
                          _ptr__1917[_1923] = (int)0;
                        }
                      }
                      int _7513 = (int)0;
                      int _7514 = _1883;
                      for (int _1924 = _7513; _1924 < _7514; ++_1924)
                      {
                        {
                          ++ _ptr__1917[safe_add( ((_ptr__1897[_1924] / _ptr__1918[_1922]) % _ptr__1891[_1922]),(int)1 )];
                        }
                      }
                      int _7515 = (int)0;
                      int _7516 = _ptr__1891[_1922];
                      for (int _1925 = _7515; _1925 < _7516; ++_1925)
                      {
                        {
                          _ptr__1917[safe_add( _1925,(int)1 )] += _ptr__1917[_1925];
                        }
                      }
                      int _7517 = (int)0;
                      int _7518 = _1883;
                      for (int _1926 = _7517; _1926 < _7518; ++_1926)
                      {
                        {
                          int _1927 = _ptr__1915[_1926];
                          long long _1928 = ((_ptr__1897[_1927] / _ptr__1918[_1922]) % _ptr__1891[_1922]);
                          _ptr__1916[_ptr__1917[_1928]] = _1927;
                          ++ _ptr__1917[_1928];
                        }
                      }
                      std::shared_ptr< monty::ndarray< int,1 > > _1929 = _1915;
                      _checked_ptr_1<int> _ptr__1929(_1929 ? _1929->raw() : nullptr,_1929 ? _1929->size(0) : 0);
                      _1915 = _1916;
                      _ptr__1915.update(_1915 ? _1915->raw() : nullptr, _1915 ? _1915->size(0) : 0);
                      _1916 = _1929;
                      _ptr__1916.update(_1916 ? _1916->raw() : nullptr, _1916 ? _1916->size(0) : 0);
                    }
                  }
                }
                std::vector<long long> _7519;
                for (int _1930 = (int)0, _7520 = _1883; _1930 < _7520 ; ++_1930)
                {
                  _7519.push_back(_ptr__1897[_ptr__1915[_1930]]);
                }
                auto _7521 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7519.size()),_7519.begin(),_7519.end()));
                std::vector<long long> _7522;
                for (int _1931 = (int)0, _7523 = _1883; _1931 < _7523 ; ++_1931)
                {
                  _7522.push_back(_ptr__1896[_ptr__1915[_1931]]);
                }
                auto _7524 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7522.size()),_7522.begin(),_7522.end()));
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1878,_1891,_7521,_7524)).as<::mosek::fusion::Variable>();
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1932 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1882)));
          _checked_ptr_1<long long> _ptr__1932(_1932 ? _1932->raw() : nullptr,_1932 ? _1932->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1933 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1882,_1877 ))));
          _checked_ptr_1<long long> _ptr__1933(_1933 ? _1933->raw() : nullptr,_1933 ? _1933->size(0) : 0);
          _1875->inst((int)0,_1932);
          int _1934 = safe_mul( _1887,_1888 );
          int _1935 = _1888;
          int _1936 = (int)0;
          int _7525 = (int)0;
          int _7526 = _1884;
          for (int _1937 = _7525; _1937 < _7526; ++_1937)
          {
            {
              int _7527 = (int)0;
              int _7528 = _1886;
              for (int _1938 = _7527; _1938 < _7528; ++_1938)
              {
                {
                  int _7529 = (int)0;
                  int _7530 = _1888;
                  for (int _1939 = _7529; _1939 < _7530; ++_1939)
                  {
                    {
                      int _7531 = (int)0;
                      int _7532 = _1877;
                      for (int _1940 = _7531; _1940 < _7532; ++_1940)
                      {
                        {
                          _ptr__1933[safe_add( safe_add( safe_mul( _1937,_1934 ),safe_mul( safe_add( _1938,safe_mul( _1940,_1886 ) ),_1935 ) ),_1939 )] = _ptr__1932[_1936];
                        }
                      }
                      ++ _1936;
                    }
                  }
                }
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1878,_1891,nullptr,_1933)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1941) { return mosek::fusion::p_Var::stack(_1941); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1941){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _7533;
  for (int _1942 = (int)0, _7534 = (int)((_1941)->size(0)); _1942 < _7534 ; ++_1942)
  {
    _7533.push_back(::mosek::fusion::p_Var::dstack(((*_1941)(_1942)),(int)1));
  }
  auto _7535 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_7533.size()),_7533.begin(),_7533.end()));
  return ::mosek::fusion::p_Var::dstack(_7535,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1943,    monty::rc_ptr< ::mosek::fusion::Variable > _1944,    monty::rc_ptr< ::mosek::fusion::Variable > _1945) { return mosek::fusion::p_Var::vstack(_1943,_1944,_1945); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1943,monty::rc_ptr< ::mosek::fusion::Variable > _1944,monty::rc_ptr< ::mosek::fusion::Variable > _1945){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1943.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1944.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1945.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1946,    monty::rc_ptr< ::mosek::fusion::Variable > _1947) { return mosek::fusion::p_Var::vstack(_1946,_1947); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1946,monty::rc_ptr< ::mosek::fusion::Variable > _1947){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1946.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1947.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1948) { return mosek::fusion::p_Var::vstack(_1948); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1948){
  return ::mosek::fusion::p_Var::dstack(_1948,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1949,    monty::rc_ptr< ::mosek::fusion::Variable > _1950,    monty::rc_ptr< ::mosek::fusion::Variable > _1951) { return mosek::fusion::p_Var::hstack(_1949,_1950,_1951); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1949,monty::rc_ptr< ::mosek::fusion::Variable > _1950,monty::rc_ptr< ::mosek::fusion::Variable > _1951){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1949.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1950.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1951.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1952,    monty::rc_ptr< ::mosek::fusion::Variable > _1953) { return mosek::fusion::p_Var::hstack(_1952,_1953); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1952,monty::rc_ptr< ::mosek::fusion::Variable > _1953){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1952.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1953.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1954) { return mosek::fusion::p_Var::hstack(_1954); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1954){
  return ::mosek::fusion::p_Var::dstack(_1954,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1955,    monty::rc_ptr< ::mosek::fusion::Variable > _1956,    monty::rc_ptr< ::mosek::fusion::Variable > _1957,    int _1958) { return mosek::fusion::p_Var::stack(_1955,_1956,_1957,_1958); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _1955,monty::rc_ptr< ::mosek::fusion::Variable > _1956,monty::rc_ptr< ::mosek::fusion::Variable > _1957,int _1958){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1955.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1956.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1957.get())}),_1958);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1959,    monty::rc_ptr< ::mosek::fusion::Variable > _1960,    int _1961) { return mosek::fusion::p_Var::stack(_1959,_1960,_1961); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _1959,monty::rc_ptr< ::mosek::fusion::Variable > _1960,int _1961){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1959.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1960.get())}),_1961);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1962,    int _1963) { return mosek::fusion::p_Var::stack(_1962,_1963); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1962,int _1963){
  int _1964 = _1963;
  int _7536 = (int)0;
  int _7537 = (int)((_1962)->size(0));
  for (int _1965 = _7536; _1965 < _7537; ++_1965)
  {
    {
      if ((_1964 < ((*_1962)(_1965))->getND()))
      {
        {
          _1964 = ((*_1962)(_1965))->getND();
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Var::dstack(_1962,_1963);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::promote  ( monty::rc_ptr< ::mosek::fusion::Variable > _1966,    int _1967) { return mosek::fusion::p_Var::promote(_1966,_1967); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::promote(monty::rc_ptr< ::mosek::fusion::Variable > _1966,int _1967){
  if ((_1967 > _1966->getND()))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1968 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1967)));
      _checked_ptr_1<int> _ptr__1968(_1968 ? _1968->raw() : nullptr,_1968 ? _1968->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1969 = _1966->getShape();
      _checked_ptr_1<int> _ptr__1969(_1969 ? _1969->raw() : nullptr,_1969 ? _1969->size(0) : 0);
      int _7538 = (int)0;
      int _7539 = (int)((_1969)->size(0));
      for (int _1970 = _7538; _1970 < _7539; ++_1970)
      {
        {
          _ptr__1968[_1970] = _ptr__1969[_1970];
        }
      }
      int _7540 = (int)((_1969)->size(0));
      int _7541 = _1967;
      for (int _1971 = _7540; _1971 < _7541; ++_1971)
      {
        {
          _ptr__1968[_1971] = (int)1;
        }
      }
      return _1966->__mosek_2fusion_2Variable__reshape(_1968);
    }
  }
  else
  {
    {
      return _1966;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1972,int _1973){
  if ((_1973 < (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Model > _1974 = nullptr;
  {
    int _7542 = (int)0;
    int _7543 = (int)((_1972)->size(0));
    for (int _1975 = _7542; _1975 < _7543; ++_1975)
    {
      {
        if ((NULL == _1974.get()))
        {
          {
            _1974 = ((*_1972)(_1975))->__mosek_2fusion_2Variable__getModel();
          }
        }
        else if(((NULL != ((*_1972)(_1975))->__mosek_2fusion_2Variable__getModel().get()) && (((*_1972)(_1975))->__mosek_2fusion_2Variable__getModel() != _1974)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1976 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7544;
            bool _7545 = ((int)((mosek::fusion::p_Model::_get_impl(_1974.get())->getName()).size()) > (int)0);
            if (_7545)
            {
              _7544 = mosek::fusion::p_Model::_get_impl(_1974.get())->getName();
            }
            else
            {
              _7544 = std::string ("?");
            }
            std::string _1977 = _7544;
            std::string _7546;
            bool _7547 = ((int)((mosek::fusion::p_Model::_get_impl(((*_1972)(_1975))->__mosek_2fusion_2Variable__getModel().get())->getName()).size()) > (int)0);
            if (_7547)
            {
              _7546 = mosek::fusion::p_Model::_get_impl(((*_1972)(_1975))->__mosek_2fusion_2Variable__getModel().get())->getName();
            }
            else
            {
              _7546 = std::string ("?");
            }
            std::string _1978 = _7546;
            _1976->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variables belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1977)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1978)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_1976->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_1972)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((_1972)->size(0)) == (int)1))
  {
    {
      return ((*_1972)((int)1));
    }
  }
  else
  {
    {
      int _1979 = (int)((_1972)->size(0));
      std::vector<int> _7548;
      for (int _1981 = (int)0, _7549 = _1979; _1981 < _7549 ; ++_1981)
      {
        _7548.push_back(((*_1972)(_1981))->numInst());
      }
      auto _7550 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7548.size()),_7548.begin(),_7548.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1980 = _7550;
      _checked_ptr_1<int> _ptr__1980(_1980 ? _1980->raw() : nullptr,_1980 ? _1980->size(0) : 0);
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7551;
      for (int _1983 = (int)0, _7552 = _1979; _1983 < _7552 ; ++_1983)
      {
        _7551.push_back(((*_1972)(_1983))->getShape());
      }
      auto _7553 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7551.size()),_7551.begin(),_7551.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _1982 = _7553;
      std::vector<int> _7554;
      for (int _1985 = (int)0, _7555 = _1979; _1985 < _7555 ; ++_1985)
      {
        _7554.push_back((int)((((*_1982)(_1985)))->size(0)));
      }
      auto _7556 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7554.size()),_7554.begin(),_7554.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1984 = _7556;
      _checked_ptr_1<int> _ptr__1984(_1984 ? _1984->raw() : nullptr,_1984 ? _1984->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1986 = ((*_1982)((int)0));
      _checked_ptr_1<int> _ptr__1986(_1986 ? _1986->raw() : nullptr,_1986 ? _1986->size(0) : 0);
      int _1987 = _ptr__1984[(int)0];
      int _1988 = (int)0;
      int _7557 = (int)0;
      int _7558 = _1979;
      for (int _1989 = _7557; _1989 < _7558; ++_1989)
      {
        {
          _1988 += _ptr__1980[_1989];
        }
      }
      int _1990 = safe_add( _1973,(int)1 );
      int _7559 = (int)0;
      int _7560 = _1979;
      for (int _1991 = _7559; _1991 < _7560; ++_1991)
      {
        {
          if ((_1990 < _ptr__1984[_1991]))
          {
            {
              _1990 = _ptr__1984[_1991];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _1992 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1990)));
      _checked_ptr_1<int> _ptr__1992(_1992 ? _1992->raw() : nullptr,_1992 ? _1992->size(0) : 0);
      int _7561 = (int)0;
      int _7562 = _1987;
      for (int _1993 = _7561; _1993 < _7562; ++_1993)
      {
        {
          _ptr__1992[_1993] = _ptr__1986[_1993];
        }
      }
      int _7563 = _1987;
      int _7564 = _1990;
      for (int _1994 = _7563; _1994 < _7564; ++_1994)
      {
        {
          _ptr__1992[_1994] = (int)1;
        }
      }
      _ptr__1992[_1973] = (int)0;
      int _7565 = (int)0;
      int _7566 = _1979;
      for (int _1995 = _7565; _1995 < _7566; ++_1995)
      {
        {
          int _7567;
          bool _7568 = ((int)((((*_1982)(_1995)))->size(0)) > _1973);
          if (_7568)
          {
            _7567 = ((*((*_1982)(_1995)))(_1973));
          }
          else
          {
            _7567 = (int)1;
          }
          _ptr__1992[_1973] += _7567;
        }
      }
      int _7569 = (int)0;
      int _7570 = _1979;
      for (int _1996 = _7569; _1996 < _7570; ++_1996)
      {
        {
          int _7571 = (int)0;
          int _7572 = (int)((((*_1982)(_1996)))->size(0));
          for (int _1997 = _7571; _1997 < _7572; ++_1997)
          {
            {
              if (((_1997 != _1973) && (((*((*_1982)(_1996)))(_1997)) != _ptr__1992[_1997])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
          int _7573 = (int)((((*_1982)(_1996)))->size(0));
          int _7574 = _1990;
          for (int _1998 = _7573; _1998 < _7574; ++_1998)
          {
            {
              if (((_1998 != _1973) && ((int)1 != _ptr__1992[_1998])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1999 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1988)));
      _checked_ptr_1<long long> _ptr__1999(_1999 ? _1999->raw() : nullptr,_1999 ? _1999->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2000 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1988)));
      _checked_ptr_1<long long> _ptr__2000(_2000 ? _2000->raw() : nullptr,_2000 ? _2000->size(0) : 0);
      std::vector<int> _7575;
      for (int _2002 = (int)0, _7576 = (int)((_1972)->size(0)); _2002 < _7576 ; ++_2002)
      {
        int _7577;
        bool _7578 = (_1973 < (int)((((*_1982)(_2002)))->size(0)));
        if (_7578)
        {
          _7577 = ((*((*_1982)(_2002)))(_1973));
        }
        else
        {
          _7577 = (int)1;
        }
        _7575.push_back(_7577);
      }
      auto _7579 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7575.size()),_7575.begin(),_7575.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2001 = _7579;
      _checked_ptr_1<int> _ptr__2001(_2001 ? _2001->raw() : nullptr,_2001 ? _2001->size(0) : 0);
      int _2003 = (int)1;
      int _7580 = (int)0;
      int _7581 = _1973;
      for (int _2004 = _7580; _2004 < _7581; ++_2004)
      {
        {
          int _7582;
          bool _7583 = (_2004 < (int)((_1986)->size(0)));
          if (_7583)
          {
            _7582 = _ptr__1986[_2004];
          }
          else
          {
            _7582 = (int)1;
          }
          _2003 *= _7582;
        }
      }
      int _2005 = (int)0;
      int _7584 = (int)0;
      int _7585 = _1979;
      for (int _2006 = _7584; _2006 < _7585; ++_2006)
      {
        {
          _2005 += _ptr__2001[_2006];
        }
      }
      int _2007 = (int)1;
      int _7586 = safe_add( _1973,(int)1 );
      int _7587 = (int)((_1986)->size(0));
      for (int _2008 = _7586; _2008 < _7587; ++_2008)
      {
        {
          _2007 *= _ptr__1986[_2008];
        }
      }
      if ((_2003 == (int)1))
      {
        {
          int _2009 = (int)0;
          long long _2010 = (int)0;
          int _7588 = (int)0;
          int _7589 = _1979;
          for (int _2011 = _7588; _2011 < _7589; ++_2011)
          {
            {
              ((*_1972)(_2011))->inst(_2009,_2000,_2009,_1999);
              int _7590 = (int)0;
              int _7591 = _ptr__1980[_2011];
              for (int _2012 = _7590; _2012 < _7591; ++_2012)
              {
                {
                  _ptr__2000[_2009] += _2010;
                  ++ _2009;
                }
              }
              _2010 += ::mosek::fusion::p_Set::size(((*_1982)(_2011)));
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7592;
          bool _7593 = (_1988 < safe_mul( safe_mul( _2003,_2005 ),_2007 ));
          if (_7593)
          {
            _7592 = _2000;
          }
          else
          {
            _7592 = nullptr;
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1974,_1992,_7592,_1999)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          int _2013 = (int)0;
          int _7594 = (int)0;
          int _7595 = _1979;
          for (int _2014 = _7594; _2014 < _7595; ++_2014)
          {
            {
              _2013 += ((*_1972)(_2014))->inst(_2013,_2000,_2013,_1999);
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2015 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1988)));
          _checked_ptr_1<int> _ptr__2015(_2015 ? _2015->raw() : nullptr,_2015 ? _2015->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2016 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1988)));
          _checked_ptr_1<int> _ptr__2016(_2016 ? _2016->raw() : nullptr,_2016 ? _2016->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2017 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1979)));
          _checked_ptr_1<int> _ptr__2017(_2017 ? _2017->raw() : nullptr,_2017 ? _2017->size(0) : 0);
          int _7596 = (int)0;
          int _7597 = (_1979 - (int)1);
          for (int _2018 = _7596; _2018 < _7597; ++_2018)
          {
            {
              _ptr__2017[safe_add( _2018,(int)1 )] = safe_add( _ptr__2017[_2018],_ptr__2001[_2018] );
            }
          }
          int _7598 = (int)0;
          int _7599 = _1988;
          for (int _2019 = _7598; _2019 < _7599; ++_2019)
          {
            {
              _ptr__2015[_2019] = _2019;
            }
          }
          int _2020 = (int)0;
          int _7600 = (int)0;
          int _7601 = _1979;
          for (int _2021 = _7600; _2021 < _7601; ++_2021)
          {
            {
              int _7602 = (int)0;
              int _7603 = _ptr__1980[_2021];
              for (int _2022 = _7602; _2022 < _7603; ++_2022)
              {
                {
                  long long _2023 = (_ptr__2000[_2020] / safe_mul( _ptr__2001[_2021],_2007 ));
                  long long _2024 = ((_ptr__2000[_2020] / _2007) % _ptr__2001[_2021]);
                  long long _2025 = (_ptr__2000[_2020] % _2007);
                  _ptr__2000[_2020] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _2023,_2005 ),_2024 ),_ptr__2017[_2021] ),_2007 ),_2025 );
                  ++ _2020;
                }
              }
            }
          }
          int _2026 = (int)1;
          int _7604 = (int)0;
          int _7605 = _1990;
          for (int _2027 = _7604; _2027 < _7605; ++_2027)
          {
            {
              int _7606;
              bool _7607 = (_2026 < _ptr__1992[_2027]);
              if (_7607)
              {
                _7606 = _ptr__1992[_2027];
              }
              else
              {
                _7606 = _2026;
              }
              _2026 = _7606;
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _2028 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1990)));
          _checked_ptr_1<long long> _ptr__2028(_2028 ? _2028->raw() : nullptr,_2028 ? _2028->size(0) : 0);
          _ptr__2028[(_1990 - (int)1)] = (int)1;
          int _7608 = (int)1;
          int _7609 = _1990;
          for (int _2029 = _7608; _2029 < _7609; ++_2029)
          {
            {
              _ptr__2028[((_1990 - _2029) - (int)1)] = safe_mul( _ptr__2028[(_1990 - _2029)],_ptr__1992[(_1990 - _2029)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2030 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _2026,(int)1 ))));
          _checked_ptr_1<int> _ptr__2030(_2030 ? _2030->raw() : nullptr,_2030 ? _2030->size(0) : 0);
          int _7610 = (int)0;
          int _7611 = _1990;
          for (int _2031 = _7610; _2031 < _7611; ++_2031)
          {
            {
              int _2032 = ((_1990 - _2031) - (int)1);
              int _7612 = (int)0;
              int _7613 = safe_add( _ptr__1992[_2032],(int)1 );
              for (int _2033 = _7612; _2033 < _7613; ++_2033)
              {
                {
                  _ptr__2030[_2033] = (int)0;
                }
              }
              int _7614 = (int)0;
              int _7615 = _1988;
              for (int _2034 = _7614; _2034 < _7615; ++_2034)
              {
                {
                  ++ _ptr__2030[safe_add( ((_ptr__2000[_2034] / _ptr__2028[_2032]) % _ptr__1992[_2032]),(int)1 )];
                }
              }
              int _7616 = (int)0;
              int _7617 = _ptr__1992[_2032];
              for (int _2035 = _7616; _2035 < _7617; ++_2035)
              {
                {
                  _ptr__2030[safe_add( _2035,(int)1 )] += _ptr__2030[_2035];
                }
              }
              int _7618 = (int)0;
              int _7619 = _1988;
              for (int _2036 = _7618; _2036 < _7619; ++_2036)
              {
                {
                  int _2037 = _ptr__2015[_2036];
                  long long _2038 = ((_ptr__2000[_2037] / _ptr__2028[_2032]) % _ptr__1992[_2032]);
                  _ptr__2016[_ptr__2030[_2038]] = _2037;
                  ++ _ptr__2030[_2038];
                }
              }
              std::shared_ptr< monty::ndarray< int,1 > > _2039 = _2015;
              _checked_ptr_1<int> _ptr__2039(_2039 ? _2039->raw() : nullptr,_2039 ? _2039->size(0) : 0);
              _2015 = _2016;
              _ptr__2015.update(_2015 ? _2015->raw() : nullptr, _2015 ? _2015->size(0) : 0);
              _2016 = _2039;
              _ptr__2016.update(_2016 ? _2016->raw() : nullptr, _2016 ? _2016->size(0) : 0);
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7620;
          bool _7621 = (_1988 < safe_mul( safe_mul( _2003,_2005 ),_2007 ));
          if (_7621)
          {
            std::vector<long long> _7622;
            for (int _2040 = (int)0, _7623 = _1988; _2040 < _7623 ; ++_2040)
            {
              _7622.push_back(_ptr__2000[_ptr__2015[_2040]]);
            }
            auto _7624 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7622.size()),_7622.begin(),_7622.end()));
            _7620 = _7624;
          }
          else
          {
            _7620 = nullptr;
          }
          std::vector<long long> _7625;
          for (int _2041 = (int)0, _7626 = _1988; _2041 < _7626 ; ++_2041)
          {
            _7625.push_back(_ptr__1999[_ptr__2015[_2041]]);
          }
          auto _7627 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7625.size()),_7625.begin(),_7625.end()));
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1974,_1992,_7620,_7627)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
void mosek::fusion::p_Var::destroy(){}void mosek::fusion::Var::destroy() { mosek::fusion::p_Var::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint(mosek::fusion::p_LinearPSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearPSDConstraint()" << this << std::endl; */ }mosek::fusion::LinearPSDConstraint::~LinearPSDConstraint() {  /* std::cout << "~LinearPSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDConstraint::p_LinearPSDConstraint  (::mosek::fusion::LinearPSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2042,    monty::rc_ptr< ::mosek::fusion::Model > _2043){ return new mosek::fusion::LinearPSDConstraint(_2042,_2043); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2042,    monty::rc_ptr< ::mosek::fusion::Model > _2043) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2042,_2043); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2042,    monty::rc_ptr< ::mosek::fusion::Model > _2043){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2042,_2043);
    conid = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2042)->conid;
    slackidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2042)->slackidxs;
    nativeidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2042)->nativeidxs;
    conedim = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2042)->conedim;
    shape = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2042)->shape;
  }
}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2044,    const std::string &  _2045,    int _2046,    std::shared_ptr< monty::ndarray< int,1 > > _2047,    int _2048,    std::shared_ptr< monty::ndarray< int,1 > > _2049,    std::shared_ptr< monty::ndarray< long long,1 > > _2050){ return new mosek::fusion::LinearPSDConstraint(_2044,_2045,_2046,_2047,_2048,_2049,_2050); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2044,    const std::string &  _2045,    int _2046,    std::shared_ptr< monty::ndarray< int,1 > > _2047,    int _2048,    std::shared_ptr< monty::ndarray< int,1 > > _2049,    std::shared_ptr< monty::ndarray< long long,1 > > _2050) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2044,_2045,_2046,_2047,_2048,_2049,_2050); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2044,    const std::string &  _2045,    int _2046,    std::shared_ptr< monty::ndarray< int,1 > > _2047,    int _2048,    std::shared_ptr< monty::ndarray< int,1 > > _2049,    std::shared_ptr< monty::ndarray< long long,1 > > _2050){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2047(_2047 ? _2047->raw() : nullptr, _2047 ? _2047->size(0) : 0);
    _checked_ptr_1<int> _ptr__2049(_2049 ? _2049->raw() : nullptr, _2049 ? _2049->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2050(_2050 ? _2050->raw() : nullptr, _2050 ? _2050->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2044,_2045,_2047,_2049);
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conid = _2046;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->slackidxs = _2050;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->nativeidxs = _2049;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conedim = _2048;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->shape = _2047;
  }
}void mosek::fusion::p_LinearPSDConstraint::domainToString(long long _2051,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2052){
  std::shared_ptr< monty::ndarray< int,1 > > _2053 = ::mosek::fusion::p_Set::idxtokey(shape,_2051);
  _checked_ptr_1<int> _ptr__2053(_2053 ? _2053->raw() : nullptr,_2053 ? _2053->size(0) : 0);
  _2052->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2053[(int)0]);
  int _7628 = (int)1;
  int _7629 = (int)((_2053)->size(0));
  for (int _2054 = _7628; _2054 < _7629; ++_2054)
  {
    {
      _2052->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2053[_2054]);
    }
  }
  _2052->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") in a positive semi-definite cone of size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7630 = (int)1;
  int _7631 = (int)((_2053)->size(0));
  for (int _2055 = _7630; _2055 < _7631; ++_2055)
  {
    {
      _2052->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_2055)));
    }
  }
  _2052->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearPSDConstraint::__mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2056){
  return (::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::LinearPSDConstraint::t(_pubthis),_2056)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearPSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDConstraint::destroy() { mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::PSDConstraint::PSDConstraint(mosek::fusion::p_PSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "PSDConstraint()" << this << std::endl; */ }mosek::fusion::PSDConstraint::~PSDConstraint() {  /* std::cout << "~PSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDConstraint::p_PSDConstraint  (::mosek::fusion::PSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2057,    monty::rc_ptr< ::mosek::fusion::Model > _2058){ return new mosek::fusion::PSDConstraint(_2057,_2058); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2057,    monty::rc_ptr< ::mosek::fusion::Model > _2058) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2057,_2058); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2057,    monty::rc_ptr< ::mosek::fusion::Model > _2058){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2057,_2058);
    conid = mosek::fusion::p_PSDConstraint::_get_impl(_2057)->conid;
    name = mosek::fusion::p_PSDConstraint::_get_impl(_2057)->name;
    shape = mosek::fusion::p_PSDConstraint::_get_impl(_2057)->shape;
    slackidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2057)->slackidxs;
    nativeidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2057)->nativeidxs;
    names_flushed = mosek::fusion::p_PSDConstraint::_get_impl(_2057)->names_flushed;
    conedim0 = mosek::fusion::p_PSDConstraint::_get_impl(_2057)->conedim0;
    conedim1 = mosek::fusion::p_PSDConstraint::_get_impl(_2057)->conedim1;
  }
}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2059,    const std::string &  _2060,    int _2061,    std::shared_ptr< monty::ndarray< int,1 > > _2062,    int _2063,    int _2064,    std::shared_ptr< monty::ndarray< long long,1 > > _2065,    std::shared_ptr< monty::ndarray< int,1 > > _2066){ return new mosek::fusion::PSDConstraint(_2059,_2060,_2061,_2062,_2063,_2064,_2065,_2066); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2059,    const std::string &  _2060,    int _2061,    std::shared_ptr< monty::ndarray< int,1 > > _2062,    int _2063,    int _2064,    std::shared_ptr< monty::ndarray< long long,1 > > _2065,    std::shared_ptr< monty::ndarray< int,1 > > _2066) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2059,_2060,_2061,_2062,_2063,_2064,_2065,_2066); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2059,    const std::string &  _2060,    int _2061,    std::shared_ptr< monty::ndarray< int,1 > > _2062,    int _2063,    int _2064,    std::shared_ptr< monty::ndarray< long long,1 > > _2065,    std::shared_ptr< monty::ndarray< int,1 > > _2066){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2062(_2062 ? _2062->raw() : nullptr, _2062 ? _2062->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2065(_2065 ? _2065->raw() : nullptr, _2065 ? _2065->size(0) : 0);
    _checked_ptr_1<int> _ptr__2066(_2066 ? _2066->raw() : nullptr, _2066 ? _2066->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2059,_2060,_2062,::mosek::fusion::p_PSDConstraint::computenidxs(_2062,_2063,_2064,_2066));
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conid = _2061;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->nativeidxs = _2066;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->slackidxs = _2065;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->name = _2060;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->shape = _2062;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim0 = _2063;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim1 = _2064;
    names_flushed = false;
  }
}std::string mosek::fusion::PSDConstraint :: toString() { return mosek::fusion::p_PSDConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDConstraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("PSDConstraint.toString not implemented"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_PSDConstraint::__mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2067){
  return (::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::PSDConstraint::t(_pubthis),_2067)).as<::mosek::fusion::ModelConstraint>();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_PSDConstraint::computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2068,int _2069,int _2070,std::shared_ptr< monty::ndarray< int,1 > > _2071){
  _checked_ptr_1<int> _ptr__2068(_2068 ? _2068->raw() : nullptr, _2068 ? _2068->size(0) : 0);
  _checked_ptr_1<int> _ptr__2071(_2071 ? _2071->raw() : nullptr, _2071 ? _2071->size(0) : 0);
  int _2072 = (int)((_2068)->size(0));
  bool _2073 = (_2069 < _2070);
  int _7632;
  bool _7633 = _2073;
  if (_7633)
  {
    _7632 = _2069;
  }
  else
  {
    _7632 = _2070;
  }
  int _2074 = _7632;
  int _7634;
  bool _7635 = _2073;
  if (_7635)
  {
    _7634 = _2070;
  }
  else
  {
    _7634 = _2069;
  }
  int _2075 = _7634;
  std::shared_ptr< monty::ndarray< int,1 > > _2076 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__2076(_2076 ? _2076->raw() : nullptr,_2076 ? _2076->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2077 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__2077(_2077 ? _2077->raw() : nullptr,_2077 ? _2077->size(0) : 0);
  int _2078 = (int)1;
  int _7636 = (int)0;
  int _7637 = (int)((_2068)->size(0));
  for (int _2079 = _7636; _2079 < _7637; ++_2079)
  {
    {
      _2078 *= _ptr__2068[_2079];
    }
  }
  int _7638 = (int)0;
  int _7639 = _2074;
  for (int _2080 = _7638; _2080 < _7639; ++_2080)
  {
    {
      _ptr__2076[(int)0] *= _ptr__2068[_2080];
    }
  }
  _ptr__2076[(int)1] = _ptr__2068[_2074];
  int _7640 = safe_add( _2074,(int)1 );
  int _7641 = _2075;
  for (int _2081 = _7640; _2081 < _7641; ++_2081)
  {
    {
      _ptr__2076[(int)2] *= _ptr__2068[_2081];
    }
  }
  _ptr__2076[(int)3] = _ptr__2068[_2075];
  int _7642 = safe_add( _2075,(int)1 );
  int _7643 = _2072;
  for (int _2082 = _7642; _2082 < _7643; ++_2082)
  {
    {
      _ptr__2076[(int)4] *= _ptr__2068[_2082];
    }
  }
  _ptr__2077[(int)4] = (int)1;
  int _7644 = (int)1;
  int _7645 = (int)5;
  for (int _2083 = _7644; _2083 < _7645; ++_2083)
  {
    {
      _ptr__2077[(((int)5 - _2083) - (int)1)] = safe_mul( _ptr__2077[((int)5 - _2083)],_ptr__2076[((int)5 - _2083)] );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2084 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2078)));
  _checked_ptr_1<int> _ptr__2084(_2084 ? _2084->raw() : nullptr,_2084 ? _2084->size(0) : 0);
  int _2085 = (int)0;
  if (_2073)
  {
    {
      int _7646 = (int)0;
      int _7647 = _ptr__2076[(int)0];
      for (int _2086 = _7646; _2086 < _7647; ++_2086)
      {
        {
          int _7648 = (int)0;
          int _7649 = _ptr__2076[(int)1];
          for (int _2087 = _7648; _2087 < _7649; ++_2087)
          {
            {
              int _7650 = (int)0;
              int _7651 = _ptr__2076[(int)2];
              for (int _2088 = _7650; _2088 < _7651; ++_2088)
              {
                {
                  int _7652 = _2087;
                  int _7653 = _ptr__2076[(int)1];
                  for (int _2089 = _7652; _2089 < _7653; ++_2089)
                  {
                    {
                      int _7654 = (int)0;
                      int _7655 = _ptr__2076[(int)4];
                      for (int _2090 = _7654; _2090 < _7655; ++_2090)
                      {
                        {
                          _ptr__2084[safe_add( safe_add( safe_add( safe_add( safe_mul( _2086,_ptr__2077[(int)0] ),safe_mul( _2087,_ptr__2077[(int)1] ) ),safe_mul( _2088,_ptr__2077[(int)2] ) ),safe_mul( _2089,_ptr__2077[(int)3] ) ),safe_mul( _2090,_ptr__2077[(int)4] ) )] = _ptr__2071[_2085];
                          _ptr__2084[safe_add( safe_add( safe_add( safe_add( safe_mul( _2086,_ptr__2077[(int)0] ),safe_mul( _2089,_ptr__2077[(int)1] ) ),safe_mul( _2088,_ptr__2077[(int)2] ) ),safe_mul( _2087,_ptr__2077[(int)3] ) ),safe_mul( _2090,_ptr__2077[(int)4] ) )] = _ptr__2071[_2085];
                          ++ _2085;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _7656 = (int)0;
      int _7657 = _ptr__2076[(int)0];
      for (int _2091 = _7656; _2091 < _7657; ++_2091)
      {
        {
          int _7658 = (int)0;
          int _7659 = _ptr__2076[(int)1];
          for (int _2092 = _7658; _2092 < _7659; ++_2092)
          {
            {
              int _7660 = (int)0;
              int _7661 = _ptr__2076[(int)2];
              for (int _2093 = _7660; _2093 < _7661; ++_2093)
              {
                {
                  int _7662 = (int)0;
                  int _7663 = safe_add( _2092,(int)1 );
                  for (int _2094 = _7662; _2094 < _7663; ++_2094)
                  {
                    {
                      int _7664 = (int)0;
                      int _7665 = _ptr__2076[(int)4];
                      for (int _2095 = _7664; _2095 < _7665; ++_2095)
                      {
                        {
                          _ptr__2084[safe_add( safe_add( safe_add( safe_add( safe_mul( _2091,_ptr__2077[(int)0] ),safe_mul( _2092,_ptr__2077[(int)1] ) ),safe_mul( _2093,_ptr__2077[(int)2] ) ),safe_mul( _2094,_ptr__2077[(int)3] ) ),safe_mul( _2095,_ptr__2077[(int)4] ) )] = _ptr__2071[_2085];
                          _ptr__2084[safe_add( safe_add( safe_add( safe_add( safe_mul( _2091,_ptr__2077[(int)0] ),safe_mul( _2094,_ptr__2077[(int)1] ) ),safe_mul( _2093,_ptr__2077[(int)2] ) ),safe_mul( _2092,_ptr__2077[(int)3] ) ),safe_mul( _2095,_ptr__2077[(int)4] ) )] = _ptr__2071[_2085];
                          ++ _2085;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _2084;
}
void mosek::fusion::p_PSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::PSDConstraint::destroy() { mosek::fusion::p_PSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConstraintCache::ConstraintCache(mosek::fusion::p_ConstraintCache *_impl) : _impl(_impl) { /*std::cout << "ConstraintCache() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConstraintCache::~ConstraintCache() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConstraintCache::p_ConstraintCache  (::mosek::fusion::ConstraintCache * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barmatidx() { return _impl->barmatidx; }
void mosek::fusion::ConstraintCache::set_barmatidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmatidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConstraintCache::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConstraintCache::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
long long mosek::fusion::ConstraintCache::get_nbarnz() { return _impl->nbarnz; }
void mosek::fusion::ConstraintCache::set_nbarnz(long long _val) { _impl->nbarnz = _val; }
long long mosek::fusion::ConstraintCache::get_nunordered() { return _impl->nunordered; }
void mosek::fusion::ConstraintCache::set_nunordered(long long _val) { _impl->nunordered = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subi() { return _impl->buffer_subi; }
void mosek::fusion::ConstraintCache::set_buffer_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subj() { return _impl->buffer_subj; }
void mosek::fusion::ConstraintCache::set_buffer_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subj = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_buffer_cof() { return _impl->buffer_cof; }
void mosek::fusion::ConstraintCache::set_buffer_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->buffer_cof = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConstraintCache::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_cof() { return _impl->cof; }
void mosek::fusion::ConstraintCache::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subi() { return _impl->subi; }
void mosek::fusion::ConstraintCache::set_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subj() { return _impl->subj; }
void mosek::fusion::ConstraintCache::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
long long mosek::fusion::ConstraintCache::get_nnz() { return _impl->nnz; }
void mosek::fusion::ConstraintCache::set_nnz(long long _val) { _impl->nnz = _val; }
int mosek::fusion::ConstraintCache::get_nrows() { return _impl->nrows; }
void mosek::fusion::ConstraintCache::set_nrows(int _val) { _impl->nrows = _val; }
mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2096){ return new mosek::fusion::ConstraintCache(_2096); }mosek::fusion::ConstraintCache::ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2096) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2096); }void mosek::fusion::p_ConstraintCache::_initialize  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2096){monty::rc_reserve __reserve_this(_pubthis);   {
    nrows = mosek::fusion::p_ConstraintCache::_get_impl(_2096)->nrows;
    nnz = mosek::fusion::p_ConstraintCache::_get_impl(_2096)->nnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7666;
    bool _7667 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->subj.get());
    if (_7667)
    {
      _7666 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->subj);
    }
    else
    {
      _7666 = nullptr;
    }
    subj = _7666;
    std::shared_ptr< monty::ndarray< int,1 > > _7668;
    bool _7669 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->subi.get());
    if (_7669)
    {
      _7668 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->subi);
    }
    else
    {
      _7668 = nullptr;
    }
    subi = _7668;
    std::shared_ptr< monty::ndarray< double,1 > > _7670;
    bool _7671 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->cof.get());
    if (_7671)
    {
      _7670 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->cof);
    }
    else
    {
      _7670 = nullptr;
    }
    cof = _7670;
    std::shared_ptr< monty::ndarray< double,1 > > _7672;
    bool _7673 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->bfix.get());
    if (_7673)
    {
      _7672 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->bfix);
    }
    else
    {
      _7672 = nullptr;
    }
    bfix = _7672;
    std::shared_ptr< monty::ndarray< double,1 > > _7674;
    bool _7675 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->buffer_cof.get());
    if (_7675)
    {
      _7674 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->buffer_cof);
    }
    else
    {
      _7674 = nullptr;
    }
    buffer_cof = _7674;
    std::shared_ptr< monty::ndarray< int,1 > > _7676;
    bool _7677 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->buffer_subj.get());
    if (_7677)
    {
      _7676 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->buffer_subj);
    }
    else
    {
      _7676 = nullptr;
    }
    buffer_subj = _7676;
    std::shared_ptr< monty::ndarray< int,1 > > _7678;
    bool _7679 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->buffer_subi.get());
    if (_7679)
    {
      _7678 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->buffer_subi);
    }
    else
    {
      _7678 = nullptr;
    }
    buffer_subi = _7678;
    nunordered = mosek::fusion::p_ConstraintCache::_get_impl(_2096)->nunordered;
    nbarnz = mosek::fusion::p_ConstraintCache::_get_impl(_2096)->nbarnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7680;
    bool _7681 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->barsubi.get());
    if (_7681)
    {
      _7680 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->barsubi);
    }
    else
    {
      _7680 = nullptr;
    }
    barsubi = _7680;
    std::shared_ptr< monty::ndarray< int,1 > > _7682;
    bool _7683 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->barsubj.get());
    if (_7683)
    {
      _7682 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->barsubj);
    }
    else
    {
      _7682 = nullptr;
    }
    barsubj = _7682;
    std::shared_ptr< monty::ndarray< int,1 > > _7684;
    bool _7685 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2096)->barmatidx.get());
    if (_7685)
    {
      _7684 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2096)->barmatidx);
    }
    else
    {
      _7684 = nullptr;
    }
    barmatidx = _7684;
  }
}mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2097,    std::shared_ptr< monty::ndarray< double,1 > > _2098,    std::shared_ptr< monty::ndarray< int,1 > > _2099,    std::shared_ptr< monty::ndarray< double,1 > > _2100,    std::shared_ptr< monty::ndarray< int,1 > > _2101,    std::shared_ptr< monty::ndarray< int,1 > > _2102,    std::shared_ptr< monty::ndarray< int,1 > > _2103){ return new mosek::fusion::ConstraintCache(_2097,_2098,_2099,_2100,_2101,_2102,_2103); }mosek::fusion::ConstraintCache::ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2097,    std::shared_ptr< monty::ndarray< double,1 > > _2098,    std::shared_ptr< monty::ndarray< int,1 > > _2099,    std::shared_ptr< monty::ndarray< double,1 > > _2100,    std::shared_ptr< monty::ndarray< int,1 > > _2101,    std::shared_ptr< monty::ndarray< int,1 > > _2102,    std::shared_ptr< monty::ndarray< int,1 > > _2103) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2097,_2098,_2099,_2100,_2101,_2102,_2103); }void mosek::fusion::p_ConstraintCache::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _2097,    std::shared_ptr< monty::ndarray< double,1 > > _2098,    std::shared_ptr< monty::ndarray< int,1 > > _2099,    std::shared_ptr< monty::ndarray< double,1 > > _2100,    std::shared_ptr< monty::ndarray< int,1 > > _2101,    std::shared_ptr< monty::ndarray< int,1 > > _2102,    std::shared_ptr< monty::ndarray< int,1 > > _2103){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2097(_2097 ? _2097->raw() : nullptr, _2097 ? _2097->size(0) : 0);
    _checked_ptr_1<double> _ptr__2098(_2098 ? _2098->raw() : nullptr, _2098 ? _2098->size(0) : 0);
    _checked_ptr_1<int> _ptr__2099(_2099 ? _2099->raw() : nullptr, _2099 ? _2099->size(0) : 0);
    _checked_ptr_1<double> _ptr__2100(_2100 ? _2100->raw() : nullptr, _2100 ? _2100->size(0) : 0);
    _checked_ptr_1<int> _ptr__2101(_2101 ? _2101->raw() : nullptr, _2101 ? _2101->size(0) : 0);
    _checked_ptr_1<int> _ptr__2102(_2102 ? _2102->raw() : nullptr, _2102 ? _2102->size(0) : 0);
    _checked_ptr_1<int> _ptr__2103(_2103 ? _2103->raw() : nullptr, _2103 ? _2103->size(0) : 0);
    nrows = ((int)((_2097)->size(0)) - (int)1);
    nnz = _ptr__2097[((int)((_2097)->size(0)) - (int)1)];
    subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nnz)));
    if ((NULL != _2100.get()))
    {
      {
        bfix = _2100;
      }
    }
    else
    {
      {
        bfix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nrows)));
      }
    }
    if (((NULL != _2101.get()) && ((NULL != _2102.get()) && (NULL != _2103.get()))))
    {
      {
        nbarnz = (int)((_2101)->size(0));
        if ((nbarnz > (int)((_2102)->size(0))))
        {
          {
            nbarnz = (int)((_2102)->size(0));
          }
        }
        {}
        if ((nbarnz > (int)((_2103)->size(0))))
        {
          {
            nbarnz = (int)((_2103)->size(0));
          }
        }
        {}
        barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        ::mosek::fusion::Utils::Tools::arraycopy(_2101,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2102,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2103,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
      }
    }
    else
    {
      {
        nbarnz = (int)0;
        barsubi = nullptr;
        barsubj = nullptr;
        barmatidx = nullptr;
      }
    }
    ::mosek::fusion::Utils::Tools::arraycopy(_2099,(long long)0,subj,(long long)0,nnz);
    ::mosek::fusion::Utils::Tools::arraycopy(_2098,(long long)0,cof,(long long)0,nnz);
    int _7686 = (int)0;
    int _7687 = nrows;
    for (int _2104 = _7686; _2104 < _7687; ++_2104)
    {
      {
        long long _7688 = _ptr__2097[_2104];
        long long _7689 = _ptr__2097[safe_add( _2104,(int)1 )];
        for (long long _2105 = _7688; _2105 < _7689; ++_2105)
        {
          {
            ((*subi)(_2105)) = _2104;
          }
        }
      }
    }
    buffer_cof = nullptr;
    buffer_subj = nullptr;
    buffer_subi = nullptr;
    nunordered = (long long)0;
  }
}void mosek::fusion::p_ConstraintCache::unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2106){
  _checked_ptr_1<double> _ptr__2106(_2106 ? _2106->raw() : nullptr, _2106 ? _2106->size(0) : 0);
  int _7690 = (int)0;
  int _7691 = nrows;
  for (int _2107 = _7690; _2107 < _7691; ++_2107)
  {
    {
      ((*bfix)(_2107)) = (((*bfix)(_2107)) + _ptr__2106[_2107]);
    }
  }
}
long long mosek::fusion::p_ConstraintCache::order_barentries(){
  std::vector<long long> _7692;
  for (long long _2109 = (long long)0, _7693 = nbarnz; _2109 < _7693 ; ++_2109)
  {
    _7692.push_back(_2109);
  }
  auto _7694 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7692.size()),_7692.begin(),_7692.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _2108 = _7694;
  _checked_ptr_1<long long> _ptr__2108(_2108 ? _2108->raw() : nullptr,_2108 ? _2108->size(0) : 0);
  if ((!::mosek::fusion::p_Sort::issorted(_2108,barsubi,barsubj,(long long)((int)0),nbarnz,false)))
  {
    {
      ::mosek::fusion::p_Sort::argsort(_2108,barsubi,barsubj,(long long)((int)0),nbarnz,false);
      std::shared_ptr< monty::ndarray< int,1 > > _2110 = barsubi;
      _checked_ptr_1<int> _ptr__2110(_2110 ? _2110->raw() : nullptr,_2110 ? _2110->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2111 = barsubj;
      _checked_ptr_1<int> _ptr__2111(_2111 ? _2111->raw() : nullptr,_2111 ? _2111->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2112 = barmatidx;
      _checked_ptr_1<int> _ptr__2112(_2112 ? _2112->raw() : nullptr,_2112 ? _2112->size(0) : 0);
      std::vector<int> _7695;
      for (long long _2113 = (int)0, _7696 = nbarnz; _2113 < _7696 ; ++_2113)
      {
        _7695.push_back(_ptr__2110[_ptr__2108[_2113]]);
      }
      auto _7697 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7695.size()),_7695.begin(),_7695.end()));
      barsubi = _7697;
      std::vector<int> _7698;
      for (long long _2114 = (int)0, _7699 = nbarnz; _2114 < _7699 ; ++_2114)
      {
        _7698.push_back(_ptr__2111[_ptr__2108[_2114]]);
      }
      auto _7700 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7698.size()),_7698.begin(),_7698.end()));
      barsubj = _7700;
      std::vector<int> _7701;
      for (long long _2115 = (int)0, _7702 = nbarnz; _2115 < _7702 ; ++_2115)
      {
        _7701.push_back(_ptr__2112[_ptr__2108[_2115]]);
      }
      auto _7703 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7701.size()),_7701.begin(),_7701.end()));
      barmatidx = _7703;
    }
  }
  {}
  return nbarnz;
}
void mosek::fusion::p_ConstraintCache::add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2116,std::shared_ptr< monty::ndarray< int,1 > > _2117,std::shared_ptr< monty::ndarray< int,1 > > _2118){
  _checked_ptr_1<int> _ptr__2116(_2116 ? _2116->raw() : nullptr, _2116 ? _2116->size(0) : 0);
  _checked_ptr_1<int> _ptr__2117(_2117 ? _2117->raw() : nullptr, _2117 ? _2117->size(0) : 0);
  _checked_ptr_1<int> _ptr__2118(_2118 ? _2118->raw() : nullptr, _2118 ? _2118->size(0) : 0);
  if ((NULL != _2116.get()))
  {
    {
      int _2119 = (int)((_2116)->size(0));
      if (((int)((_2116)->size(0)) <= safe_add( nbarnz,_2119 )))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2120 = barsubi;
          _checked_ptr_1<int> _ptr__2120(_2120 ? _2120->raw() : nullptr,_2120 ? _2120->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2121 = barsubj;
          _checked_ptr_1<int> _ptr__2121(_2121 ? _2121->raw() : nullptr,_2121 ? _2121->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2122 = barmatidx;
          _checked_ptr_1<int> _ptr__2122(_2122 ? _2122->raw() : nullptr,_2122 ? _2122->size(0) : 0);
          long long _7704;
          bool _7705 = (safe_mul( (int)2,nbarnz ) > safe_add( nbarnz,_2119 ));
          if (_7705)
          {
            _7704 = safe_mul( (int)2,nbarnz );
          }
          else
          {
            _7704 = safe_add( nbarnz,safe_mul( _2119,(int)2 ) );
          }
          long long _2123 = _7704;
          barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2123)));
          barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2123)));
          barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2123)));
          if ((nbarnz > (int)0))
          {
            {
              ::mosek::fusion::Utils::Tools::arraycopy(_2120,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2121,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2122,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
            }
          }
          {}
        }
      }
      {}
      ::mosek::fusion::Utils::Tools::arraycopy(_2116,(long long)((int)0),barsubi,nbarnz,(long long)(_2119));
      ::mosek::fusion::Utils::Tools::arraycopy(_2117,(long long)((int)0),barsubj,nbarnz,(long long)(_2119));
      ::mosek::fusion::Utils::Tools::arraycopy(_2118,(long long)((int)0),barmatidx,nbarnz,(long long)(_2119));
      nbarnz += _2119;
    }
  }
  {}
}
void mosek::fusion::p_ConstraintCache::unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2124,std::shared_ptr< monty::ndarray< int,1 > > _2125,std::shared_ptr< monty::ndarray< double,1 > > _2126,std::shared_ptr< monty::ndarray< double,1 > > _2127){
  _checked_ptr_1<long long> _ptr__2124(_2124 ? _2124->raw() : nullptr, _2124 ? _2124->size(0) : 0);
  _checked_ptr_1<int> _ptr__2125(_2125 ? _2125->raw() : nullptr, _2125 ? _2125->size(0) : 0);
  _checked_ptr_1<double> _ptr__2126(_2126 ? _2126->raw() : nullptr, _2126 ? _2126->size(0) : 0);
  _checked_ptr_1<double> _ptr__2127(_2127 ? _2127->raw() : nullptr, _2127 ? _2127->size(0) : 0);
  long long _2128 = safe_add( nunordered,_ptr__2124[nrows] );
  long long _2129 = _ptr__2124[nrows];
  std::shared_ptr< monty::ndarray< int,1 > > _2130;
  _checked_ptr_1<int> _ptr__2130(_2130 ? _2130->raw() : nullptr,_2130 ? _2130->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2131;
  _checked_ptr_1<int> _ptr__2131(_2131 ? _2131->raw() : nullptr,_2131 ? _2131->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2132;
  _checked_ptr_1<double> _ptr__2132(_2132 ? _2132->raw() : nullptr,_2132 ? _2132->size(0) : 0);
  if (((NULL == buffer_cof.get()) || ((int)((buffer_cof)->size(0)) < _2128)))
  {
    {
      _2130 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2128)));
      _ptr__2130.update(_2130 ? _2130->raw() : nullptr, _2130 ? _2130->size(0) : 0);
      _2131 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2128)));
      _ptr__2131.update(_2131 ? _2131->raw() : nullptr, _2131 ? _2131->size(0) : 0);
      _2132 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2128)));
      _ptr__2132.update(_2132 ? _2132->raw() : nullptr, _2132 ? _2132->size(0) : 0);
      if ((NULL != buffer_cof.get()))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subi,(long long)0,_2130,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subj,(long long)0,_2131,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_cof,(long long)0,_2132,(long long)0,nunordered);
        }
      }
      {}
    }
  }
  else
  {
    {
      _2130 = buffer_subi;
      _ptr__2130.update(_2130 ? _2130->raw() : nullptr, _2130 ? _2130->size(0) : 0);
      _2131 = buffer_subj;
      _ptr__2131.update(_2131 ? _2131->raw() : nullptr, _2131 ? _2131->size(0) : 0);
      _2132 = buffer_cof;
      _ptr__2132.update(_2132 ? _2132->raw() : nullptr, _2132 ? _2132->size(0) : 0);
    }
  }
  int _7706 = (int)0;
  int _7707 = nrows;
  for (int _2133 = _7706; _2133 < _7707; ++_2133)
  {
    {
      long long _7708 = _ptr__2124[_2133];
      long long _7709 = _ptr__2124[safe_add( _2133,(int)1 )];
      for (long long _2134 = _7708; _2134 < _7709; ++_2134)
      {
        {
          _ptr__2130[safe_add( nunordered,_2134 )] = _2133;
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(_2125,(long long)0,_2131,nunordered,_2129);
  ::mosek::fusion::Utils::Tools::arraycopy(_2126,(long long)0,_2132,nunordered,_2129);
  buffer_subi = _2130;
  buffer_subj = _2131;
  buffer_cof = _2132;
  if ((NULL != _2127.get()))
  {
    {
      int _7710 = (int)0;
      int _7711 = nrows;
      for (int _2135 = _7710; _2135 < _7711; ++_2135)
      {
        {
          ((*bfix)(_2135)) = (((*bfix)(_2135)) + _ptr__2127[_2135]);
        }
      }
    }
  }
  {}
  nunordered = _2128;
}
void mosek::fusion::ConstraintCache :: add(std::shared_ptr< monty::ndarray< long long,1 > > _2136,std::shared_ptr< monty::ndarray< int,1 > > _2137,std::shared_ptr< monty::ndarray< double,1 > > _2138,std::shared_ptr< monty::ndarray< double,1 > > _2139) { mosek::fusion::p_ConstraintCache::_get_impl(this)->add(_2136,_2137,_2138,_2139); }void mosek::fusion::p_ConstraintCache::add(std::shared_ptr< monty::ndarray< long long,1 > > _2136,std::shared_ptr< monty::ndarray< int,1 > > _2137,std::shared_ptr< monty::ndarray< double,1 > > _2138,std::shared_ptr< monty::ndarray< double,1 > > _2139){
  _checked_ptr_1<long long> _ptr__2136(_2136 ? _2136->raw() : nullptr, _2136 ? _2136->size(0) : 0);
  _checked_ptr_1<int> _ptr__2137(_2137 ? _2137->raw() : nullptr, _2137 ? _2137->size(0) : 0);
  _checked_ptr_1<double> _ptr__2138(_2138 ? _2138->raw() : nullptr, _2138 ? _2138->size(0) : 0);
  _checked_ptr_1<double> _ptr__2139(_2139 ? _2139->raw() : nullptr, _2139 ? _2139->size(0) : 0);
  if ((((int)((_2136)->size(0)) != safe_add( nrows,(int)1 )) || ((NULL != _2139.get()) && ((int)((_2139)->size(0)) != nrows))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching expression lengths"));
    }
  }
  {}
  unchecked_add_l(_2136,_2137,_2138,_2139);
}
long long mosek::fusion::ConstraintCache :: flush(std::shared_ptr< monty::ndarray< int,1 > > _2140,std::shared_ptr< monty::ndarray< int,1 > > _2141,std::shared_ptr< monty::ndarray< double,1 > > _2142,std::shared_ptr< monty::ndarray< double,1 > > _2143) { return mosek::fusion::p_ConstraintCache::_get_impl(this)->flush(_2140,_2141,_2142,_2143); }long long mosek::fusion::p_ConstraintCache::flush(std::shared_ptr< monty::ndarray< int,1 > > _2140,std::shared_ptr< monty::ndarray< int,1 > > _2141,std::shared_ptr< monty::ndarray< double,1 > > _2142,std::shared_ptr< monty::ndarray< double,1 > > _2143){
  _checked_ptr_1<int> _ptr__2140(_2140 ? _2140->raw() : nullptr, _2140 ? _2140->size(0) : 0);
  _checked_ptr_1<int> _ptr__2141(_2141 ? _2141->raw() : nullptr, _2141 ? _2141->size(0) : 0);
  _checked_ptr_1<double> _ptr__2142(_2142 ? _2142->raw() : nullptr, _2142 ? _2142->size(0) : 0);
  _checked_ptr_1<double> _ptr__2143(_2143 ? _2143->raw() : nullptr, _2143 ? _2143->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2144 = nullptr;
  _checked_ptr_1<long long> _ptr__2144(_2144 ? _2144->raw() : nullptr,_2144 ? _2144->size(0) : 0);
  if (((NULL != bfix.get()) && (NULL != _2143.get())))
  {
    {
      int _7712 = (int)0;
      int _7713 = nrows;
      for (int _2145 = _7712; _2145 < _7713; ++_2145)
      {
        {
          _ptr__2143[_2145] = ((*bfix)(_2145));
        }
      }
    }
  }
  {}
  if ((nunordered == (long long)0))
  {
    {
      return (long long)0;
    }
  }
  {}
  bool _2146 = false;
  {
    int _2147 = (int)1;
    while ( ((_2147 < nunordered) && ((((*buffer_subi)((_2147 - (int)1))) < ((*buffer_subi)(_2147))) || ((((*buffer_subi)((_2147 - (int)1))) == ((*buffer_subi)(_2147))) && (((*buffer_subj)((_2147 - (int)1))) <= ((*buffer_subj)(_2147)))))) )
    {
      {
        ++ _2147;
      }
    }
    _2146 = (_2147 == nunordered);
  }
  if ((!_2146))
  {
    {
      std::vector<long long> _7714;
      for (long long _2148 = (int)0, _7715 = nunordered; _2148 < _7715 ; ++_2148)
      {
        _7714.push_back(_2148);
      }
      auto _7716 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7714.size()),_7714.begin(),_7714.end()));
      _2144 = _7716;
      _ptr__2144.update(_2144 ? _2144->raw() : nullptr, _2144 ? _2144->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2144,buffer_subi,buffer_subj,(long long)0,nunordered);
    }
  }
  {}
  long long _2149 = nnz;
  std::shared_ptr< monty::ndarray< int,1 > > _2150 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2149 ))));
  _checked_ptr_1<int> _ptr__2150(_2150 ? _2150->raw() : nullptr,_2150 ? _2150->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2151 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2149 ))));
  _checked_ptr_1<int> _ptr__2151(_2151 ? _2151->raw() : nullptr,_2151 ? _2151->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2152 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_add( nunordered,_2149 ))));
  _checked_ptr_1<double> _ptr__2152(_2152 ? _2152->raw() : nullptr,_2152 ? _2152->size(0) : 0);
  long long _2153 = (long long)0;
  if (_2146)
  {
    {
      long long _2154 = (long long)0;
      int _2155 = (int)0;
      long long _2156 = nunordered;
      long long _2157 = _2149;
      int _2158 = (int)0;
      int _2159 = (int)0;
      while ( ((_2159 < _2157) && (_2158 < _2156)) )
      {
        {
          if (((((*subi)(_2159)) < ((*buffer_subi)(_2158))) || ((((*subi)(_2159)) == ((*buffer_subi)(_2158))) && (((*subj)(_2159)) < ((*buffer_subj)(_2158))))))
          {
            {
              _ptr__2150[_2155] = ((*subi)(_2159));
              _ptr__2151[_2155] = ((*subj)(_2159));
              _ptr__2152[_2155] = ((*cof)(_2159));
              ++ _2159;
              ++ _2155;
            }
          }
          else if(((((*subi)(_2159)) > ((*buffer_subi)(_2158))) || ((((*subi)(_2159)) == ((*buffer_subi)(_2158))) && (((*subj)(_2159)) > ((*buffer_subj)(_2158))))))
          {
            {
              _ptr__2150[_2155] = ((*buffer_subi)(_2158));
              _ptr__2151[_2155] = ((*buffer_subj)(_2158));
              _ptr__2152[_2155] = ((*buffer_cof)(_2158));
              _ptr__2140[_2153] = _ptr__2150[_2155];
              _ptr__2141[_2153] = _ptr__2151[_2155];
              _ptr__2142[_2153] = _ptr__2152[_2155];
              ++ _2153;
              ++ _2158;
              ++ _2155;
            }
          }
          else
          {
            {
              _ptr__2150[_2155] = ((*subi)(_2159));
              _ptr__2151[_2155] = ((*subj)(_2159));
              _ptr__2152[_2155] = ((*cof)(_2159));
              while ( ((_2159 < (int)((subi)->size(0))) && ((_2158 < (int)((buffer_subi)->size(0))) && ((((*subi)(_2159)) == ((*buffer_subi)(_2158))) && (((*subj)(_2159)) == ((*buffer_subj)(_2158)))))) )
              {
                {
                  _ptr__2152[_2155] = (_ptr__2152[_2155] + ((*buffer_cof)(_2158)));
                  ++ _2158;
                }
              }
              _ptr__2140[_2153] = _ptr__2150[_2155];
              _ptr__2141[_2153] = _ptr__2151[_2155];
              _ptr__2142[_2153] = _ptr__2152[_2155];
              ++ _2153;
              ++ _2159;
              ++ _2155;
            }
          }
        }
      }
      while ( (_2159 < _2157) )
      {
        {
          _ptr__2150[_2155] = ((*subi)(_2159));
          _ptr__2151[_2155] = ((*subj)(_2159));
          _ptr__2152[_2155] = ((*cof)(_2159));
          ++ _2159;
          ++ _2155;
        }
      }
      while ( (_2158 < _2156) )
      {
        {
          _ptr__2150[_2155] = ((*buffer_subi)(_2158));
          _ptr__2151[_2155] = ((*buffer_subj)(_2158));
          _ptr__2152[_2155] = ((*buffer_cof)(_2158));
          _ptr__2140[_2153] = _ptr__2150[_2155];
          _ptr__2141[_2153] = _ptr__2151[_2155];
          _ptr__2142[_2153] = _ptr__2152[_2155];
          ++ _2153;
          ++ _2158;
          ++ _2155;
        }
      }
      nnz = _2155;
    }
  }
  else
  {
    {
      long long _2160 = (long long)0;
      int _2161 = (int)0;
      long long _2162 = nunordered;
      long long _2163 = _2149;
      int _2164 = (int)0;
      int _2165 = (int)0;
      while ( ((_2165 < _2163) && (_2164 < _2162)) )
      {
        {
          if (((((*subi)(_2165)) < ((*buffer_subi)(_ptr__2144[_2164]))) || ((((*subi)(_2165)) == ((*buffer_subi)(_ptr__2144[_2164]))) && (((*subj)(_2165)) < ((*buffer_subj)(_ptr__2144[_2164]))))))
          {
            {
              _ptr__2150[_2161] = ((*subi)(_2165));
              _ptr__2151[_2161] = ((*subj)(_2165));
              _ptr__2152[_2161] = ((*cof)(_2165));
              ++ _2165;
              ++ _2161;
            }
          }
          else if(((((*subi)(_2165)) > ((*buffer_subi)(_ptr__2144[_2164]))) || ((((*subi)(_2165)) == ((*buffer_subi)(_ptr__2144[_2164]))) && (((*subj)(_2165)) > ((*buffer_subj)(_ptr__2144[_2164]))))))
          {
            {
              _ptr__2150[_2161] = ((*buffer_subi)(_ptr__2144[_2164]));
              _ptr__2151[_2161] = ((*buffer_subj)(_ptr__2144[_2164]));
              _ptr__2152[_2161] = ((*buffer_cof)(_ptr__2144[_2164]));
              _ptr__2140[_2153] = _ptr__2150[_2161];
              _ptr__2141[_2153] = _ptr__2151[_2161];
              _ptr__2142[_2153] = _ptr__2152[_2161];
              ++ _2153;
              ++ _2164;
              ++ _2161;
            }
          }
          else
          {
            {
              _ptr__2150[_2161] = ((*subi)(_2165));
              _ptr__2151[_2161] = ((*subj)(_2165));
              _ptr__2152[_2161] = ((*cof)(_2165));
              while ( ((((*subi)(_2165)) == ((*buffer_subi)(_ptr__2144[_2164]))) && (((*subj)(_2165)) == ((*buffer_subj)(_ptr__2144[_2164])))) )
              {
                {
                  _ptr__2152[_2161] = (_ptr__2152[_2161] + ((*buffer_cof)(_ptr__2144[_2164])));
                  ++ _2164;
                }
              }
              _ptr__2140[_2153] = _ptr__2150[_2161];
              _ptr__2141[_2153] = _ptr__2151[_2161];
              _ptr__2142[_2153] = _ptr__2152[_2161];
              ++ _2153;
              ++ _2165;
              ++ _2161;
            }
          }
        }
      }
      nnz = _2161;
    }
  }
  subi = _2150;
  subj = _2151;
  cof = _2152;
  nunordered = (long long)0;
  return _2153;
}
long long mosek::fusion::ConstraintCache :: numUnsorted() { return mosek::fusion::p_ConstraintCache::_get_impl(this)->numUnsorted(); }long long mosek::fusion::p_ConstraintCache::numUnsorted(){
  return nunordered;
}
monty::rc_ptr< ::mosek::fusion::ConstraintCache > mosek::fusion::p_ConstraintCache::__mosek_2fusion_2ConstraintCache__clone(){
  return ::mosek::fusion::p_ConstraintCache::_new_ConstraintCache(::mosek::fusion::ConstraintCache::t(_pubthis));
}
void mosek::fusion::p_ConstraintCache::destroy(){barmatidx.reset();barsubj.reset();barsubi.reset();buffer_subi.reset();buffer_subj.reset();buffer_cof.reset();bfix.reset();cof.reset();subi.reset();subj.reset();}void mosek::fusion::ConstraintCache::destroy() { mosek::fusion::p_ConstraintCache::_get_impl(this)->destroy(); }mosek::fusion::SliceConstraint::SliceConstraint(mosek::fusion::p_SliceConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "SliceConstraint()" << this << std::endl; */ }mosek::fusion::SliceConstraint::~SliceConstraint() {  /* std::cout << "~SliceConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceConstraint::p_SliceConstraint  (::mosek::fusion::SliceConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceConstraint::t mosek::fusion::p_SliceConstraint::_new_SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2166,    std::shared_ptr< monty::ndarray< int,1 > > _2167,    std::shared_ptr< monty::ndarray< int,1 > > _2168){ return new mosek::fusion::SliceConstraint(_2166,_2167,_2168); }mosek::fusion::SliceConstraint::SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2166,    std::shared_ptr< monty::ndarray< int,1 > > _2167,    std::shared_ptr< monty::ndarray< int,1 > > _2168) :    SliceConstraint(new mosek::fusion::p_SliceConstraint(this)){ mosek::fusion::p_SliceConstraint::_get_impl(this)->_initialize(_2166,_2167,_2168); }void mosek::fusion::p_SliceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2166,    std::shared_ptr< monty::ndarray< int,1 > > _2167,    std::shared_ptr< monty::ndarray< int,1 > > _2168){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2167(_2167 ? _2167->raw() : nullptr, _2167 ? _2167->size(0) : 0);
    _checked_ptr_1<int> _ptr__2168(_2168 ? _2168->raw() : nullptr, _2168 ? _2168->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2166,_2167,_2168);
  }
}std::string mosek::fusion::SliceConstraint :: toString() { return mosek::fusion::p_SliceConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_SliceConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2169 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2169->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SliceConstraint()"));
  return _2169->toString();
}
void mosek::fusion::p_SliceConstraint::destroy(){}void mosek::fusion::SliceConstraint::destroy() { mosek::fusion::p_SliceConstraint::_get_impl(this)->destroy(); }mosek::fusion::RangedConstraint::RangedConstraint(mosek::fusion::p_RangedConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "RangedConstraint()" << this << std::endl; */ }mosek::fusion::RangedConstraint::~RangedConstraint() {  /* std::cout << "~RangedConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedConstraint::p_RangedConstraint  (::mosek::fusion::RangedConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2170,    monty::rc_ptr< ::mosek::fusion::Model > _2171){ return new mosek::fusion::RangedConstraint(_2170,_2171); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2170,    monty::rc_ptr< ::mosek::fusion::Model > _2171) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2170,_2171); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2170,    monty::rc_ptr< ::mosek::fusion::Model > _2171){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2170,_2171);
    shape = mosek::fusion::p_RangedConstraint::_get_impl(_2170)->shape;
    nativeidxs = mosek::fusion::p_RangedConstraint::_get_impl(_2170)->nativeidxs;
  }
}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2172,    const std::string &  _2173,    std::shared_ptr< monty::ndarray< int,1 > > _2174,    std::shared_ptr< monty::ndarray< int,1 > > _2175){ return new mosek::fusion::RangedConstraint(_2172,_2173,_2174,_2175); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2172,    const std::string &  _2173,    std::shared_ptr< monty::ndarray< int,1 > > _2174,    std::shared_ptr< monty::ndarray< int,1 > > _2175) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2172,_2173,_2174,_2175); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2172,    const std::string &  _2173,    std::shared_ptr< monty::ndarray< int,1 > > _2174,    std::shared_ptr< monty::ndarray< int,1 > > _2175){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2174(_2174 ? _2174->raw() : nullptr, _2174 ? _2174->size(0) : 0);
    _checked_ptr_1<int> _ptr__2175(_2175 ? _2175->raw() : nullptr, _2175 ? _2175->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2172,_2173,_2174,_2175);
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->shape = _2174;
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->nativeidxs = _2175;
  }
}monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_RangedConstraint::__mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2176){
  return (::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::RangedConstraint::t(_pubthis),_2176)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_RangedConstraint::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::RangedConstraint::destroy() { mosek::fusion::p_RangedConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConicConstraint::ConicConstraint(mosek::fusion::p_ConicConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "ConicConstraint()" << this << std::endl; */ }mosek::fusion::ConicConstraint::~ConicConstraint() {  /* std::cout << "~ConicConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicConstraint::p_ConicConstraint  (::mosek::fusion::ConicConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2177,    monty::rc_ptr< ::mosek::fusion::Model > _2178){ return new mosek::fusion::ConicConstraint(_2177,_2178); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2177,    monty::rc_ptr< ::mosek::fusion::Model > _2178) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2177,_2178); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2177,    monty::rc_ptr< ::mosek::fusion::Model > _2178){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2177,_2178);
    dom = mosek::fusion::p_ConicConstraint::_get_impl(_2177)->dom;
    conid = mosek::fusion::p_ConicConstraint::_get_impl(_2177)->conid;
    shape = mosek::fusion::p_ConicConstraint::_get_impl(_2177)->shape;
    name = mosek::fusion::p_ConicConstraint::_get_impl(_2177)->name;
    nativeidxs = mosek::fusion::p_ConicConstraint::_get_impl(_2177)->nativeidxs;
    nativeslack = mosek::fusion::p_ConicConstraint::_get_impl(_2177)->nativeslack;
    names_flushed = mosek::fusion::p_ConicConstraint::_get_impl(_2177)->names_flushed;
  }
}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2179,    const std::string &  _2180,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2181,    std::shared_ptr< monty::ndarray< int,1 > > _2182,    int _2183,    std::shared_ptr< monty::ndarray< int,1 > > _2184,    std::shared_ptr< monty::ndarray< int,1 > > _2185){ return new mosek::fusion::ConicConstraint(_2179,_2180,_2181,_2182,_2183,_2184,_2185); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2179,    const std::string &  _2180,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2181,    std::shared_ptr< monty::ndarray< int,1 > > _2182,    int _2183,    std::shared_ptr< monty::ndarray< int,1 > > _2184,    std::shared_ptr< monty::ndarray< int,1 > > _2185) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2179,_2180,_2181,_2182,_2183,_2184,_2185); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2179,    const std::string &  _2180,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2181,    std::shared_ptr< monty::ndarray< int,1 > > _2182,    int _2183,    std::shared_ptr< monty::ndarray< int,1 > > _2184,    std::shared_ptr< monty::ndarray< int,1 > > _2185){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2182(_2182 ? _2182->raw() : nullptr, _2182 ? _2182->size(0) : 0);
    _checked_ptr_1<int> _ptr__2184(_2184 ? _2184->raw() : nullptr, _2184 ? _2184->size(0) : 0);
    _checked_ptr_1<int> _ptr__2185(_2185 ? _2185->raw() : nullptr, _2185 ? _2185->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2179,_2180,_2182,_2184);
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->dom = _2181;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->shape = _2182;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->name = _2180;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeidxs = _2184;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeslack = _2185;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->conid = _2183;
    names_flushed = false;
  }
}void mosek::fusion::p_ConicConstraint::flushNames(){
  ::mosek::fusion::p_ModelConstraint::flushNames();
  int _2186 = (int)((nativeslack)->size(0));
  monty::rc_ptr< ::mosek::fusion::Model > _2187 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          int _7717 = (int)0;
          int _7718 = _2186;
          for (int _2188 = _7717; _2188 < _7718; ++_2188)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2187.get())->task_var_name(((*nativeslack)(_2188)),std::string (""));
            }
          }
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2189 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          int _7719 = (int)0;
          int _7720 = _2186;
          for (int _2190 = _7719; _2190 < _7720; ++_2190)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2187.get())->task_var_name(((*nativeslack)(_2190)),_2189->__mosek_2fusion_2Utils_2StringBuffer__clear()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,(long long)(_2190)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("].coneslack"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
std::string mosek::fusion::ConicConstraint :: toString() { return mosek::fusion::p_ConicConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2191 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2191->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2191->toString();
}
void mosek::fusion::p_ConicConstraint::domainToString(long long _2192,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2193){
  throw ::mosek::fusion::UnimplementedError(std::string ("ConicConstraint.domainToString"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_ConicConstraint::__mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2194){
  return (::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::ConicConstraint::t(_pubthis),_2194)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_ConicConstraint::destroy(){nativeslack.reset();nativeidxs.reset();shape.reset();dom.reset();}void mosek::fusion::ConicConstraint::destroy() { mosek::fusion::p_ConicConstraint::_get_impl(this)->destroy(); }mosek::fusion::LinearConstraint::LinearConstraint(mosek::fusion::p_LinearConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearConstraint()" << this << std::endl; */ }mosek::fusion::LinearConstraint::~LinearConstraint() {  /* std::cout << "~LinearConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearConstraint::p_LinearConstraint  (::mosek::fusion::LinearConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2195,    monty::rc_ptr< ::mosek::fusion::Model > _2196){ return new mosek::fusion::LinearConstraint(_2195,_2196); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2195,    monty::rc_ptr< ::mosek::fusion::Model > _2196) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2195,_2196); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2195,    monty::rc_ptr< ::mosek::fusion::Model > _2196){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2195,_2196);
    conid = mosek::fusion::p_LinearConstraint::_get_impl(_2195)->conid;
    name = mosek::fusion::p_LinearConstraint::_get_impl(_2195)->name;
  }
}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2197,    const std::string &  _2198,    int _2199,    std::shared_ptr< monty::ndarray< int,1 > > _2200,    std::shared_ptr< monty::ndarray< int,1 > > _2201){ return new mosek::fusion::LinearConstraint(_2197,_2198,_2199,_2200,_2201); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2197,    const std::string &  _2198,    int _2199,    std::shared_ptr< monty::ndarray< int,1 > > _2200,    std::shared_ptr< monty::ndarray< int,1 > > _2201) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2197,_2198,_2199,_2200,_2201); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2197,    const std::string &  _2198,    int _2199,    std::shared_ptr< monty::ndarray< int,1 > > _2200,    std::shared_ptr< monty::ndarray< int,1 > > _2201){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2200(_2200 ? _2200->raw() : nullptr, _2200 ? _2200->size(0) : 0);
    _checked_ptr_1<int> _ptr__2201(_2201 ? _2201->raw() : nullptr, _2201 ? _2201->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2197,_2198,_2200,_2201);
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->conid = _2199;
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->name = _2198;
  }
}std::string mosek::fusion::LinearConstraint :: toString() { return mosek::fusion::p_LinearConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2202 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2202->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2202->toString();
}
void mosek::fusion::p_LinearConstraint::domainToString(long long _2203,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2204){
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearConstraint::__mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2205){
  return (::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::LinearConstraint::t(_pubthis),_2205)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearConstraint::destroy(){}void mosek::fusion::LinearConstraint::destroy() { mosek::fusion::p_LinearConstraint::_get_impl(this)->destroy(); }mosek::fusion::ModelConstraint::ModelConstraint(mosek::fusion::p_ModelConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "ModelConstraint()" << this << std::endl; */ }mosek::fusion::ModelConstraint::~ModelConstraint() {  /* std::cout << "~ModelConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelConstraint::p_ModelConstraint  (::mosek::fusion::ModelConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2206,    monty::rc_ptr< ::mosek::fusion::Model > _2207){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Constraint::_initialize(_2206,_2207);
    name = mosek::fusion::p_ModelConstraint::_get_impl(_2206)->name;
    names_flushed = mosek::fusion::p_ModelConstraint::_get_impl(_2206)->names_flushed;
    nativeidxs = mosek::fusion::p_ModelConstraint::_get_impl(_2206)->nativeidxs;
    shape = mosek::fusion::p_ModelConstraint::_get_impl(_2206)->shape;
  }
}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2208,    const std::string &  _2209,    std::shared_ptr< monty::ndarray< int,1 > > _2210,    std::shared_ptr< monty::ndarray< int,1 > > _2211){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2210(_2210 ? _2210->raw() : nullptr, _2210 ? _2210->size(0) : 0);
    _checked_ptr_1<int> _ptr__2211(_2211 ? _2211->raw() : nullptr, _2211 ? _2211->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2208,_2210,_2211);
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->name = _2209;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->nativeidxs = _2211;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->shape = _2210;
  }
}std::string mosek::fusion::ModelConstraint :: toString() { return mosek::fusion::p_ModelConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ModelConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2212 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2212->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2212->toString();
}
void mosek::fusion::p_ModelConstraint::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _2213 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if ((!names_flushed))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          mosek::fusion::p_Model::_get_impl(_2213.get())->connames(nativeidxs,std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_pubthis->getSize())}),std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2214 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          _2214->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
          if ((_pubthis->getND() > (int)0))
          {
            {
              _2214->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
              int _7721 = (int)1;
              int _7722 = _pubthis->getND();
              for (int _2215 = _7721; _2215 < _7722; ++_2215)
              {
                {
                  _2214->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2215);
                }
              }
            }
          }
          {}
          _2214->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
          std::shared_ptr< monty::ndarray< int,1 > > _7723;
          bool _7724 = (_pubthis->getND() > (int)0);
          if (_7724)
          {
            _7723 = _pubthis->getShape();
          }
          else
          {
            _7723 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
          }
          mosek::fusion::p_Model::_get_impl(_2213.get())->connames(nativeidxs,_2214->toString(),_7723,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
          names_flushed = true;
        }
      }
    }
  }
  {}
}
void mosek::fusion::p_ModelConstraint::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::ModelConstraint::destroy() { mosek::fusion::p_ModelConstraint::_get_impl(this)->destroy(); }mosek::fusion::Constraint::Constraint(mosek::fusion::p_Constraint *_impl) : _impl(_impl) { /*std::cout << "Constraint() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Constraint::~Constraint() { delete _impl; _impl = nullptr; }mosek::fusion::p_Constraint::p_Constraint  (::mosek::fusion::Constraint * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Constraint > _2217,    monty::rc_ptr< ::mosek::fusion::Model > _2218){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _2218;
    shape = mosek::fusion::p_Constraint::_get_impl(_2217)->shape;
    nativeidxs = mosek::fusion::p_Constraint::_get_impl(_2217)->nativeidxs;
  }
}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2219,    std::shared_ptr< monty::ndarray< int,1 > > _2220,    std::shared_ptr< monty::ndarray< int,1 > > _2221){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2220(_2220 ? _2220->raw() : nullptr, _2220 ? _2220->size(0) : 0);
    _checked_ptr_1<int> _ptr__2221(_2221 ? _2221->raw() : nullptr, _2221 ? _2221->size(0) : 0);
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->model = _2219;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->shape = _2220;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->nativeidxs = _2221;
  }
}std::string mosek::fusion::Constraint :: toString() { return mosek::fusion::p_Constraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_Constraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("Constraint.toString"));
}
void mosek::fusion::p_Constraint::toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2222,long long _2223,std::shared_ptr< monty::ndarray< std::string,1 > > _2224){
  _checked_ptr_1<long long> _ptr__2222(_2222 ? _2222->raw() : nullptr, _2222 ? _2222->size(0) : 0);
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: dual() { return mosek::fusion::p_Constraint::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _2225 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2225(_2225 ? _2225->raw() : nullptr,_2225 ? _2225->size(0) : 0);
  values(false,(int)0,_2225);
  return _2225;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: level() { return mosek::fusion::p_Constraint::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _2226 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2226(_2226 ? _2226->raw() : nullptr,_2226 ? _2226->size(0) : 0);
  values(true,(int)0,_2226);
  return _2226;
}
void mosek::fusion::p_Constraint::values(bool _2227,int _2228,std::shared_ptr< monty::ndarray< double,1 > > _2229){
  _checked_ptr_1<double> _ptr__2229(_2229 ? _2229->raw() : nullptr, _2229 ? _2229->size(0) : 0);
  model->getConstraintValues(_2227,nativeidxs,_2229,_2228);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2230) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2230); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2230){
  std::shared_ptr< monty::ndarray< int,1 > > _2231 = _2230->getShape();
  _checked_ptr_1<int> _ptr__2231(_2231 ? _2231->raw() : nullptr,_2231 ? _2231->size(0) : 0);
  if (((int)((shape)->size(0)) < (int)((_2231)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7725 = (int)0;
  int _7726 = (int)((_2231)->size(0));
  for (int _2232 = _7725; _2232 < _7726; ++_2232)
  {
    {
      if ((_ptr__2231[_2232] != ((*shape)(_2232))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7727 = (int)((_2231)->size(0));
  int _7728 = (int)((shape)->size(0));
  for (int _2233 = _7727; _2233 < _7728; ++_2233)
  {
    {
      if ((((*shape)(_2233)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2230);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2234,monty::rc_ptr< ::mosek::fusion::Variable > _2235) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2234,_2235); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2234,monty::rc_ptr< ::mosek::fusion::Variable > _2235){
  int _2236 = _pubthis->getND();
  std::shared_ptr< monty::ndarray< int,1 > > _2237 = _2234->getShape();
  _checked_ptr_1<int> _ptr__2237(_2237 ? _2237->raw() : nullptr,_2237 ? _2237->size(0) : 0);
  if ((_2236 < (int)((_2237)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7729 = (int)0;
  int _7730 = (int)((_2237)->size(0));
  for (int _2238 = _7729; _2238 < _7730; ++_2238)
  {
    {
      if ((_ptr__2237[_2238] != ((*shape)(_2238))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7731 = (int)((_2237)->size(0));
  int _7732 = (int)((shape)->size(0));
  for (int _2239 = _7731; _2239 < _7732; ++_2239)
  {
    {
      if ((((*shape)(_2239)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _2240 = _2235->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _2241 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2240)));
  _checked_ptr_1<long long> _ptr__2241(_2241 ? _2241->raw() : nullptr,_2241 ? _2241->size(0) : 0);
  if ((_2240 < _2235->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2242 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2240)));
      _checked_ptr_1<long long> _ptr__2242(_2242 ? _2242->raw() : nullptr,_2242 ? _2242->size(0) : 0);
      _2235->inst((int)0,_2242,(int)0,_2241);
    }
  }
  else
  {
    {
      _2235->inst((int)0,_2241);
    }
  }
  int _7733 = (int)0;
  int _7734 = _2240;
  for (int _2243 = _7733; _2243 < _7734; ++_2243)
  {
    {
      if ((_ptr__2241[_2243] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2244;
  _checked_ptr_1<int> _ptr__2244(_2244 ? _2244->raw() : nullptr,_2244 ? _2244->size(0) : 0);
  {
    bool _2245 = true;
    int _7735 = (int)0;
    int _7736 = (_2240 - (int)1);
    for (int _2246 = _7735; _2246 < _7736; ++_2246)
    {
      {
        _2245 = (_2245 && (_ptr__2241[_2246] < _ptr__2241[safe_add( _2246,(int)1 )]));
      }
    }
    if (_2245)
    {
      {
        std::vector<int> _7737;
        for (int _2247 = (int)0, _7738 = _2240; _2247 < _7738 ; ++_2247)
        {
          _7737.push_back((int)(_ptr__2241[_2247] - (int)1));
        }
        auto _7739 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7737.size()),_7737.begin(),_7737.end()));
        _2244 = _7739;
        _ptr__2244.update(_2244 ? _2244->raw() : nullptr, _2244 ? _2244->size(0) : 0);
      }
    }
    else
    {
      {
        std::vector<long long> _7740;
        for (int _2249 = (int)0, _7741 = _2240; _2249 < _7741 ; ++_2249)
        {
          _7740.push_back(_2249);
        }
        auto _7742 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7740.size()),_7740.begin(),_7740.end()));
        std::shared_ptr< monty::ndarray< long long,1 > > _2248 = _7742;
        _checked_ptr_1<long long> _ptr__2248(_2248 ? _2248->raw() : nullptr,_2248 ? _2248->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_2248,_2241,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2240));
        int _2250 = (int)1;
        int _7743 = (int)1;
        int _7744 = _2240;
        for (int _2251 = _7743; _2251 < _7744; ++_2251)
        {
          {
            if ((_ptr__2241[_ptr__2248[(_2251 - (int)1)]] < _ptr__2241[_ptr__2248[_2251]]))
            {
              {
                ++ _2250;
              }
            }
            {}
          }
        }
        _2244 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2250)));
        _ptr__2244.update(_2244 ? _2244->raw() : nullptr, _2244 ? _2244->size(0) : 0);
        int _2252 = (int)0;
        _ptr__2244[(int)0] = (int)(_ptr__2241[_ptr__2248[(int)0]] - (int)1);
        int _7745 = (int)1;
        int _7746 = _2240;
        for (int _2253 = _7745; _2253 < _7746; ++_2253)
        {
          {
            if ((_ptr__2241[(_2253 - (int)1)] < _ptr__2241[_2253]))
            {
              {
                _ptr__2244[_2252] = (int)(_ptr__2241[_ptr__2248[_2253]] - (int)1);
                ++ _2252;
              }
            }
            {}
          }
        }
      }
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2234,_2244);
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__get_model() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__get_model(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::get_model() { return __mosek_2fusion_2Constraint__get_model(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__get_model(){
  return model;
}
int mosek::fusion::Constraint :: get_nd() { return mosek::fusion::p_Constraint::_get_impl(this)->get_nd(); }int mosek::fusion::p_Constraint::get_nd(){
  return (int)((shape)->size(0));
}
long long mosek::fusion::Constraint :: size() { return mosek::fusion::p_Constraint::_get_impl(this)->size(); }long long mosek::fusion::p_Constraint::size(){
  long long _2254 = (int)1;
  int _7747 = (int)0;
  int _7748 = (int)((shape)->size(0));
  for (int _2255 = _7747; _2255 < _7748; ++_2255)
  {
    {
      _2254 *= ((*shape)(_2255));
    }
  }
  return _2254;
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2256,    int _2257) { return mosek::fusion::p_Constraint::stack(_2256,_2257); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2256,int _2257){
  return ::mosek::fusion::p_Constraint::dstack(_2256,_2257);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2258,    monty::rc_ptr< ::mosek::fusion::Constraint > _2259,    monty::rc_ptr< ::mosek::fusion::Constraint > _2260,    int _2261) { return mosek::fusion::p_Constraint::stack(_2258,_2259,_2260,_2261); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2258,monty::rc_ptr< ::mosek::fusion::Constraint > _2259,monty::rc_ptr< ::mosek::fusion::Constraint > _2260,int _2261){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2258.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2259.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2260.get())}),_2261);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2262,    monty::rc_ptr< ::mosek::fusion::Constraint > _2263,    int _2264) { return mosek::fusion::p_Constraint::stack(_2262,_2263,_2264); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2262,monty::rc_ptr< ::mosek::fusion::Constraint > _2263,int _2264){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2262.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2263.get())}),_2264);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2265) { return mosek::fusion::p_Constraint::hstack(_2265); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2265){
  return ::mosek::fusion::p_Constraint::dstack(_2265,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2266) { return mosek::fusion::p_Constraint::vstack(_2266); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2266){
  return ::mosek::fusion::p_Constraint::dstack(_2266,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2267,    monty::rc_ptr< ::mosek::fusion::Constraint > _2268,    monty::rc_ptr< ::mosek::fusion::Constraint > _2269) { return mosek::fusion::p_Constraint::hstack(_2267,_2268,_2269); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2267,monty::rc_ptr< ::mosek::fusion::Constraint > _2268,monty::rc_ptr< ::mosek::fusion::Constraint > _2269){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2267.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2268.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2269.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2270,    monty::rc_ptr< ::mosek::fusion::Constraint > _2271,    monty::rc_ptr< ::mosek::fusion::Constraint > _2272) { return mosek::fusion::p_Constraint::vstack(_2270,_2271,_2272); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2270,monty::rc_ptr< ::mosek::fusion::Constraint > _2271,monty::rc_ptr< ::mosek::fusion::Constraint > _2272){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2270.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2271.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2272.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2273,    monty::rc_ptr< ::mosek::fusion::Constraint > _2274) { return mosek::fusion::p_Constraint::hstack(_2273,_2274); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2273,monty::rc_ptr< ::mosek::fusion::Constraint > _2274){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2273.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2274.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2275,    monty::rc_ptr< ::mosek::fusion::Constraint > _2276) { return mosek::fusion::p_Constraint::vstack(_2275,_2276); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2275,monty::rc_ptr< ::mosek::fusion::Constraint > _2276){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2275.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2276.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2277,int _2278){
  monty::rc_ptr< ::mosek::fusion::Model > _2279 = nullptr;
  {
    int _7749 = (int)0;
    int _7750 = (int)((_2277)->size(0));
    for (int _2280 = _7749; _2280 < _7750; ++_2280)
    {
      {
        if ((NULL == _2279.get()))
        {
          {
            _2279 = ((*_2277)(_2280))->__mosek_2fusion_2Constraint__getModel();
          }
        }
        else if(((NULL != mosek::fusion::p_Constraint::_get_impl(((*_2277)(_2280)))->model.get()) && (mosek::fusion::p_Constraint::_get_impl(((*_2277)(_2280)))->model != _2279)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2281 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7751;
            bool _7752 = ((int)((mosek::fusion::p_Model::_get_impl(_2279.get())->getName()).size()) > (int)0);
            if (_7752)
            {
              _7751 = mosek::fusion::p_Model::_get_impl(_2279.get())->getName();
            }
            else
            {
              _7751 = std::string ("?");
            }
            std::string _2282 = _7751;
            std::string _7753;
            bool _7754 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2277)(_2280))->__mosek_2fusion_2Constraint__getModel().get())->getName()).size()) > (int)0);
            if (_7754)
            {
              _7753 = mosek::fusion::p_Model::_get_impl(((*_2277)(_2280))->__mosek_2fusion_2Constraint__getModel().get())->getName();
            }
            else
            {
              _7753 = std::string ("?");
            }
            std::string _2283 = _7753;
            _2281->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraints belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2282)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2283)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2281->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2277)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
    }
  }
  else if(((int)((_2277)->size(0)) == (int)1))
  {
    {
      return ((*_2277)((int)1));
    }
  }
  else
  {
    {
      int _2284 = (int)((_2277)->size(0));
      int _2285 = (int)1;
      int _7755 = (int)0;
      int _7756 = _2284;
      for (int _2286 = _7755; _2286 < _7756; ++_2286)
      {
        {
          int _7757;
          bool _7758 = (((*_2277)(_2286))->getND() > _2285);
          if (_7758)
          {
            _7757 = ((*_2277)(_2286))->getND();
          }
          else
          {
            _7757 = _2285;
          }
          _2285 = _7757;
        }
      }
      if ((_2278 == _2285))
      {
        {
          ++ _2285;
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,2 > > _2287 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape(_2284,_2285)));
      int _7759 = (int)0;
      int _7760 = _2284;
      for (int _2288 = _7759; _2288 < _7760; ++_2288)
      {
        {
          int _7761 = (int)0;
          int _7762 = _2285;
          for (int _2289 = _7761; _2289 < _7762; ++_2289)
          {
            {
              ((*_2287)(_2288,_2289)) = (int)1;
            }
          }
        }
      }
      std::vector<int> _7763;
      for (int _2291 = (int)0, _7764 = _2284; _2291 < _7764 ; ++_2291)
      {
        _7763.push_back(((*_2277)(_2291))->getSize());
      }
      auto _7765 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7763.size()),_7763.begin(),_7763.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2290 = _7765;
      _checked_ptr_1<int> _ptr__2290(_2290 ? _2290->raw() : nullptr,_2290 ? _2290->size(0) : 0);
      int _2292 = (int)0;
      int _7766 = (int)0;
      int _7767 = _2284;
      for (int _2293 = _7766; _2293 < _7767; ++_2293)
      {
        {
          _2292 += _ptr__2290[_2293];
        }
      }
      int _7768 = (int)0;
      int _7769 = _2284;
      for (int _2294 = _7768; _2294 < _7769; ++_2294)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2295 = ((*_2277)(_2294))->getShape();
          _checked_ptr_1<int> _ptr__2295(_2295 ? _2295->raw() : nullptr,_2295 ? _2295->size(0) : 0);
          int _7770 = (int)0;
          int _7771 = (int)((_2295)->size(0));
          for (int _2296 = _7770; _2296 < _7771; ++_2296)
          {
            {
              ((*_2287)(_2294,_2296)) = _ptr__2295[_2296];
            }
          }
        }
      }
      if (((_2278 < (int)0) || (_2278 > _2285)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      int _7772 = (int)0;
      int _7773 = _2278;
      for (int _2297 = _7772; _2297 < _7773; ++_2297)
      {
        {
          int _7774 = (int)1;
          int _7775 = _2284;
          for (int _2298 = _7774; _2298 < _7775; ++_2298)
          {
            {
              if ((((*_2287)((int)0,_2297)) != ((*_2287)(_2298,_2297))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      int _7776 = safe_add( _2278,(int)1 );
      int _7777 = _2285;
      for (int _2299 = _7776; _2299 < _7777; ++_2299)
      {
        {
          int _7778 = (int)1;
          int _7779 = _2284;
          for (int _2300 = _7778; _2300 < _7779; ++_2300)
          {
            {
              if ((((*_2287)((int)0,_2299)) != ((*_2287)(_2300,_2299))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2301 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2292)));
      _checked_ptr_1<int> _ptr__2301(_2301 ? _2301->raw() : nullptr,_2301 ? _2301->size(0) : 0);
      std::vector<int> _7780;
      for (int _2303 = (int)0, _7781 = _2285; _2303 < _7781 ; ++_2303)
      {
        _7780.push_back(((*_2287)((int)0,_2303)));
      }
      auto _7782 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7780.size()),_7780.begin(),_7780.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2302 = _7782;
      _checked_ptr_1<int> _ptr__2302(_2302 ? _2302->raw() : nullptr,_2302 ? _2302->size(0) : 0);
      int _7783 = (int)0;
      int _7784 = _2285;
      for (int _2304 = _7783; _2304 < _7784; ++_2304)
      {
        {
          _ptr__2302[_2278] += ((*_2287)(_2304,_2278));
        }
      }
      {
        int _2305 = (int)((_2302)->size(0));
        std::shared_ptr< monty::ndarray< long long,1 > > _2306 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( (int)((_2277)->size(0)),(int)1 ))));
        _checked_ptr_1<long long> _ptr__2306(_2306 ? _2306->raw() : nullptr,_2306 ? _2306->size(0) : 0);
        int _7785 = (int)0;
        int _7786 = (int)((_2277)->size(0));
        for (int _2307 = _7785; _2307 < _7786; ++_2307)
        {
          {
            _ptr__2306[safe_add( _2307,(int)1 )] = safe_add( _ptr__2306[_2307],((*_2287)(_2307,_2278)) );
          }
        }
        if ((_2278 == (int)0))
        {
          {
            int _2308 = (int)0;
            int _7787 = (int)0;
            int _7788 = _2284;
            for (int _2309 = _7787; _2309 < _7788; ++_2309)
            {
              {
                int _2310 = (int)((mosek::fusion::p_Constraint::_get_impl(((*_2277)(_2309)))->nativeidxs)->size(0));
                ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Constraint::_get_impl(((*_2277)(_2309)))->nativeidxs,(int)0,_2301,_2308,_2310);
                _2308 += _2310;
              }
            }
          }
        }
        else
        {
          {
            std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7789;
            for (int _2312 = (int)0, _7790 = _2284; _2312 < _7790 ; ++_2312)
            {
              _7789.push_back(mosek::fusion::p_Constraint::_get_impl(((*_2277)(_2312)))->nativeidxs);
            }
            auto _7791 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7789.size()),_7789.begin(),_7789.end()));
            std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2311 = _7791;
            if ((_2278 < _2285))
            {
              {
                int _2313 = (int)1;
                int _7792 = (int)0;
                int _7793 = _2278;
                for (int _2314 = _7792; _2314 < _7793; ++_2314)
                {
                  {
                    _2313 *= _ptr__2302[_2314];
                  }
                }
                int _2315 = (int)1;
                int _7794 = safe_add( _2278,(int)1 );
                int _7795 = _2285;
                for (int _2316 = _7794; _2316 < _7795; ++_2316)
                {
                  {
                    _2315 *= _ptr__2302[_2316];
                  }
                }
                int _2317 = (int)0;
                int _7796 = (int)0;
                int _7797 = _2313;
                for (int _2318 = _7796; _2318 < _7797; ++_2318)
                {
                  {
                    int _7798 = (int)0;
                    int _7799 = _2284;
                    for (int _2319 = _7798; _2319 < _7799; ++_2319)
                    {
                      {
                        int _2320 = (int)0;
                        int _2321 = ((*_2287)(_2319,_2278));
                        int _7800 = (int)0;
                        int _7801 = _2321;
                        for (int _2322 = _7800; _2322 < _7801; ++_2322)
                        {
                          {
                            int _7802 = (int)0;
                            int _7803 = _2315;
                            for (int _2323 = _7802; _2323 < _7803; ++_2323)
                            {
                              {
                                _ptr__2301[_2317] = ((*mosek::fusion::p_Constraint::_get_impl(((*_2277)(_2284)))->nativeidxs)(safe_add( safe_mul( safe_mul( _2318,_2315 ),_2321 ),_2320 )));
                                ++ _2317;
                                ++ _2320;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            else
            {
              {
                int _2324 = (int)1;
                int _7804 = (int)0;
                int _7805 = _2285;
                for (int _2325 = _7804; _2325 < _7805; ++_2325)
                {
                  {
                    _2324 *= _ptr__2302[_2325];
                  }
                }
                int _2326 = (int)0;
                int _7806 = (int)0;
                int _7807 = _2324;
                for (int _2327 = _7806; _2327 < _7807; ++_2327)
                {
                  {
                    int _7808 = (int)0;
                    int _7809 = _2284;
                    for (int _2328 = _7808; _2328 < _7809; ++_2328)
                    {
                      {
                        _ptr__2301[_2326] = ((*((*_2311)(_2328)))(_2327));
                        ++ _2326;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_2279,_2302,_2301)).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2329) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2329); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(std::shared_ptr< monty::ndarray< int,1 > > _2329) { return __mosek_2fusion_2Constraint__index(_2329); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2329){
  _checked_ptr_1<int> _ptr__2329(_2329 ? _2329->raw() : nullptr, _2329 ? _2329->size(0) : 0);
  if (((int)((_2329)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7810 = (int)0;
      int _7811 = (int)((shape)->size(0));
      for (int _2330 = _7810; _2330 < _7811; ++_2330)
      {
        {
          if (((_ptr__2329[_2330] < (int)0) || (_ptr__2329[_2330] > ((*shape)(_2330)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("index is out of bounds"));
            }
          }
          {}
        }
      }
      int _2331 = (int)((shape)->size(0));
      std::shared_ptr< monty::ndarray< long long,1 > > _2332 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2331)));
      _checked_ptr_1<long long> _ptr__2332(_2332 ? _2332->raw() : nullptr,_2332 ? _2332->size(0) : 0);
      _ptr__2332[(_2331 - (int)1)] = (int)1;
      int _7812 = (int)1;
      int _7813 = _2331;
      for (int _2333 = _7812; _2333 < _7813; ++_2333)
      {
        {
          _ptr__2332[((_2331 - _2333) - (int)1)] = safe_mul( _ptr__2332[(_2331 - _2333)],((*shape)(_2333)) );
        }
      }
      int _2334 = (int)0;
      int _7814 = (int)0;
      int _7815 = _2331;
      for (int _2335 = _7814; _2335 < _7815; ++_2335)
      {
        {
          _2334 += (int)safe_mul( _ptr__2332[_2335],_ptr__2329[_2335] );
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2334)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(int _2336) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2336); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(int _2336) { return __mosek_2fusion_2Constraint__index(_2336); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(int _2336){
  if ((((int)((shape)->size(0)) == (int)0) && (_2336 == (int)0)))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else if(((_2336 < (int)0) || (_2336 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index is out of bounds"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2336)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2337,std::shared_ptr< monty::ndarray< int,1 > > _2338) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2337,_2338); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(std::shared_ptr< monty::ndarray< int,1 > > _2337,std::shared_ptr< monty::ndarray< int,1 > > _2338) { return __mosek_2fusion_2Constraint__slice(_2337,_2338); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2337,std::shared_ptr< monty::ndarray< int,1 > > _2338){
  _checked_ptr_1<int> _ptr__2337(_2337 ? _2337->raw() : nullptr, _2337 ? _2337->size(0) : 0);
  _checked_ptr_1<int> _ptr__2338(_2338 ? _2338->raw() : nullptr, _2338 ? _2338->size(0) : 0);
  if (((int)((_2337)->size(0)) != (int)((_2338)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
    }
  }
  else if(((int)((_2337)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7816 = (int)0;
      int _7817 = (int)((shape)->size(0));
      for (int _2339 = _7816; _2339 < _7817; ++_2339)
      {
        {
          if (((_ptr__2337[_2339] < (int)0) || (_ptr__2338[_2339] > ((*shape)(_2339)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("slice is out of bounds"));
            }
          }
          else if((_ptr__2337[_2339] > _ptr__2338[_2339]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
            }
          }
          {}
        }
      }
      int _2340 = (int)((shape)->size(0));
      std::vector<int> _7818;
      for (int _2342 = (int)0, _7819 = _2340; _2342 < _7819 ; ++_2342)
      {
        _7818.push_back((_ptr__2338[_2342] - _ptr__2337[_2342]));
      }
      auto _7820 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7818.size()),_7818.begin(),_7818.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2341 = _7820;
      _checked_ptr_1<int> _ptr__2341(_2341 ? _2341->raw() : nullptr,_2341 ? _2341->size(0) : 0);
      int _2343 = (int)1;
      int _7821 = (int)0;
      int _7822 = _2340;
      for (int _2344 = _7821; _2344 < _7822; ++_2344)
      {
        {
          _2343 *= (_ptr__2338[_2344] - _ptr__2337[_2344]);
        }
      }
      if ((_2343 == (int)0))
      {
        {
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,_2341,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2345 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2343)));
          _checked_ptr_1<int> _ptr__2345(_2345 ? _2345->raw() : nullptr,_2345 ? _2345->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _2346 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2340)));
            _checked_ptr_1<int> _ptr__2346(_2346 ? _2346->raw() : nullptr,_2346 ? _2346->size(0) : 0);
            _ptr__2346[(_2340 - (int)1)] = (int)1;
            int _7823 = (int)1;
            int _7824 = _2340;
            for (int _2347 = _7823; _2347 < _7824; ++_2347)
            {
              {
                _ptr__2346[((_2340 - _2347) - (int)1)] = safe_mul( _ptr__2346[(_2340 - _2347)],((*shape)((_2340 - _2347))) );
              }
            }
            int _2348 = (int)0;
            int _7825 = (int)0;
            int _7826 = _2340;
            for (int _2349 = _7825; _2349 < _7826; ++_2349)
            {
              {
                _2348 += safe_mul( _ptr__2337[_2349],_ptr__2346[_2349] );
              }
            }
            std::vector<int> _7827;
            for (int _2351 = (int)0, _7828 = _2340; _2351 < _7828 ; ++_2351)
            {
              _7827.push_back(_2348);
            }
            auto _7829 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7827.size()),_7827.begin(),_7827.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2350 = _7829;
            _checked_ptr_1<int> _ptr__2350(_2350 ? _2350->raw() : nullptr,_2350 ? _2350->size(0) : 0);
            std::vector<int> _7830;
            for (int _2353 = (int)0, _7831 = _2340; _2353 < _7831 ; ++_2353)
            {
              _7830.push_back(_ptr__2337[_2353]);
            }
            auto _7832 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7830.size()),_7830.begin(),_7830.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2352 = _7832;
            _checked_ptr_1<int> _ptr__2352(_2352 ? _2352->raw() : nullptr,_2352 ? _2352->size(0) : 0);
            int _7833 = (int)0;
            int _7834 = _2343;
            for (int _2354 = _7833; _2354 < _7834; ++_2354)
            {
              {
                _ptr__2345[_2354] = ((*nativeidxs)(_ptr__2350[(_2340 - (int)1)]));
                _ptr__2352[(_2340 - (int)1)] += (int)1;
                _ptr__2350[(_2340 - (int)1)] += _ptr__2346[(_2340 - (int)1)];
                if ((_ptr__2352[(_2340 - (int)1)] >= _ptr__2338[(_2340 - (int)1)]))
                {
                  {
                    int _2355 = (_2340 - (int)1);
                    while ( ((_2355 > (int)0) && (_ptr__2352[_2355] >= _ptr__2338[_2355])) )
                    {
                      {
                        _ptr__2352[_2355] = _ptr__2337[_2355];
                        _ptr__2352[(_2355 - (int)1)] += (int)1;
                        _ptr__2350[(_2355 - (int)1)] += _ptr__2346[(_2355 - (int)1)];
                        -- _2355;
                      }
                    }
                    int _7835 = safe_add( _2355,(int)1 );
                    int _7836 = _2340;
                    for (int _2356 = _7835; _2356 < _7836; ++_2356)
                    {
                      {
                        _ptr__2350[_2356] = _ptr__2350[_2355];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_pubthis->__mosek_2fusion_2Constraint__getModel(),_2341,_2345)).as<::mosek::fusion::Constraint>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(int _2357,int _2358) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2357,_2358); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(int _2357,int _2358) { return __mosek_2fusion_2Constraint__slice(_2357,_2358); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(int _2357,int _2358){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_2357 == (int)0) && (_2358 == ((*shape)((int)0)))))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((_2357 < (int)0) || (_2358 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_2357 > _2358))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else
  {
    {
      std::vector<int> _7837;
      for (int _2359 = _2357, _7838 = _2358; _2359 < _7838 ; ++_2359)
      {
        _7837.push_back(((*nativeidxs)(_2359)));
      }
      auto _7839 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7837.size()),_7837.begin(),_7837.end()));
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_2358 - _2357))}),_7839)).as<::mosek::fusion::Constraint>();
    }
  }
}
int mosek::fusion::Constraint :: getND() { return mosek::fusion::p_Constraint::_get_impl(this)->getND(); }int mosek::fusion::p_Constraint::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::Constraint :: getSize() { return mosek::fusion::p_Constraint::_get_impl(this)->getSize(); }int mosek::fusion::p_Constraint::getSize(){
  int _2360 = (int)1;
  int _7840 = (int)0;
  int _7841 = (int)((shape)->size(0));
  for (int _2361 = _7840; _2361 < _7841; ++_2361)
  {
    {
      _2360 *= ((*shape)(_2361));
    }
  }
  return _2360;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__getModel() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::getModel() { return __mosek_2fusion_2Constraint__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__getModel(){
  return model;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Constraint :: getShape() { return mosek::fusion::p_Constraint::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Constraint::getShape(){
  std::vector<int> _7842;
  for (int _2362 = (int)0, _7843 = (int)((shape)->size(0)); _2362 < _7843 ; ++_2362)
  {
    _7842.push_back(((*shape)(_2362)));
  }
  auto _7844 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7842.size()),_7842.begin(),_7842.end()));
  return _7844;
}
void mosek::fusion::p_Constraint::destroy(){nativeidxs.reset();shape.reset();model.reset();}void mosek::fusion::Constraint::destroy() { mosek::fusion::p_Constraint::_get_impl(this)->destroy(); }mosek::fusion::Set::Set(mosek::fusion::p_Set *_impl) : _impl(_impl) { /*std::cout << "Set() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Set::~Set() { delete _impl; _impl = nullptr; }mosek::fusion::p_Set::p_Set  (::mosek::fusion::Set * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::Set::size  ( std::shared_ptr< monty::ndarray< int,1 > > _2363) { return mosek::fusion::p_Set::size(_2363); }long long mosek::fusion::p_Set::size(std::shared_ptr< monty::ndarray< int,1 > > _2363){
  _checked_ptr_1<int> _ptr__2363(_2363 ? _2363->raw() : nullptr, _2363 ? _2363->size(0) : 0);
  long long _2364 = (long long)1;
  int _7845 = (int)0;
  int _7846 = (int)((_2363)->size(0));
  for (int _2365 = _7845; _2365 < _7846; ++_2365)
  {
    {
      _2364 *= _ptr__2363[_2365];
    }
  }
  return _2364;
}
bool mosek::fusion::Set::match  ( std::shared_ptr< monty::ndarray< int,1 > > _2366,    std::shared_ptr< monty::ndarray< int,1 > > _2367) { return mosek::fusion::p_Set::match(_2366,_2367); }bool mosek::fusion::p_Set::match(std::shared_ptr< monty::ndarray< int,1 > > _2366,std::shared_ptr< monty::ndarray< int,1 > > _2367){
  _checked_ptr_1<int> _ptr__2366(_2366 ? _2366->raw() : nullptr, _2366 ? _2366->size(0) : 0);
  _checked_ptr_1<int> _ptr__2367(_2367 ? _2367->raw() : nullptr, _2367 ? _2367->size(0) : 0);
  if (((int)((_2366)->size(0)) != (int)((_2367)->size(0))))
  {
    {
      return false;
    }
  }
  {}
  int _7847 = (int)0;
  int _7848 = (int)((_2366)->size(0));
  for (int _2368 = _7847; _2368 < _7848; ++_2368)
  {
    {
      if ((_ptr__2366[_2368] != _ptr__2367[_2368]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
long long mosek::fusion::Set::linearidx  ( std::shared_ptr< monty::ndarray< int,1 > > _2369,    std::shared_ptr< monty::ndarray< int,1 > > _2370) { return mosek::fusion::p_Set::linearidx(_2369,_2370); }long long mosek::fusion::p_Set::linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2369,std::shared_ptr< monty::ndarray< int,1 > > _2370){
  _checked_ptr_1<int> _ptr__2369(_2369 ? _2369->raw() : nullptr, _2369 ? _2369->size(0) : 0);
  _checked_ptr_1<int> _ptr__2370(_2370 ? _2370->raw() : nullptr, _2370 ? _2370->size(0) : 0);
  long long _2371 = _ptr__2370[(int)0];
  int _7849 = (int)1;
  int _7850 = (int)((_2370)->size(0));
  for (int _2372 = _7849; _2372 < _7850; ++_2372)
  {
    {
      _2371 = safe_add( safe_mul( _2371,_ptr__2369[_2372] ),_ptr__2370[_2372] );
    }
  }
  return _2371;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2373,    long long _2374) { return mosek::fusion::p_Set::idxtokey(_2373,_2374); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2373,long long _2374){
  _checked_ptr_1<int> _ptr__2373(_2373 ? _2373->raw() : nullptr, _2373 ? _2373->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2375 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_2373)->size(0)))));
  _checked_ptr_1<int> _ptr__2375(_2375 ? _2375->raw() : nullptr,_2375 ? _2375->size(0) : 0);
  ::mosek::fusion::p_Set::idxtokey(_2373,_2374,_2375);
  return _2375;
}
void mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2376,    long long _2377,    std::shared_ptr< monty::ndarray< int,1 > > _2378) { mosek::fusion::p_Set::idxtokey(_2376,_2377,_2378); }void mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2376,long long _2377,std::shared_ptr< monty::ndarray< int,1 > > _2378){
  _checked_ptr_1<int> _ptr__2376(_2376 ? _2376->raw() : nullptr, _2376 ? _2376->size(0) : 0);
  _checked_ptr_1<int> _ptr__2378(_2378 ? _2378->raw() : nullptr, _2378 ? _2378->size(0) : 0);
  int _2379 = (int)((_2376)->size(0));
  if ((_2379 > (int)0))
  {
    {
      long long _2380 = _2377;
      int _7851 = (int)0;
      int _7852 = (_2379 - (int)1);
      for (int _2381 = _7851; _2381 < _7852; ++_2381)
      {
        {
          _ptr__2378[((_2379 - _2381) - (int)1)] = (int)(_2380 % _ptr__2376[((_2379 - _2381) - (int)1)]);
          _2380 /= _ptr__2376[((_2379 - _2381) - (int)1)];
        }
      }
      _ptr__2378[(int)0] = (int)_2380;
    }
  }
  {}
}
std::string mosek::fusion::Set::indexToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2382,    long long _2383) { return mosek::fusion::p_Set::indexToString(_2382,_2383); }std::string mosek::fusion::p_Set::indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2382,long long _2383){
  _checked_ptr_1<int> _ptr__2382(_2382 ? _2382->raw() : nullptr, _2382 ? _2382->size(0) : 0);
  int _2384 = (int)((_2382)->size(0));
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2385 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  if ((_2384 == (int)0))
  {
    {
      return std::string ("0");
    }
  }
  else if((_2384 == (int)1))
  {
    {
      return _2385->__mosek_2fusion_2Utils_2StringBuffer__a(_2383)->toString();
    }
  }
  else
  {
    {
      long long _2386 = _2383;
      std::shared_ptr< monty::ndarray< int,1 > > _2387 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2384)));
      _checked_ptr_1<int> _ptr__2387(_2387 ? _2387->raw() : nullptr,_2387 ? _2387->size(0) : 0);
      int _7853 = (int)1;
      int _7854 = _2384;
      for (int _2388 = _7853; _2388 < _7854; ++_2388)
      {
        {
          _ptr__2387[(_2384 - _2388)] = (int)(_2386 % _ptr__2382[(_2384 - _2388)]);
          _2386 /= _ptr__2382[(_2384 - _2388)];
        }
      }
      _ptr__2387[(int)0] = (int)_2386;
      _2385->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2387[(int)0]);
      int _7855 = (int)1;
      int _7856 = _2384;
      for (int _2389 = _7855; _2389 < _7856; ++_2389)
      {
        {
          _2385->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2387[_2389]);
        }
      }
      return _2385->toString();
    }
  }
}
std::string mosek::fusion::Set::keyToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2390) { return mosek::fusion::p_Set::keyToString(_2390); }std::string mosek::fusion::p_Set::keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2390){
  _checked_ptr_1<int> _ptr__2390(_2390 ? _2390->raw() : nullptr, _2390 ? _2390->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2391 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2391->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2390[(int)0]);
  int _7857 = (int)1;
  int _7858 = (int)((_2390)->size(0));
  for (int _2392 = _7857; _2392 < _7858; ++_2392)
  {
    {
      _2391->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2390[_2392]);
    }
  }
  return _2391->toString();
}
void mosek::fusion::Set::indexToKey  ( std::shared_ptr< monty::ndarray< int,1 > > _2393,    long long _2394,    std::shared_ptr< monty::ndarray< int,1 > > _2395) { mosek::fusion::p_Set::indexToKey(_2393,_2394,_2395); }void mosek::fusion::p_Set::indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2393,long long _2394,std::shared_ptr< monty::ndarray< int,1 > > _2395){
  _checked_ptr_1<int> _ptr__2393(_2393 ? _2393->raw() : nullptr, _2393 ? _2393->size(0) : 0);
  _checked_ptr_1<int> _ptr__2395(_2395 ? _2395->raw() : nullptr, _2395 ? _2395->size(0) : 0);
  int _2396 = (int)((_2393)->size(0));
  if ((_2396 == (int)1))
  {
    {
      _ptr__2395[(int)0] = (int)_2394;
    }
  }
  else
  {
    {
      long long _2397 = _2394;
      int _7859 = (int)1;
      int _7860 = _2396;
      for (int _2398 = _7859; _2398 < _7860; ++_2398)
      {
        {
          _ptr__2395[(_2396 - _2398)] = (int)(_2397 % _ptr__2393[(_2396 - _2398)]);
          _2397 /= _ptr__2393[(_2396 - _2398)];
        }
      }
      _ptr__2395[(int)0] = (int)_2397;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::Set::strides  ( std::shared_ptr< monty::ndarray< int,1 > > _2399) { return mosek::fusion::p_Set::strides(_2399); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_Set::strides(std::shared_ptr< monty::ndarray< int,1 > > _2399){
  _checked_ptr_1<int> _ptr__2399(_2399 ? _2399->raw() : nullptr, _2399 ? _2399->size(0) : 0);
  int _2400 = (int)((_2399)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _2401 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2400)));
  _checked_ptr_1<long long> _ptr__2401(_2401 ? _2401->raw() : nullptr,_2401 ? _2401->size(0) : 0);
  _ptr__2401[(_2400 - (int)1)] = (int)1;
  int _7861 = (int)1;
  int _7862 = _2400;
  for (int _2402 = _7861; _2402 < _7862; ++_2402)
  {
    {
      _ptr__2401[((_2400 - _2402) - (int)1)] = safe_mul( _ptr__2401[(_2400 - _2402)],_ptr__2399[(_2400 - _2402)] );
    }
  }
  return _2401;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2403,    std::shared_ptr< monty::ndarray< int,1 > > _2404) { return mosek::fusion::p_Set::make(_2403,_2404); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2403,std::shared_ptr< monty::ndarray< int,1 > > _2404){
  _checked_ptr_1<int> _ptr__2403(_2403 ? _2403->raw() : nullptr, _2403 ? _2403->size(0) : 0);
  _checked_ptr_1<int> _ptr__2404(_2404 ? _2404->raw() : nullptr, _2404 ? _2404->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2405 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( (int)((_2403)->size(0)),(int)((_2404)->size(0)) ))));
  _checked_ptr_1<int> _ptr__2405(_2405 ? _2405->raw() : nullptr,_2405 ? _2405->size(0) : 0);
  int _7863 = (int)0;
  int _7864 = (int)((_2403)->size(0));
  for (int _2406 = _7863; _2406 < _7864; ++_2406)
  {
    {
      _ptr__2405[_2406] = _ptr__2403[_2406];
    }
  }
  int _7865 = (int)0;
  int _7866 = (int)((_2404)->size(0));
  for (int _2407 = _7865; _2407 < _7866; ++_2407)
  {
    {
      _ptr__2405[safe_add( (int)((_2403)->size(0)),_2407 )] = _ptr__2404[_2407];
    }
  }
  return _2405;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2408) { return mosek::fusion::p_Set::make(_2408); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2408){
  _checked_ptr_1<int> _ptr__2408(_2408 ? _2408->raw() : nullptr, _2408 ? _2408->size(0) : 0);
  std::vector<int> _7867;
  for (int _2409 = (int)0, _7868 = (int)((_2408)->size(0)); _2409 < _7868 ; ++_2409)
  {
    _7867.push_back(_ptr__2408[_2409]);
  }
  auto _7869 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7867.size()),_7867.begin(),_7867.end()));
  return _7869;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2410,    int _2411,    int _2412) { return mosek::fusion::p_Set::make(_2410,_2411,_2412); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2410,int _2411,int _2412){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2410),(int)(_2411),(int)(_2412)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2413,    int _2414) { return mosek::fusion::p_Set::make(_2413,_2414); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2413,int _2414){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2413),(int)(_2414)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2415) { return mosek::fusion::p_Set::make(_2415); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2415){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2415)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::scalar  ( ) { return mosek::fusion::p_Set::scalar(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::scalar(){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< std::string,1 > > _2416) { return mosek::fusion::p_Set::make(_2416); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< std::string,1 > > _2416){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2416)->size(0)))});
}
void mosek::fusion::p_Set::destroy(){}void mosek::fusion::Set::destroy() { mosek::fusion::p_Set::_get_impl(this)->destroy(); }mosek::fusion::ConeDomain::ConeDomain(mosek::fusion::p_ConeDomain *_impl) : _impl(_impl) { /*std::cout << "ConeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConeDomain::~ConeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConeDomain::p_ConeDomain  (::mosek::fusion::ConeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2417,    double _2418,    std::shared_ptr< monty::ndarray< int,1 > > _2419){ return new mosek::fusion::ConeDomain(_2417,_2418,_2419); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2417,    double _2418,    std::shared_ptr< monty::ndarray< int,1 > > _2419) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2417,_2418,_2419); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2417,    double _2418,    std::shared_ptr< monty::ndarray< int,1 > > _2419){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2419(_2419 ? _2419->raw() : nullptr, _2419 ? _2419->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _7870;
    bool _7871 = (NULL != _2419.get());
    if (_7871)
    {
      _7870 = ::mosek::fusion::p_Set::make(_2419);
    }
    else
    {
      _7870 = nullptr;
    }
    shape = _7870;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2418;
    key = _2417;
    axisidx = (int)0;
    axisset = false;
    int_flag = false;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2418;
  }
}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2420,    std::shared_ptr< monty::ndarray< int,1 > > _2421){ return new mosek::fusion::ConeDomain(_2420,_2421); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2420,    std::shared_ptr< monty::ndarray< int,1 > > _2421) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2420,_2421); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2420,    std::shared_ptr< monty::ndarray< int,1 > > _2421){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2421(_2421 ? _2421->raw() : nullptr, _2421 ? _2421->size(0) : 0);
    mosek::fusion::p_ConeDomain::_initialize(_2420,1.0,_2421);
  }
}bool mosek::fusion::p_ConeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2422){
  _checked_ptr_1<int> _ptr__2422(_2422 ? _2422->raw() : nullptr, _2422 ? _2422->size(0) : 0);
  return ((NULL == shape.get()) || ::mosek::fusion::p_Set::match(_2422,shape));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__integral() { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::integral() { return __mosek_2fusion_2ConeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__integral(){
  int_flag = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
bool mosek::fusion::ConeDomain :: axisIsSet() { return mosek::fusion::p_ConeDomain::_get_impl(this)->axisIsSet(); }bool mosek::fusion::p_ConeDomain::axisIsSet(){
  return axisset;
}
int mosek::fusion::ConeDomain :: getAxis() { return mosek::fusion::p_ConeDomain::_get_impl(this)->getAxis(); }int mosek::fusion::p_ConeDomain::getAxis(){
  return axisidx;
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__axis(int _2423) { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__axis(_2423); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::axis(int _2423) { return __mosek_2fusion_2ConeDomain__axis(_2423); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__axis(int _2423){
  axisidx = _2423;
  axisset = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
void mosek::fusion::p_ConeDomain::destroy(){shape.reset();}void mosek::fusion::ConeDomain::destroy() { mosek::fusion::p_ConeDomain::_get_impl(this)->destroy(); }mosek::fusion::LinPSDDomain::LinPSDDomain(mosek::fusion::p_LinPSDDomain *_impl) : _impl(_impl) { /*std::cout << "LinPSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinPSDDomain::~LinPSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinPSDDomain::p_LinPSDDomain  (::mosek::fusion::LinPSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2424,    int _2425){ return new mosek::fusion::LinPSDDomain(_2424,_2425); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2424,    int _2425) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2424,_2425); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2424,    int _2425){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2424(_2424 ? _2424->raw() : nullptr, _2424 ? _2424->size(0) : 0);
    mosek::fusion::p_LinPSDDomain::_get_impl(::mosek::fusion::LinPSDDomain::t(_pubthis))->conedim = _2425;
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2424);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2426){ return new mosek::fusion::LinPSDDomain(_2426); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2426) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2426); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2426){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2426(_2426 ? _2426->raw() : nullptr, _2426 ? _2426->size(0) : 0);
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2426);
    conedim = ((int)((shape)->size(0)) - (int)1);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (){ return new mosek::fusion::LinPSDDomain(); }mosek::fusion::LinPSDDomain::LinPSDDomain  () :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinPSDDomain::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    conedim = (int)0;
    shape = nullptr;
  }
}void mosek::fusion::p_LinPSDDomain::destroy(){shape.reset();}void mosek::fusion::LinPSDDomain::destroy() { mosek::fusion::p_LinPSDDomain::_get_impl(this)->destroy(); }mosek::fusion::PSDDomain::PSDDomain(mosek::fusion::p_PSDDomain *_impl) : _impl(_impl) { /*std::cout << "PSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::PSDDomain::~PSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_PSDDomain::p_PSDDomain  (::mosek::fusion::PSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2427,    std::shared_ptr< monty::ndarray< int,1 > > _2428,    int _2429,    int _2430){ return new mosek::fusion::PSDDomain(_2427,_2428,_2429,_2430); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2427,    std::shared_ptr< monty::ndarray< int,1 > > _2428,    int _2429,    int _2430) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2427,_2428,_2429,_2430); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2427,    std::shared_ptr< monty::ndarray< int,1 > > _2428,    int _2429,    int _2430){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2428(_2428 ? _2428->raw() : nullptr, _2428 ? _2428->size(0) : 0);
    axisIsSet = true;
    shape = _2428;
    key = _2427;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2429;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2430;
    int _2431 = (int)((shape)->size(0));
    if (((!(((int)((shape)->size(0)) > _2429) && (((int)((shape)->size(0)) > _2430) && ((_2429 >= (int)0) && ((_2430 >= (int)0) && (_2429 != _2430)))))) && (((*shape)(_2429)) == ((*shape)(_2430)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
      }
    }
    {}
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2432,    std::shared_ptr< monty::ndarray< int,1 > > _2433){ return new mosek::fusion::PSDDomain(_2432,_2433); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2432,    std::shared_ptr< monty::ndarray< int,1 > > _2433) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2432,_2433); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2432,    std::shared_ptr< monty::ndarray< int,1 > > _2433){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2433(_2433 ? _2433->raw() : nullptr, _2433 ? _2433->size(0) : 0);
    mosek::fusion::p_PSDDomain::_initialize(_2432,_2433,((int)((_2433)->size(0)) - (int)2),((int)((_2433)->size(0)) - (int)1));
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2434){ return new mosek::fusion::PSDDomain(_2434); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2434) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2434); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2434){monty::rc_reserve __reserve_this(_pubthis);   {
    shape = nullptr;
    key = _2434;
    conedim1 = (int)0;
    conedim2 = (int)0;
    axisIsSet = false;
  }
}monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain :: __mosek_2fusion_2PSDDomain__axis(int _2435,int _2436) { return mosek::fusion::p_PSDDomain::_get_impl(this)->__mosek_2fusion_2PSDDomain__axis(_2435,_2436); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain::axis(int _2435,int _2436) { return __mosek_2fusion_2PSDDomain__axis(_2435,_2436); }
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_PSDDomain::__mosek_2fusion_2PSDDomain__axis(int _2435,int _2436){
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2435;
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2436;
  axisIsSet = true;
  if (((NULL == shape.get()) && (!((_2435 >= (int)0) && ((_2436 >= (int)0) && (_2435 != _2436))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  else if(((NULL != shape.get()) && ((!(((int)((shape)->size(0)) > _2435) && (((int)((shape)->size(0)) > _2436) && ((_2435 >= (int)0) && ((_2436 >= (int)0) && (_2435 != _2436)))))) && (((*shape)(_2435)) == ((*shape)(_2436))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  {}
  return ::mosek::fusion::PSDDomain::t(_pubthis);
}
void mosek::fusion::p_PSDDomain::destroy(){shape.reset();}void mosek::fusion::PSDDomain::destroy() { mosek::fusion::p_PSDDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain(mosek::fusion::p_SymmetricRangeDomain *_impl) : mosek::fusion::RangeDomain(_impl) { /*std::cout << "SymmetricRangeDomain()" << this << std::endl; */ }mosek::fusion::SymmetricRangeDomain::~SymmetricRangeDomain() {  /* std::cout << "~SymmetricRangeDomain()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymmetricRangeDomain::p_SymmetricRangeDomain  (::mosek::fusion::SymmetricRangeDomain * _pubthis) :     mosek::fusion::p_RangeDomain(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymmetricRangeDomain::t mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2437){ return new mosek::fusion::SymmetricRangeDomain(_2437); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2437) :    SymmetricRangeDomain(new mosek::fusion::p_SymmetricRangeDomain(this)){ mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->_initialize(_2437); }void mosek::fusion::p_SymmetricRangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2437){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_RangeDomain::_initialize(_2437);
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _7872;
    bool _7873 = (NULL == shape.get());
    if (_7873)
    {
      _7872 = (int)0;
    }
    else
    {
      _7872 = ((*shape)((int)0));
    }
    dim = _7872;
  }
}void mosek::fusion::p_SymmetricRangeDomain::destroy(){}void mosek::fusion::SymmetricRangeDomain::destroy() { mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->destroy(); }mosek::fusion::RangeDomain::RangeDomain(mosek::fusion::p_RangeDomain *_impl) : _impl(_impl) { /*std::cout << "RangeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::RangeDomain::~RangeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_RangeDomain::p_RangeDomain  (::mosek::fusion::RangeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2438,    std::shared_ptr< monty::ndarray< double,1 > > _2439,    std::shared_ptr< monty::ndarray< double,1 > > _2440,    std::shared_ptr< monty::ndarray< int,1 > > _2441){ return new mosek::fusion::RangeDomain(_2438,_2439,_2440,_2441); }mosek::fusion::RangeDomain::RangeDomain  (bool _2438,    std::shared_ptr< monty::ndarray< double,1 > > _2439,    std::shared_ptr< monty::ndarray< double,1 > > _2440,    std::shared_ptr< monty::ndarray< int,1 > > _2441) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2438,_2439,_2440,_2441); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2438,    std::shared_ptr< monty::ndarray< double,1 > > _2439,    std::shared_ptr< monty::ndarray< double,1 > > _2440,    std::shared_ptr< monty::ndarray< int,1 > > _2441){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2439(_2439 ? _2439->raw() : nullptr, _2439 ? _2439->size(0) : 0);
    _checked_ptr_1<double> _ptr__2440(_2440 ? _2440->raw() : nullptr, _2440 ? _2440->size(0) : 0);
    _checked_ptr_1<int> _ptr__2441(_2441 ? _2441->raw() : nullptr, _2441 ? _2441->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2438,_2439,_2440,_2441,nullptr,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2442,    std::shared_ptr< monty::ndarray< double,1 > > _2443,    std::shared_ptr< monty::ndarray< double,1 > > _2444,    std::shared_ptr< monty::ndarray< int,1 > > _2445,    std::shared_ptr< monty::ndarray< int,2 > > _2446){ return new mosek::fusion::RangeDomain(_2442,_2443,_2444,_2445,_2446); }mosek::fusion::RangeDomain::RangeDomain  (bool _2442,    std::shared_ptr< monty::ndarray< double,1 > > _2443,    std::shared_ptr< monty::ndarray< double,1 > > _2444,    std::shared_ptr< monty::ndarray< int,1 > > _2445,    std::shared_ptr< monty::ndarray< int,2 > > _2446) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2442,_2443,_2444,_2445,_2446); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2442,    std::shared_ptr< monty::ndarray< double,1 > > _2443,    std::shared_ptr< monty::ndarray< double,1 > > _2444,    std::shared_ptr< monty::ndarray< int,1 > > _2445,    std::shared_ptr< monty::ndarray< int,2 > > _2446){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2443(_2443 ? _2443->raw() : nullptr, _2443 ? _2443->size(0) : 0);
    _checked_ptr_1<double> _ptr__2444(_2444 ? _2444->raw() : nullptr, _2444 ? _2444->size(0) : 0);
    _checked_ptr_1<int> _ptr__2445(_2445 ? _2445->raw() : nullptr, _2445 ? _2445->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2442,_2443,_2444,_2445,_2446,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2447,    std::shared_ptr< monty::ndarray< double,1 > > _2448,    std::shared_ptr< monty::ndarray< double,1 > > _2449,    std::shared_ptr< monty::ndarray< int,1 > > _2450,    std::shared_ptr< monty::ndarray< int,2 > > _2451,    int _2452){ return new mosek::fusion::RangeDomain(_2447,_2448,_2449,_2450,_2451,_2452); }mosek::fusion::RangeDomain::RangeDomain  (bool _2447,    std::shared_ptr< monty::ndarray< double,1 > > _2448,    std::shared_ptr< monty::ndarray< double,1 > > _2449,    std::shared_ptr< monty::ndarray< int,1 > > _2450,    std::shared_ptr< monty::ndarray< int,2 > > _2451,    int _2452) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2447,_2448,_2449,_2450,_2451,_2452); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2447,    std::shared_ptr< monty::ndarray< double,1 > > _2448,    std::shared_ptr< monty::ndarray< double,1 > > _2449,    std::shared_ptr< monty::ndarray< int,1 > > _2450,    std::shared_ptr< monty::ndarray< int,2 > > _2451,    int _2452){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2448(_2448 ? _2448->raw() : nullptr, _2448 ? _2448->size(0) : 0);
    _checked_ptr_1<double> _ptr__2449(_2449 ? _2449->raw() : nullptr, _2449 ? _2449->size(0) : 0);
    _checked_ptr_1<int> _ptr__2450(_2450 ? _2450->raw() : nullptr, _2450 ? _2450->size(0) : 0);
    cardinal_flag = false;
    shape = _2450;
    sparsity = nullptr;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->scalable = _2447;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->ub = _2449;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->lb = _2448;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = _2451;
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2453){ return new mosek::fusion::RangeDomain(_2453); }mosek::fusion::RangeDomain::RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2453) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2453); }void mosek::fusion::p_RangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2453){monty::rc_reserve __reserve_this(_pubthis);   {
    cardinal_flag = mosek::fusion::p_RangeDomain::_get_impl(_2453)->cardinal_flag;
    sparsity = mosek::fusion::p_RangeDomain::_get_impl(_2453)->sparsity;
    scalable = mosek::fusion::p_RangeDomain::_get_impl(_2453)->scalable;
    shape = mosek::fusion::p_RangeDomain::_get_impl(_2453)->shape;
    ub = mosek::fusion::p_RangeDomain::_get_impl(_2453)->ub;
    lb = mosek::fusion::p_RangeDomain::_get_impl(_2453)->lb;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__symmetric() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain::symmetric() { return __mosek_2fusion_2RangeDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain(::mosek::fusion::RangeDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2454) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2454); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2454) { return __mosek_2fusion_2RangeDomain__sparse(_2454); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2454){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2454)->size(0)),(int)((_2454)->size(1)))));
  {
    int _2455 = (int)0;
    for(;(_2455 < (int)((_2454)->size(0)));++ _2455)
    {
      {
        {
          int _2456 = (int)0;
          for(;(_2456 < (int)((_2454)->size(1)));++ _2456)
          {
            {
              ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2455,_2456)) = ((*_2454)(_2455,_2456));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2457) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2457); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2457) { return __mosek_2fusion_2RangeDomain__sparse(_2457); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2457){
  _checked_ptr_1<int> _ptr__2457(_2457 ? _2457->raw() : nullptr, _2457 ? _2457->size(0) : 0);
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2457)->size(0)),(int)1)));
  int _7874 = (int)0;
  int _7875 = (int)((_2457)->size(0));
  for (int _2458 = _7874; _2458 < _7875; ++_2458)
  {
    {
      ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2458,(int)0)) = _ptr__2457[_2458];
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__integral() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::integral() { return __mosek_2fusion_2RangeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2459) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2459); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2459) { return __mosek_2fusion_2RangeDomain__withShape(_2459); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2459){
  _checked_ptr_1<int> _ptr__2459(_2459 ? _2459->raw() : nullptr, _2459 ? _2459->size(0) : 0);
  shape = _2459;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
bool mosek::fusion::p_RangeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2460){
  _checked_ptr_1<int> _ptr__2460(_2460 ? _2460->raw() : nullptr, _2460 ? _2460->size(0) : 0);
  if (scalable)
  {
    {
      return true;
    }
  }
  else if(((int)((shape)->size(0)) != (int)((_2460)->size(0))))
  {
    {
      return false;
    }
  }
  else
  {
    {
      int _7876 = (int)0;
      int _7877 = (int)((shape)->size(0));
      for (int _2461 = _7876; _2461 < _7877; ++_2461)
      {
        {
          if ((((*shape)(_2461)) != _ptr__2460[_2461]))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  return true;
}
void mosek::fusion::p_RangeDomain::destroy(){ub.reset();lb.reset();sparsity.reset();shape.reset();}void mosek::fusion::RangeDomain::destroy() { mosek::fusion::p_RangeDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain(mosek::fusion::p_SymmetricLinearDomain *_impl) : _impl(_impl) { /*std::cout << "SymmetricLinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricLinearDomain::~SymmetricLinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricLinearDomain::p_SymmetricLinearDomain  (::mosek::fusion::SymmetricLinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricLinearDomain::t mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2462){ return new mosek::fusion::SymmetricLinearDomain(_2462); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2462) :    SymmetricLinearDomain(new mosek::fusion::p_SymmetricLinearDomain(this)){ mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->_initialize(_2462); }void mosek::fusion::p_SymmetricLinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2462){monty::rc_reserve __reserve_this(_pubthis);   {
    dom = _2462;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2462)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2462)->key;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2462)->cardinal_flag;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2462)->sparsity;
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _7878;
    bool _7879 = (NULL == shape.get());
    if (_7879)
    {
      _7878 = (int)0;
    }
    else
    {
      _7878 = ((*shape)((int)0));
    }
    dim = _7878;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2463) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2463); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2463) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2463); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2463){
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2463)->size(0)),(int)((_2463)->size(1)))));
  {
    int _2464 = (int)0;
    for(;(_2464 < (int)((_2463)->size(0)));++ _2464)
    {
      {
        {
          int _2465 = (int)0;
          for(;(_2465 < (int)((_2463)->size(1)));++ _2465)
          {
            {
              ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2464,_2465)) = ((*_2463)(_2464,_2465));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2466) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2466); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2466) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2466); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2466){
  _checked_ptr_1<int> _ptr__2466(_2466 ? _2466->raw() : nullptr, _2466 ? _2466->size(0) : 0);
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2466)->size(0)),(int)1)));
  int _7880 = (int)0;
  int _7881 = (int)((_2466)->size(0));
  for (int _2467 = _7880; _2467 < _7881; ++_2467)
  {
    {
      ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2467,(int)0)) = _ptr__2466[_2467];
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__integral() { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::integral() { return __mosek_2fusion_2SymmetricLinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
bool mosek::fusion::p_SymmetricLinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2468){
  _checked_ptr_1<int> _ptr__2468(_2468 ? _2468->raw() : nullptr, _2468 ? _2468->size(0) : 0);
  int _7882 = (int)0;
  int _7883 = (int)((_2468)->size(0));
  for (int _2469 = _7882; _2469 < _7883; ++_2469)
  {
    {
      if ((_ptr__2468[_2469] == ((*shape)(_2469))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_SymmetricLinearDomain::destroy(){sparsity.reset();shape.reset();dom.reset();}void mosek::fusion::SymmetricLinearDomain::destroy() { mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->destroy(); }mosek::fusion::LinearDomain::LinearDomain(mosek::fusion::p_LinearDomain *_impl) : _impl(_impl) { /*std::cout << "LinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinearDomain::~LinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinearDomain::p_LinearDomain  (::mosek::fusion::LinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2470,    bool _2471,    std::shared_ptr< monty::ndarray< double,1 > > _2472,    std::shared_ptr< monty::ndarray< int,1 > > _2473){ return new mosek::fusion::LinearDomain(_2470,_2471,_2472,_2473); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2470,    bool _2471,    std::shared_ptr< monty::ndarray< double,1 > > _2472,    std::shared_ptr< monty::ndarray< int,1 > > _2473) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2470,_2471,_2472,_2473); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2470,    bool _2471,    std::shared_ptr< monty::ndarray< double,1 > > _2472,    std::shared_ptr< monty::ndarray< int,1 > > _2473){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2472(_2472 ? _2472->raw() : nullptr, _2472 ? _2472->size(0) : 0);
    _checked_ptr_1<int> _ptr__2473(_2473 ? _2473->raw() : nullptr, _2473 ? _2473->size(0) : 0);
    mosek::fusion::p_LinearDomain::_initialize(_2470,_2471,_2472,_2473,nullptr,(int)1);
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2474,    bool _2475,    std::shared_ptr< monty::ndarray< double,1 > > _2476,    std::shared_ptr< monty::ndarray< int,1 > > _2477,    std::shared_ptr< monty::ndarray< int,2 > > _2478,    int _2479){ return new mosek::fusion::LinearDomain(_2474,_2475,_2476,_2477,_2478,_2479); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2474,    bool _2475,    std::shared_ptr< monty::ndarray< double,1 > > _2476,    std::shared_ptr< monty::ndarray< int,1 > > _2477,    std::shared_ptr< monty::ndarray< int,2 > > _2478,    int _2479) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2474,_2475,_2476,_2477,_2478,_2479); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2474,    bool _2475,    std::shared_ptr< monty::ndarray< double,1 > > _2476,    std::shared_ptr< monty::ndarray< int,1 > > _2477,    std::shared_ptr< monty::ndarray< int,2 > > _2478,    int _2479){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2476(_2476 ? _2476->raw() : nullptr, _2476 ? _2476->size(0) : 0);
    _checked_ptr_1<int> _ptr__2477(_2477 ? _2477->raw() : nullptr, _2477 ? _2477->size(0) : 0);
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->scalable = _2475;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->shape = _2477;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->key = _2474;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->bnd = _2476;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = _2478;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->cardinal_flag = false;
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2480){ return new mosek::fusion::LinearDomain(_2480); }mosek::fusion::LinearDomain::LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2480) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2480); }void mosek::fusion::p_LinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2480){monty::rc_reserve __reserve_this(_pubthis);   {
    scalable = mosek::fusion::p_LinearDomain::_get_impl(_2480)->scalable;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2480)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2480)->key;
    bnd = mosek::fusion::p_LinearDomain::_get_impl(_2480)->bnd;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2480)->sparsity;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2480)->cardinal_flag;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__symmetric() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain::symmetric() { return __mosek_2fusion_2LinearDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain(::mosek::fusion::LinearDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2481) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2481); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2481) { return __mosek_2fusion_2LinearDomain__sparse(_2481); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2481){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2481)->size(0)),(int)((_2481)->size(1)))));
  {
    int _2482 = (int)0;
    for(;(_2482 < (int)((_2481)->size(0)));++ _2482)
    {
      {
        {
          int _2483 = (int)0;
          for(;(_2483 < (int)((_2481)->size(1)));++ _2483)
          {
            {
              ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2482,_2483)) = ((*_2481)(_2482,_2483));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2484) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2484); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2484) { return __mosek_2fusion_2LinearDomain__sparse(_2484); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2484){
  _checked_ptr_1<int> _ptr__2484(_2484 ? _2484->raw() : nullptr, _2484 ? _2484->size(0) : 0);
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2484)->size(0)),(int)1)));
  int _7884 = (int)0;
  int _7885 = (int)((_2484)->size(0));
  for (int _2485 = _7884; _2485 < _7885; ++_2485)
  {
    {
      ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2485,(int)0)) = _ptr__2484[_2485];
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__integral() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::integral() { return __mosek_2fusion_2LinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2486) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2486); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2486) { return __mosek_2fusion_2LinearDomain__withShape(_2486); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2486){
  _checked_ptr_1<int> _ptr__2486(_2486 ? _2486->raw() : nullptr, _2486 ? _2486->size(0) : 0);
  shape = _2486;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
bool mosek::fusion::p_LinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2487){
  _checked_ptr_1<int> _ptr__2487(_2487 ? _2487->raw() : nullptr, _2487 ? _2487->size(0) : 0);
  if ((!scalable))
  {
    {
      int _7886 = (int)0;
      int _7887 = (int)((_2487)->size(0));
      for (int _2488 = _7886; _2488 < _7887; ++_2488)
      {
        {
          if ((_ptr__2487[_2488] == ((*shape)(_2488))))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinearDomain::destroy(){sparsity.reset();bnd.reset();shape.reset();}void mosek::fusion::LinearDomain::destroy() { mosek::fusion::p_LinearDomain::_get_impl(this)->destroy(); }mosek::fusion::Domain::Domain(mosek::fusion::p_Domain *_impl) : _impl(_impl) { /*std::cout << "Domain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Domain::~Domain() { delete _impl; _impl = nullptr; }mosek::fusion::p_Domain::p_Domain  (::mosek::fusion::Domain * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::p_Domain::dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2489){
  _checked_ptr_1<int> _ptr__2489(_2489 ? _2489->raw() : nullptr, _2489 ? _2489->size(0) : 0);
  long long _2490 = (long long)1;
  int _7888 = (int)0;
  int _7889 = (int)((_2489)->size(0));
  for (int _2491 = _7888; _2491 < _7889; ++_2491)
  {
    {
      _2490 *= _ptr__2489[_2491];
    }
  }
  return _2490;
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::mkLinearDomain(mosek::fusion::RelationKey _2492,monty::rc_ptr< ::mosek::fusion::Matrix > _2493){
  if (_2493->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2494 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2493->numNonzeros())));
      _checked_ptr_1<int> _ptr__2494(_2494 ? _2494->raw() : nullptr,_2494 ? _2494->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2495 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2493->numNonzeros())));
      _checked_ptr_1<int> _ptr__2495(_2495 ? _2495->raw() : nullptr,_2495 ? _2495->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2496 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2493->numNonzeros())));
      _checked_ptr_1<double> _ptr__2496(_2496 ? _2496->raw() : nullptr,_2496 ? _2496->size(0) : 0);
      _2493->getDataAsTriplets(_2494,_2495,_2496);
      std::shared_ptr< monty::ndarray< int,2 > > _2497 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2494)->size(0)),(int)2)));
      int _7890 = (int)0;
      int _7891 = (int)((_2494)->size(0));
      for (int _2498 = _7890; _2498 < _7891; ++_2498)
      {
        {
          ((*_2497)(_2498,(int)0)) = _ptr__2494[_2498];
          ((*_2497)(_2498,(int)1)) = _ptr__2495[_2498];
        }
      }
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2492,false,_2496,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2493)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2493)->dimj)}),_2497,(int)1);
    }
  }
  else
  {
    {
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2492,false,_2493->getDataAsArray(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2493)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2493)->dimj)}),nullptr,(int)1);
    }
  }
}
long long mosek::fusion::p_Domain::prod(std::shared_ptr< monty::ndarray< int,1 > > _2499){
  _checked_ptr_1<int> _ptr__2499(_2499 ? _2499->raw() : nullptr, _2499 ? _2499->size(0) : 0);
  long long _2500 = (int)1;
  int _7892 = (int)0;
  int _7893 = (int)((_2499)->size(0));
  for (int _2501 = _7892; _2501 < _7893; ++_2501)
  {
    {
      _2500 *= _ptr__2499[_2501];
    }
  }
  return _2500;
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(bool _2502,std::shared_ptr< monty::ndarray< double,1 > > _2503,std::shared_ptr< monty::ndarray< double,1 > > _2504,std::shared_ptr< monty::ndarray< int,2 > > _2505,std::shared_ptr< monty::ndarray< int,1 > > _2506){
  _checked_ptr_1<double> _ptr__2503(_2503 ? _2503->raw() : nullptr, _2503 ? _2503->size(0) : 0);
  _checked_ptr_1<double> _ptr__2504(_2504 ? _2504->raw() : nullptr, _2504 ? _2504->size(0) : 0);
  _checked_ptr_1<int> _ptr__2506(_2506 ? _2506->raw() : nullptr, _2506 ? _2506->size(0) : 0);
  if (((!_2502) && ((int)((_2503)->size(0)) != (int)((_2504)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper and lower bounds."));
    }
  }
  {}
  if (((NULL != _2505.get()) && ((int)((_2505)->size(0)) != (int)((_2503)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper/lower bounds and sparsity."));
    }
  }
  {}
  int _7894 = (int)0;
  int _7895 = (int)((_2504)->size(0));
  for (int _2507 = _7894; _2507 < _7895; ++_2507)
  {
    {
      if ((_ptr__2503[_2507] > _ptr__2504[_2507]))
      {
        {
          throw ::mosek::fusion::DomainError(std::string ("Invalid range specified"));
        }
      }
      {}
    }
  }
  if (((NULL != _2506.get()) && (::mosek::fusion::p_Domain::dimsize(_2506) != (int)((_2503)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching dimensions."));
    }
  }
  {}
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(_2502,_2503,_2504,_2506)->__mosek_2fusion_2RangeDomain__sparse(_2505);
}
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2508) { return mosek::fusion::p_Domain::symmetric(_2508); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2508){
  return _2508->__mosek_2fusion_2RangeDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2509) { return mosek::fusion::p_Domain::symmetric(_2509); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2509){
  return _2509->__mosek_2fusion_2LinearDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2510,    std::shared_ptr< monty::ndarray< int,2 > > _2511) { return mosek::fusion::p_Domain::sparse(_2510,_2511); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2510,std::shared_ptr< monty::ndarray< int,2 > > _2511){
  return _2510->__mosek_2fusion_2RangeDomain__sparse(_2511);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2512,    std::shared_ptr< monty::ndarray< int,1 > > _2513) { return mosek::fusion::p_Domain::sparse(_2512,_2513); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2512,std::shared_ptr< monty::ndarray< int,1 > > _2513){
  _checked_ptr_1<int> _ptr__2513(_2513 ? _2513->raw() : nullptr, _2513 ? _2513->size(0) : 0);
  return _2512->__mosek_2fusion_2RangeDomain__sparse(_2513);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2514,    std::shared_ptr< monty::ndarray< int,2 > > _2515) { return mosek::fusion::p_Domain::sparse(_2514,_2515); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2514,std::shared_ptr< monty::ndarray< int,2 > > _2515){
  return _2514->__mosek_2fusion_2LinearDomain__sparse(_2515);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2516,    std::shared_ptr< monty::ndarray< int,1 > > _2517) { return mosek::fusion::p_Domain::sparse(_2516,_2517); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2516,std::shared_ptr< monty::ndarray< int,1 > > _2517){
  _checked_ptr_1<int> _ptr__2517(_2517 ? _2517->raw() : nullptr, _2517 ? _2517->size(0) : 0);
  return _2516->__mosek_2fusion_2LinearDomain__sparse(_2517);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2518) { return mosek::fusion::p_Domain::integral(_2518); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2518){
  return _2518->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2519) { return mosek::fusion::p_Domain::integral(_2519); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2519){
  return _2519->__mosek_2fusion_2LinearDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2520) { return mosek::fusion::p_Domain::integral(_2520); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2520){
  return _2520->__mosek_2fusion_2ConeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::axis  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2521,    int _2522) { return mosek::fusion::p_Domain::axis(_2521,_2522); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2521,int _2522){
  return _2521->__mosek_2fusion_2ConeDomain__axis(_2522);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2523,    std::shared_ptr< monty::ndarray< int,1 > > _2524) { return mosek::fusion::p_Domain::inDPowerCone(_2523,_2524); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2523,std::shared_ptr< monty::ndarray< int,1 > > _2524){
  _checked_ptr_1<int> _ptr__2524(_2524 ? _2524->raw() : nullptr, _2524 ? _2524->size(0) : 0);
  std::vector<int> _7896;
  for (int _2525 = (int)0, _7897 = (int)((_2524)->size(0)); _2525 < _7897 ; ++_2525)
  {
    _7896.push_back(_ptr__2524[_2525]);
  }
  auto _7898 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7896.size()),_7896.begin(),_7896.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2523,_7898);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2526,    int _2527) { return mosek::fusion::p_Domain::inDPowerCone(_2526,_2527); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2526,int _2527){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2526,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2527),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2528) { return mosek::fusion::p_Domain::inDPowerCone(_2528); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2528){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2528,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2529,    std::shared_ptr< monty::ndarray< int,1 > > _2530) { return mosek::fusion::p_Domain::inPPowerCone(_2529,_2530); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2529,std::shared_ptr< monty::ndarray< int,1 > > _2530){
  _checked_ptr_1<int> _ptr__2530(_2530 ? _2530->raw() : nullptr, _2530 ? _2530->size(0) : 0);
  std::vector<int> _7899;
  for (int _2531 = (int)0, _7900 = (int)((_2530)->size(0)); _2531 < _7900 ; ++_2531)
  {
    _7899.push_back(_ptr__2530[_2531]);
  }
  auto _7901 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7899.size()),_7899.begin(),_7899.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2529,_7901);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2532,    int _2533) { return mosek::fusion::p_Domain::inPPowerCone(_2532,_2533); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2532,int _2533){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2532,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2533),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2534) { return mosek::fusion::p_Domain::inPPowerCone(_2534); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2534){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2534,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2535) { return mosek::fusion::p_Domain::inDExpCone(_2535); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2535){
  _checked_ptr_1<int> _ptr__2535(_2535 ? _2535->raw() : nullptr, _2535 ? _2535->size(0) : 0);
  std::vector<int> _7902;
  for (int _2536 = (int)0, _7903 = (int)((_2535)->size(0)); _2536 < _7903 ; ++_2536)
  {
    _7902.push_back(_ptr__2535[_2536]);
  }
  auto _7904 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7902.size()),_7902.begin(),_7902.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,_7904);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( int _2537) { return mosek::fusion::p_Domain::inDExpCone(_2537); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(int _2537){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2537),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( ) { return mosek::fusion::p_Domain::inDExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2538) { return mosek::fusion::p_Domain::inPExpCone(_2538); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2538){
  _checked_ptr_1<int> _ptr__2538(_2538 ? _2538->raw() : nullptr, _2538 ? _2538->size(0) : 0);
  std::vector<int> _7905;
  for (int _2539 = (int)0, _7906 = (int)((_2538)->size(0)); _2539 < _7906 ; ++_2539)
  {
    _7905.push_back(_ptr__2538[_2539]);
  }
  auto _7907 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7905.size()),_7905.begin(),_7905.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,_7907);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( int _2540) { return mosek::fusion::p_Domain::inPExpCone(_2540); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(int _2540){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2540),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( ) { return mosek::fusion::p_Domain::inPExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2541) { return mosek::fusion::p_Domain::inRotatedQCone(_2541); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2541){
  _checked_ptr_1<int> _ptr__2541(_2541 ? _2541->raw() : nullptr, _2541 ? _2541->size(0) : 0);
  std::vector<int> _7908;
  for (int _2542 = (int)0, _7909 = (int)((_2541)->size(0)); _2542 < _7909 ; ++_2542)
  {
    _7908.push_back(_ptr__2541[_2542]);
  }
  auto _7910 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7908.size()),_7908.begin(),_7908.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,_7910);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2543,    int _2544) { return mosek::fusion::p_Domain::inRotatedQCone(_2543,_2544); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2543,int _2544){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2543),(int)(_2544)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2545) { return mosek::fusion::p_Domain::inRotatedQCone(_2545); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2545){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2545)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( ) { return mosek::fusion::p_Domain::inRotatedQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2546) { return mosek::fusion::p_Domain::inQCone(_2546); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2546){
  _checked_ptr_1<int> _ptr__2546(_2546 ? _2546->raw() : nullptr, _2546 ? _2546->size(0) : 0);
  std::vector<int> _7911;
  for (int _2547 = (int)0, _7912 = (int)((_2546)->size(0)); _2547 < _7912 ; ++_2547)
  {
    _7911.push_back(_ptr__2546[_2547]);
  }
  auto _7913 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7911.size()),_7911.begin(),_7911.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,_7913);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2548,    int _2549) { return mosek::fusion::p_Domain::inQCone(_2548,_2549); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2548,int _2549){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2548),(int)(_2549)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2550) { return mosek::fusion::p_Domain::inQCone(_2550); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2550){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2550)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( ) { return mosek::fusion::p_Domain::inQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2551,    int _2552) { return mosek::fusion::p_Domain::isLinPSD(_2551,_2552); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2551,int _2552){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2551,safe_add( _2551,(int)1 ) ) / (int)2),_2552));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2553) { return mosek::fusion::p_Domain::isLinPSD(_2553); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2553){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2553,safe_add( _2553,(int)1 ) ) / (int)2)));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( ) { return mosek::fusion::p_Domain::isLinPSD(); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain();
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2554,    int _2555) { return mosek::fusion::p_Domain::isTrilPSD(_2554,_2555); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2554,int _2555){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2555),(int)(_2554),(int)(_2554)}),(int)1,(int)2);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2556) { return mosek::fusion::p_Domain::isTrilPSD(_2556); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2556){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2556),(int)(_2556)}),(int)0,(int)1);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( ) { return mosek::fusion::p_Domain::isTrilPSD(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2557,    int _2558) { return mosek::fusion::p_Domain::inPSDCone(_2557,_2558); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2557,int _2558){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2558),(int)(_2557),(int)(_2557)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2559) { return mosek::fusion::p_Domain::inPSDCone(_2559); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2559){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2559),(int)(_2559)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( ) { return mosek::fusion::p_Domain::inPSDCone(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( ) { return mosek::fusion::p_Domain::binary(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),nullptr)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( std::shared_ptr< monty::ndarray< int,1 > > _2560) { return mosek::fusion::p_Domain::binary(_2560); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(std::shared_ptr< monty::ndarray< int,1 > > _2560){
  _checked_ptr_1<int> _ptr__2560(_2560 ? _2560->raw() : nullptr, _2560 ? _2560->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),_2560)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2561,    int _2562) { return mosek::fusion::p_Domain::binary(_2561,_2562); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2561,int _2562){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2561),(int)(_2562)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2563) { return mosek::fusion::p_Domain::binary(_2563); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2563){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2563)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2564,    std::shared_ptr< monty::ndarray< double,1 > > _2565,    std::shared_ptr< monty::ndarray< int,1 > > _2566) { return mosek::fusion::p_Domain::inRange(_2564,_2565,_2566); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2564,std::shared_ptr< monty::ndarray< double,1 > > _2565,std::shared_ptr< monty::ndarray< int,1 > > _2566){
  _checked_ptr_1<double> _ptr__2564(_2564 ? _2564->raw() : nullptr, _2564 ? _2564->size(0) : 0);
  _checked_ptr_1<double> _ptr__2565(_2565 ? _2565->raw() : nullptr, _2565 ? _2565->size(0) : 0);
  _checked_ptr_1<int> _ptr__2566(_2566 ? _2566->raw() : nullptr, _2566 ? _2566->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2564,_2565,_2566);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2567,    double _2568,    std::shared_ptr< monty::ndarray< int,1 > > _2569) { return mosek::fusion::p_Domain::inRange(_2567,_2568,_2569); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2567,double _2568,std::shared_ptr< monty::ndarray< int,1 > > _2569){
  _checked_ptr_1<double> _ptr__2567(_2567 ? _2567->raw() : nullptr, _2567 ? _2567->size(0) : 0);
  _checked_ptr_1<int> _ptr__2569(_2569 ? _2569->raw() : nullptr, _2569 ? _2569->size(0) : 0);
  std::vector<double> _7914;
  for (int _2570 = (int)0, _7915 = (int)((_2567)->size(0)); _2570 < _7915 ; ++_2570)
  {
    _7914.push_back(_2568);
  }
  auto _7916 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7914.size()),_7914.begin(),_7914.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2567,_7916,_2569);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2571,    std::shared_ptr< monty::ndarray< double,1 > > _2572,    std::shared_ptr< monty::ndarray< int,1 > > _2573) { return mosek::fusion::p_Domain::inRange(_2571,_2572,_2573); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2571,std::shared_ptr< monty::ndarray< double,1 > > _2572,std::shared_ptr< monty::ndarray< int,1 > > _2573){
  _checked_ptr_1<double> _ptr__2572(_2572 ? _2572->raw() : nullptr, _2572 ? _2572->size(0) : 0);
  _checked_ptr_1<int> _ptr__2573(_2573 ? _2573->raw() : nullptr, _2573 ? _2573->size(0) : 0);
  std::vector<double> _7917;
  for (int _2574 = (int)0, _7918 = (int)((_2572)->size(0)); _2574 < _7918 ; ++_2574)
  {
    _7917.push_back(_2571);
  }
  auto _7919 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7917.size()),_7917.begin(),_7917.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_7919,_2572,_2573);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2575,    double _2576,    std::shared_ptr< monty::ndarray< int,1 > > _2577) { return mosek::fusion::p_Domain::inRange(_2575,_2576,_2577); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2575,double _2576,std::shared_ptr< monty::ndarray< int,1 > > _2577){
  _checked_ptr_1<int> _ptr__2577(_2577 ? _2577->raw() : nullptr, _2577 ? _2577->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2575)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2576)}),_2577);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2578,    std::shared_ptr< monty::ndarray< double,1 > > _2579) { return mosek::fusion::p_Domain::inRange(_2578,_2579); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2578,std::shared_ptr< monty::ndarray< double,1 > > _2579){
  _checked_ptr_1<double> _ptr__2578(_2578 ? _2578->raw() : nullptr, _2578 ? _2578->size(0) : 0);
  _checked_ptr_1<double> _ptr__2579(_2579 ? _2579->raw() : nullptr, _2579 ? _2579->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2578,_2579,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2578)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2580,    double _2581) { return mosek::fusion::p_Domain::inRange(_2580,_2581); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2580,double _2581){
  _checked_ptr_1<double> _ptr__2580(_2580 ? _2580->raw() : nullptr, _2580 ? _2580->size(0) : 0);
  std::vector<double> _7920;
  for (int _2582 = (int)0, _7921 = (int)((_2580)->size(0)); _2582 < _7921 ; ++_2582)
  {
    _7920.push_back(_2581);
  }
  auto _7922 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7920.size()),_7920.begin(),_7920.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2580,_7922,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2580)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2583,    std::shared_ptr< monty::ndarray< double,1 > > _2584) { return mosek::fusion::p_Domain::inRange(_2583,_2584); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2583,std::shared_ptr< monty::ndarray< double,1 > > _2584){
  _checked_ptr_1<double> _ptr__2584(_2584 ? _2584->raw() : nullptr, _2584 ? _2584->size(0) : 0);
  std::vector<double> _7923;
  for (int _2585 = (int)0, _7924 = (int)((_2584)->size(0)); _2585 < _7924 ; ++_2585)
  {
    _7923.push_back(_2583);
  }
  auto _7925 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7923.size()),_7923.begin(),_7923.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_7925,_2584,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2584)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2586,    double _2587) { return mosek::fusion::p_Domain::inRange(_2586,_2587); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2586,double _2587){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2586)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2587)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2588) { return mosek::fusion::p_Domain::greaterThan(_2588); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2588){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::GreaterThan,_2588);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2589,    std::shared_ptr< monty::ndarray< int,1 > > _2590) { return mosek::fusion::p_Domain::greaterThan(_2589,_2590); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2589,std::shared_ptr< monty::ndarray< int,1 > > _2590){
  _checked_ptr_1<double> _ptr__2589(_2589 ? _2589->raw() : nullptr, _2589 ? _2589->size(0) : 0);
  _checked_ptr_1<int> _ptr__2590(_2590 ? _2590->raw() : nullptr, _2590 ? _2590->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2589),_2590);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2591) { return mosek::fusion::p_Domain::greaterThan(_2591); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2591){
  std::vector<double> _7926;
  for (int _2592 = (int)0, _7927 = (int)((_2591)->size(0)); _2592 < _7927 ; ++_2592)
  {
    for (int _2593 = (int)0, _7928 = (int)((_2591)->size(1)); _2593 < _7928 ; ++_2593)
    {
      _7926.push_back(((*_2591)(_2592,_2593)));
    }
  }
  auto _7929 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7926.size()),_7926.begin(),_7926.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,_7929,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2591)->size(0))),(int)((int)((_2591)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2594) { return mosek::fusion::p_Domain::greaterThan(_2594); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2594){
  _checked_ptr_1<double> _ptr__2594(_2594 ? _2594->raw() : nullptr, _2594 ? _2594->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2594),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2594)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2595,    std::shared_ptr< monty::ndarray< int,1 > > _2596) { return mosek::fusion::p_Domain::greaterThan(_2595,_2596); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2595,std::shared_ptr< monty::ndarray< int,1 > > _2596){
  _checked_ptr_1<int> _ptr__2596(_2596 ? _2596->raw() : nullptr, _2596 ? _2596->size(0) : 0);
  std::vector<double> _7930;
  for (long long _2597 = (int)0, _7931 = ::mosek::fusion::p_Domain::prod(_2596); _2597 < _7931 ; ++_2597)
  {
    _7930.push_back(_2595);
  }
  auto _7932 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7930.size()),_7930.begin(),_7930.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_7932,_2596);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2598,    int _2599,    int _2600) { return mosek::fusion::p_Domain::greaterThan(_2598,_2599,_2600); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2598,int _2599,int _2600){
  std::vector<double> _7933;
  for (int _2601 = (int)0, _7934 = safe_mul( _2600,_2599 ); _2601 < _7934 ; ++_2601)
  {
    _7933.push_back(_2598);
  }
  auto _7935 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7933.size()),_7933.begin(),_7933.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_7935,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2599),(int)(_2600)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2602,    int _2603) { return mosek::fusion::p_Domain::greaterThan(_2602,_2603); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2602,int _2603){
  std::vector<double> _7936;
  for (int _2604 = (int)0, _7937 = _2603; _2604 < _7937 ; ++_2604)
  {
    _7936.push_back(_2602);
  }
  auto _7938 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7936.size()),_7936.begin(),_7936.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_7938,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2603)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2605) { return mosek::fusion::p_Domain::greaterThan(_2605); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2605){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2605)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2606) { return mosek::fusion::p_Domain::lessThan(_2606); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2606){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::LessThan,_2606);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2607,    std::shared_ptr< monty::ndarray< int,1 > > _2608) { return mosek::fusion::p_Domain::lessThan(_2607,_2608); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2607,std::shared_ptr< monty::ndarray< int,1 > > _2608){
  _checked_ptr_1<double> _ptr__2607(_2607 ? _2607->raw() : nullptr, _2607 ? _2607->size(0) : 0);
  _checked_ptr_1<int> _ptr__2608(_2608 ? _2608->raw() : nullptr, _2608 ? _2608->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2607),_2608);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2609) { return mosek::fusion::p_Domain::lessThan(_2609); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2609){
  std::vector<double> _7939;
  for (int _2610 = (int)0, _7940 = (int)((_2609)->size(0)); _2610 < _7940 ; ++_2610)
  {
    for (int _2611 = (int)0, _7941 = (int)((_2609)->size(1)); _2611 < _7941 ; ++_2611)
    {
      _7939.push_back(((*_2609)(_2610,_2611)));
    }
  }
  auto _7942 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7939.size()),_7939.begin(),_7939.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,_7942,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2609)->size(0))),(int)((int)((_2609)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2612) { return mosek::fusion::p_Domain::lessThan(_2612); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2612){
  _checked_ptr_1<double> _ptr__2612(_2612 ? _2612->raw() : nullptr, _2612 ? _2612->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2612),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2612)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2613,    std::shared_ptr< monty::ndarray< int,1 > > _2614) { return mosek::fusion::p_Domain::lessThan(_2613,_2614); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2613,std::shared_ptr< monty::ndarray< int,1 > > _2614){
  _checked_ptr_1<int> _ptr__2614(_2614 ? _2614->raw() : nullptr, _2614 ? _2614->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2613)}),_2614);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2615,    int _2616,    int _2617) { return mosek::fusion::p_Domain::lessThan(_2615,_2616,_2617); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2615,int _2616,int _2617){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2615)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2616),(int)(_2617)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2618,    int _2619) { return mosek::fusion::p_Domain::lessThan(_2618,_2619); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2618,int _2619){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2618)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2619)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2620) { return mosek::fusion::p_Domain::lessThan(_2620); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2620){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2620)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2621) { return mosek::fusion::p_Domain::equalsTo(_2621); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2621){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::EqualsTo,_2621);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2622,    std::shared_ptr< monty::ndarray< int,1 > > _2623) { return mosek::fusion::p_Domain::equalsTo(_2622,_2623); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2622,std::shared_ptr< monty::ndarray< int,1 > > _2623){
  _checked_ptr_1<double> _ptr__2622(_2622 ? _2622->raw() : nullptr, _2622 ? _2622->size(0) : 0);
  _checked_ptr_1<int> _ptr__2623(_2623 ? _2623->raw() : nullptr, _2623 ? _2623->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2622),_2623);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,2 > > _2624) { return mosek::fusion::p_Domain::equalsTo(_2624); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2624){
  std::vector<double> _7943;
  for (int _2625 = (int)0, _7944 = (int)((_2624)->size(0)); _2625 < _7944 ; ++_2625)
  {
    for (int _2626 = (int)0, _7945 = (int)((_2624)->size(1)); _2626 < _7945 ; ++_2626)
    {
      _7943.push_back(((*_2624)(_2625,_2626)));
    }
  }
  auto _7946 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7943.size()),_7943.begin(),_7943.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,_7946,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2624)->size(0))),(int)((int)((_2624)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2627) { return mosek::fusion::p_Domain::equalsTo(_2627); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2627){
  _checked_ptr_1<double> _ptr__2627(_2627 ? _2627->raw() : nullptr, _2627 ? _2627->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2627),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2627)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2628,    std::shared_ptr< monty::ndarray< int,1 > > _2629) { return mosek::fusion::p_Domain::equalsTo(_2628,_2629); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2628,std::shared_ptr< monty::ndarray< int,1 > > _2629){
  _checked_ptr_1<int> _ptr__2629(_2629 ? _2629->raw() : nullptr, _2629 ? _2629->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2628)}),_2629);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2630,    int _2631,    int _2632) { return mosek::fusion::p_Domain::equalsTo(_2630,_2631,_2632); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2630,int _2631,int _2632){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2630)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2631),(int)(_2632)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2633,    int _2634) { return mosek::fusion::p_Domain::equalsTo(_2633,_2634); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2633,int _2634){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2633)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2634)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2635) { return mosek::fusion::p_Domain::equalsTo(_2635); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2635){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2635)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( std::shared_ptr< monty::ndarray< int,1 > > _2636) { return mosek::fusion::p_Domain::unbounded(_2636); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2636){
  _checked_ptr_1<int> _ptr__2636(_2636 ? _2636->raw() : nullptr, _2636 ? _2636->size(0) : 0);
  std::vector<int> _7947;
  for (int _2637 = (int)0, _7948 = (int)((_2636)->size(0)); _2637 < _7948 ; ++_2637)
  {
    _7947.push_back(_ptr__2636[_2637]);
  }
  auto _7949 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7947.size()),_7947.begin(),_7947.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,_7949);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2638,    int _2639) { return mosek::fusion::p_Domain::unbounded(_2638,_2639); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2638,int _2639){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2638),(int)(_2639)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2640) { return mosek::fusion::p_Domain::unbounded(_2640); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2640){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2640)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( ) { return mosek::fusion::p_Domain::unbounded(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,true,nullptr,nullptr);
}
void mosek::fusion::p_Domain::destroy(){}void mosek::fusion::Domain::destroy() { mosek::fusion::p_Domain::_get_impl(this)->destroy(); }mosek::fusion::ExprConst::ExprConst(mosek::fusion::p_ExprConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprConst()" << this << std::endl; */ }mosek::fusion::ExprConst::~ExprConst() {  /* std::cout << "~ExprConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprConst::p_ExprConst  (::mosek::fusion::ExprConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2641,    std::shared_ptr< monty::ndarray< long long,1 > > _2642,    std::shared_ptr< monty::ndarray< double,1 > > _2643){ return new mosek::fusion::ExprConst(_2641,_2642,_2643); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2641,    std::shared_ptr< monty::ndarray< long long,1 > > _2642,    std::shared_ptr< monty::ndarray< double,1 > > _2643) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2641,_2642,_2643); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2641,    std::shared_ptr< monty::ndarray< long long,1 > > _2642,    std::shared_ptr< monty::ndarray< double,1 > > _2643){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2641(_2641 ? _2641->raw() : nullptr, _2641 ? _2641->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2642(_2642 ? _2642->raw() : nullptr, _2642 ? _2642->size(0) : 0);
    _checked_ptr_1<double> _ptr__2643(_2643 ? _2643->raw() : nullptr, _2643 ? _2643->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2641);
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = ::mosek::fusion::Utils::Tools::arraycopy(_2643);
    std::shared_ptr< monty::ndarray< long long,1 > > _7950;
    bool _7951 = (NULL != _2642.get());
    if (_7951)
    {
      _7950 = ::mosek::fusion::Utils::Tools::arraycopy(_2642);
    }
    else
    {
      _7950 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _7950;
    ::mosek::fusion::p_ExprConst::validate(_2641,_2643,_2642);
  }
}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2644,    std::shared_ptr< monty::ndarray< long long,1 > > _2645,    double _2646){ return new mosek::fusion::ExprConst(_2644,_2645,_2646); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2644,    std::shared_ptr< monty::ndarray< long long,1 > > _2645,    double _2646) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2644,_2645,_2646); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2644,    std::shared_ptr< monty::ndarray< long long,1 > > _2645,    double _2646){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2644(_2644 ? _2644->raw() : nullptr, _2644 ? _2644->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2645(_2645 ? _2645->raw() : nullptr, _2645 ? _2645->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2644);
    long long _7952;
    bool _7953 = (NULL == _2645.get());
    if (_7953)
    {
      _7952 = ::mosek::fusion::p_Set::size(_2644);
    }
    else
    {
      _7952 = (int)((_2645)->size(0));
    }
    long long _2647 = _7952;
    std::vector<double> _7954;
    for (long long _2648 = (int)0, _7955 = _2647; _2648 < _7955 ; ++_2648)
    {
      _7954.push_back(_2646);
    }
    auto _7956 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7954.size()),_7954.begin(),_7954.end()));
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = _7956;
    std::shared_ptr< monty::ndarray< long long,1 > > _7957;
    bool _7958 = (NULL != _2645.get());
    if (_7958)
    {
      _7957 = ::mosek::fusion::Utils::Tools::arraycopy(_2645);
    }
    else
    {
      _7957 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _7957;
    ::mosek::fusion::p_ExprConst::validate(_2644,mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix,_2645);
  }
}void mosek::fusion::ExprConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2649,monty::rc_ptr< ::mosek::fusion::WorkStack > _2650,monty::rc_ptr< ::mosek::fusion::WorkStack > _2651) { mosek::fusion::p_ExprConst::_get_impl(this)->eval(_2649,_2650,_2651); }void mosek::fusion::p_ExprConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2649,monty::rc_ptr< ::mosek::fusion::WorkStack > _2650,monty::rc_ptr< ::mosek::fusion::WorkStack > _2651){
  std::shared_ptr< monty::ndarray< int,1 > > _2652 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__2652(_2652 ? _2652->raw() : nullptr,_2652 ? _2652->size(0) : 0);
  int _2653 = (int)((bfix)->size(0));
  bool _2654 = ((NULL != sparsity.get()) && ((int)((sparsity)->size(0)) < ::mosek::fusion::p_Set::size(_2652)));
  int _2655 = _2649->alloci32(safe_add( _2653,(int)1 ));
  int _7959;
  bool _7960 = _2654;
  if (_7960)
  {
    _7959 = (int)1;
  }
  else
  {
    _7959 = (int)0;
  }
  _2649->pushi32(_7959);
  _2649->pushi32((int)0);
  _2649->pushi32(_2653);
  int _7961 = (int)0;
  int _7962 = (int)((_2652)->size(0));
  for (int _2656 = _7961; _2656 < _7962; ++_2656)
  {
    {
      _2649->pushi32(_ptr__2652[_2656]);
    }
  }
  _2649->pushi32((int)((_2652)->size(0)));
  if ((NULL != sparsity.get()))
  {
    {
      int _2657 = _2649->alloci64((int)((sparsity)->size(0)));
      std::shared_ptr< monty::ndarray< long long,1 > > _2658 = mosek::fusion::p_WorkStack::_get_impl(_2649)->i64;
      _checked_ptr_1<long long> _ptr__2658(_2658 ? _2658->raw() : nullptr,_2658 ? _2658->size(0) : 0);
      int _7963 = (int)0;
      int _7964 = (int)((sparsity)->size(0));
      for (int _2659 = _7963; _2659 < _7964; ++_2659)
      {
        {
          _ptr__2658[safe_add( _2657,_2659 )] = ((*sparsity)(_2659));
        }
      }
    }
  }
  {}
  int _2660 = _2649->allocf64((int)((bfix)->size(0)));
  std::shared_ptr< monty::ndarray< double,1 > > _2661 = mosek::fusion::p_WorkStack::_get_impl(_2649)->f64;
  _checked_ptr_1<double> _ptr__2661(_2661 ? _2661->raw() : nullptr,_2661 ? _2661->size(0) : 0);
  int _7965 = (int)0;
  int _7966 = (int)((bfix)->size(0));
  for (int _2662 = _7965; _2662 < _7966; ++_2662)
  {
    {
      _ptr__2661[safe_add( _2660,_2662 )] = ((*bfix)(_2662));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2663 = mosek::fusion::p_WorkStack::_get_impl(_2649)->i32;
  _checked_ptr_1<int> _ptr__2663(_2663 ? _2663->raw() : nullptr,_2663 ? _2663->size(0) : 0);
  int _7967 = (int)0;
  int _7968 = safe_add( _2653,(int)1 );
  for (int _2664 = _7967; _2664 < _7968; ++_2664)
  {
    {
      _ptr__2663[safe_add( _2655,_2664 )] = (int)0;
    }
  }
}
void mosek::fusion::p_ExprConst::validate(std::shared_ptr< monty::ndarray< int,1 > > _2665,std::shared_ptr< monty::ndarray< double,1 > > _2666,std::shared_ptr< monty::ndarray< long long,1 > > _2667){
  _checked_ptr_1<int> _ptr__2665(_2665 ? _2665->raw() : nullptr, _2665 ? _2665->size(0) : 0);
  _checked_ptr_1<double> _ptr__2666(_2666 ? _2666->raw() : nullptr, _2666 ? _2666->size(0) : 0);
  _checked_ptr_1<long long> _ptr__2667(_2667 ? _2667->raw() : nullptr, _2667 ? _2667->size(0) : 0);
  long long _2668 = ::mosek::fusion::p_Set::size(_2665);
  if ((NULL != _2667.get()))
  {
    {
      if (((int)((_2667)->size(0)) != (int)((_2666)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data lengths"));
        }
      }
      {}
      int _7969 = (int)0;
      int _7970 = (int)((_2667)->size(0));
      for (int _2669 = _7969; _2669 < _7970; ++_2669)
      {
        {
          if (((_ptr__2667[_2669] < (int)0) || (_ptr__2667[_2669] >= _2668)))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Invalid sparsity index"));
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_2666)->size(0)) != _2668))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data length"));
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprConst :: toString() { return mosek::fusion::p_ExprConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprConst::toString(){
  return std::string ("ExprConst()");
}
void mosek::fusion::p_ExprConst::destroy(){sparsity.reset();bfix.reset();}void mosek::fusion::ExprConst::destroy() { mosek::fusion::p_ExprConst::_get_impl(this)->destroy(); }mosek::fusion::ExprPick::ExprPick(mosek::fusion::p_ExprPick *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPick()" << this << std::endl; */ }mosek::fusion::ExprPick::~ExprPick() {  /* std::cout << "~ExprPick()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPick::p_ExprPick  (::mosek::fusion::ExprPick * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2670,    std::shared_ptr< monty::ndarray< int,2 > > _2671){ return new mosek::fusion::ExprPick(_2670,_2671); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2670,    std::shared_ptr< monty::ndarray< int,2 > > _2671) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2670,_2671); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2670,    std::shared_ptr< monty::ndarray< int,2 > > _2671){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2671)->size(0)))}));
    std::shared_ptr< monty::ndarray< int,1 > > _2672 = _2670->getShape();
    _checked_ptr_1<int> _ptr__2672(_2672 ? _2672->raw() : nullptr,_2672 ? _2672->size(0) : 0);
    int _2673 = (int)((_2672)->size(0));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2670;
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_2671)->size(0)))));
    std::shared_ptr< monty::ndarray< long long,1 > > _2674 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
    _checked_ptr_1<long long> _ptr__2674(_2674 ? _2674->raw() : nullptr,_2674 ? _2674->size(0) : 0);
    if (((int)((_2671)->size(1)) != _2673))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and index dimensions"));
      }
    }
    {}
    int _7971 = (int)0;
    int _7972 = (int)((_2671)->size(0));
    for (int _2675 = _7971; _2675 < _7972; ++_2675)
    {
      {
        int _7973 = (int)0;
        int _7974 = _2673;
        for (int _2676 = _7973; _2676 < _7974; ++_2676)
        {
          {
            if (((((*_2671)(_2675,_2676)) < (int)0) || (((*_2671)(_2675,_2676)) >= _ptr__2672[_2676])))
            {
              {
                throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
              }
            }
            {}
          }
        }
      }
    }
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2677 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2673)));
      _checked_ptr_1<long long> _ptr__2677(_2677 ? _2677->raw() : nullptr,_2677 ? _2677->size(0) : 0);
      _ptr__2677[(_2673 - (int)1)] = (int)1;
      int _7975 = (int)1;
      int _7976 = _2673;
      for (int _2678 = _7975; _2678 < _7976; ++_2678)
      {
        {
          _ptr__2677[((_2673 - _2678) - (int)1)] = safe_mul( _ptr__2677[(_2673 - _2678)],_ptr__2672[(_2673 - _2678)] );
        }
      }
      int _7977 = (int)0;
      int _7978 = (int)((_2671)->size(0));
      for (int _2679 = _7977; _2679 < _7978; ++_2679)
      {
        {
          long long _2680 = (long long)0;
          int _7979 = (int)0;
          int _7980 = _2673;
          for (int _2681 = _7979; _2681 < _7980; ++_2681)
          {
            {
              _2680 += safe_mul( _ptr__2677[_2681],((*_2671)(_2679,_2681)) );
            }
          }
          _ptr__2674[_2679] = _2680;
        }
      }
    }
  }
}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2682,    std::shared_ptr< monty::ndarray< long long,1 > > _2683){ return new mosek::fusion::ExprPick(_2682,_2683); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2682,    std::shared_ptr< monty::ndarray< long long,1 > > _2683) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2682,_2683); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2682,    std::shared_ptr< monty::ndarray< long long,1 > > _2683){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2683(_2683 ? _2683->raw() : nullptr, _2683 ? _2683->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2683)->size(0)))}));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2682;
    std::shared_ptr< monty::ndarray< int,1 > > _2684 = _2682->getShape();
    _checked_ptr_1<int> _ptr__2684(_2684 ? _2684->raw() : nullptr,_2684 ? _2684->size(0) : 0);
    long long _2685 = ::mosek::fusion::p_Set::size(_2684);
    int _7981 = (int)0;
    int _7982 = (int)((_2683)->size(0));
    for (int _2686 = _7981; _2686 < _7982; ++_2686)
    {
      {
        if (((_ptr__2683[_2686] < (int)0) || (_ptr__2683[_2686] >= _2685)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
          }
        }
        {}
      }
    }
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = ::mosek::fusion::Utils::Tools::arraycopy(_2683);
  }
}void mosek::fusion::ExprPick :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2687,monty::rc_ptr< ::mosek::fusion::WorkStack > _2688,monty::rc_ptr< ::mosek::fusion::WorkStack > _2689) { mosek::fusion::p_ExprPick::_get_impl(this)->eval(_2687,_2688,_2689); }void mosek::fusion::p_ExprPick::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2687,monty::rc_ptr< ::mosek::fusion::WorkStack > _2688,monty::rc_ptr< ::mosek::fusion::WorkStack > _2689){
  expr->eval(_2688,_2687,_2689);
  _2688->pop_expr();
  int _2690 = mosek::fusion::p_WorkStack::_get_impl(_2688)->nd;
  int _2691 = mosek::fusion::p_WorkStack::_get_impl(_2688)->shape_base;
  int _2692 = mosek::fusion::p_WorkStack::_get_impl(_2688)->nelem;
  int _2693 = mosek::fusion::p_WorkStack::_get_impl(_2688)->nnz;
  bool _2694 = mosek::fusion::p_WorkStack::_get_impl(_2688)->hassp;
  int _2695 = mosek::fusion::p_WorkStack::_get_impl(_2688)->ptr_base;
  int _2696 = mosek::fusion::p_WorkStack::_get_impl(_2688)->sp_base;
  int _2697 = mosek::fusion::p_WorkStack::_get_impl(_2688)->nidxs_base;
  int _2698 = mosek::fusion::p_WorkStack::_get_impl(_2688)->bfix_base;
  int _2699 = mosek::fusion::p_WorkStack::_get_impl(_2688)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _2700 = mosek::fusion::p_WorkStack::_get_impl(_2688)->i32;
  _checked_ptr_1<int> _ptr__2700(_2700 ? _2700->raw() : nullptr,_2700 ? _2700->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2701 = mosek::fusion::p_WorkStack::_get_impl(_2688)->i64;
  _checked_ptr_1<long long> _ptr__2701(_2701 ? _2701->raw() : nullptr,_2701 ? _2701->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2702 = mosek::fusion::p_WorkStack::_get_impl(_2688)->f64;
  _checked_ptr_1<double> _ptr__2702(_2702 ? _2702->raw() : nullptr,_2702 ? _2702->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2703 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
  _checked_ptr_1<long long> _ptr__2703(_2703 ? _2703->raw() : nullptr,_2703 ? _2703->size(0) : 0);
  if ((!_2694))
  {
    {
      int _2704 = (int)((_2703)->size(0));
      int _2705 = (int)1;
      int _2706 = (int)0;
      int _7983 = (int)0;
      int _7984 = (int)((_2703)->size(0));
      for (int _2707 = _7983; _2707 < _7984; ++_2707)
      {
        {
          _2706 += (_ptr__2700[safe_add( safe_add( _2695,_ptr__2703[_2707] ),(int)1 )] - _ptr__2700[safe_add( _2695,_ptr__2703[_2707] )]);
        }
      }
      _2687->alloc_expr(_2705,_2704,_2706,false);
      int _2708 = mosek::fusion::p_WorkStack::_get_impl(_2687)->cof_base;
      int _2709 = mosek::fusion::p_WorkStack::_get_impl(_2687)->bfix_base;
      int _2710 = mosek::fusion::p_WorkStack::_get_impl(_2687)->nidxs_base;
      int _2711 = mosek::fusion::p_WorkStack::_get_impl(_2687)->ptr_base;
      int _2712 = mosek::fusion::p_WorkStack::_get_impl(_2687)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2713 = mosek::fusion::p_WorkStack::_get_impl(_2687)->i32;
      _checked_ptr_1<int> _ptr__2713(_2713 ? _2713->raw() : nullptr,_2713 ? _2713->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2714 = mosek::fusion::p_WorkStack::_get_impl(_2687)->i64;
      _checked_ptr_1<long long> _ptr__2714(_2714 ? _2714->raw() : nullptr,_2714 ? _2714->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2715 = mosek::fusion::p_WorkStack::_get_impl(_2687)->f64;
      _checked_ptr_1<double> _ptr__2715(_2715 ? _2715->raw() : nullptr,_2715 ? _2715->size(0) : 0);
      _ptr__2713[_2712] = (int)((_2703)->size(0));
      int _2716 = (int)0;
      _ptr__2713[_2711] = (int)0;
      int _7985 = (int)0;
      int _7986 = (int)((_2703)->size(0));
      for (int _2717 = _7985; _2717 < _7986; ++_2717)
      {
        {
          int _7987 = _ptr__2700[safe_add( _2695,_ptr__2703[_2717] )];
          int _7988 = _ptr__2700[safe_add( safe_add( _2695,_ptr__2703[_2717] ),(int)1 )];
          for (int _2718 = _7987; _2718 < _7988; ++_2718)
          {
            {
              _ptr__2714[safe_add( _2710,_2716 )] = _ptr__2701[safe_add( _2697,_2718 )];
              _ptr__2715[safe_add( _2708,_2716 )] = _ptr__2702[safe_add( _2699,_2718 )];
              ++ _2716;
            }
          }
          _ptr__2715[safe_add( _2709,_2717 )] = _ptr__2702[safe_add( _2698,_ptr__2703[_2717] )];
          _ptr__2713[safe_add( safe_add( _2711,_2717 ),(int)1 )] = _2716;
        }
      }
    }
  }
  else
  {
    {
      int _2719 = (int)1;
      int _2720 = (int)((_2703)->size(0));
      int _2721 = (int)0;
      std::shared_ptr< monty::ndarray< long long,1 > > _2722 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
      _checked_ptr_1<long long> _ptr__2722(_2722 ? _2722->raw() : nullptr,_2722 ? _2722->size(0) : 0);
      int _2723 = _2689->alloci32((int)((_2722)->size(0)));
      std::shared_ptr< monty::ndarray< int,1 > > _2724 = mosek::fusion::p_WorkStack::_get_impl(_2689)->i32;
      _checked_ptr_1<int> _ptr__2724(_2724 ? _2724->raw() : nullptr,_2724 ? _2724->size(0) : 0);
      int _7989 = (int)0;
      int _7990 = (int)((_2722)->size(0));
      for (int _2725 = _7989; _2725 < _7990; ++_2725)
      {
        {
          int _2726 = _2692;
          int _2727 = (int)0;
          while ( (_2727 < (_2726 - (int)1)) )
          {
            {
              int _2728 = (safe_add( safe_add( _2726,_2727 ),(int)1 ) / (int)2);
              if ((_ptr__2701[safe_add( _2696,_2728 )] >= _ptr__2722[_2725]))
              {
                {
                  _2726 = _2728;
                }
              }
              else
              {
                {
                  _2727 = _2728;
                }
              }
            }
          }
          ++ _2727;
          if (((_2727 < _2692) && (_ptr__2701[safe_add( _2696,_2727 )] == _ptr__2722[_2725])))
          {
            {
              _ptr__2724[safe_add( _2723,_2725 )] = _2727;
              _2721 += (_ptr__2700[safe_add( safe_add( _2695,_2727 ),(int)1 )] - _ptr__2700[safe_add( _2695,_2727 )]);
            }
          }
          else
          {
            {
              _ptr__2724[safe_add( _2723,_2725 )] = (-(int)1);
            }
          }
        }
      }
      _2687->alloc_expr(_2719,_2720,_2721,false);
      int _2729 = mosek::fusion::p_WorkStack::_get_impl(_2687)->ptr_base;
      int _2730 = mosek::fusion::p_WorkStack::_get_impl(_2687)->nidxs_base;
      int _2731 = mosek::fusion::p_WorkStack::_get_impl(_2687)->cof_base;
      int _2732 = mosek::fusion::p_WorkStack::_get_impl(_2687)->bfix_base;
      int _2733 = mosek::fusion::p_WorkStack::_get_impl(_2687)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2734 = mosek::fusion::p_WorkStack::_get_impl(_2687)->i32;
      _checked_ptr_1<int> _ptr__2734(_2734 ? _2734->raw() : nullptr,_2734 ? _2734->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2735 = mosek::fusion::p_WorkStack::_get_impl(_2687)->i64;
      _checked_ptr_1<long long> _ptr__2735(_2735 ? _2735->raw() : nullptr,_2735 ? _2735->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2736 = mosek::fusion::p_WorkStack::_get_impl(_2687)->f64;
      _checked_ptr_1<double> _ptr__2736(_2736 ? _2736->raw() : nullptr,_2736 ? _2736->size(0) : 0);
      _ptr__2734[_2733] = (int)((_2722)->size(0));
      _ptr__2734[_2729] = (int)0;
      int _2737 = (int)0;
      int _7991 = (int)0;
      int _7992 = (int)((_2722)->size(0));
      for (int _2738 = _7991; _2738 < _7992; ++_2738)
      {
        {
          if ((_ptr__2724[safe_add( _2723,_2738 )] >= (int)0))
          {
            {
              int _2739 = _ptr__2724[safe_add( _2723,_2738 )];
              int _7993 = _ptr__2700[safe_add( _2695,_2739 )];
              int _7994 = _ptr__2700[safe_add( safe_add( _2695,_2739 ),(int)1 )];
              for (int _2740 = _7993; _2740 < _7994; ++_2740)
              {
                {
                  _ptr__2735[safe_add( _2730,_2737 )] = _ptr__2701[safe_add( _2697,_2740 )];
                  _ptr__2736[safe_add( _2731,_2737 )] = _ptr__2702[safe_add( _2699,_2740 )];
                  ++ _2737;
                }
              }
              _ptr__2736[safe_add( _2732,_2738 )] = _ptr__2702[safe_add( _2698,_2739 )];
            }
          }
          else
          {
            {
              _ptr__2736[safe_add( _2732,_2738 )] = 0.0;
            }
          }
          _ptr__2734[safe_add( safe_add( _2729,_2738 ),(int)1 )] = _2737;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprPick :: toString() { return mosek::fusion::p_ExprPick::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprPick::toString(){
  return std::string ("ExprPick()");
}
void mosek::fusion::p_ExprPick::destroy(){idxs.reset();expr.reset();}void mosek::fusion::ExprPick::destroy() { mosek::fusion::p_ExprPick::_get_impl(this)->destroy(); }mosek::fusion::ExprSlice::ExprSlice(mosek::fusion::p_ExprSlice *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSlice()" << this << std::endl; */ }mosek::fusion::ExprSlice::~ExprSlice() {  /* std::cout << "~ExprSlice()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSlice::p_ExprSlice  (::mosek::fusion::ExprSlice * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSlice::t mosek::fusion::p_ExprSlice::_new_ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2741,    std::shared_ptr< monty::ndarray< int,1 > > _2742,    std::shared_ptr< monty::ndarray< int,1 > > _2743){ return new mosek::fusion::ExprSlice(_2741,_2742,_2743); }mosek::fusion::ExprSlice::ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2741,    std::shared_ptr< monty::ndarray< int,1 > > _2742,    std::shared_ptr< monty::ndarray< int,1 > > _2743) :    ExprSlice(new mosek::fusion::p_ExprSlice(this)){ mosek::fusion::p_ExprSlice::_get_impl(this)->_initialize(_2741,_2742,_2743); }void mosek::fusion::p_ExprSlice::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2741,    std::shared_ptr< monty::ndarray< int,1 > > _2742,    std::shared_ptr< monty::ndarray< int,1 > > _2743){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2742(_2742 ? _2742->raw() : nullptr, _2742 ? _2742->size(0) : 0);
    _checked_ptr_1<int> _ptr__2743(_2743 ? _2743->raw() : nullptr, _2743 ? _2743->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSlice::makeShape(_2741->getShape(),_2742,_2743));
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->expr = _2741;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->first = _2742;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->last = _2743;
  }
}void mosek::fusion::ExprSlice :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2744,monty::rc_ptr< ::mosek::fusion::WorkStack > _2745,monty::rc_ptr< ::mosek::fusion::WorkStack > _2746) { mosek::fusion::p_ExprSlice::_get_impl(this)->eval(_2744,_2745,_2746); }void mosek::fusion::p_ExprSlice::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2744,monty::rc_ptr< ::mosek::fusion::WorkStack > _2745,monty::rc_ptr< ::mosek::fusion::WorkStack > _2746){
  expr->eval(_2745,_2744,_2746);
  int _2747 = _2745->popi32();
  int _2748 = _2745->popi32(_2747);
  int _2749 = _2745->popi32();
  int _2750 = _2745->popi32();
  bool _2751 = (_2745->popi32() != (int)0);
  int _2752 = _2745->popi32(safe_add( _2749,(int)1 ));
  int _7995;
  bool _7996 = _2751;
  if (_7996)
  {
    _7995 = _2745->popi64(_2749);
  }
  else
  {
    _7995 = (-(int)1);
  }
  int _2753 = _7995;
  int _2754 = _2745->popi64(_2750);
  int _2755 = _2745->popf64(_2749);
  int _2756 = _2745->popf64(_2750);
  std::shared_ptr< monty::ndarray< int,1 > > _2757 = mosek::fusion::p_WorkStack::_get_impl(_2745)->i32;
  _checked_ptr_1<int> _ptr__2757(_2757 ? _2757->raw() : nullptr,_2757 ? _2757->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2758 = mosek::fusion::p_WorkStack::_get_impl(_2745)->i64;
  _checked_ptr_1<long long> _ptr__2758(_2758 ? _2758->raw() : nullptr,_2758 ? _2758->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2759 = mosek::fusion::p_WorkStack::_get_impl(_2745)->f64;
  _checked_ptr_1<double> _ptr__2759(_2759 ? _2759->raw() : nullptr,_2759 ? _2759->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2760 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2747)));
  _checked_ptr_1<long long> _ptr__2760(_2760 ? _2760->raw() : nullptr,_2760 ? _2760->size(0) : 0);
  _ptr__2760[(_2747 - (int)1)] = (int)1;
  int _7997 = (int)1;
  int _7998 = _2747;
  for (int _2761 = _7997; _2761 < _7998; ++_2761)
  {
    {
      _ptr__2760[((_2747 - _2761) - (int)1)] = safe_mul( _ptr__2760[(_2747 - _2761)],_ptr__2757[(safe_add( _2748,_2747 ) - _2761)] );
    }
  }
  int _2762 = (int)0;
  int _2763 = (int)0;
  if (_2751)
  {
    {
      int _7999 = (int)0;
      int _8000 = _2749;
      for (int _2764 = _7999; _2764 < _8000; ++_2764)
      {
        {
          bool _2765 = true;
          int _8001 = (int)0;
          int _8002 = _2747;
          for (int _2766 = _8001; _2766 < _8002; ++_2766)
          {
            {
              long long _2767 = ((_ptr__2758[safe_add( _2753,_2764 )] / _ptr__2760[_2766]) % _ptr__2757[safe_add( _2748,_2766 )]);
              _2765 = (_2765 && ((_2767 >= ((*first)(_2766))) && (_2767 < ((*last)(_2766)))));
            }
          }
          if (_2765)
          {
            {
              _2763 += (_ptr__2757[safe_add( safe_add( _2752,_2764 ),(int)1 )] - _ptr__2757[safe_add( _2752,_2764 )]);
              ++ _2762;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      _2762 = (int)1;
      int _8003 = (int)0;
      int _8004 = _2747;
      for (int _2768 = _8003; _2768 < _8004; ++_2768)
      {
        {
          _2762 *= (((*last)(_2768)) - ((*first)(_2768)));
        }
      }
      int _8005 = (int)0;
      int _8006 = _2749;
      for (int _2769 = _8005; _2769 < _8006; ++_2769)
      {
        {
          bool _2770 = true;
          int _8007 = (int)0;
          int _8008 = _2747;
          for (int _2771 = _8007; _2771 < _8008; ++_2771)
          {
            {
              long long _2772 = ((_2769 / _ptr__2760[_2771]) % _ptr__2757[safe_add( _2748,_2771 )]);
              _2770 = (_2770 && ((_2772 >= ((*first)(_2771))) && (_2772 < ((*last)(_2771)))));
            }
          }
          if (_2770)
          {
            {
              _2763 += (_ptr__2757[safe_add( safe_add( _2752,_2769 ),(int)1 )] - _ptr__2757[safe_add( _2752,_2769 )]);
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _8009;
  for (int _2774 = (int)0, _8010 = _2747; _2774 < _8010 ; ++_2774)
  {
    _8009.push_back((((*last)(_2774)) - ((*first)(_2774))));
  }
  auto _8011 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8009.size()),_8009.begin(),_8009.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _2773 = _8011;
  _checked_ptr_1<int> _ptr__2773(_2773 ? _2773->raw() : nullptr,_2773 ? _2773->size(0) : 0);
  int _2775 = _2744->allocf64(_2763);
  int _2776 = _2744->allocf64(_2762);
  int _2777 = _2744->alloci64(_2763);
  int _8012;
  bool _8013 = _2751;
  if (_8013)
  {
    _8012 = _2744->alloci64(_2762);
  }
  else
  {
    _8012 = (-(int)1);
  }
  int _2778 = _8012;
  int _2779 = _2744->alloci32(safe_add( _2762,(int)1 ));
  int _8014;
  bool _8015 = _2751;
  if (_8015)
  {
    _8014 = (int)1;
  }
  else
  {
    _8014 = (int)0;
  }
  _2744->pushi32(_8014);
  _2744->pushi32(_2763);
  _2744->pushi32(_2762);
  int _8016 = (int)0;
  int _8017 = _2747;
  for (int _2780 = _8016; _2780 < _8017; ++_2780)
  {
    {
      _2744->pushi32(_ptr__2773[_2780]);
    }
  }
  _2744->pushi32(_2747);
  std::shared_ptr< monty::ndarray< int,1 > > _2781 = mosek::fusion::p_WorkStack::_get_impl(_2744)->i32;
  _checked_ptr_1<int> _ptr__2781(_2781 ? _2781->raw() : nullptr,_2781 ? _2781->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2782 = mosek::fusion::p_WorkStack::_get_impl(_2744)->i64;
  _checked_ptr_1<long long> _ptr__2782(_2782 ? _2782->raw() : nullptr,_2782 ? _2782->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2783 = mosek::fusion::p_WorkStack::_get_impl(_2744)->f64;
  _checked_ptr_1<double> _ptr__2783(_2783 ? _2783->raw() : nullptr,_2783 ? _2783->size(0) : 0);
  _ptr__2781[_2779] = (int)0;
  std::shared_ptr< monty::ndarray< long long,1 > > _2784 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2747)));
  _checked_ptr_1<long long> _ptr__2784(_2784 ? _2784->raw() : nullptr,_2784 ? _2784->size(0) : 0);
  _ptr__2784[(_2747 - (int)1)] = (int)1;
  int _8018 = (int)1;
  int _8019 = _2747;
  for (int _2785 = _8018; _2785 < _8019; ++_2785)
  {
    {
      _ptr__2784[((_2747 - _2785) - (int)1)] = safe_mul( _ptr__2784[(_2747 - _2785)],_ptr__2773[(_2747 - _2785)] );
    }
  }
  int _2786 = (int)0;
  int _2787 = (int)0;
  if (_2751)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2788 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2747)));
      _checked_ptr_1<int> _ptr__2788(_2788 ? _2788->raw() : nullptr,_2788 ? _2788->size(0) : 0);
      int _8020 = (int)0;
      int _8021 = _2749;
      for (int _2789 = _8020; _2789 < _8021; ++_2789)
      {
        {
          bool _2790 = true;
          int _8022 = (int)0;
          int _8023 = _2747;
          for (int _2791 = _8022; _2791 < _8023; ++_2791)
          {
            {
              _ptr__2788[_2791] = (int)((_ptr__2758[safe_add( _2753,_2789 )] / _ptr__2760[_2791]) % _ptr__2757[safe_add( _2748,_2791 )]);
              _2790 = (_2790 && ((_ptr__2788[_2791] >= ((*first)(_2791))) && (_ptr__2788[_2791] < ((*last)(_2791)))));
            }
          }
          if (_2790)
          {
            {
              int _8024 = _ptr__2757[safe_add( _2752,_2789 )];
              int _8025 = _ptr__2757[safe_add( safe_add( _2752,_2789 ),(int)1 )];
              for (int _2792 = _8024; _2792 < _8025; ++_2792)
              {
                {
                  _ptr__2782[safe_add( _2777,_2787 )] = _ptr__2758[safe_add( _2754,_2792 )];
                  _ptr__2783[safe_add( _2775,_2787 )] = _ptr__2759[safe_add( _2756,_2792 )];
                  ++ _2787;
                }
              }
              long long _2793 = (long long)0;
              int _8026 = (int)0;
              int _8027 = _2747;
              for (int _2794 = _8026; _2794 < _8027; ++_2794)
              {
                {
                  _2793 += safe_mul( _ptr__2784[_2794],(_ptr__2788[_2794] - ((*first)(_2794))) );
                }
              }
              _ptr__2782[safe_add( _2778,_2786 )] = _2793;
              _ptr__2783[safe_add( _2776,_2786 )] = _ptr__2759[safe_add( _2755,_2789 )];
              _ptr__2781[safe_add( safe_add( _2779,_2786 ),(int)1 )] = _2787;
              ++ _2786;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _8028 = (int)0;
      int _8029 = _2749;
      for (int _2795 = _8028; _2795 < _8029; ++_2795)
      {
        {
          bool _2796 = true;
          int _8030 = (int)0;
          int _8031 = _2747;
          for (int _2797 = _8030; _2797 < _8031; ++_2797)
          {
            {
              long long _2798 = ((_2795 / _ptr__2760[_2797]) % _ptr__2757[safe_add( _2748,_2797 )]);
              _2796 = (_2796 && ((_2798 >= ((*first)(_2797))) && (_2798 < ((*last)(_2797)))));
            }
          }
          if (_2796)
          {
            {
              int _8032 = _ptr__2757[safe_add( _2752,_2795 )];
              int _8033 = _ptr__2757[safe_add( safe_add( _2752,_2795 ),(int)1 )];
              for (int _2799 = _8032; _2799 < _8033; ++_2799)
              {
                {
                  _ptr__2782[safe_add( _2777,_2787 )] = _ptr__2758[safe_add( _2754,_2799 )];
                  _ptr__2783[safe_add( _2775,_2787 )] = _ptr__2759[safe_add( _2756,_2799 )];
                  ++ _2787;
                }
              }
              _ptr__2783[safe_add( _2776,_2786 )] = _ptr__2759[safe_add( _2755,_2795 )];
              _ptr__2781[safe_add( safe_add( _2779,_2786 ),(int)1 )] = _2787;
              ++ _2786;
            }
          }
          {}
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSlice::makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2800,std::shared_ptr< monty::ndarray< int,1 > > _2801,std::shared_ptr< monty::ndarray< int,1 > > _2802){
  _checked_ptr_1<int> _ptr__2800(_2800 ? _2800->raw() : nullptr, _2800 ? _2800->size(0) : 0);
  _checked_ptr_1<int> _ptr__2801(_2801 ? _2801->raw() : nullptr, _2801 ? _2801->size(0) : 0);
  _checked_ptr_1<int> _ptr__2802(_2802 ? _2802->raw() : nullptr, _2802 ? _2802->size(0) : 0);
  if ((((int)((_2800)->size(0)) != (int)((_2801)->size(0))) || ((int)((_2800)->size(0)) != (int)((_2802)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid or mismatching index lengths"));
    }
  }
  {}
  int _8034 = (int)0;
  int _8035 = (int)((_2800)->size(0));
  for (int _2803 = _8034; _2803 < _8035; ++_2803)
  {
    {
      if (((_ptr__2801[_2803] < (int)0) || ((_ptr__2802[_2803] < _ptr__2801[_2803]) || (_ptr__2802[_2803] > _ptr__2800[_2803]))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _8036;
  for (int _2804 = (int)0, _8037 = (int)((_2800)->size(0)); _2804 < _8037 ; ++_2804)
  {
    _8036.push_back((_ptr__2802[_2804] - _ptr__2801[_2804]));
  }
  auto _8038 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8036.size()),_8036.begin(),_8036.end()));
  return _8038;
}
std::string mosek::fusion::ExprSlice :: toString() { return mosek::fusion::p_ExprSlice::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSlice::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2805 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprSlice(["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)((int)0)));
  int _8039 = (int)1;
  int _8040 = (int)((first)->size(0));
  for (int _2806 = _8039; _2806 < _8040; ++_2806)
  {
    {
      _2805->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)(_2806)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)(_2806)));
    }
  }
  _2805->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("],"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _2805->toString();
}
void mosek::fusion::p_ExprSlice::destroy(){last.reset();first.reset();expr.reset();}void mosek::fusion::ExprSlice::destroy() { mosek::fusion::p_ExprSlice::_get_impl(this)->destroy(); }mosek::fusion::ExprPermuteDims::ExprPermuteDims(mosek::fusion::p_ExprPermuteDims *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPermuteDims()" << this << std::endl; */ }mosek::fusion::ExprPermuteDims::~ExprPermuteDims() {  /* std::cout << "~ExprPermuteDims()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPermuteDims::p_ExprPermuteDims  (::mosek::fusion::ExprPermuteDims * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2807,    monty::rc_ptr< ::mosek::fusion::Expression > _2808){ return new mosek::fusion::ExprPermuteDims(_2807,_2808); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2807,    monty::rc_ptr< ::mosek::fusion::Expression > _2808) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2807,_2808); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2807,    monty::rc_ptr< ::mosek::fusion::Expression > _2808){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2807(_2807 ? _2807->raw() : nullptr, _2807 ? _2807->size(0) : 0);
    mosek::fusion::p_ExprPermuteDims::_initialize(_2807,_2808,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _2809 = _2808->getShape();
    _checked_ptr_1<int> _ptr__2809(_2809 ? _2809->raw() : nullptr,_2809 ? _2809->size(0) : 0);
    if (((int)((_2807)->size(0)) != (int)((_2809)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
      }
    }
    {}
    std::vector<int> _8041;
    for (int _2811 = (int)0, _8042 = (int)((_2807)->size(0)); _2811 < _8042 ; ++_2811)
    {
      _8041.push_back((int)0);
    }
    auto _8043 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8041.size()),_8041.begin(),_8041.end()));
    std::shared_ptr< monty::ndarray< int,1 > > _2810 = _8043;
    _checked_ptr_1<int> _ptr__2810(_2810 ? _2810->raw() : nullptr,_2810 ? _2810->size(0) : 0);
    int _8044 = (int)0;
    int _8045 = (int)((_2810)->size(0));
    for (int _2812 = _8044; _2812 < _8045; ++_2812)
    {
      {
        if (((_ptr__2807[_2812] < (int)0) || (_ptr__2807[_2812] > (int)((_2809)->size(0)))))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
        ++ _ptr__2810[_ptr__2807[_2812]];
      }
    }
    int _8046 = (int)0;
    int _8047 = (int)((_2810)->size(0));
    for (int _2813 = _8046; _2813 < _8047; ++_2813)
    {
      {
        if (((_ptr__2810[_2813] < (int)1) || (_ptr__2810[_2813] > (int)1)))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2814,    monty::rc_ptr< ::mosek::fusion::Expression > _2815,    int _2816){ return new mosek::fusion::ExprPermuteDims(_2814,_2815,_2816); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2814,    monty::rc_ptr< ::mosek::fusion::Expression > _2815,    int _2816) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2814,_2815,_2816); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2814,    monty::rc_ptr< ::mosek::fusion::Expression > _2815,    int _2816){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2814(_2814 ? _2814->raw() : nullptr, _2814 ? _2814->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprPermuteDims::computeshape(_2814,_2815->getShape()));
    mosek::fusion::p_ExprPermuteDims::_get_impl(::mosek::fusion::ExprPermuteDims::t(_pubthis))->expr = _2815;
    dperm = ::mosek::fusion::Utils::Tools::arraycopy(_2814);
  }
}void mosek::fusion::ExprPermuteDims :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2817,monty::rc_ptr< ::mosek::fusion::WorkStack > _2818,monty::rc_ptr< ::mosek::fusion::WorkStack > _2819) { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->eval(_2817,_2818,_2819); }void mosek::fusion::p_ExprPermuteDims::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2817,monty::rc_ptr< ::mosek::fusion::WorkStack > _2818,monty::rc_ptr< ::mosek::fusion::WorkStack > _2819){
  expr->eval(_2818,_2817,_2819);
  int _2820 = _2818->popi32();
  int _2821 = _2818->popi32(_2820);
  std::shared_ptr< monty::ndarray< long long,1 > > _2822 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2820)));
  _checked_ptr_1<long long> _ptr__2822(_2822 ? _2822->raw() : nullptr,_2822 ? _2822->size(0) : 0);
  _ptr__2822[(_2820 - (int)1)] = (int)1;
  int _8048 = (int)1;
  int _8049 = _2820;
  for (int _2823 = _8048; _2823 < _8049; ++_2823)
  {
    {
      _ptr__2822[((_2820 - _2823) - (int)1)] = safe_mul( _ptr__2822[(_2820 - _2823)],((*mosek::fusion::p_WorkStack::_get_impl(_2818)->i32)((safe_add( _2821,_2820 ) - _2823))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2824 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2820)));
  _checked_ptr_1<int> _ptr__2824(_2824 ? _2824->raw() : nullptr,_2824 ? _2824->size(0) : 0);
  _ptr__2824[(_2820 - (int)1)] = (int)1;
  int _8050 = (int)1;
  int _8051 = _2820;
  for (int _2825 = _8050; _2825 < _8051; ++_2825)
  {
    {
      _ptr__2824[((_2820 - _2825) - (int)1)] = safe_mul( _ptr__2824[(_2820 - _2825)],((*mosek::fusion::p_WorkStack::_get_impl(_2818)->i32)(safe_add( _2821,((*dperm)((_2820 - _2825))) ))) );
    }
  }
  int _2826 = _2818->popi32();
  int _2827 = _2818->popi32();
  bool _2828 = (_2818->popi32() != (int)0);
  int _2829 = _2818->popi32(safe_add( _2826,(int)1 ));
  int _8052;
  bool _8053 = (!_2828);
  if (_8053)
  {
    _8052 = (-(int)1);
  }
  else
  {
    _8052 = _2818->popi64(_2826);
  }
  int _2830 = _8052;
  int _2831 = _2818->popi64(_2827);
  int _2832 = _2818->popf64(_2826);
  int _2833 = _2818->popf64(_2827);
  std::shared_ptr< monty::ndarray< int,1 > > _2834 = mosek::fusion::p_WorkStack::_get_impl(_2818)->i32;
  _checked_ptr_1<int> _ptr__2834(_2834 ? _2834->raw() : nullptr,_2834 ? _2834->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2835 = mosek::fusion::p_WorkStack::_get_impl(_2818)->i64;
  _checked_ptr_1<long long> _ptr__2835(_2835 ? _2835->raw() : nullptr,_2835 ? _2835->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2836 = mosek::fusion::p_WorkStack::_get_impl(_2818)->f64;
  _checked_ptr_1<double> _ptr__2836(_2836 ? _2836->raw() : nullptr,_2836 ? _2836->size(0) : 0);
  if (_2828)
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2837 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2826)));
      _checked_ptr_1<long long> _ptr__2837(_2837 ? _2837->raw() : nullptr,_2837 ? _2837->size(0) : 0);
      {
        int _8054 = (int)0;
        int _8055 = _2826;
        for (int _2838 = _8054; _2838 < _8055; ++_2838)
        {
          {
            long long _2839 = (long long)0;
            int _8056 = (int)0;
            int _8057 = _2820;
            for (int _2840 = _8056; _2840 < _8057; ++_2840)
            {
              {
                _2839 += safe_mul( ((_ptr__2835[safe_add( _2830,_2838 )] / _ptr__2822[_2840]) % _ptr__2834[safe_add( _2821,_2840 )]),_ptr__2824[((*dperm)(_2840))] );
              }
            }
            _ptr__2837[_2838] = _2839;
          }
        }
      }
      std::vector<long long> _8058;
      for (int _2842 = (int)0, _8059 = _2826; _2842 < _8059 ; ++_2842)
      {
        _8058.push_back(_2842);
      }
      auto _8060 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8058.size()),_8058.begin(),_8058.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _2841 = _8060;
      _checked_ptr_1<long long> _ptr__2841(_2841 ? _2841->raw() : nullptr,_2841 ? _2841->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2841,_2837,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2826));
      int _2843 = _2817->alloci32(safe_add( _2826,(int)1 ));
      int _2844 = _2817->alloci64(_2827);
      int _2845 = _2817->alloci64(_2826);
      int _2846 = _2817->allocf64(_2827);
      int _2847 = _2817->allocf64(_2826);
      _2817->pushi32((int)1);
      _2817->pushi32(_2827);
      _2817->pushi32(_2826);
      int _8061 = (int)0;
      int _8062 = _2820;
      for (int _2848 = _8061; _2848 < _8062; ++_2848)
      {
        {
          _2817->pushi32(_ptr__2834[safe_add( _2821,((*dperm)(_2848)) )]);
        }
      }
      _2817->pushi32(_2820);
      std::shared_ptr< monty::ndarray< int,1 > > _2849 = mosek::fusion::p_WorkStack::_get_impl(_2817)->i32;
      _checked_ptr_1<int> _ptr__2849(_2849 ? _2849->raw() : nullptr,_2849 ? _2849->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2850 = mosek::fusion::p_WorkStack::_get_impl(_2817)->i64;
      _checked_ptr_1<long long> _ptr__2850(_2850 ? _2850->raw() : nullptr,_2850 ? _2850->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2851 = mosek::fusion::p_WorkStack::_get_impl(_2817)->f64;
      _checked_ptr_1<double> _ptr__2851(_2851 ? _2851->raw() : nullptr,_2851 ? _2851->size(0) : 0);
      _ptr__2849[_2843] = (int)0;
      int _2852 = (int)0;
      int _2853 = (int)0;
      int _8063 = (int)0;
      int _8064 = _2826;
      for (int _2854 = _8063; _2854 < _8064; ++_2854)
      {
        {
          long long _2855 = _ptr__2841[_2854];
          int _8065 = _ptr__2834[safe_add( _2829,_2855 )];
          int _8066 = _ptr__2834[safe_add( safe_add( _2829,_2855 ),(int)1 )];
          for (int _2856 = _8065; _2856 < _8066; ++_2856)
          {
            {
              _ptr__2850[safe_add( _2844,_2853 )] = _ptr__2835[safe_add( _2831,_2856 )];
              _ptr__2851[safe_add( _2846,_2853 )] = _ptr__2836[safe_add( _2833,_2856 )];
              ++ _2853;
            }
          }
          _ptr__2850[safe_add( _2845,_2854 )] = _ptr__2837[_2855];
          _ptr__2851[safe_add( _2847,_2854 )] = _ptr__2836[safe_add( _2832,_2855 )];
          ++ _2852;
          _ptr__2849[safe_add( safe_add( _2843,_2854 ),(int)1 )] = _2853;
        }
      }
    }
  }
  else
  {
    {
      int _2857 = _2817->alloci32(safe_add( _2826,(int)1 ));
      int _2858 = _2817->alloci64(_2827);
      int _2859 = _2817->allocf64(_2827);
      int _2860 = _2817->allocf64(_2826);
      _2817->pushi32((int)0);
      _2817->pushi32(_2827);
      _2817->pushi32(_2826);
      int _8067 = (int)0;
      int _8068 = _2820;
      for (int _2861 = _8067; _2861 < _8068; ++_2861)
      {
        {
          _2817->pushi32(_ptr__2834[safe_add( _2821,((*dperm)(_2861)) )]);
        }
      }
      _2817->pushi32(_2820);
      std::shared_ptr< monty::ndarray< int,1 > > _2862 = mosek::fusion::p_WorkStack::_get_impl(_2817)->i32;
      _checked_ptr_1<int> _ptr__2862(_2862 ? _2862->raw() : nullptr,_2862 ? _2862->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2863 = mosek::fusion::p_WorkStack::_get_impl(_2817)->i64;
      _checked_ptr_1<long long> _ptr__2863(_2863 ? _2863->raw() : nullptr,_2863 ? _2863->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2864 = mosek::fusion::p_WorkStack::_get_impl(_2817)->f64;
      _checked_ptr_1<double> _ptr__2864(_2864 ? _2864->raw() : nullptr,_2864 ? _2864->size(0) : 0);
      _ptr__2862[_2857] = (int)0;
      int _2865 = (int)0;
      int _2866 = (int)0;
      int _8069 = (int)0;
      int _8070 = _2826;
      for (int _2867 = _8069; _2867 < _8070; ++_2867)
      {
        {
          long long _2868 = (long long)0;
          int _8071 = (int)0;
          int _8072 = _2820;
          for (int _2869 = _8071; _2869 < _8072; ++_2869)
          {
            {
              _2868 += safe_mul( ((_2867 / _ptr__2822[((*dperm)(_2869))]) % _ptr__2834[safe_add( _2821,((*dperm)(_2869)) )]),_ptr__2824[_2869] );
            }
          }
          int _8073 = _ptr__2834[safe_add( _2829,_2868 )];
          int _8074 = _ptr__2834[safe_add( safe_add( _2829,_2868 ),(int)1 )];
          for (int _2870 = _8073; _2870 < _8074; ++_2870)
          {
            {
              _ptr__2863[safe_add( _2858,_2866 )] = _ptr__2835[safe_add( _2831,_2870 )];
              _ptr__2864[safe_add( _2859,_2866 )] = _ptr__2836[safe_add( _2833,_2870 )];
              ++ _2866;
            }
          }
          _ptr__2864[safe_add( _2860,_2865 )] = _ptr__2836[safe_add( _2832,_2868 )];
          ++ _2865;
          _ptr__2862[safe_add( _2857,_2865 )] = _2866;
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprPermuteDims::computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2871,std::shared_ptr< monty::ndarray< int,1 > > _2872){
  _checked_ptr_1<int> _ptr__2871(_2871 ? _2871->raw() : nullptr, _2871 ? _2871->size(0) : 0);
  _checked_ptr_1<int> _ptr__2872(_2872 ? _2872->raw() : nullptr, _2872 ? _2872->size(0) : 0);
  std::vector<int> _8075;
  for (int _2873 = (int)0, _8076 = (int)((_2871)->size(0)); _2873 < _8076 ; ++_2873)
  {
    _8075.push_back(_ptr__2872[_ptr__2871[_2873]]);
  }
  auto _8077 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8075.size()),_8075.begin(),_8075.end()));
  return _8077;
}
void mosek::fusion::p_ExprPermuteDims::destroy(){dperm.reset();expr.reset();}void mosek::fusion::ExprPermuteDims::destroy() { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->destroy(); }mosek::fusion::ExprTranspose::ExprTranspose(mosek::fusion::p_ExprTranspose *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprTranspose()" << this << std::endl; */ }mosek::fusion::ExprTranspose::~ExprTranspose() {  /* std::cout << "~ExprTranspose()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprTranspose::p_ExprTranspose  (::mosek::fusion::ExprTranspose * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprTranspose::t mosek::fusion::p_ExprTranspose::_new_ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2874){ return new mosek::fusion::ExprTranspose(_2874); }mosek::fusion::ExprTranspose::ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2874) :    ExprTranspose(new mosek::fusion::p_ExprTranspose(this)){ mosek::fusion::p_ExprTranspose::_get_impl(this)->_initialize(_2874); }void mosek::fusion::p_ExprTranspose::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2874){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprTranspose::transposeShape(_2874->getShape()));
    mosek::fusion::p_ExprTranspose::_get_impl(::mosek::fusion::ExprTranspose::t(_pubthis))->expr = _2874;
  }
}void mosek::fusion::ExprTranspose :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2875,monty::rc_ptr< ::mosek::fusion::WorkStack > _2876,monty::rc_ptr< ::mosek::fusion::WorkStack > _2877) { mosek::fusion::p_ExprTranspose::_get_impl(this)->eval(_2875,_2876,_2877); }void mosek::fusion::p_ExprTranspose::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2875,monty::rc_ptr< ::mosek::fusion::WorkStack > _2876,monty::rc_ptr< ::mosek::fusion::WorkStack > _2877){
  expr->eval(_2876,_2875,_2877);
  _2876->pop_expr();
  if ((mosek::fusion::p_WorkStack::_get_impl(_2876)->nd != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      int _2878 = mosek::fusion::p_WorkStack::_get_impl(_2876)->shape_base;
      int _2879 = mosek::fusion::p_WorkStack::_get_impl(_2876)->nelem;
      int _2880 = mosek::fusion::p_WorkStack::_get_impl(_2876)->nnz;
      bool _2881 = mosek::fusion::p_WorkStack::_get_impl(_2876)->hassp;
      int _2882 = mosek::fusion::p_WorkStack::_get_impl(_2876)->ptr_base;
      int _2883 = mosek::fusion::p_WorkStack::_get_impl(_2876)->sp_base;
      int _2884 = mosek::fusion::p_WorkStack::_get_impl(_2876)->nidxs_base;
      int _2885 = mosek::fusion::p_WorkStack::_get_impl(_2876)->bfix_base;
      int _2886 = mosek::fusion::p_WorkStack::_get_impl(_2876)->cof_base;
      int _2887 = ((*mosek::fusion::p_WorkStack::_get_impl(_2876)->i32)(_2878));
      int _2888 = ((*mosek::fusion::p_WorkStack::_get_impl(_2876)->i32)(safe_add( _2878,(int)1 )));
      std::shared_ptr< monty::ndarray< int,1 > > _2889 = mosek::fusion::p_WorkStack::_get_impl(_2876)->i32;
      _checked_ptr_1<int> _ptr__2889(_2889 ? _2889->raw() : nullptr,_2889 ? _2889->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2890 = mosek::fusion::p_WorkStack::_get_impl(_2876)->i64;
      _checked_ptr_1<long long> _ptr__2890(_2890 ? _2890->raw() : nullptr,_2890 ? _2890->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2891 = mosek::fusion::p_WorkStack::_get_impl(_2876)->f64;
      _checked_ptr_1<double> _ptr__2891(_2891 ? _2891->raw() : nullptr,_2891 ? _2891->size(0) : 0);
      _2875->alloc_expr((int)2,_2879,_2880,_2881);
      int _2892 = mosek::fusion::p_WorkStack::_get_impl(_2875)->ptr_base;
      int _2893 = mosek::fusion::p_WorkStack::_get_impl(_2875)->nidxs_base;
      int _2894 = mosek::fusion::p_WorkStack::_get_impl(_2875)->sp_base;
      int _2895 = mosek::fusion::p_WorkStack::_get_impl(_2875)->cof_base;
      int _2896 = mosek::fusion::p_WorkStack::_get_impl(_2875)->bfix_base;
      int _2897 = mosek::fusion::p_WorkStack::_get_impl(_2875)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2898 = mosek::fusion::p_WorkStack::_get_impl(_2875)->i32;
      _checked_ptr_1<int> _ptr__2898(_2898 ? _2898->raw() : nullptr,_2898 ? _2898->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2899 = mosek::fusion::p_WorkStack::_get_impl(_2875)->i64;
      _checked_ptr_1<long long> _ptr__2899(_2899 ? _2899->raw() : nullptr,_2899 ? _2899->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2900 = mosek::fusion::p_WorkStack::_get_impl(_2875)->f64;
      _checked_ptr_1<double> _ptr__2900(_2900 ? _2900->raw() : nullptr,_2900 ? _2900->size(0) : 0);
      _ptr__2898[_2897] = _2888;
      _ptr__2898[safe_add( _2897,(int)1 )] = _2887;
      if (_2881)
      {
        {
          int _2901 = _2877->alloci32(_2879);
          int _2902 = _2877->alloci32(safe_add( _2888,(int)1 ));
          std::shared_ptr< monty::ndarray< int,1 > > _2903 = mosek::fusion::p_WorkStack::_get_impl(_2877)->i32;
          _checked_ptr_1<int> _ptr__2903(_2903 ? _2903->raw() : nullptr,_2903 ? _2903->size(0) : 0);
          int _8078 = (int)0;
          int _8079 = safe_add( _2888,(int)1 );
          for (int _2904 = _8078; _2904 < _8079; ++_2904)
          {
            {
              _ptr__2903[safe_add( _2902,_2904 )] = (int)0;
            }
          }
          int _8080 = (int)0;
          int _8081 = _2879;
          for (int _2905 = _8080; _2905 < _8081; ++_2905)
          {
            {
              ++ _ptr__2903[safe_add( safe_add( _2902,(_ptr__2890[safe_add( _2883,_2905 )] % _2888) ),(int)1 )];
            }
          }
          int _8082 = (int)0;
          int _8083 = _2888;
          for (int _2906 = _8082; _2906 < _8083; ++_2906)
          {
            {
              _ptr__2903[safe_add( safe_add( _2902,_2906 ),(int)1 )] += _ptr__2903[safe_add( _2902,_2906 )];
            }
          }
          int _8084 = (int)0;
          int _8085 = _2879;
          for (int _2907 = _8084; _2907 < _8085; ++_2907)
          {
            {
              long long _2908 = (_ptr__2890[safe_add( _2883,_2907 )] % _2888);
              _ptr__2903[safe_add( _2901,_ptr__2903[safe_add( _2902,_2908 )] )] = _2907;
              ++ _ptr__2903[safe_add( _2902,_2908 )];
            }
          }
          _ptr__2898[_2892] = (int)0;
          int _2909 = (int)0;
          int _8086 = (int)0;
          int _8087 = _2879;
          for (int _2910 = _8086; _2910 < _8087; ++_2910)
          {
            {
              int _2911 = _ptr__2903[safe_add( _2901,_2910 )];
              int _8088 = _ptr__2889[safe_add( _2882,_2911 )];
              int _8089 = _ptr__2889[safe_add( safe_add( _2882,_2911 ),(int)1 )];
              for (int _2912 = _8088; _2912 < _8089; ++_2912)
              {
                {
                  _ptr__2899[safe_add( _2893,_2909 )] = _ptr__2890[safe_add( _2884,_2912 )];
                  _ptr__2900[safe_add( _2895,_2909 )] = _ptr__2891[safe_add( _2886,_2912 )];
                  ++ _2909;
                }
              }
              long long _2913 = (_ptr__2890[safe_add( _2883,_2911 )] / _2888);
              long long _2914 = (_ptr__2890[safe_add( _2883,_2911 )] % _2888);
              _ptr__2898[safe_add( safe_add( _2892,_2910 ),(int)1 )] = _2909;
              _ptr__2899[safe_add( _2894,_2910 )] = safe_add( safe_mul( _2914,_2888 ),_2913 );
              _ptr__2900[safe_add( _2896,_2910 )] = _ptr__2891[safe_add( _2885,_2911 )];
            }
          }
        }
      }
      else
      {
        {
          _ptr__2898[_2892] = (int)0;
          int _2915 = (int)0;
          int _2916 = (int)0;
          int _8090 = (int)0;
          int _8091 = _2888;
          for (int _2917 = _8090; _2917 < _8091; ++_2917)
          {
            {
              int _8092 = (int)0;
              int _8093 = _2887;
              for (int _2918 = _8092; _2918 < _8093; ++_2918)
              {
                {
                  int _2919 = safe_add( safe_mul( _2918,_2888 ),_2917 );
                  int _8094 = _ptr__2889[safe_add( _2882,_2919 )];
                  int _8095 = _ptr__2889[safe_add( safe_add( _2882,_2919 ),(int)1 )];
                  for (int _2920 = _8094; _2920 < _8095; ++_2920)
                  {
                    {
                      _ptr__2899[safe_add( _2893,_2915 )] = _ptr__2890[safe_add( _2884,_2920 )];
                      _ptr__2900[safe_add( _2895,_2915 )] = _ptr__2891[safe_add( _2886,_2920 )];
                      ++ _2915;
                    }
                  }
                  _ptr__2900[safe_add( _2896,_2916 )] = _ptr__2891[safe_add( _2885,_2919 )];
                  _ptr__2898[safe_add( safe_add( _2892,_2916 ),(int)1 )] = _2915;
                  ++ _2916;
                }
              }
            }
          }
        }
      }
      _2877->clear();
    }
  }
}
std::string mosek::fusion::ExprTranspose :: toString() { return mosek::fusion::p_ExprTranspose::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprTranspose::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprTranspose("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprTranspose::transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _2921){
  _checked_ptr_1<int> _ptr__2921(_2921 ? _2921->raw() : nullptr, _2921 ? _2921->size(0) : 0);
  if (((int)((_2921)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__2921[(int)1]),(int)(_ptr__2921[(int)0])});
    }
  }
}
void mosek::fusion::p_ExprTranspose::destroy(){expr.reset();}void mosek::fusion::ExprTranspose::destroy() { mosek::fusion::p_ExprTranspose::_get_impl(this)->destroy(); }mosek::fusion::ExprStack::ExprStack(mosek::fusion::p_ExprStack *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprStack()" << this << std::endl; */ }mosek::fusion::ExprStack::~ExprStack() {  /* std::cout << "~ExprStack()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprStack::p_ExprStack  (::mosek::fusion::ExprStack * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprStack::t mosek::fusion::p_ExprStack::_new_ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2922,    int _2923){ return new mosek::fusion::ExprStack(_2922,_2923); }mosek::fusion::ExprStack::ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2922,    int _2923) :    ExprStack(new mosek::fusion::p_ExprStack(this)){ mosek::fusion::p_ExprStack::_get_impl(this)->_initialize(_2922,_2923); }void mosek::fusion::p_ExprStack::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2922,    int _2923){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprStack::getshape(_2922,_2923));
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8096;
    for (int _2924 = (int)0, _8097 = (int)((_2922)->size(0)); _2924 < _8097 ; ++_2924)
    {
      _8096.push_back(((*_2922)(_2924)));
    }
    auto _8098 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8096.size()),_8096.begin(),_8096.end()));
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->exprs = _8098;
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->dim = _2923;
  }
}void mosek::fusion::ExprStack :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2925,monty::rc_ptr< ::mosek::fusion::WorkStack > _2926,monty::rc_ptr< ::mosek::fusion::WorkStack > _2927) { mosek::fusion::p_ExprStack::_get_impl(this)->eval(_2925,_2926,_2927); }void mosek::fusion::p_ExprStack::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2925,monty::rc_ptr< ::mosek::fusion::WorkStack > _2926,monty::rc_ptr< ::mosek::fusion::WorkStack > _2927){
  int _2928 = (int)((exprs)->size(0));
  if ((_2928 == (int)1))
  {
    {
      ((*exprs)((int)0))->eval(_2925,_2926,_2927);
    }
  }
  else
  {
    {
      int _8099 = (int)0;
      int _8100 = _2928;
      for (int _2929 = _8099; _2929 < _8100; ++_2929)
      {
        {
          ((*exprs)(((_2928 - _2929) - (int)1)))->eval(_2926,_2925,_2927);
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2930 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2930(_2930 ? _2930->raw() : nullptr,_2930 ? _2930->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2931 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2931(_2931 ? _2931->raw() : nullptr,_2931 ? _2931->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2932 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2932(_2932 ? _2932->raw() : nullptr,_2932 ? _2932->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2933 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2933(_2933 ? _2933->raw() : nullptr,_2933 ? _2933->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _2934 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_2928)));
      std::shared_ptr< monty::ndarray< int,1 > > _2935 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2935(_2935 ? _2935->raw() : nullptr,_2935 ? _2935->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2936 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2936(_2936 ? _2936->raw() : nullptr,_2936 ? _2936->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2937 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2937(_2937 ? _2937->raw() : nullptr,_2937 ? _2937->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2938 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2938(_2938 ? _2938->raw() : nullptr,_2938 ? _2938->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2939 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2939(_2939 ? _2939->raw() : nullptr,_2939 ? _2939->size(0) : 0);
      int _8101 = (int)0;
      int _8102 = _2928;
      for (int _2940 = _8101; _2940 < _8102; ++_2940)
      {
        {
          _2926->pop_expr();
          _ptr__2930[_2940] = mosek::fusion::p_WorkStack::_get_impl(_2926)->nd;
          _ptr__2931[_2940] = mosek::fusion::p_WorkStack::_get_impl(_2926)->shape_base;
          _ptr__2932[_2940] = mosek::fusion::p_WorkStack::_get_impl(_2926)->nelem;
          _ptr__2933[_2940] = mosek::fusion::p_WorkStack::_get_impl(_2926)->nnz;
          ((*_2934)(_2940)) = mosek::fusion::p_WorkStack::_get_impl(_2926)->hassp;
          _ptr__2935[_2940] = mosek::fusion::p_WorkStack::_get_impl(_2926)->ptr_base;
          _ptr__2937[_2940] = mosek::fusion::p_WorkStack::_get_impl(_2926)->sp_base;
          _ptr__2936[_2940] = mosek::fusion::p_WorkStack::_get_impl(_2926)->nidxs_base;
          _ptr__2939[_2940] = mosek::fusion::p_WorkStack::_get_impl(_2926)->bfix_base;
          _ptr__2938[_2940] = mosek::fusion::p_WorkStack::_get_impl(_2926)->cof_base;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2941 = mosek::fusion::p_WorkStack::_get_impl(_2926)->i32;
      _checked_ptr_1<int> _ptr__2941(_2941 ? _2941->raw() : nullptr,_2941 ? _2941->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2942 = mosek::fusion::p_WorkStack::_get_impl(_2926)->i64;
      _checked_ptr_1<long long> _ptr__2942(_2942 ? _2942->raw() : nullptr,_2942 ? _2942->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2943 = mosek::fusion::p_WorkStack::_get_impl(_2926)->f64;
      _checked_ptr_1<double> _ptr__2943(_2943 ? _2943->raw() : nullptr,_2943 ? _2943->size(0) : 0);
      int _2944 = _ptr__2930[(int)0];
      int _2945 = _ptr__2931[(int)0];
      bool _2946 = (!((*_2934)((int)0)));
      bool _2947 = false;
      int _8103 = (int)1;
      int _8104 = _2928;
      for (int _2948 = _8103; _2948 < _8104; ++_2948)
      {
        {
          _2947 = (_2947 || ((dim != _2948) && (_ptr__2930[_2948] != _2944)));
          if ((!_2947))
          {
            {
              int _8105 = (int)0;
              int _8106 = dim;
              for (int _2949 = _8105; _2949 < _8106; ++_2949)
              {
                {
                  _2947 = (_2947 || (_ptr__2941[safe_add( _2945,_2949 )] != _ptr__2941[safe_add( _ptr__2931[_2948],_2949 )]));
                }
              }
            }
          }
          {}
          if ((!_2947))
          {
            {
              int _8107 = safe_add( dim,(int)1 );
              int _8108 = _2944;
              for (int _2950 = _8107; _2950 < _8108; ++_2950)
              {
                {
                  _2947 = (_2947 || (_ptr__2941[safe_add( _2945,_2950 )] != _ptr__2941[safe_add( _ptr__2931[_2948],_2950 )]));
                }
              }
            }
          }
          {}
          _2946 = (_2946 && (!((*_2934)(_2948))));
        }
      }
      if (_2947)
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
        }
      }
      {}
      int _2951 = (int)0;
      if ((dim < _2944))
      {
        {
          int _8109 = (int)0;
          int _8110 = _2928;
          for (int _2952 = _8109; _2952 < _8110; ++_2952)
          {
            {
              _2951 += _ptr__2941[safe_add( _ptr__2931[_2952],dim )];
            }
          }
        }
      }
      else
      {
        {
          _2951 = _2928;
        }
      }
      int _8111;
      bool _8112 = (dim < _2944);
      if (_8112)
      {
        _8111 = _2944;
      }
      else
      {
        _8111 = safe_add( _2944,(int)1 );
      }
      int _2953 = _8111;
      if ((_2953 != _pubthis->getND()))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Oops!!"));
        }
      }
      {}
      int _2954 = (int)0;
      int _2955 = (int)0;
      {
        int _8113 = (int)0;
        int _8114 = _2928;
        for (int _2956 = _8113; _2956 < _8114; ++_2956)
        {
          {
            _2955 += _ptr__2933[_2956];
          }
        }
        int _8115 = (int)0;
        int _8116 = _2928;
        for (int _2957 = _8115; _2957 < _8116; ++_2957)
        {
          {
            _2954 += _ptr__2932[_2957];
          }
        }
      }
      int _2958 = (int)1;
      int _8117 = (int)0;
      int _8118 = dim;
      for (int _2959 = _8117; _2959 < _8118; ++_2959)
      {
        {
          _2958 *= _ptr__2941[safe_add( _2945,_2959 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _8119;
      bool _8120 = (dim < _2944);
      if (_8120)
      {
        std::vector<int> _8121;
        for (int _2961 = (int)0, _8122 = _2928; _2961 < _8122 ; ++_2961)
        {
          _8121.push_back(_ptr__2941[safe_add( _ptr__2931[_2961],dim )]);
        }
        auto _8123 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8121.size()),_8121.begin(),_8121.end()));
        _8119 = _8123;
      }
      else
      {
        std::vector<int> _8124;
        for (int _2962 = (int)0, _8125 = _2928; _2962 < _8125 ; ++_2962)
        {
          _8124.push_back((int)1);
        }
        auto _8126 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8124.size()),_8124.begin(),_8124.end()));
        _8119 = _8126;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2960 = _8119;
      _checked_ptr_1<int> _ptr__2960(_2960 ? _2960->raw() : nullptr,_2960 ? _2960->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2963 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2928)));
      _checked_ptr_1<int> _ptr__2963(_2963 ? _2963->raw() : nullptr,_2963 ? _2963->size(0) : 0);
      _ptr__2963[(int)0] = (int)0;
      int _8127 = (int)1;
      int _8128 = _2944;
      for (int _2964 = _8127; _2964 < _8128; ++_2964)
      {
        {
          _ptr__2963[_2964] = safe_add( _ptr__2963[(_2964 - (int)1)],_ptr__2960[(_2964 - (int)1)] );
        }
      }
      int _2965 = (int)0;
      int _8129 = (int)0;
      int _8130 = _2928;
      for (int _2966 = _8129; _2966 < _8130; ++_2966)
      {
        {
          _2965 += _ptr__2960[_2966];
        }
      }
      int _2967 = (int)1;
      int _8131 = safe_add( dim,(int)1 );
      int _8132 = _2944;
      for (int _2968 = _8131; _2968 < _8132; ++_2968)
      {
        {
          _2967 *= _ptr__2941[safe_add( _2945,_2968 )];
        }
      }
      if (_2946)
      {
        {
          _2925->alloc_expr(_2953,_2954,_2955,false);
          int _2969 = mosek::fusion::p_WorkStack::_get_impl(_2925)->ptr_base;
          int _2970 = mosek::fusion::p_WorkStack::_get_impl(_2925)->shape_base;
          int _2971 = mosek::fusion::p_WorkStack::_get_impl(_2925)->nidxs_base;
          int _2972 = mosek::fusion::p_WorkStack::_get_impl(_2925)->cof_base;
          int _2973 = mosek::fusion::p_WorkStack::_get_impl(_2925)->bfix_base;
          std::shared_ptr< monty::ndarray< int,1 > > _2974 = mosek::fusion::p_WorkStack::_get_impl(_2925)->i32;
          _checked_ptr_1<int> _ptr__2974(_2974 ? _2974->raw() : nullptr,_2974 ? _2974->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _2975 = mosek::fusion::p_WorkStack::_get_impl(_2925)->i64;
          _checked_ptr_1<long long> _ptr__2975(_2975 ? _2975->raw() : nullptr,_2975 ? _2975->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _2976 = mosek::fusion::p_WorkStack::_get_impl(_2925)->f64;
          _checked_ptr_1<double> _ptr__2976(_2976 ? _2976->raw() : nullptr,_2976 ? _2976->size(0) : 0);
          int _8133 = (int)0;
          int _8134 = _2944;
          for (int _2977 = _8133; _2977 < _8134; ++_2977)
          {
            {
              _ptr__2974[safe_add( _2970,_2977 )] = _ptr__2941[safe_add( _2945,_2977 )];
            }
          }
          _ptr__2974[safe_add( _2970,dim )] = _2951;
          {
            _ptr__2974[_2969] = (int)0;
            {
              int _2978 = (int)0;
              int _8135 = (int)0;
              int _8136 = _2928;
              for (int _2979 = _8135; _2979 < _8136; ++_2979)
              {
                {
                  int _2980 = _ptr__2935[_2979];
                  int _2981 = (int)0;
                  int _8137 = (int)0;
                  int _8138 = _2958;
                  for (int _2982 = _8137; _2982 < _8138; ++_2982)
                  {
                    {
                      int _8139 = (int)0;
                      int _8140 = _ptr__2960[_2979];
                      for (int _2983 = _8139; _2983 < _8140; ++_2983)
                      {
                        {
                          int _8141 = (int)0;
                          int _8142 = _2967;
                          for (int _2984 = _8141; _2984 < _8142; ++_2984)
                          {
                            {
                              int _2985 = safe_add( safe_add( _2984,safe_mul( safe_add( _2983,_2978 ),_2967 ) ),safe_mul( safe_mul( _2982,_2965 ),_2967 ) );
                              int _2986 = (_ptr__2941[safe_add( safe_add( _2980,_2981 ),(int)1 )] - _ptr__2941[safe_add( _2980,_2981 )]);
                              _ptr__2974[safe_add( safe_add( _2969,_2985 ),(int)1 )] = _2986;
                              _ptr__2976[safe_add( _2973,_2985 )] = _ptr__2943[safe_add( _ptr__2939[_2979],_2981 )];
                              ++ _2981;
                            }
                          }
                        }
                      }
                    }
                  }
                  _2978 += _ptr__2960[_2979];
                }
              }
              int _8143 = (int)0;
              int _8144 = _2954;
              for (int _2987 = _8143; _2987 < _8144; ++_2987)
              {
                {
                  _ptr__2974[safe_add( safe_add( _2969,_2987 ),(int)1 )] += _ptr__2974[safe_add( _2969,_2987 )];
                }
              }
            }
            {
              int _2988 = (int)0;
              int _8145 = (int)0;
              int _8146 = _2928;
              for (int _2989 = _8145; _2989 < _8146; ++_2989)
              {
                {
                  int _2990 = _ptr__2935[_2989];
                  int _2991 = (int)0;
                  int _8147 = (int)0;
                  int _8148 = _2958;
                  for (int _2992 = _8147; _2992 < _8148; ++_2992)
                  {
                    {
                      int _8149 = (int)0;
                      int _8150 = _ptr__2960[_2989];
                      for (int _2993 = _8149; _2993 < _8150; ++_2993)
                      {
                        {
                          int _8151 = (int)0;
                          int _8152 = _2967;
                          for (int _2994 = _8151; _2994 < _8152; ++_2994)
                          {
                            {
                              int _2995 = safe_add( safe_add( _2994,safe_mul( safe_add( _2993,_2988 ),_2967 ) ),safe_mul( safe_mul( _2992,_2965 ),_2967 ) );
                              int _2996 = _ptr__2941[safe_add( _2990,_2991 )];
                              int _2997 = (_ptr__2941[safe_add( safe_add( _2990,_2991 ),(int)1 )] - _2996);
                              int _8153 = (int)0;
                              int _8154 = _2997;
                              for (int _2998 = _8153; _2998 < _8154; ++_2998)
                              {
                                {
                                  _ptr__2975[safe_add( safe_add( _2971,_ptr__2974[safe_add( _2969,_2995 )] ),_2998 )] = _ptr__2942[safe_add( safe_add( _ptr__2936[_2989],_2996 ),_2998 )];
                                }
                              }
                              int _8155 = (int)0;
                              int _8156 = _2997;
                              for (int _2999 = _8155; _2999 < _8156; ++_2999)
                              {
                                {
                                  _ptr__2976[safe_add( safe_add( _2972,_ptr__2974[safe_add( _2969,_2995 )] ),_2999 )] = _ptr__2943[safe_add( safe_add( _ptr__2938[_2989],_2996 ),_2999 )];
                                }
                              }
                              ++ _2991;
                            }
                          }
                        }
                      }
                    }
                  }
                  _2988 += _ptr__2960[_2989];
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _3000 = (int)1;
          int _8157 = (int)0;
          int _8158 = dim;
          for (int _3001 = _8157; _3001 < _8158; ++_3001)
          {
            {
              _3000 *= _ptr__2941[safe_add( _2945,_3001 )];
            }
          }
          _3000 *= _2951;
          int _8159 = safe_add( dim,(int)1 );
          int _8160 = _2944;
          for (int _3002 = _8159; _3002 < _8160; ++_3002)
          {
            {
              _3000 *= _ptr__2941[safe_add( _2945,_3002 )];
            }
          }
          bool _3003 = (_2954 < _3000);
          _2925->alloc_expr(_2953,_2954,_2955,_3003);
          int _3004 = mosek::fusion::p_WorkStack::_get_impl(_2925)->ptr_base;
          int _3005 = mosek::fusion::p_WorkStack::_get_impl(_2925)->nidxs_base;
          int _8161;
          bool _8162 = _3003;
          if (_8162)
          {
            _8161 = mosek::fusion::p_WorkStack::_get_impl(_2925)->sp_base;
          }
          else
          {
            _8161 = _2925->alloci64(_2954);
          }
          int _3006 = _8161;
          int _3007 = mosek::fusion::p_WorkStack::_get_impl(_2925)->cof_base;
          int _3008 = mosek::fusion::p_WorkStack::_get_impl(_2925)->bfix_base;
          int _3009 = mosek::fusion::p_WorkStack::_get_impl(_2925)->shape_base;
          int _8163 = (int)0;
          int _8164 = _2944;
          for (int _3010 = _8163; _3010 < _8164; ++_3010)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_2925)->i32)(safe_add( _3009,_3010 ))) = _ptr__2941[safe_add( _2945,_3010 )];
            }
          }
          ((*mosek::fusion::p_WorkStack::_get_impl(_2925)->i32)(safe_add( _3009,dim ))) = _2951;
          int _3011 = _2927->alloci32(safe_add( _2954,(int)1 ));
          int _3012 = _2927->alloci64(_2955);
          int _3013 = _2927->alloci64(_2954);
          int _3014 = _2927->allocf64(_2955);
          int _3015 = _2927->allocf64(_2954);
          std::shared_ptr< monty::ndarray< int,1 > > _3016 = mosek::fusion::p_WorkStack::_get_impl(_2925)->i32;
          _checked_ptr_1<int> _ptr__3016(_3016 ? _3016->raw() : nullptr,_3016 ? _3016->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3017 = mosek::fusion::p_WorkStack::_get_impl(_2925)->i64;
          _checked_ptr_1<long long> _ptr__3017(_3017 ? _3017->raw() : nullptr,_3017 ? _3017->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3018 = mosek::fusion::p_WorkStack::_get_impl(_2925)->f64;
          _checked_ptr_1<double> _ptr__3018(_3018 ? _3018->raw() : nullptr,_3018 ? _3018->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _3019 = mosek::fusion::p_WorkStack::_get_impl(_2927)->i32;
          _checked_ptr_1<int> _ptr__3019(_3019 ? _3019->raw() : nullptr,_3019 ? _3019->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3020 = mosek::fusion::p_WorkStack::_get_impl(_2927)->i64;
          _checked_ptr_1<long long> _ptr__3020(_3020 ? _3020->raw() : nullptr,_3020 ? _3020->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3021 = mosek::fusion::p_WorkStack::_get_impl(_2927)->f64;
          _checked_ptr_1<double> _ptr__3021(_3021 ? _3021->raw() : nullptr,_3021 ? _3021->size(0) : 0);
          {
            int _3022 = (int)0;
            int _3023 = (int)0;
            int _8165 = (int)0;
            int _8166 = _2928;
            for (int _3024 = _8165; _3024 < _8166; ++_3024)
            {
              {
                ::mosek::fusion::Utils::Tools::arraycopy(_2942,_ptr__2936[_3024],_3020,safe_add( _3012,_3023 ),_ptr__2933[_3024]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2943,_ptr__2938[_3024],_3021,safe_add( _3014,_3023 ),_ptr__2933[_3024]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2943,_ptr__2939[_3024],_3021,safe_add( _3015,_3022 ),_ptr__2932[_3024]);
                _3023 += _ptr__2933[_3024];
                _3022 += _ptr__2932[_3024];
              }
            }
          }
          {
            _ptr__3019[_3011] = (int)0;
            int _3025 = (int)0;
            int _3026 = (int)0;
            int _8167 = (int)0;
            int _8168 = _2928;
            for (int _3027 = _8167; _3027 < _8168; ++_3027)
            {
              {
                int _3028 = _ptr__2960[_3027];
                int _3029 = safe_mul( _3028,_2967 );
                int _3030 = _2967;
                if (((*_2934)(_3027)))
                {
                  {
                    int _8169 = (int)0;
                    int _8170 = _ptr__2932[_3027];
                    for (int _3031 = _8169; _3031 < _8170; ++_3031)
                    {
                      {
                        long long _3032 = (_ptr__2942[safe_add( _ptr__2937[_3027],_3031 )] / _3029);
                        long long _3033 = ((_ptr__2942[safe_add( _ptr__2937[_3027],_3031 )] / _3030) % _3028);
                        long long _3034 = (_ptr__2942[safe_add( _ptr__2937[_3027],_3031 )] % _2967);
                        _ptr__3020[safe_add( _3013,_3026 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3032,_2951 ),_3033 ),_ptr__2963[_3027] ),_2967 ),_3034 );
                        _ptr__3019[safe_add( safe_add( _3011,_3026 ),(int)1 )] = safe_add( _3025,_ptr__2941[safe_add( safe_add( _ptr__2935[_3027],_3031 ),(int)1 )] );
                        ++ _3026;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _3035 = (int)0;
                    int _8171 = (int)0;
                    int _8172 = _2958;
                    for (int _3036 = _8171; _3036 < _8172; ++_3036)
                    {
                      {
                        int _8173 = (int)0;
                        int _8174 = _3028;
                        for (int _3037 = _8173; _3037 < _8174; ++_3037)
                        {
                          {
                            int _8175 = (int)0;
                            int _8176 = _2967;
                            for (int _3038 = _8175; _3038 < _8176; ++_3038)
                            {
                              {
                                _ptr__3020[safe_add( _3013,_3026 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3036,_2951 ),_3037 ),_ptr__2963[_3027] ),_2967 ),_3038 );
                                _ptr__3019[safe_add( safe_add( _3011,_3026 ),(int)1 )] = safe_add( _3025,_ptr__2941[safe_add( safe_add( _ptr__2935[_3027],_3035 ),(int)1 )] );
                                ++ _3026;
                                ++ _3035;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                _3025 += _ptr__2933[_3027];
              }
            }
          }
          if ((dim > (int)0))
          {
            {
              int _3039 = (int)0;
              int _8177 = (int)0;
              int _8178 = _2944;
              for (int _3040 = _8177; _3040 < _8178; ++_3040)
              {
                {
                  if ((_3039 < _ptr__3016[safe_add( _3009,_3040 )]))
                  {
                    {
                      _3039 = _ptr__3016[safe_add( _3009,_3040 )];
                    }
                  }
                  {}
                }
              }
              std::shared_ptr< monty::ndarray< long long,1 > > _3041 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2953)));
              _checked_ptr_1<long long> _ptr__3041(_3041 ? _3041->raw() : nullptr,_3041 ? _3041->size(0) : 0);
              _ptr__3041[(_2953 - (int)1)] = (int)1;
              int _8179 = (int)1;
              int _8180 = _2953;
              for (int _3042 = _8179; _3042 < _8180; ++_3042)
              {
                {
                  _ptr__3041[((_2953 - _3042) - (int)1)] = safe_mul( _ptr__3041[(_2953 - _3042)],_ptr__3016[(safe_add( _3009,_2953 ) - _3042)] );
                }
              }
              int _3043 = _2927->alloci32(_2954);
              int _3044 = _2927->alloci32(_2954);
              int _3045 = _2927->alloci32(safe_add( _3039,(int)1 ));
              std::shared_ptr< monty::ndarray< int,1 > > _3046 = mosek::fusion::p_WorkStack::_get_impl(_2927)->i32;
              _checked_ptr_1<int> _ptr__3046(_3046 ? _3046->raw() : nullptr,_3046 ? _3046->size(0) : 0);
              std::shared_ptr< monty::ndarray< long long,1 > > _3047 = mosek::fusion::p_WorkStack::_get_impl(_2927)->i64;
              _checked_ptr_1<long long> _ptr__3047(_3047 ? _3047->raw() : nullptr,_3047 ? _3047->size(0) : 0);
              std::shared_ptr< monty::ndarray< double,1 > > _3048 = mosek::fusion::p_WorkStack::_get_impl(_2927)->f64;
              _checked_ptr_1<double> _ptr__3048(_3048 ? _3048->raw() : nullptr,_3048 ? _3048->size(0) : 0);
              {
                int _8181 = (int)0;
                int _8182 = _2954;
                for (int _3049 = _8181; _3049 < _8182; ++_3049)
                {
                  {
                    _ptr__3046[safe_add( _3043,_3049 )] = _3049;
                  }
                }
                int _8183 = (int)0;
                int _8184 = _2953;
                for (int _3050 = _8183; _3050 < _8184; ++_3050)
                {
                  {
                    int _3051 = ((_2953 - _3050) - (int)1);
                    int _3052 = _ptr__3016[safe_add( _3009,_3051 )];
                    int _8185 = (int)0;
                    int _8186 = safe_add( _3052,(int)1 );
                    for (int _3053 = _8185; _3053 < _8186; ++_3053)
                    {
                      {
                        _ptr__3046[safe_add( _3045,_3053 )] = (int)0;
                      }
                    }
                    int _8187 = (int)0;
                    int _8188 = _2954;
                    for (int _3054 = _8187; _3054 < _8188; ++_3054)
                    {
                      {
                        int _3055 = _ptr__3046[safe_add( _3043,_3054 )];
                        long long _3056 = ((_ptr__3047[safe_add( _3013,_3055 )] / _ptr__3041[_3051]) % _3052);
                        ++ _ptr__3046[safe_add( safe_add( _3045,_3056 ),(int)1 )];
                      }
                    }
                    {
                      int _8189 = (int)0;
                      int _8190 = _3052;
                      for (int _3057 = _8189; _3057 < _8190; ++_3057)
                      {
                        {
                          _ptr__3046[safe_add( safe_add( _3045,_3057 ),(int)1 )] += _ptr__3046[safe_add( _3045,_3057 )];
                        }
                      }
                      int _8191 = (int)0;
                      int _8192 = _2954;
                      for (int _3058 = _8191; _3058 < _8192; ++_3058)
                      {
                        {
                          int _3059 = _ptr__3046[safe_add( _3043,_3058 )];
                          long long _3060 = ((_ptr__3047[safe_add( _3013,_3059 )] / _ptr__3041[_3051]) % _3052);
                          _ptr__3046[safe_add( _3044,_ptr__3046[safe_add( _3045,_3060 )] )] = _3059;
                          ++ _ptr__3046[safe_add( _3045,_3060 )];
                        }
                      }
                    }
                    int _3061 = _3043;
                    _3043 = _3044;
                    _3044 = _3061;
                  }
                }
                int _3062 = (int)0;
                _ptr__3016[_3004] = (int)0;
                int _8193 = (int)0;
                int _8194 = _2954;
                for (int _3063 = _8193; _3063 < _8194; ++_3063)
                {
                  {
                    int _3064 = _ptr__3046[safe_add( _3043,_3063 )];
                    int _3065 = _ptr__3046[safe_add( _3011,_3064 )];
                    int _3066 = _ptr__3046[safe_add( safe_add( _3011,_3064 ),(int)1 )];
                    int _3067 = (_3066 - _3065);
                    _ptr__3016[safe_add( safe_add( _3004,_3063 ),(int)1 )] = safe_add( _ptr__3016[safe_add( _3004,_3063 )],_3067 );
                    _ptr__3018[safe_add( _3008,_3063 )] = _ptr__3048[safe_add( _3015,_3064 )];
                    _ptr__3017[safe_add( _3006,_3063 )] = _ptr__3047[safe_add( _3013,_3064 )];
                    int _8195 = _3065;
                    int _8196 = _3066;
                    for (int _3068 = _8195; _3068 < _8196; ++_3068)
                    {
                      {
                        _ptr__3017[safe_add( _3005,_3062 )] = _ptr__3047[safe_add( _3012,_3068 )];
                        _ptr__3018[safe_add( _3007,_3062 )] = _ptr__3048[safe_add( _3014,_3068 )];
                        ++ _3062;
                      }
                    }
                  }
                }
              }
            }
          }
          else
          {
            {
              int _3069 = (int)0;
              _ptr__3016[_3004] = (int)0;
              int _8197 = (int)0;
              int _8198 = _2954;
              for (int _3070 = _8197; _3070 < _8198; ++_3070)
              {
                {
                  int _3071 = _ptr__3019[safe_add( _3011,_3070 )];
                  int _3072 = _ptr__3019[safe_add( safe_add( _3011,_3070 ),(int)1 )];
                  int _3073 = (_3072 - _3071);
                  _ptr__3016[safe_add( safe_add( _3004,_3070 ),(int)1 )] = safe_add( _ptr__3016[safe_add( _3004,_3070 )],_3073 );
                  _ptr__3018[safe_add( _3008,_3070 )] = _ptr__3021[safe_add( _3015,_3070 )];
                  _ptr__3017[safe_add( _3006,_3070 )] = _ptr__3020[safe_add( _3013,_3070 )];
                  int _8199 = _3071;
                  int _8200 = _3072;
                  for (int _3074 = _8199; _3074 < _8200; ++_3074)
                  {
                    {
                      _ptr__3017[safe_add( _3005,_3069 )] = _ptr__3020[safe_add( _3012,_3074 )];
                      _ptr__3018[safe_add( _3007,_3069 )] = _ptr__3021[safe_add( _3014,_3074 )];
                      ++ _3069;
                    }
                  }
                }
              }
            }
          }
          if ((!_3003))
          {
            {
              _2925->popi64(_2954);
            }
          }
          {}
          _2927->clear();
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprStack::getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3075,int _3076){
  if (((int)((_3075)->size(0)) == (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot stack empty list"));
    }
  }
  else if(((int)((_3075)->size(0)) == (int)1))
  {
    {
      return ((*_3075)((int)0))->getShape();
    }
  }
  else
  {
    {
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _8201;
      for (int _3078 = (int)0, _8202 = (int)((_3075)->size(0)); _3078 < _8202 ; ++_3078)
      {
        _8201.push_back(((*_3075)(_3078))->getShape());
      }
      auto _8203 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_8201.size()),_8201.begin(),_8201.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _3077 = _8203;
      std::shared_ptr< monty::ndarray< int,1 > > _3079 = ((*_3077)((int)0));
      _checked_ptr_1<int> _ptr__3079(_3079 ? _3079->raw() : nullptr,_3079 ? _3079->size(0) : 0);
      int _3080 = (int)((_3079)->size(0));
      int _8204 = (int)1;
      int _8205 = (int)((_3077)->size(0));
      for (int _3081 = _8204; _3081 < _8205; ++_3081)
      {
        {
          if ((_3080 != (int)((((*_3077)(_3081)))->size(0))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
            }
          }
          {}
          int _8206 = (int)0;
          int _8207 = _3076;
          for (int _3082 = _8206; _3082 < _8207; ++_3082)
          {
            {
              if ((_ptr__3079[_3082] != ((*((*_3077)(_3081)))(_3082))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
          int _8208 = safe_add( _3076,(int)1 );
          int _8209 = _3080;
          for (int _3083 = _8208; _3083 < _8209; ++_3083)
          {
            {
              if ((_ptr__3079[_3083] != ((*((*_3077)(_3081)))(_3083))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
        }
      }
      if ((_3076 == _3080))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3084 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _3080,(int)1 ))));
          _checked_ptr_1<int> _ptr__3084(_3084 ? _3084->raw() : nullptr,_3084 ? _3084->size(0) : 0);
          int _8210 = (int)0;
          int _8211 = _3080;
          for (int _3085 = _8210; _3085 < _8211; ++_3085)
          {
            {
              _ptr__3084[_3085] = _ptr__3079[_3085];
            }
          }
          _ptr__3084[_3080] = (int)((_3077)->size(0));
          return _3084;
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3086 = _3079;
          _checked_ptr_1<int> _ptr__3086(_3086 ? _3086->raw() : nullptr,_3086 ? _3086->size(0) : 0);
          int _8212 = (int)1;
          int _8213 = (int)((_3077)->size(0));
          for (int _3087 = _8212; _3087 < _8213; ++_3087)
          {
            {
              _ptr__3086[_3076] += ((*((*_3077)(_3087)))(_3076));
            }
          }
          return _3086;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprStack :: toString() { return mosek::fusion::p_ExprStack::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprStack::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _3088 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprStack(dim="))->__mosek_2fusion_2Utils_2StringBuffer__a(dim)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)((int)0))->toString());
  int _8214 = (int)1;
  int _8215 = (int)((exprs)->size(0));
  for (int _3089 = _8214; _3089 < _8215; ++_3089)
  {
    {
      _3088->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)(_3089))->toString());
    }
  }
  _3088->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("])"));
  return _3088->toString();
}
void mosek::fusion::p_ExprStack::destroy(){exprs.reset();}void mosek::fusion::ExprStack::destroy() { mosek::fusion::p_ExprStack::_get_impl(this)->destroy(); }mosek::fusion::ExprInner::ExprInner(mosek::fusion::p_ExprInner *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprInner()" << this << std::endl; */ }mosek::fusion::ExprInner::~ExprInner() {  /* std::cout << "~ExprInner()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprInner::p_ExprInner  (::mosek::fusion::ExprInner * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3090,    std::shared_ptr< monty::ndarray< long long,1 > > _3091,    std::shared_ptr< monty::ndarray< double,1 > > _3092){ return new mosek::fusion::ExprInner(_3090,_3091,_3092); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3090,    std::shared_ptr< monty::ndarray< long long,1 > > _3091,    std::shared_ptr< monty::ndarray< double,1 > > _3092) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3090,_3091,_3092); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3090,    std::shared_ptr< monty::ndarray< long long,1 > > _3091,    std::shared_ptr< monty::ndarray< double,1 > > _3092){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__3091(_3091 ? _3091->raw() : nullptr, _3091 ? _3091->size(0) : 0);
    _checked_ptr_1<double> _ptr__3092(_3092 ? _3092->raw() : nullptr, _3092 ? _3092->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->expr = _3090;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vsub = _3091;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vcof = _3092;
    if (((int)((_3091)->size(0)) != (int)((_3092)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of vcof and vsub"));
      }
    }
    {}
    std::shared_ptr< monty::ndarray< int,1 > > _3093 = _3090->getShape();
    _checked_ptr_1<int> _ptr__3093(_3093 ? _3093->raw() : nullptr,_3093 ? _3093->size(0) : 0);
    long long _3094 = ::mosek::fusion::p_Set::size(_3093);
    int _8216 = (int)1;
    int _8217 = (int)((_3091)->size(0));
    for (int _3095 = _8216; _3095 < _8217; ++_3095)
    {
      {
        if ((_ptr__3091[_3095] <= _ptr__3091[(_3095 - (int)1)]))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Unordered coefficcient subscripts"));
          }
        }
        {}
      }
    }
    if (((int)((_3091)->size(0)) > (int)0))
    {
      {
        if (((_ptr__3091[(int)0] < (int)0) || (_ptr__3091[((int)((_3091)->size(0)) - (int)1)] > _3094)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Coefficient subscript out of bounds"));
          }
        }
        {}
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3096,    std::shared_ptr< monty::ndarray< double,1 > > _3097){ return new mosek::fusion::ExprInner(_3096,_3097); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3096,    std::shared_ptr< monty::ndarray< double,1 > > _3097) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3096,_3097); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3096,    std::shared_ptr< monty::ndarray< double,1 > > _3097){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3097(_3097 ? _3097->raw() : nullptr, _3097 ? _3097->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3096,::mosek::fusion::p_ExprInner::range((int)((_3097)->size(0))),_3097);
    std::shared_ptr< monty::ndarray< int,1 > > _3098 = _3096->getShape();
    _checked_ptr_1<int> _ptr__3098(_3098 ? _3098->raw() : nullptr,_3098 ? _3098->size(0) : 0);
    if ((((int)((_3098)->size(0)) != (int)1) || (_ptr__3098[(int)0] != (int)((_3097)->size(0)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3099,    std::shared_ptr< monty::ndarray< int,2 > > _3100,    std::shared_ptr< monty::ndarray< double,1 > > _3101){ return new mosek::fusion::ExprInner(_3099,_3100,_3101); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3099,    std::shared_ptr< monty::ndarray< int,2 > > _3100,    std::shared_ptr< monty::ndarray< double,1 > > _3101) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3099,_3100,_3101); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3099,    std::shared_ptr< monty::ndarray< int,2 > > _3100,    std::shared_ptr< monty::ndarray< double,1 > > _3101){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3101(_3101 ? _3101->raw() : nullptr, _3101 ? _3101->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3099,::mosek::fusion::p_ExprInner::convert(_3099->getShape(),_3100),_3101);
  }
}void mosek::fusion::ExprInner :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3102,monty::rc_ptr< ::mosek::fusion::WorkStack > _3103,monty::rc_ptr< ::mosek::fusion::WorkStack > _3104) { mosek::fusion::p_ExprInner::_get_impl(this)->eval(_3102,_3103,_3104); }void mosek::fusion::p_ExprInner::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3102,monty::rc_ptr< ::mosek::fusion::WorkStack > _3103,monty::rc_ptr< ::mosek::fusion::WorkStack > _3104){
  expr->eval(_3103,_3102,_3104);
  int _3105 = _3103->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _3106 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3105)));
  _checked_ptr_1<int> _ptr__3106(_3106 ? _3106->raw() : nullptr,_3106 ? _3106->size(0) : 0);
  _3103->popi32(_3105,_3106,(int)0);
  int _3107 = _3103->popi32();
  int _3108 = _3103->popi32();
  bool _3109 = (_3103->popi32() != (int)0);
  int _3110 = _3103->popi32(safe_add( _3107,(int)1 ));
  int _8218;
  bool _8219 = _3109;
  if (_8219)
  {
    _8218 = _3103->popi64(_3107);
  }
  else
  {
    _8218 = (int)0;
  }
  int _3111 = _8218;
  int _3112 = _3103->popi64(_3108);
  int _3113 = _3103->popf64(_3107);
  int _3114 = _3103->popf64(_3108);
  std::shared_ptr< monty::ndarray< int,1 > > _3115 = mosek::fusion::p_WorkStack::_get_impl(_3103)->i32;
  _checked_ptr_1<int> _ptr__3115(_3115 ? _3115->raw() : nullptr,_3115 ? _3115->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3116 = mosek::fusion::p_WorkStack::_get_impl(_3103)->i64;
  _checked_ptr_1<long long> _ptr__3116(_3116 ? _3116->raw() : nullptr,_3116 ? _3116->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3117 = mosek::fusion::p_WorkStack::_get_impl(_3103)->f64;
  _checked_ptr_1<double> _ptr__3117(_3117 ? _3117->raw() : nullptr,_3117 ? _3117->size(0) : 0);
  int _3118 = (int)0;
  if (_3109)
  {
    {
      int _3119 = (int)0;
      int _3120 = (int)0;
      while ( ((_3120 < (int)((vsub)->size(0))) && (_3119 < _3107)) )
      {
        {
          if ((_ptr__3116[safe_add( _3111,_3119 )] < ((*vsub)(_3120))))
          {
            {
              ++ _3119;
            }
          }
          else if((_ptr__3116[safe_add( _3111,_3119 )] > ((*vsub)(_3120))))
          {
            {
              ++ _3120;
            }
          }
          else
          {
            {
              _3118 += (_ptr__3115[safe_add( safe_add( _3110,_3119 ),(int)1 )] - _ptr__3115[safe_add( _3110,_3119 )]);
              ++ _3120;
              ++ _3119;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8220 = (int)0;
      int _8221 = (int)((vsub)->size(0));
      for (int _3121 = _8220; _3121 < _8221; ++_3121)
      {
        {
          _3118 += (_ptr__3115[safe_add( safe_add( _3110,((*vsub)(_3121)) ),(int)1 )] - _ptr__3115[safe_add( _3110,((*vsub)(_3121)) )]);
        }
      }
    }
  }
  int _3122 = _3102->alloci32((int)2);
  int _3123 = _3102->alloci64(_3118);
  int _3124 = _3102->allocf64(_3118);
  int _3125 = _3102->allocf64((int)1);
  _3102->pushi32((int)0);
  _3102->pushi32(_3118);
  _3102->pushi32((int)1);
  _3102->pushi32((int)0);
  std::shared_ptr< monty::ndarray< int,1 > > _3126 = mosek::fusion::p_WorkStack::_get_impl(_3102)->i32;
  _checked_ptr_1<int> _ptr__3126(_3126 ? _3126->raw() : nullptr,_3126 ? _3126->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3127 = mosek::fusion::p_WorkStack::_get_impl(_3102)->i64;
  _checked_ptr_1<long long> _ptr__3127(_3127 ? _3127->raw() : nullptr,_3127 ? _3127->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3128 = mosek::fusion::p_WorkStack::_get_impl(_3102)->f64;
  _checked_ptr_1<double> _ptr__3128(_3128 ? _3128->raw() : nullptr,_3128 ? _3128->size(0) : 0);
  _ptr__3126[_3122] = (int)0;
  _ptr__3126[safe_add( _3122,(int)1 )] = _3118;
  int _3129 = (int)0;
  double _3130 = 0.0;
  if (_3109)
  {
    {
      int _3131 = (int)0;
      int _3132 = (int)0;
      while ( ((_3132 < (int)((vsub)->size(0))) && (_3131 < _3107)) )
      {
        {
          if ((_ptr__3116[safe_add( _3111,_3131 )] < ((*vsub)(_3132))))
          {
            {
              ++ _3131;
            }
          }
          else if((_ptr__3116[safe_add( _3111,_3131 )] > ((*vsub)(_3132))))
          {
            {
              ++ _3132;
            }
          }
          else
          {
            {
              int _3133 = _ptr__3115[safe_add( _3110,_3131 )];
              int _3134 = _ptr__3115[safe_add( safe_add( _3110,_3131 ),(int)1 )];
              int _8222 = _3133;
              int _8223 = _3134;
              for (int _3135 = _8222; _3135 < _8223; ++_3135)
              {
                {
                  _ptr__3127[safe_add( _3123,_3129 )] = _ptr__3116[safe_add( _3112,_3135 )];
                  _ptr__3128[safe_add( _3124,_3129 )] = (((*vcof)(_3132)) * _ptr__3117[safe_add( _3114,_3135 )]);
                  ++ _3129;
                }
              }
              _3130 += (((*vcof)(_3132)) * _ptr__3117[safe_add( _3113,_3131 )]);
              ++ _3132;
              ++ _3131;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8224 = (int)0;
      int _8225 = (int)((vsub)->size(0));
      for (int _3136 = _8224; _3136 < _8225; ++_3136)
      {
        {
          int _3137 = _ptr__3115[safe_add( _3110,((*vsub)(_3136)) )];
          int _3138 = _ptr__3115[safe_add( safe_add( _3110,((*vsub)(_3136)) ),(int)1 )];
          int _8226 = _3137;
          int _8227 = _3138;
          for (int _3139 = _8226; _3139 < _8227; ++_3139)
          {
            {
              _ptr__3127[safe_add( _3123,_3129 )] = _ptr__3116[safe_add( _3112,_3139 )];
              _ptr__3128[safe_add( _3124,_3129 )] = (((*vcof)(_3136)) * _ptr__3117[safe_add( _3114,_3139 )]);
              ++ _3129;
            }
          }
          _3130 += (((*vcof)(_3136)) * _ptr__3117[safe_add( _3113,((*vsub)(_3136)) )]);
        }
      }
    }
  }
  _ptr__3128[_3125] = _3130;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::range(int _3140){
  std::vector<long long> _8228;
  for (int _3141 = (int)0, _8229 = _3140; _3141 < _8229 ; ++_3141)
  {
    _8228.push_back(_3141);
  }
  auto _8230 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8228.size()),_8228.begin(),_8228.end()));
  return _8230;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::convert(std::shared_ptr< monty::ndarray< int,1 > > _3142,std::shared_ptr< monty::ndarray< int,2 > > _3143){
  _checked_ptr_1<int> _ptr__3142(_3142 ? _3142->raw() : nullptr, _3142 ? _3142->size(0) : 0);
  int _3144 = (int)((_3142)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _3145 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3144)));
  _checked_ptr_1<long long> _ptr__3145(_3145 ? _3145->raw() : nullptr,_3145 ? _3145->size(0) : 0);
  _ptr__3145[(_3144 - (int)1)] = (int)1;
  int _8231 = (int)1;
  int _8232 = _3144;
  for (int _3146 = _8231; _3146 < _8232; ++_3146)
  {
    {
      _ptr__3145[((_3144 - _3146) - (int)1)] = safe_mul( _ptr__3145[(_3144 - _3146)],_ptr__3142[(_3144 - _3146)] );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _3147 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_3143)->size(0)))));
  _checked_ptr_1<long long> _ptr__3147(_3147 ? _3147->raw() : nullptr,_3147 ? _3147->size(0) : 0);
  int _8233 = (int)0;
  int _8234 = (int)((_3143)->size(0));
  for (int _3148 = _8233; _3148 < _8234; ++_3148)
  {
    {
      int _8235 = (int)0;
      int _8236 = _3144;
      for (int _3149 = _8235; _3149 < _8236; ++_3149)
      {
        {
          _ptr__3147[_3148] += safe_mul( _ptr__3145[_3149],((*_3143)(_3148,_3149)) );
        }
      }
    }
  }
  return _3147;
}
std::string mosek::fusion::ExprInner :: toString() { return mosek::fusion::p_ExprInner::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprInner::toString(){
  return std::string ("ExprInner()");
}
void mosek::fusion::p_ExprInner::destroy(){vcof.reset();vsub.reset();expr.reset();}void mosek::fusion::ExprInner::destroy() { mosek::fusion::p_ExprInner::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight(mosek::fusion::p_ExprMulDiagRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagRight()" << this << std::endl; */ }mosek::fusion::ExprMulDiagRight::~ExprMulDiagRight() {  /* std::cout << "~ExprMulDiagRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagRight::p_ExprMulDiagRight  (::mosek::fusion::ExprMulDiagRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3150,    int _3151,    std::shared_ptr< monty::ndarray< int,1 > > _3152,    std::shared_ptr< monty::ndarray< int,1 > > _3153,    std::shared_ptr< monty::ndarray< double,1 > > _3154,    monty::rc_ptr< ::mosek::fusion::Expression > _3155,    int _3156){ return new mosek::fusion::ExprMulDiagRight(_3150,_3151,_3152,_3153,_3154,_3155,_3156); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3150,    int _3151,    std::shared_ptr< monty::ndarray< int,1 > > _3152,    std::shared_ptr< monty::ndarray< int,1 > > _3153,    std::shared_ptr< monty::ndarray< double,1 > > _3154,    monty::rc_ptr< ::mosek::fusion::Expression > _3155,    int _3156) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3150,_3151,_3152,_3153,_3154,_3155,_3156); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3150,    int _3151,    std::shared_ptr< monty::ndarray< int,1 > > _3152,    std::shared_ptr< monty::ndarray< int,1 > > _3153,    std::shared_ptr< monty::ndarray< double,1 > > _3154,    monty::rc_ptr< ::mosek::fusion::Expression > _3155,    int _3156){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3152(_3152 ? _3152->raw() : nullptr, _3152 ? _3152->size(0) : 0);
    _checked_ptr_1<int> _ptr__3153(_3153 ? _3153->raw() : nullptr, _3153 ? _3153->size(0) : 0);
    _checked_ptr_1<double> _ptr__3154(_3154 ? _3154->raw() : nullptr, _3154 ? _3154->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3151)}));
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim0 = _3150;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim1 = _3151;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi = _3152;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj = _3153;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval = _3154;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr = _3155;
  }
}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3157,    int _3158,    std::shared_ptr< monty::ndarray< int,1 > > _3159,    std::shared_ptr< monty::ndarray< int,1 > > _3160,    std::shared_ptr< monty::ndarray< double,1 > > _3161,    monty::rc_ptr< ::mosek::fusion::Expression > _3162){ return new mosek::fusion::ExprMulDiagRight(_3157,_3158,_3159,_3160,_3161,_3162); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3157,    int _3158,    std::shared_ptr< monty::ndarray< int,1 > > _3159,    std::shared_ptr< monty::ndarray< int,1 > > _3160,    std::shared_ptr< monty::ndarray< double,1 > > _3161,    monty::rc_ptr< ::mosek::fusion::Expression > _3162) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3157,_3158,_3159,_3160,_3161,_3162); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3157,    int _3158,    std::shared_ptr< monty::ndarray< int,1 > > _3159,    std::shared_ptr< monty::ndarray< int,1 > > _3160,    std::shared_ptr< monty::ndarray< double,1 > > _3161,    monty::rc_ptr< ::mosek::fusion::Expression > _3162){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3159(_3159 ? _3159->raw() : nullptr, _3159 ? _3159->size(0) : 0);
    _checked_ptr_1<int> _ptr__3160(_3160 ? _3160->raw() : nullptr, _3160 ? _3160->size(0) : 0);
    _checked_ptr_1<double> _ptr__3161(_3161 ? _3161->raw() : nullptr, _3161 ? _3161->size(0) : 0);
    mosek::fusion::p_ExprMulDiagRight::_initialize(_3157,_3158,_3159,_3160,_3161,_3162,::mosek::fusion::p_ExprMulDiagRight::validate(_3157,_3158,_3159,_3160,_3161,_3162));
  }
}void mosek::fusion::ExprMulDiagRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3163,monty::rc_ptr< ::mosek::fusion::WorkStack > _3164,monty::rc_ptr< ::mosek::fusion::WorkStack > _3165) { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->eval(_3163,_3164,_3165); }void mosek::fusion::p_ExprMulDiagRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3163,monty::rc_ptr< ::mosek::fusion::WorkStack > _3164,monty::rc_ptr< ::mosek::fusion::WorkStack > _3165){
  mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr->eval(_3164,_3163,_3165);
  int _3166 = (int)0;
  int _3167 = (int)99999;
  int _3168 = (int)0;
  bool _3169 = (_3164->peeki32((int)5) != (int)0);
  if (_3169)
  {
    {
      _3168 = _3164->peeki32((int)2);
      _3167 = _3164->alloci32(safe_add( _3168,(int)1 ));
      _3166 += safe_add( _3168,(int)1 );
    }
  }
  {}
  int _3170 = (int)((mval)->size(0));
  int _3171 = _3164->alloci32(_3170);
  int _3172 = _3164->alloci32(safe_add( mdim1,(int)1 ));
  _3166 += safe_add( safe_add( _3170,mdim1 ),(int)1 );
  {
    std::shared_ptr< monty::ndarray< int,1 > > _3173 = mosek::fusion::p_WorkStack::_get_impl(_3164)->i32;
    _checked_ptr_1<int> _ptr__3173(_3173 ? _3173->raw() : nullptr,_3173 ? _3173->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _3174 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj;
    _checked_ptr_1<int> _ptr__3174(_3174 ? _3174->raw() : nullptr,_3174 ? _3174->size(0) : 0);
    {
      int _8237 = (int)0;
      int _8238 = safe_add( mdim1,(int)1 );
      for (int _3175 = _8237; _3175 < _8238; ++_3175)
      {
        {
          _ptr__3173[safe_add( _3172,_3175 )] = (int)0;
        }
      }
      int _8239 = (int)0;
      int _8240 = _3170;
      for (int _3176 = _8239; _3176 < _8240; ++_3176)
      {
        {
          ++ _ptr__3173[safe_add( safe_add( _3172,_ptr__3174[_3176] ),(int)1 )];
        }
      }
      int _8241 = (int)0;
      int _8242 = mdim1;
      for (int _3177 = _8241; _3177 < _8242; ++_3177)
      {
        {
          _ptr__3173[safe_add( safe_add( _3172,_3177 ),(int)1 )] += _ptr__3173[safe_add( _3172,_3177 )];
        }
      }
      int _8243 = (int)0;
      int _8244 = _3170;
      for (int _3178 = _8243; _3178 < _8244; ++_3178)
      {
        {
          _ptr__3173[safe_add( _3171,_ptr__3173[safe_add( _3172,_ptr__3174[_3178] )] )] = _3178;
          ++ _ptr__3173[safe_add( _3172,_ptr__3174[_3178] )];
        }
      }
      int _8245 = (int)0;
      int _8246 = mdim1;
      for (int _3179 = _8245; _3179 < _8246; ++_3179)
      {
        {
          _ptr__3173[(safe_add( _3172,mdim1 ) - _3179)] = _ptr__3173[((safe_add( _3172,mdim1 ) - _3179) - (int)1)];
        }
      }
      _ptr__3173[_3172] = (int)0;
    }
  }
  _3164->popi32(_3166);
  int _3180 = _3164->popi32();
  if ((_3180 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3181 = _3164->popi32();
  int _3182 = _3164->popi32();
  int _3183 = _3164->popi32();
  int _3184 = _3164->popi32();
  bool _3185 = (_3164->popi32() != (int)0);
  int _3186 = _3164->popi32(safe_add( _3183,(int)1 ));
  int _8247;
  bool _8248 = _3185;
  if (_8248)
  {
    _8247 = _3164->popi64(_3183);
  }
  else
  {
    _8247 = (int)9999;
  }
  int _3187 = _8247;
  int _3188 = _3164->popi64(_3184);
  int _3189 = _3164->popf64(_3183);
  int _3190 = _3164->popf64(_3184);
  std::shared_ptr< monty::ndarray< int,1 > > _3191 = mosek::fusion::p_WorkStack::_get_impl(_3164)->i32;
  _checked_ptr_1<int> _ptr__3191(_3191 ? _3191->raw() : nullptr,_3191 ? _3191->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3192 = mosek::fusion::p_WorkStack::_get_impl(_3164)->i64;
  _checked_ptr_1<long long> _ptr__3192(_3192 ? _3192->raw() : nullptr,_3192 ? _3192->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3193 = mosek::fusion::p_WorkStack::_get_impl(_3164)->f64;
  _checked_ptr_1<double> _ptr__3193(_3193 ? _3193->raw() : nullptr,_3193 ? _3193->size(0) : 0);
  if (_3185)
  {
    {
      int _8249 = (int)0;
      int _8250 = safe_add( _3182,(int)1 );
      for (int _3194 = _8249; _3194 < _8250; ++_3194)
      {
        {
          _ptr__3191[safe_add( _3167,_3194 )] = (int)0;
        }
      }
      int _8251 = (int)0;
      int _8252 = _3183;
      for (int _3195 = _8251; _3195 < _8252; ++_3195)
      {
        {
          ++ _ptr__3191[safe_add( safe_add( _3167,(_ptr__3192[safe_add( _3187,_3195 )] / _3181) ),(int)1 )];
        }
      }
      int _8253 = (int)0;
      int _8254 = _3182;
      for (int _3196 = _8253; _3196 < _8254; ++_3196)
      {
        {
          _ptr__3191[safe_add( safe_add( _3167,_3196 ),(int)1 )] += _ptr__3191[safe_add( _3167,_3196 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3197 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3197(_3197 ? _3197->raw() : nullptr,_3197 ? _3197->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3198 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3198(_3198 ? _3198->raw() : nullptr,_3198 ? _3198->size(0) : 0);
      int _3199 = (int)0;
      int _3200 = (int)0;
      {
        int _8255 = (int)0;
        int _8256 = _3182;
        for (int _3201 = _8255; _3201 < _8256; ++_3201)
        {
          {
            int _3202 = _ptr__3191[safe_add( safe_add( _3172,_3201 ),(int)1 )];
            int _3203 = _ptr__3191[safe_add( _3172,_3201 )];
            int _3204 = _ptr__3191[safe_add( safe_add( _3167,_3201 ),(int)1 )];
            int _3205 = _ptr__3191[safe_add( _3167,_3201 )];
            bool _3206 = false;
            while ( ((_3205 < _3204) && (_3203 < _3202)) )
            {
              {
                int _3207 = _ptr__3191[safe_add( _3171,_3203 )];
                long long _3208 = (_ptr__3192[safe_add( _3187,_3205 )] % _3181);
                if ((_ptr__3197[_3207] < _3208))
                {
                  {
                    ++ _3203;
                  }
                }
                else if((_ptr__3197[_3207] > _3208))
                {
                  {
                    ++ _3205;
                  }
                }
                else
                {
                  {
                    _3206 = true;
                    _3199 += (_ptr__3191[safe_add( safe_add( _3186,_3205 ),(int)1 )] - _ptr__3191[safe_add( _3186,_3205 )]);
                    ++ _3205;
                    ++ _3203;
                  }
                }
              }
            }
            if (_3206)
            {
              {
                ++ _3200;
              }
            }
            {}
          }
        }
      }
      bool _3209 = (_3200 < _3182);
      int _3210 = _3163->alloci32(safe_add( _3200,(int)1 ));
      int _3211 = _3163->alloci64(_3199);
      int _3212 = _3163->alloci64(_3200);
      int _3213 = _3163->allocf64(_3199);
      int _3214 = _3163->allocf64(_3200);
      int _8257;
      bool _8258 = _3209;
      if (_8258)
      {
        _8257 = (int)1;
      }
      else
      {
        _8257 = (int)0;
      }
      _3163->pushi32(_8257);
      _3163->pushi32(_3199);
      _3163->pushi32(_3200);
      _3163->pushi32(_3182);
      _3163->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3215 = mosek::fusion::p_WorkStack::_get_impl(_3163)->i32;
      _checked_ptr_1<int> _ptr__3215(_3215 ? _3215->raw() : nullptr,_3215 ? _3215->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3216 = mosek::fusion::p_WorkStack::_get_impl(_3163)->i64;
      _checked_ptr_1<long long> _ptr__3216(_3216 ? _3216->raw() : nullptr,_3216 ? _3216->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3217 = mosek::fusion::p_WorkStack::_get_impl(_3163)->f64;
      _checked_ptr_1<double> _ptr__3217(_3217 ? _3217->raw() : nullptr,_3217 ? _3217->size(0) : 0);
      {
        int _3218 = (int)0;
        int _3219 = (int)0;
        _ptr__3215[_3210] = (int)0;
        int _8259 = (int)0;
        int _8260 = _3182;
        for (int _3220 = _8259; _3220 < _8260; ++_3220)
        {
          {
            int _3221 = _ptr__3191[safe_add( safe_add( _3172,_3220 ),(int)1 )];
            int _3222 = _ptr__3191[safe_add( _3172,_3220 )];
            int _3223 = _ptr__3191[safe_add( safe_add( _3167,_3220 ),(int)1 )];
            int _3224 = _ptr__3191[safe_add( _3167,_3220 )];
            bool _3225 = false;
            double _3226 = 0.0;
            while ( ((_3224 < _3223) && (_3222 < _3221)) )
            {
              {
                int _3227 = _ptr__3191[safe_add( _3171,_3222 )];
                long long _3228 = (_ptr__3192[safe_add( _3187,_3224 )] % _3181);
                if ((_ptr__3197[_3227] < _3228))
                {
                  {
                    ++ _3222;
                  }
                }
                else if((_ptr__3197[_3227] > _3228))
                {
                  {
                    ++ _3224;
                  }
                }
                else
                {
                  {
                    _3225 = true;
                    int _8261 = _ptr__3191[safe_add( _3186,_3224 )];
                    int _8262 = _ptr__3191[safe_add( safe_add( _3186,_3224 ),(int)1 )];
                    for (int _3229 = _8261; _3229 < _8262; ++_3229)
                    {
                      {
                        _ptr__3216[safe_add( _3211,_3219 )] = _ptr__3192[safe_add( _3188,_3229 )];
                        _ptr__3217[safe_add( _3213,_3219 )] = (_ptr__3193[safe_add( _3190,_3229 )] * _ptr__3198[_3227]);
                        ++ _3219;
                      }
                    }
                    _3226 += (_ptr__3193[safe_add( _3189,_3224 )] * _ptr__3198[_3227]);
                    ++ _3224;
                    ++ _3222;
                  }
                }
              }
            }
            if (_3225)
            {
              {
                _ptr__3215[safe_add( safe_add( _3210,_3218 ),(int)1 )] = _3219;
                _ptr__3216[safe_add( _3212,_3218 )] = _3220;
                _ptr__3217[safe_add( _3214,_3218 )] = _3226;
                ++ _3218;
              }
            }
            {}
          }
        }
      }
      if ((!_3209))
      {
        {
          _3163->popi64(_3200);
        }
      }
      {}
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _3230 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3230(_3230 ? _3230->raw() : nullptr,_3230 ? _3230->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3231 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3231(_3231 ? _3231->raw() : nullptr,_3231 ? _3231->size(0) : 0);
      int _3232 = (int)0;
      int _3233 = (int)0;
      {
        int _8263 = (int)0;
        int _8264 = _3182;
        for (int _3234 = _8263; _3234 < _8264; ++_3234)
        {
          {
            bool _3235 = false;
            int _8265 = _ptr__3191[safe_add( _3172,_3234 )];
            int _8266 = _ptr__3191[safe_add( safe_add( _3172,_3234 ),(int)1 )];
            for (int _3236 = _8265; _3236 < _8266; ++_3236)
            {
              {
                int _3237 = _ptr__3191[safe_add( _3171,_3236 )];
                int _3238 = safe_add( safe_mul( _3234,_3181 ),_ptr__3230[_3237] );
                _3233 += (_ptr__3191[safe_add( safe_add( _3186,_3238 ),(int)1 )] - _ptr__3191[safe_add( _3186,_3238 )]);
                if ((_ptr__3191[safe_add( safe_add( _3186,_3238 ),(int)1 )] > _ptr__3191[safe_add( _3186,_3238 )]))
                {
                  {
                    _3235 = true;
                  }
                }
                {}
              }
            }
            if (_3235)
            {
              {
                ++ _3232;
              }
            }
            {}
          }
        }
      }
      bool _3239 = (_3232 < _3182);
      int _3240 = _3163->alloci32(safe_add( _3232,(int)1 ));
      int _3241 = _3163->alloci64(_3233);
      int _3242 = _3163->alloci64(_3232);
      int _3243 = _3163->allocf64(_3233);
      int _3244 = _3163->allocf64(_3232);
      int _8267;
      bool _8268 = _3239;
      if (_8268)
      {
        _8267 = (int)1;
      }
      else
      {
        _8267 = (int)0;
      }
      _3163->pushi32(_8267);
      _3163->pushi32(_3233);
      _3163->pushi32(_3232);
      _3163->pushi32(_3182);
      _3163->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3245 = mosek::fusion::p_WorkStack::_get_impl(_3163)->i32;
      _checked_ptr_1<int> _ptr__3245(_3245 ? _3245->raw() : nullptr,_3245 ? _3245->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3246 = mosek::fusion::p_WorkStack::_get_impl(_3163)->i64;
      _checked_ptr_1<long long> _ptr__3246(_3246 ? _3246->raw() : nullptr,_3246 ? _3246->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3247 = mosek::fusion::p_WorkStack::_get_impl(_3163)->f64;
      _checked_ptr_1<double> _ptr__3247(_3247 ? _3247->raw() : nullptr,_3247 ? _3247->size(0) : 0);
      {
        int _3248 = (int)0;
        int _3249 = (int)0;
        _ptr__3245[_3240] = (int)0;
        int _8269 = (int)0;
        int _8270 = _3182;
        for (int _3250 = _8269; _3250 < _8270; ++_3250)
        {
          {
            bool _3251 = false;
            double _3252 = 0.0;
            int _8271 = _ptr__3191[safe_add( _3172,_3250 )];
            int _8272 = _ptr__3191[safe_add( safe_add( _3172,_3250 ),(int)1 )];
            for (int _3253 = _8271; _3253 < _8272; ++_3253)
            {
              {
                int _3254 = _ptr__3191[safe_add( _3171,_3253 )];
                int _3255 = safe_add( safe_mul( _3250,_3181 ),_ptr__3230[_3254] );
                int _8273 = _ptr__3191[safe_add( _3186,_3255 )];
                int _8274 = _ptr__3191[safe_add( safe_add( _3186,_3255 ),(int)1 )];
                for (int _3256 = _8273; _3256 < _8274; ++_3256)
                {
                  {
                    _3251 = true;
                    _ptr__3246[safe_add( _3241,_3249 )] = _ptr__3192[safe_add( _3188,_3256 )];
                    _ptr__3247[safe_add( _3243,_3249 )] = (_ptr__3193[safe_add( _3190,_3256 )] * _ptr__3231[_3254]);
                    ++ _3249;
                  }
                }
                _3252 += (_ptr__3193[safe_add( _3189,_3255 )] * _ptr__3231[_3254]);
              }
            }
            if (_3251)
            {
              {
                _ptr__3247[safe_add( _3244,_3248 )] = _3252;
                _ptr__3246[safe_add( _3242,_3248 )] = _3250;
                _ptr__3245[safe_add( safe_add( _3240,_3248 ),(int)1 )] = _3249;
                ++ _3248;
              }
            }
            {}
          }
        }
      }
      if ((!_3239))
      {
        {
          _3163->popi64(_3232);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagRight::validate(int _3257,int _3258,std::shared_ptr< monty::ndarray< int,1 > > _3259,std::shared_ptr< monty::ndarray< int,1 > > _3260,std::shared_ptr< monty::ndarray< double,1 > > _3261,monty::rc_ptr< ::mosek::fusion::Expression > _3262){
  _checked_ptr_1<int> _ptr__3259(_3259 ? _3259->raw() : nullptr, _3259 ? _3259->size(0) : 0);
  _checked_ptr_1<int> _ptr__3260(_3260 ? _3260->raw() : nullptr, _3260 ? _3260->size(0) : 0);
  _checked_ptr_1<double> _ptr__3261(_3261 ? _3261->raw() : nullptr, _3261 ? _3261->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3263 = _3262->getShape();
  _checked_ptr_1<int> _ptr__3263(_3263 ? _3263->raw() : nullptr,_3263 ? _3263->size(0) : 0);
  if (((int)((_3263)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3264 = _ptr__3263[(int)0];
  int _3265 = _ptr__3263[(int)1];
  if (((_3257 < (int)0) || ((_3258 < (int)0) || ((_3264 < (int)0) || (_3265 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3257 != _3265) || (_3258 != _3264)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3259)->size(0)) != (int)((_3260)->size(0))) || ((int)((_3259)->size(0)) != (int)((_3261)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3266 = (int)((_3259)->size(0));
  int _8275 = (int)0;
  int _8276 = _3266;
  for (int _3267 = _8275; _3267 < _8276; ++_3267)
  {
    {
      if (((_ptr__3259[_3267] < (int)0) || ((_ptr__3259[_3267] >= _3257) || ((_ptr__3260[_3267] < (int)0) || (_ptr__3260[_3267] >= _3258)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8277 = (int)0;
  int _8278 = (_3266 - (int)1);
  for (int _3268 = _8277; _3268 < _8278; ++_3268)
  {
    {
      if (((_ptr__3259[_3268] > _ptr__3259[safe_add( _3268,(int)1 )]) || ((_ptr__3259[_3268] == _ptr__3259[safe_add( _3268,(int)1 )]) && (_ptr__3260[_3268] >= _ptr__3260[safe_add( _3268,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8279 = (int)0;
  int _8280 = _3266;
  for (int _3269 = _8279; _3269 < _8280; ++_3269)
  {
    {
      if (((_ptr__3259[_3269] < (int)0) || ((_ptr__3259[_3269] >= _3257) || ((_ptr__3260[_3269] < (int)0) || (_ptr__3260[_3269] >= _3258)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagRight :: toString() { return mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagRight::toString(){
  return std::string ("ExprMulDiagRight()");
}
void mosek::fusion::p_ExprMulDiagRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagRight::destroy() { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft(mosek::fusion::p_ExprMulDiagLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagLeft()" << this << std::endl; */ }mosek::fusion::ExprMulDiagLeft::~ExprMulDiagLeft() {  /* std::cout << "~ExprMulDiagLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagLeft::p_ExprMulDiagLeft  (::mosek::fusion::ExprMulDiagLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3270,    int _3271,    std::shared_ptr< monty::ndarray< int,1 > > _3272,    std::shared_ptr< monty::ndarray< int,1 > > _3273,    std::shared_ptr< monty::ndarray< double,1 > > _3274,    monty::rc_ptr< ::mosek::fusion::Expression > _3275,    int _3276){ return new mosek::fusion::ExprMulDiagLeft(_3270,_3271,_3272,_3273,_3274,_3275,_3276); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3270,    int _3271,    std::shared_ptr< monty::ndarray< int,1 > > _3272,    std::shared_ptr< monty::ndarray< int,1 > > _3273,    std::shared_ptr< monty::ndarray< double,1 > > _3274,    monty::rc_ptr< ::mosek::fusion::Expression > _3275,    int _3276) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3270,_3271,_3272,_3273,_3274,_3275,_3276); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3270,    int _3271,    std::shared_ptr< monty::ndarray< int,1 > > _3272,    std::shared_ptr< monty::ndarray< int,1 > > _3273,    std::shared_ptr< monty::ndarray< double,1 > > _3274,    monty::rc_ptr< ::mosek::fusion::Expression > _3275,    int _3276){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3272(_3272 ? _3272->raw() : nullptr, _3272 ? _3272->size(0) : 0);
    _checked_ptr_1<int> _ptr__3273(_3273 ? _3273->raw() : nullptr, _3273 ? _3273->size(0) : 0);
    _checked_ptr_1<double> _ptr__3274(_3274 ? _3274->raw() : nullptr, _3274 ? _3274->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3270)}));
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim0 = _3270;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim1 = _3271;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubi = _3272;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubj = _3273;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mval = _3274;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr = _3275;
  }
}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3277,    int _3278,    std::shared_ptr< monty::ndarray< int,1 > > _3279,    std::shared_ptr< monty::ndarray< int,1 > > _3280,    std::shared_ptr< monty::ndarray< double,1 > > _3281,    monty::rc_ptr< ::mosek::fusion::Expression > _3282){ return new mosek::fusion::ExprMulDiagLeft(_3277,_3278,_3279,_3280,_3281,_3282); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3277,    int _3278,    std::shared_ptr< monty::ndarray< int,1 > > _3279,    std::shared_ptr< monty::ndarray< int,1 > > _3280,    std::shared_ptr< monty::ndarray< double,1 > > _3281,    monty::rc_ptr< ::mosek::fusion::Expression > _3282) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3277,_3278,_3279,_3280,_3281,_3282); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3277,    int _3278,    std::shared_ptr< monty::ndarray< int,1 > > _3279,    std::shared_ptr< monty::ndarray< int,1 > > _3280,    std::shared_ptr< monty::ndarray< double,1 > > _3281,    monty::rc_ptr< ::mosek::fusion::Expression > _3282){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3279(_3279 ? _3279->raw() : nullptr, _3279 ? _3279->size(0) : 0);
    _checked_ptr_1<int> _ptr__3280(_3280 ? _3280->raw() : nullptr, _3280 ? _3280->size(0) : 0);
    _checked_ptr_1<double> _ptr__3281(_3281 ? _3281->raw() : nullptr, _3281 ? _3281->size(0) : 0);
    mosek::fusion::p_ExprMulDiagLeft::_initialize(_3277,_3278,_3279,_3280,_3281,_3282,::mosek::fusion::p_ExprMulDiagLeft::validate(_3277,_3278,_3279,_3280,_3281,_3282));
  }
}void mosek::fusion::ExprMulDiagLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3283,monty::rc_ptr< ::mosek::fusion::WorkStack > _3284,monty::rc_ptr< ::mosek::fusion::WorkStack > _3285) { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->eval(_3283,_3284,_3285); }void mosek::fusion::p_ExprMulDiagLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3283,monty::rc_ptr< ::mosek::fusion::WorkStack > _3284,monty::rc_ptr< ::mosek::fusion::WorkStack > _3285){
  mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr->eval(_3284,_3283,_3285);
  if ((_3284->peeki32() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3286 = (int)((msubi)->size(0));
  int _3287 = (int)9999;
  int _3288 = (int)9999;
  int _3289 = (int)0;
  int _3290 = _3284->peeki32((int)5);
  if ((_3290 != (int)0))
  {
    {
      int _3291 = _3284->peeki32((int)1);
      int _3292 = _3284->peeki32((int)3);
      _3287 = _3284->alloci32(safe_add( _3291,(int)1 ));
      _3288 = _3284->alloci32(_3292);
      _3289 += safe_add( safe_add( _3292,_3291 ),(int)1 );
    }
  }
  {}
  int _3293 = _3284->alloci32(safe_add( mdim0,(int)1 ));
  _3289 += safe_add( mdim0,(int)1 );
  _3284->popi32(_3289);
  std::shared_ptr< monty::ndarray< int,1 > > _3294 = mosek::fusion::p_WorkStack::_get_impl(_3284)->i32;
  _checked_ptr_1<int> _ptr__3294(_3294 ? _3294->raw() : nullptr,_3294 ? _3294->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3295 = mosek::fusion::p_WorkStack::_get_impl(_3284)->i64;
  _checked_ptr_1<long long> _ptr__3295(_3295 ? _3295->raw() : nullptr,_3295 ? _3295->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3296 = mosek::fusion::p_WorkStack::_get_impl(_3284)->f64;
  _checked_ptr_1<double> _ptr__3296(_3296 ? _3296->raw() : nullptr,_3296 ? _3296->size(0) : 0);
  int _8281 = (int)0;
  int _8282 = safe_add( mdim0,(int)1 );
  for (int _3297 = _8281; _3297 < _8282; ++_3297)
  {
    {
      _ptr__3294[safe_add( _3293,_3297 )] = (int)0;
    }
  }
  int _8283 = (int)0;
  int _8284 = _3286;
  for (int _3298 = _8283; _3298 < _8284; ++_3298)
  {
    {
      ++ _ptr__3294[safe_add( safe_add( _3293,((*msubi)(_3298)) ),(int)1 )];
    }
  }
  int _8285 = (int)0;
  int _8286 = mdim0;
  for (int _3299 = _8285; _3299 < _8286; ++_3299)
  {
    {
      _ptr__3294[safe_add( safe_add( _3293,_3299 ),(int)1 )] += _ptr__3294[safe_add( _3293,_3299 )];
    }
  }
  int _3300 = _3284->popi32();
  int _3301 = _3284->popi32();
  int _3302 = _3284->popi32();
  int _3303 = _3284->popi32();
  int _3304 = _3284->popi32();
  bool _3305 = (_3284->popi32() != (int)0);
  int _3306 = _3284->popi32(safe_add( _3303,(int)1 ));
  int _8287;
  bool _8288 = _3305;
  if (_8288)
  {
    _8287 = _3284->popi64(_3303);
  }
  else
  {
    _8287 = (int)9999;
  }
  int _3307 = _8287;
  int _3308 = _3284->popi64(_3304);
  int _3309 = _3284->popf64(_3303);
  int _3310 = _3284->popf64(_3304);
  if ((!_3305))
  {
    {
      int _3311 = (int)((msubi)->size(0));
      int _3312 = (int)0;
      int _8289 = (int)0;
      int _8290 = mdim0;
      for (int _3313 = _8289; _3313 < _8290; ++_3313)
      {
        {
          if ((_ptr__3294[safe_add( _3293,_3313 )] < _ptr__3294[safe_add( safe_add( _3293,_3313 ),(int)1 )]))
          {
            {
              ++ _3312;
            }
          }
          {}
        }
      }
      bool _3314 = (_3312 < mdim0);
      int _3315 = _3283->alloci32(safe_add( _3312,(int)1 ));
      int _3316 = _3283->alloci64(_3311);
      int _3317 = _3283->alloci64(_3312);
      int _3318 = _3283->allocf64(_3311);
      int _3319 = _3283->allocf64(_3312);
      int _8291;
      bool _8292 = _3314;
      if (_8292)
      {
        _8291 = (int)1;
      }
      else
      {
        _8291 = (int)0;
      }
      _3283->pushi32(_8291);
      _3283->pushi32(_3311);
      _3283->pushi32(_3312);
      _3283->pushi32(mdim0);
      _3283->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3320 = mosek::fusion::p_WorkStack::_get_impl(_3283)->i32;
      _checked_ptr_1<int> _ptr__3320(_3320 ? _3320->raw() : nullptr,_3320 ? _3320->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3321 = mosek::fusion::p_WorkStack::_get_impl(_3283)->i64;
      _checked_ptr_1<long long> _ptr__3321(_3321 ? _3321->raw() : nullptr,_3321 ? _3321->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3322 = mosek::fusion::p_WorkStack::_get_impl(_3283)->f64;
      _checked_ptr_1<double> _ptr__3322(_3322 ? _3322->raw() : nullptr,_3322 ? _3322->size(0) : 0);
      {
        _ptr__3320[_3315] = (int)0;
        int _3323 = (int)0;
        int _3324 = (int)0;
        int _8293 = (int)0;
        int _8294 = mdim0;
        for (int _3325 = _8293; _3325 < _8294; ++_3325)
        {
          {
            if ((_ptr__3294[safe_add( _3293,_3325 )] < _ptr__3294[safe_add( safe_add( _3293,_3325 ),(int)1 )]))
            {
              {
                int _3326 = (int)0;
                int _8295 = _ptr__3294[safe_add( _3293,_3325 )];
                int _8296 = _ptr__3294[safe_add( safe_add( _3293,_3325 ),(int)1 )];
                for (int _3327 = _8295; _3327 < _8296; ++_3327)
                {
                  {
                    int _3328 = ((*msubj)(_3327));
                    int _3329 = safe_add( safe_mul( _3328,_3301 ),_3325 );
                    int _8297 = _ptr__3294[safe_add( _3306,_3329 )];
                    int _8298 = _ptr__3294[safe_add( safe_add( _3306,_3329 ),(int)1 )];
                    for (int _3330 = _8297; _3330 < _8298; ++_3330)
                    {
                      {
                        _ptr__3321[safe_add( _3316,_3324 )] = _ptr__3295[safe_add( _3308,_3330 )];
                        _ptr__3322[safe_add( _3318,_3324 )] = (_ptr__3296[safe_add( _3310,_3330 )] * ((*mval)(_3327)));
                        ++ _3324;
                      }
                    }
                  }
                }
                _ptr__3322[safe_add( _3319,_3323 )] = _3326;
                _ptr__3321[safe_add( _3317,_3323 )] = _3325;
                _ptr__3320[safe_add( safe_add( _3315,_3323 ),(int)1 )] = _3324;
                ++ _3323;
              }
            }
            {}
          }
        }
      }
      if ((!_3314))
      {
        {
          _3283->popi64(_3312);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _8299 = (int)0;
      int _8300 = safe_add( _3301,(int)1 );
      for (int _3331 = _8299; _3331 < _8300; ++_3331)
      {
        {
          _ptr__3294[safe_add( _3287,_3331 )] = (int)0;
        }
      }
      int _8301 = (int)0;
      int _8302 = _3303;
      for (int _3332 = _8301; _3332 < _8302; ++_3332)
      {
        {
          ++ _ptr__3294[safe_add( safe_add( _3287,(_ptr__3295[safe_add( _3307,_3332 )] % _3301) ),(int)1 )];
        }
      }
      int _8303 = (int)0;
      int _8304 = _3301;
      for (int _3333 = _8303; _3333 < _8304; ++_3333)
      {
        {
          _ptr__3294[safe_add( safe_add( _3287,_3333 ),(int)1 )] += _ptr__3294[safe_add( _3287,_3333 )];
        }
      }
      int _8305 = (int)0;
      int _8306 = _3303;
      for (int _3334 = _8305; _3334 < _8306; ++_3334)
      {
        {
          long long _3335 = (_ptr__3295[safe_add( _3307,_3334 )] % _3301);
          _ptr__3294[safe_add( _3288,_ptr__3294[safe_add( _3287,_3335 )] )] = _3334;
          ++ _ptr__3294[safe_add( _3287,_3335 )];
        }
      }
      int _8307 = (int)0;
      int _8308 = _3301;
      for (int _3336 = _8307; _3336 < _8308; ++_3336)
      {
        {
          _ptr__3294[(safe_add( _3287,_3301 ) - _3336)] = _ptr__3294[((safe_add( _3287,_3301 ) - _3336) - (int)1)];
        }
      }
      _ptr__3294[_3287] = (int)0;
      int _3337 = (int)0;
      int _3338 = (int)0;
      {
        int _8309 = (int)0;
        int _8310 = mdim0;
        for (int _3339 = _8309; _3339 < _8310; ++_3339)
        {
          {
            int _3340 = _ptr__3294[safe_add( safe_add( _3287,_3339 ),(int)1 )];
            int _3341 = _ptr__3294[safe_add( _3287,_3339 )];
            int _3342 = _ptr__3294[safe_add( safe_add( _3293,_3339 ),(int)1 )];
            int _3343 = _ptr__3294[safe_add( _3293,_3339 )];
            bool _3344 = false;
            while ( ((_3343 < _3342) && (_3341 < _3340)) )
            {
              {
                int _3345 = _ptr__3294[safe_add( _3288,_3341 )];
                long long _3346 = (_ptr__3295[safe_add( _3307,_3345 )] / _3301);
                if ((((*msubj)(_3343)) < _3346))
                {
                  {
                    ++ _3343;
                  }
                }
                else if((((*msubj)(_3343)) > _3346))
                {
                  {
                    ++ _3341;
                  }
                }
                else
                {
                  {
                    _3344 = true;
                    _3338 += (_ptr__3294[safe_add( safe_add( _3306,_3345 ),(int)1 )] - _ptr__3294[safe_add( _3306,_3345 )]);
                    ++ _3343;
                    ++ _3341;
                  }
                }
              }
            }
            if (_3344)
            {
              {
                ++ _3337;
              }
            }
            {}
          }
        }
      }
      int _3347 = _3337;
      int _3348 = _3338;
      bool _3349 = (_3347 < mdim0);
      int _3350 = _3283->alloci32(safe_add( _3347,(int)1 ));
      int _3351 = _3283->alloci64(_3348);
      int _3352 = _3283->alloci64(_3347);
      int _3353 = _3283->allocf64(_3348);
      int _3354 = _3283->allocf64(_3347);
      int _8311;
      bool _8312 = _3349;
      if (_8312)
      {
        _8311 = (int)1;
      }
      else
      {
        _8311 = (int)0;
      }
      _3283->pushi32(_8311);
      _3283->pushi32(_3348);
      _3283->pushi32(_3347);
      _3283->pushi32(mdim0);
      _3283->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3355 = mosek::fusion::p_WorkStack::_get_impl(_3283)->i32;
      _checked_ptr_1<int> _ptr__3355(_3355 ? _3355->raw() : nullptr,_3355 ? _3355->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3356 = mosek::fusion::p_WorkStack::_get_impl(_3283)->i64;
      _checked_ptr_1<long long> _ptr__3356(_3356 ? _3356->raw() : nullptr,_3356 ? _3356->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3357 = mosek::fusion::p_WorkStack::_get_impl(_3283)->f64;
      _checked_ptr_1<double> _ptr__3357(_3357 ? _3357->raw() : nullptr,_3357 ? _3357->size(0) : 0);
      {
        _ptr__3355[_3350] = (int)0;
        int _3358 = (int)0;
        int _3359 = (int)0;
        int _8313 = (int)0;
        int _8314 = mdim0;
        for (int _3360 = _8313; _3360 < _8314; ++_3360)
        {
          {
            int _3361 = _ptr__3294[safe_add( safe_add( _3287,_3360 ),(int)1 )];
            int _3362 = _ptr__3294[safe_add( _3287,_3360 )];
            int _3363 = _ptr__3294[safe_add( safe_add( _3293,_3360 ),(int)1 )];
            int _3364 = _ptr__3294[safe_add( _3293,_3360 )];
            bool _3365 = false;
            double _3366 = 0.0;
            while ( ((_3364 < _3363) && (_3362 < _3361)) )
            {
              {
                int _3367 = _ptr__3294[safe_add( _3288,_3362 )];
                long long _3368 = (_ptr__3295[safe_add( _3307,_3367 )] / _3301);
                if ((((*msubj)(_3364)) < _3368))
                {
                  {
                    ++ _3364;
                  }
                }
                else if((((*msubj)(_3364)) > _3368))
                {
                  {
                    ++ _3362;
                  }
                }
                else
                {
                  {
                    _3365 = true;
                    int _8315 = _ptr__3294[safe_add( _3306,_3367 )];
                    int _8316 = _ptr__3294[safe_add( safe_add( _3306,_3367 ),(int)1 )];
                    for (int _3369 = _8315; _3369 < _8316; ++_3369)
                    {
                      {
                        _ptr__3356[safe_add( _3351,_3359 )] = _ptr__3295[safe_add( _3308,_3369 )];
                        _ptr__3357[safe_add( _3353,_3359 )] = (_ptr__3296[safe_add( _3310,_3369 )] * ((*mval)(_3364)));
                        ++ _3359;
                      }
                    }
                    _3366 += _ptr__3296[safe_add( _3309,_3367 )];
                    ++ _3364;
                    ++ _3362;
                  }
                }
              }
            }
            if (_3365)
            {
              {
                _ptr__3356[safe_add( _3352,_3358 )] = _3360;
                _ptr__3357[safe_add( _3354,_3358 )] = (_3366 * ((*mval)(_3364)));
                _ptr__3355[safe_add( safe_add( _3350,_3358 ),(int)1 )] = _3359;
                ++ _3358;
              }
            }
            {}
          }
        }
      }
      if ((!_3349))
      {
        {
          _3283->popi64(_3347);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagLeft::validate(int _3370,int _3371,std::shared_ptr< monty::ndarray< int,1 > > _3372,std::shared_ptr< monty::ndarray< int,1 > > _3373,std::shared_ptr< monty::ndarray< double,1 > > _3374,monty::rc_ptr< ::mosek::fusion::Expression > _3375){
  _checked_ptr_1<int> _ptr__3372(_3372 ? _3372->raw() : nullptr, _3372 ? _3372->size(0) : 0);
  _checked_ptr_1<int> _ptr__3373(_3373 ? _3373->raw() : nullptr, _3373 ? _3373->size(0) : 0);
  _checked_ptr_1<double> _ptr__3374(_3374 ? _3374->raw() : nullptr, _3374 ? _3374->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3376 = _3375->getShape();
  _checked_ptr_1<int> _ptr__3376(_3376 ? _3376->raw() : nullptr,_3376 ? _3376->size(0) : 0);
  if (((int)((_3376)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3377 = _ptr__3376[(int)0];
  int _3378 = _ptr__3376[(int)1];
  if (((_3370 < (int)0) || (_3371 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3371 != _3377) || (_3370 != _3378)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3372)->size(0)) != (int)((_3373)->size(0))) || ((int)((_3372)->size(0)) != (int)((_3374)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3379 = (int)((_3372)->size(0));
  int _8317 = (int)0;
  int _8318 = _3379;
  for (int _3380 = _8317; _3380 < _8318; ++_3380)
  {
    {
      if (((_ptr__3372[_3380] < (int)0) || ((_ptr__3372[_3380] >= _3370) || ((_ptr__3373[_3380] < (int)0) || (_ptr__3373[_3380] >= _3371)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8319 = (int)0;
  int _8320 = (_3379 - (int)1);
  for (int _3381 = _8319; _3381 < _8320; ++_3381)
  {
    {
      if (((_ptr__3372[_3381] > _ptr__3372[safe_add( _3381,(int)1 )]) || ((_ptr__3372[_3381] == _ptr__3372[safe_add( _3381,(int)1 )]) && (_ptr__3373[_3381] >= _ptr__3373[safe_add( _3381,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8321 = (int)0;
  int _8322 = _3379;
  for (int _3382 = _8321; _3382 < _8322; ++_3382)
  {
    {
      if (((_ptr__3372[_3382] < (int)0) || ((_ptr__3372[_3382] >= _3370) || ((_ptr__3373[_3382] < (int)0) || (_ptr__3373[_3382] >= _3371)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagLeft :: toString() { return mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagLeft::toString(){
  return std::string ("ExprMulDiagLeft()");
}
void mosek::fusion::p_ExprMulDiagLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagLeft::destroy() { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulElement::ExprMulElement(mosek::fusion::p_ExprMulElement *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulElement()" << this << std::endl; */ }mosek::fusion::ExprMulElement::~ExprMulElement() {  /* std::cout << "~ExprMulElement()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulElement::p_ExprMulElement  (::mosek::fusion::ExprMulElement * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3383,    std::shared_ptr< monty::ndarray< long long,1 > > _3384,    monty::rc_ptr< ::mosek::fusion::Expression > _3385){ return new mosek::fusion::ExprMulElement(_3383,_3384,_3385); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3383,    std::shared_ptr< monty::ndarray< long long,1 > > _3384,    monty::rc_ptr< ::mosek::fusion::Expression > _3385) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3383,_3384,_3385); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3383,    std::shared_ptr< monty::ndarray< long long,1 > > _3384,    monty::rc_ptr< ::mosek::fusion::Expression > _3385){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3383(_3383 ? _3383->raw() : nullptr, _3383 ? _3383->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3384(_3384 ? _3384->raw() : nullptr, _3384 ? _3384->size(0) : 0);
    mosek::fusion::p_ExprMulElement::_initialize(_3383,_3384,_3385,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3386 = _3385->getShape();
    _checked_ptr_1<int> _ptr__3386(_3386 ? _3386->raw() : nullptr,_3386 ? _3386->size(0) : 0);
    if (((int)((_3383)->size(0)) != (int)((_3384)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix specification"));
      }
    }
    {}
    long long _3387 = ::mosek::fusion::p_Set::size(_3386);
    int _8323 = (int)0;
    int _8324 = (int)((_3384)->size(0));
    for (int _3388 = _8323; _3388 < _8324; ++_3388)
    {
      {
        if (((_ptr__3384[_3388] < (int)0) || (_ptr__3384[_3388] >= _3387)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
          }
        }
        {}
      }
    }
    int _8325 = (int)0;
    int _8326 = ((int)((_3384)->size(0)) - (int)1);
    for (int _3389 = _8325; _3389 < _8326; ++_3389)
    {
      {
        if ((_ptr__3384[_3389] >= _ptr__3384[safe_add( _3389,(int)1 )]))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Matrix data not sorted"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3390,    std::shared_ptr< monty::ndarray< long long,1 > > _3391,    monty::rc_ptr< ::mosek::fusion::Expression > _3392,    int _3393){ return new mosek::fusion::ExprMulElement(_3390,_3391,_3392,_3393); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3390,    std::shared_ptr< monty::ndarray< long long,1 > > _3391,    monty::rc_ptr< ::mosek::fusion::Expression > _3392,    int _3393) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3390,_3391,_3392,_3393); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3390,    std::shared_ptr< monty::ndarray< long long,1 > > _3391,    monty::rc_ptr< ::mosek::fusion::Expression > _3392,    int _3393){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3390(_3390 ? _3390->raw() : nullptr, _3390 ? _3390->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3391(_3391 ? _3391->raw() : nullptr, _3391 ? _3391->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_3392->getShape());
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->expr = _3392;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->mcof = _3390;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->msp = _3391;
  }
}void mosek::fusion::ExprMulElement :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3394,monty::rc_ptr< ::mosek::fusion::WorkStack > _3395,monty::rc_ptr< ::mosek::fusion::WorkStack > _3396) { mosek::fusion::p_ExprMulElement::_get_impl(this)->eval(_3394,_3395,_3396); }void mosek::fusion::p_ExprMulElement::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3394,monty::rc_ptr< ::mosek::fusion::WorkStack > _3395,monty::rc_ptr< ::mosek::fusion::WorkStack > _3396){
  expr->eval(_3395,_3394,_3396);
  int _3397 = _3395->popi32();
  int _3398 = _3395->popi32(_3397);
  int _3399 = _3395->popi32();
  int _3400 = _3395->popi32();
  bool _3401 = (_3395->popi32() != (int)0);
  int _3402 = _3395->popi32(safe_add( _3399,(int)1 ));
  int _8327;
  bool _8328 = _3401;
  if (_8328)
  {
    _8327 = _3395->popi64(_3399);
  }
  else
  {
    _8327 = (-(int)1);
  }
  int _3403 = _8327;
  int _3404 = _3395->popi64(_3400);
  int _3405 = _3395->popf64(_3399);
  int _3406 = _3395->popf64(_3400);
  std::shared_ptr< monty::ndarray< int,1 > > _3407 = mosek::fusion::p_WorkStack::_get_impl(_3395)->i32;
  _checked_ptr_1<int> _ptr__3407(_3407 ? _3407->raw() : nullptr,_3407 ? _3407->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3408 = mosek::fusion::p_WorkStack::_get_impl(_3395)->i64;
  _checked_ptr_1<long long> _ptr__3408(_3408 ? _3408->raw() : nullptr,_3408 ? _3408->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3409 = mosek::fusion::p_WorkStack::_get_impl(_3395)->f64;
  _checked_ptr_1<double> _ptr__3409(_3409 ? _3409->raw() : nullptr,_3409 ? _3409->size(0) : 0);
  int _3410 = (int)0;
  int _3411 = (int)0;
  if ((!_3401))
  {
    {
      _3411 = (int)((msp)->size(0));
      int _8329 = (int)0;
      int _8330 = (int)((msp)->size(0));
      for (int _3412 = _8329; _3412 < _8330; ++_3412)
      {
        {
          _3410 += (_ptr__3407[safe_add( safe_add( _3402,((*msp)(_3412)) ),(int)1 )] - _ptr__3407[safe_add( _3402,((*msp)(_3412)) )]);
        }
      }
    }
  }
  else
  {
    {
      int _3413 = (int)((msp)->size(0));
      int _3414 = (int)0;
      int _3415 = _3399;
      int _3416 = (int)0;
      while ( ((_3414 < _3413) && (_3416 < _3415)) )
      {
        {
          if ((((*msp)(_3414)) < _ptr__3408[safe_add( _3403,_3416 )]))
          {
            {
              ++ _3414;
            }
          }
          else if((((*msp)(_3414)) > _ptr__3408[safe_add( _3403,_3416 )]))
          {
            {
              ++ _3416;
            }
          }
          else
          {
            {
              _3410 += (_ptr__3407[safe_add( safe_add( _3402,_3416 ),(int)1 )] - _ptr__3407[safe_add( _3402,_3416 )]);
              ++ _3414;
              ++ _3416;
              ++ _3411;
            }
          }
        }
      }
    }
  }
  int _3417 = _3394->alloci32(safe_add( _3411,(int)1 ));
  int _3418 = _3394->alloci64(_3410);
  int _3419 = _3394->alloci64(_3411);
  int _3420 = _3394->allocf64(_3410);
  int _3421 = _3394->allocf64(_3411);
  int _3422 = (int)1;
  int _8331 = (int)0;
  int _8332 = _3397;
  for (int _3423 = _8331; _3423 < _8332; ++_3423)
  {
    {
      _3422 *= _ptr__3407[safe_add( _3398,_3423 )];
    }
  }
  bool _3424 = (_3411 < _3422);
  int _8333;
  bool _8334 = _3424;
  if (_8334)
  {
    _8333 = (int)1;
  }
  else
  {
    _8333 = (int)0;
  }
  _3394->pushi32(_8333);
  _3394->pushi32(_3410);
  _3394->pushi32(_3411);
  int _3425 = _3394->alloci32(_3397);
  _3394->pushi32(_3397);
  std::shared_ptr< monty::ndarray< int,1 > > _3426 = mosek::fusion::p_WorkStack::_get_impl(_3394)->i32;
  _checked_ptr_1<int> _ptr__3426(_3426 ? _3426->raw() : nullptr,_3426 ? _3426->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3427 = mosek::fusion::p_WorkStack::_get_impl(_3394)->i64;
  _checked_ptr_1<long long> _ptr__3427(_3427 ? _3427->raw() : nullptr,_3427 ? _3427->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3428 = mosek::fusion::p_WorkStack::_get_impl(_3394)->f64;
  _checked_ptr_1<double> _ptr__3428(_3428 ? _3428->raw() : nullptr,_3428 ? _3428->size(0) : 0);
  {
    int _3429 = (int)0;
    int _3430 = (int)0;
    _ptr__3426[_3417] = (int)0;
    int _8335 = (int)0;
    int _8336 = _3397;
    for (int _3431 = _8335; _3431 < _8336; ++_3431)
    {
      {
        _ptr__3426[safe_add( _3425,_3431 )] = _ptr__3407[safe_add( _3398,_3431 )];
      }
    }
    if ((!_3401))
    {
      {
        int _8337 = (int)0;
        int _8338 = (int)((msp)->size(0));
        for (int _3432 = _8337; _3432 < _8338; ++_3432)
        {
          {
            int _3433 = _ptr__3407[safe_add( _3402,((*msp)(_3432)) )];
            int _3434 = _ptr__3407[safe_add( safe_add( _3402,((*msp)(_3432)) ),(int)1 )];
            int _8339 = _3433;
            int _8340 = _3434;
            for (int _3435 = _8339; _3435 < _8340; ++_3435)
            {
              {
                _ptr__3427[safe_add( _3418,_3430 )] = _ptr__3408[safe_add( _3404,_3435 )];
                _ptr__3428[safe_add( _3420,_3430 )] = (_ptr__3409[safe_add( _3406,_3435 )] * ((*mcof)(_3432)));
                ++ _3430;
              }
            }
            _ptr__3426[safe_add( safe_add( _3417,_3432 ),(int)1 )] = _3430;
            _ptr__3428[safe_add( _3421,_3432 )] = (_ptr__3409[safe_add( _3405,((*msp)(_3432)) )] * ((*mcof)(_3432)));
            _ptr__3427[safe_add( _3419,_3432 )] = ((*msp)(_3432));
          }
        }
      }
    }
    else
    {
      {
        int _3436 = (int)((msp)->size(0));
        int _3437 = (int)0;
        int _3438 = _3399;
        int _3439 = (int)0;
        while ( ((_3437 < _3436) && (_3439 < _3438)) )
        {
          {
            if ((((*msp)(_3437)) < _ptr__3408[safe_add( _3403,_3439 )]))
            {
              {
                ++ _3437;
              }
            }
            else if((((*msp)(_3437)) > _ptr__3408[safe_add( _3403,_3439 )]))
            {
              {
                ++ _3439;
              }
            }
            else
            {
              {
                int _3440 = _ptr__3407[safe_add( _3402,_3439 )];
                int _3441 = _ptr__3407[safe_add( safe_add( _3402,_3439 ),(int)1 )];
                int _8341 = _3440;
                int _8342 = _3441;
                for (int _3442 = _8341; _3442 < _8342; ++_3442)
                {
                  {
                    _ptr__3427[safe_add( _3418,_3430 )] = _ptr__3408[safe_add( _3404,_3442 )];
                    _ptr__3428[safe_add( _3418,_3430 )] = (_ptr__3409[safe_add( _3404,_3442 )] * ((*mcof)(_3437)));
                    ++ _3430;
                  }
                }
                _ptr__3426[safe_add( safe_add( _3417,_3429 ),(int)1 )] = _3430;
                _ptr__3428[safe_add( _3421,_3429 )] = (_ptr__3409[safe_add( _3405,_3439 )] * ((*mcof)(_3437)));
                _ptr__3427[safe_add( _3419,_3429 )] = ((*msp)(_3437));
                ++ _3429;
                ++ _3437;
                ++ _3439;
              }
            }
          }
        }
      }
    }
  }
  if ((!_3424))
  {
    {
      _3394->popi64(_3411);
    }
  }
  {}
}
std::string mosek::fusion::ExprMulElement :: toString() { return mosek::fusion::p_ExprMulElement::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulElement::toString(){
  return std::string ("ExprMulElement()");
}
void mosek::fusion::p_ExprMulElement::destroy(){expr.reset();msp.reset();mcof.reset();}void mosek::fusion::ExprMulElement::destroy() { mosek::fusion::p_ExprMulElement::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst(mosek::fusion::p_ExprMulScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulScalarConst::~ExprMulScalarConst() {  /* std::cout << "~ExprMulScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarConst::p_ExprMulScalarConst  (::mosek::fusion::ExprMulScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarConst::t mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst  (double _3443,    monty::rc_ptr< ::mosek::fusion::Expression > _3444){ return new mosek::fusion::ExprMulScalarConst(_3443,_3444); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst  (double _3443,    monty::rc_ptr< ::mosek::fusion::Expression > _3444) :    ExprMulScalarConst(new mosek::fusion::p_ExprMulScalarConst(this)){ mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->_initialize(_3443,_3444); }void mosek::fusion::p_ExprMulScalarConst::_initialize  (double _3443,    monty::rc_ptr< ::mosek::fusion::Expression > _3444){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3444->getShape());
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->c = _3443;
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->expr = _3444;
  }
}void mosek::fusion::ExprMulScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3445,monty::rc_ptr< ::mosek::fusion::WorkStack > _3446,monty::rc_ptr< ::mosek::fusion::WorkStack > _3447) { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->eval(_3445,_3446,_3447); }void mosek::fusion::p_ExprMulScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3445,monty::rc_ptr< ::mosek::fusion::WorkStack > _3446,monty::rc_ptr< ::mosek::fusion::WorkStack > _3447){
  expr->eval(_3445,_3446,_3447);
  int _3448 = _3445->peeki32((int)0);
  int _3449 = _3445->peeki32(safe_add( _3448,(int)1 ));
  int _3450 = _3445->peeki32(safe_add( _3448,(int)2 ));
  int _3451 = (mosek::fusion::p_WorkStack::_get_impl(_3445)->pf64 - _3449);
  int _3452 = (_3451 - _3450);
  std::shared_ptr< monty::ndarray< double,1 > > _3453 = mosek::fusion::p_WorkStack::_get_impl(_3445)->f64;
  _checked_ptr_1<double> _ptr__3453(_3453 ? _3453->raw() : nullptr,_3453 ? _3453->size(0) : 0);
  int _8343 = (int)0;
  int _8344 = safe_add( _3450,_3449 );
  for (int _3454 = _8343; _3454 < _8344; ++_3454)
  {
    {
      _ptr__3453[safe_add( _3452,_3454 )] *= c;
    }
  }
}
std::string mosek::fusion::ExprMulScalarConst :: toString() { return mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarConst::toString(){
  return std::string ("ExprMulScalarConst()");
}
void mosek::fusion::p_ExprMulScalarConst::destroy(){expr.reset();}void mosek::fusion::ExprMulScalarConst::destroy() { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprScalarMul::ExprScalarMul(mosek::fusion::p_ExprScalarMul *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprScalarMul()" << this << std::endl; */ }mosek::fusion::ExprScalarMul::~ExprScalarMul() {  /* std::cout << "~ExprScalarMul()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprScalarMul::p_ExprScalarMul  (::mosek::fusion::ExprScalarMul * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3455,    int _3456,    std::shared_ptr< monty::ndarray< int,1 > > _3457,    std::shared_ptr< monty::ndarray< int,1 > > _3458,    std::shared_ptr< monty::ndarray< double,1 > > _3459,    monty::rc_ptr< ::mosek::fusion::Expression > _3460,    int _3461){ return new mosek::fusion::ExprScalarMul(_3455,_3456,_3457,_3458,_3459,_3460,_3461); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3455,    int _3456,    std::shared_ptr< monty::ndarray< int,1 > > _3457,    std::shared_ptr< monty::ndarray< int,1 > > _3458,    std::shared_ptr< monty::ndarray< double,1 > > _3459,    monty::rc_ptr< ::mosek::fusion::Expression > _3460,    int _3461) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3455,_3456,_3457,_3458,_3459,_3460,_3461); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3455,    int _3456,    std::shared_ptr< monty::ndarray< int,1 > > _3457,    std::shared_ptr< monty::ndarray< int,1 > > _3458,    std::shared_ptr< monty::ndarray< double,1 > > _3459,    monty::rc_ptr< ::mosek::fusion::Expression > _3460,    int _3461){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3457(_3457 ? _3457->raw() : nullptr, _3457 ? _3457->size(0) : 0);
    _checked_ptr_1<int> _ptr__3458(_3458 ? _3458->raw() : nullptr, _3458 ? _3458->size(0) : 0);
    _checked_ptr_1<double> _ptr__3459(_3459 ? _3459->raw() : nullptr, _3459 ? _3459->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3455),(int)(_3456)}));
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim0 = _3455;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim1 = _3456;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubi = _3457;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubj = _3458;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mval = _3459;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr = _3460;
  }
}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3462,    int _3463,    std::shared_ptr< monty::ndarray< int,1 > > _3464,    std::shared_ptr< monty::ndarray< int,1 > > _3465,    std::shared_ptr< monty::ndarray< double,1 > > _3466,    monty::rc_ptr< ::mosek::fusion::Expression > _3467){ return new mosek::fusion::ExprScalarMul(_3462,_3463,_3464,_3465,_3466,_3467); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3462,    int _3463,    std::shared_ptr< monty::ndarray< int,1 > > _3464,    std::shared_ptr< monty::ndarray< int,1 > > _3465,    std::shared_ptr< monty::ndarray< double,1 > > _3466,    monty::rc_ptr< ::mosek::fusion::Expression > _3467) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3462,_3463,_3464,_3465,_3466,_3467); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3462,    int _3463,    std::shared_ptr< monty::ndarray< int,1 > > _3464,    std::shared_ptr< monty::ndarray< int,1 > > _3465,    std::shared_ptr< monty::ndarray< double,1 > > _3466,    monty::rc_ptr< ::mosek::fusion::Expression > _3467){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3464(_3464 ? _3464->raw() : nullptr, _3464 ? _3464->size(0) : 0);
    _checked_ptr_1<int> _ptr__3465(_3465 ? _3465->raw() : nullptr, _3465 ? _3465->size(0) : 0);
    _checked_ptr_1<double> _ptr__3466(_3466 ? _3466->raw() : nullptr, _3466 ? _3466->size(0) : 0);
    mosek::fusion::p_ExprScalarMul::_initialize(_3462,_3463,_3464,_3465,_3466,_3467,::mosek::fusion::p_ExprScalarMul::validate(_3462,_3463,_3464,_3465,_3466,_3467));
  }
}void mosek::fusion::ExprScalarMul :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3468,monty::rc_ptr< ::mosek::fusion::WorkStack > _3469,monty::rc_ptr< ::mosek::fusion::WorkStack > _3470) { mosek::fusion::p_ExprScalarMul::_get_impl(this)->eval(_3468,_3469,_3470); }void mosek::fusion::p_ExprScalarMul::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3468,monty::rc_ptr< ::mosek::fusion::WorkStack > _3469,monty::rc_ptr< ::mosek::fusion::WorkStack > _3470){
  mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr->eval(_3469,_3468,_3470);
  _3469->pop_expr();
  int _3471 = mosek::fusion::p_WorkStack::_get_impl(_3469)->nd;
  int _3472 = mosek::fusion::p_WorkStack::_get_impl(_3469)->nelem;
  int _3473 = mosek::fusion::p_WorkStack::_get_impl(_3469)->nnz;
  bool _3474 = mosek::fusion::p_WorkStack::_get_impl(_3469)->hassp;
  int _3475 = mosek::fusion::p_WorkStack::_get_impl(_3469)->ptr_base;
  int _3476 = mosek::fusion::p_WorkStack::_get_impl(_3469)->sp_base;
  int _3477 = mosek::fusion::p_WorkStack::_get_impl(_3469)->nidxs_base;
  int _3478 = mosek::fusion::p_WorkStack::_get_impl(_3469)->bfix_base;
  int _3479 = mosek::fusion::p_WorkStack::_get_impl(_3469)->cof_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3480 = mosek::fusion::p_WorkStack::_get_impl(_3469)->i64;
  _checked_ptr_1<long long> _ptr__3480(_3480 ? _3480->raw() : nullptr,_3480 ? _3480->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3481 = mosek::fusion::p_WorkStack::_get_impl(_3469)->f64;
  _checked_ptr_1<double> _ptr__3481(_3481 ? _3481->raw() : nullptr,_3481 ? _3481->size(0) : 0);
  int _3482 = (int)((mval)->size(0));
  if ((_3471 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression shape"));
    }
  }
  {}
  if ((_3472 == (int)0))
  {
    {
      _3468->alloc_expr((int)2,(int)0,(int)0,true);
      ((*mosek::fusion::p_WorkStack::_get_impl(_3468)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3468)->shape_base)) = mdim0;
      ((*mosek::fusion::p_WorkStack::_get_impl(_3468)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_3468)->shape_base,(int)1 ))) = mdim1;
    }
  }
  else
  {
    {
      _3468->alloc_expr((int)2,_3482,safe_mul( _3482,_3473 ),true);
      int _3483 = mosek::fusion::p_WorkStack::_get_impl(_3468)->ptr_base;
      int _3484 = mosek::fusion::p_WorkStack::_get_impl(_3468)->nidxs_base;
      int _3485 = mosek::fusion::p_WorkStack::_get_impl(_3468)->sp_base;
      int _3486 = mosek::fusion::p_WorkStack::_get_impl(_3468)->cof_base;
      int _3487 = mosek::fusion::p_WorkStack::_get_impl(_3468)->bfix_base;
      int _3488 = mosek::fusion::p_WorkStack::_get_impl(_3468)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _3489 = mosek::fusion::p_WorkStack::_get_impl(_3468)->i32;
      _checked_ptr_1<int> _ptr__3489(_3489 ? _3489->raw() : nullptr,_3489 ? _3489->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3490 = mosek::fusion::p_WorkStack::_get_impl(_3468)->i64;
      _checked_ptr_1<long long> _ptr__3490(_3490 ? _3490->raw() : nullptr,_3490 ? _3490->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3491 = mosek::fusion::p_WorkStack::_get_impl(_3468)->f64;
      _checked_ptr_1<double> _ptr__3491(_3491 ? _3491->raw() : nullptr,_3491 ? _3491->size(0) : 0);
      _ptr__3489[_3488] = mdim0;
      _ptr__3489[safe_add( _3488,(int)1 )] = mdim1;
      int _3492 = (int)0;
      _ptr__3489[_3483] = (int)0;
      int _8345 = (int)0;
      int _8346 = _3482;
      for (int _3493 = _8345; _3493 < _8346; ++_3493)
      {
        {
          int _8347 = (int)0;
          int _8348 = _3473;
          for (int _3494 = _8347; _3494 < _8348; ++_3494)
          {
            {
              _ptr__3490[safe_add( _3484,_3492 )] = _ptr__3480[safe_add( _3477,_3494 )];
              _ptr__3491[safe_add( _3486,_3492 )] = (_ptr__3481[safe_add( _3479,_3494 )] * ((*mval)(_3493)));
              ++ _3492;
            }
          }
          _ptr__3490[safe_add( _3485,_3493 )] = safe_add( safe_mul( ((*msubi)(_3493)),mdim1 ),((*msubj)(_3493)) );
          _ptr__3491[safe_add( _3487,_3493 )] = (((*mval)(_3493)) * _ptr__3481[_3478]);
          _ptr__3489[safe_add( safe_add( _3483,_3493 ),(int)1 )] = _3492;
        }
      }
    }
  }
}
int mosek::fusion::p_ExprScalarMul::validate(int _3495,int _3496,std::shared_ptr< monty::ndarray< int,1 > > _3497,std::shared_ptr< monty::ndarray< int,1 > > _3498,std::shared_ptr< monty::ndarray< double,1 > > _3499,monty::rc_ptr< ::mosek::fusion::Expression > _3500){
  _checked_ptr_1<int> _ptr__3497(_3497 ? _3497->raw() : nullptr, _3497 ? _3497->size(0) : 0);
  _checked_ptr_1<int> _ptr__3498(_3498 ? _3498->raw() : nullptr, _3498 ? _3498->size(0) : 0);
  _checked_ptr_1<double> _ptr__3499(_3499 ? _3499->raw() : nullptr, _3499 ? _3499->size(0) : 0);
  int _3501 = _3500->getND();
  if ((_3501 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3495 < (int)0) || (_3496 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((((int)((_3497)->size(0)) != (int)((_3498)->size(0))) || ((int)((_3497)->size(0)) != (int)((_3499)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3502 = (int)((_3497)->size(0));
  int _8349 = (int)0;
  int _8350 = _3502;
  for (int _3503 = _8349; _3503 < _8350; ++_3503)
  {
    {
      if (((_ptr__3497[_3503] < (int)0) || ((_ptr__3497[_3503] >= _3495) || ((_ptr__3498[_3503] < (int)0) || (_ptr__3498[_3503] >= _3496)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8351 = (int)0;
  int _8352 = (_3502 - (int)1);
  for (int _3504 = _8351; _3504 < _8352; ++_3504)
  {
    {
      if (((_ptr__3497[_3504] > _ptr__3497[safe_add( _3504,(int)1 )]) || ((_ptr__3497[_3504] == _ptr__3497[safe_add( _3504,(int)1 )]) && (_ptr__3498[_3504] >= _ptr__3498[safe_add( _3504,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8353 = (int)0;
  int _8354 = _3502;
  for (int _3505 = _8353; _3505 < _8354; ++_3505)
  {
    {
      if (((_ptr__3497[_3505] < (int)0) || ((_ptr__3497[_3505] >= _3495) || ((_ptr__3498[_3505] < (int)0) || (_ptr__3498[_3505] >= _3496)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprScalarMul :: toString() { return mosek::fusion::p_ExprScalarMul::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprScalarMul::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprScalarMul(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprScalarMul::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprScalarMul::destroy() { mosek::fusion::p_ExprScalarMul::_get_impl(this)->destroy(); }mosek::fusion::ExprMulRight::ExprMulRight(mosek::fusion::p_ExprMulRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulRight()" << this << std::endl; */ }mosek::fusion::ExprMulRight::~ExprMulRight() {  /* std::cout << "~ExprMulRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulRight::p_ExprMulRight  (::mosek::fusion::ExprMulRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3506,    int _3507,    std::shared_ptr< monty::ndarray< int,1 > > _3508,    std::shared_ptr< monty::ndarray< int,1 > > _3509,    std::shared_ptr< monty::ndarray< double,1 > > _3510,    monty::rc_ptr< ::mosek::fusion::Expression > _3511,    int _3512){ return new mosek::fusion::ExprMulRight(_3506,_3507,_3508,_3509,_3510,_3511,_3512); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3506,    int _3507,    std::shared_ptr< monty::ndarray< int,1 > > _3508,    std::shared_ptr< monty::ndarray< int,1 > > _3509,    std::shared_ptr< monty::ndarray< double,1 > > _3510,    monty::rc_ptr< ::mosek::fusion::Expression > _3511,    int _3512) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3506,_3507,_3508,_3509,_3510,_3511,_3512); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3506,    int _3507,    std::shared_ptr< monty::ndarray< int,1 > > _3508,    std::shared_ptr< monty::ndarray< int,1 > > _3509,    std::shared_ptr< monty::ndarray< double,1 > > _3510,    monty::rc_ptr< ::mosek::fusion::Expression > _3511,    int _3512){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3508(_3508 ? _3508->raw() : nullptr, _3508 ? _3508->size(0) : 0);
    _checked_ptr_1<int> _ptr__3509(_3509 ? _3509->raw() : nullptr, _3509 ? _3509->size(0) : 0);
    _checked_ptr_1<double> _ptr__3510(_3510 ? _3510->raw() : nullptr, _3510 ? _3510->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulRight::computeshape(_3507,_3511->getShape()));
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim0 = _3506;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim1 = _3507;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubi = _3508;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubj = _3509;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mval = _3510;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr = _3511;
  }
}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3513,    int _3514,    std::shared_ptr< monty::ndarray< int,1 > > _3515,    std::shared_ptr< monty::ndarray< int,1 > > _3516,    std::shared_ptr< monty::ndarray< double,1 > > _3517,    monty::rc_ptr< ::mosek::fusion::Expression > _3518){ return new mosek::fusion::ExprMulRight(_3513,_3514,_3515,_3516,_3517,_3518); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3513,    int _3514,    std::shared_ptr< monty::ndarray< int,1 > > _3515,    std::shared_ptr< monty::ndarray< int,1 > > _3516,    std::shared_ptr< monty::ndarray< double,1 > > _3517,    monty::rc_ptr< ::mosek::fusion::Expression > _3518) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3513,_3514,_3515,_3516,_3517,_3518); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3513,    int _3514,    std::shared_ptr< monty::ndarray< int,1 > > _3515,    std::shared_ptr< monty::ndarray< int,1 > > _3516,    std::shared_ptr< monty::ndarray< double,1 > > _3517,    monty::rc_ptr< ::mosek::fusion::Expression > _3518){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3515(_3515 ? _3515->raw() : nullptr, _3515 ? _3515->size(0) : 0);
    _checked_ptr_1<int> _ptr__3516(_3516 ? _3516->raw() : nullptr, _3516 ? _3516->size(0) : 0);
    _checked_ptr_1<double> _ptr__3517(_3517 ? _3517->raw() : nullptr, _3517 ? _3517->size(0) : 0);
    mosek::fusion::p_ExprMulRight::_initialize(_3513,_3514,_3515,_3516,_3517,_3518,::mosek::fusion::p_ExprMulRight::validate(_3513,_3514,_3515,_3516,_3517,_3518));
  }
}void mosek::fusion::ExprMulRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3519,monty::rc_ptr< ::mosek::fusion::WorkStack > _3520,monty::rc_ptr< ::mosek::fusion::WorkStack > _3521) { mosek::fusion::p_ExprMulRight::_get_impl(this)->eval(_3519,_3520,_3521); }void mosek::fusion::p_ExprMulRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3519,monty::rc_ptr< ::mosek::fusion::WorkStack > _3520,monty::rc_ptr< ::mosek::fusion::WorkStack > _3521){
  mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr->eval(_3520,_3519,_3521);
  int _3522 = _3520->peeki32();
  bool _3523 = (_3520->peeki32(safe_add( _3522,(int)3 )) != (int)0);
  int _3524 = (int)((mval)->size(0));
  bool _3525 = (_3524 < safe_mul( mdim0,mdim1 ));
  int _3526 = _3520->peeki32((int)2);
  if (_3525)
  {
    {
      int _3527 = _3520->alloci32(safe_add( mdim1,(int)1 ));
      int _3528 = _3520->alloci32(_3524);
      int _3529 = _3520->alloci32(safe_add( _3526,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3530 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i32;
      _checked_ptr_1<int> _ptr__3530(_3530 ? _3530->raw() : nullptr,_3530 ? _3530->size(0) : 0);
      int _8355 = (int)0;
      int _8356 = safe_add( mdim1,(int)1 );
      for (int _3531 = _8355; _3531 < _8356; ++_3531)
      {
        {
          _ptr__3530[safe_add( _3527,_3531 )] = (int)0;
        }
      }
      int _8357 = (int)0;
      int _8358 = _3524;
      for (int _3532 = _8357; _3532 < _8358; ++_3532)
      {
        {
          ++ _ptr__3530[safe_add( safe_add( _3527,((*msubj)(_3532)) ),(int)1 )];
        }
      }
      int _8359 = (int)0;
      int _8360 = mdim1;
      for (int _3533 = _8359; _3533 < _8360; ++_3533)
      {
        {
          _ptr__3530[safe_add( safe_add( _3527,_3533 ),(int)1 )] += _ptr__3530[safe_add( _3527,_3533 )];
        }
      }
      int _8361 = (int)0;
      int _8362 = _3524;
      for (int _3534 = _8361; _3534 < _8362; ++_3534)
      {
        {
          _ptr__3530[safe_add( _3528,_3534 )] = _ptr__3530[safe_add( _3527,((*msubj)(_3534)) )];
          ++ _ptr__3530[safe_add( _3527,((*msubj)(_3534)) )];
        }
      }
      int _8363 = (int)0;
      int _8364 = mdim1;
      for (int _3535 = _8363; _3535 < _8364; ++_3535)
      {
        {
          _ptr__3530[(safe_add( _3527,mdim1 ) - _3535)] = _ptr__3530[((safe_add( _3527,mdim1 ) - _3535) - (int)1)];
        }
      }
      _ptr__3530[_3527] = (int)0;
      int _8365 = (int)0;
      int _8366 = safe_add( _3526,(int)1 );
      for (int _3536 = _8365; _3536 < _8366; ++_3536)
      {
        {
          _ptr__3530[safe_add( _3529,_3536 )] = (int)0;
        }
      }
      _3520->popi32(safe_add( safe_add( safe_add( _3526,mdim1 ),(int)2 ),_3524 ));
      int _3537 = _3520->popi32();
      if ((_3537 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      int _3538 = _3520->popi32();
      int _3539 = _3520->popi32();
      int _3540 = _3520->popi32();
      int _3541 = _3520->popi32();
      bool _3542 = (_3520->popi32() != (int)0);
      int _3543 = _3520->popi32(safe_add( _3540,(int)1 ));
      int _8367;
      bool _8368 = _3542;
      if (_8368)
      {
        _8367 = _3520->popi64(_3540);
      }
      else
      {
        _8367 = (int)999999;
      }
      int _3544 = _8367;
      int _3545 = _3520->popi64(_3541);
      int _3546 = _3520->popf64(_3540);
      int _3547 = _3520->popf64(_3541);
      std::shared_ptr< monty::ndarray< int,1 > > _3548 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i32;
      _checked_ptr_1<int> _ptr__3548(_3548 ? _3548->raw() : nullptr,_3548 ? _3548->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3549 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i64;
      _checked_ptr_1<long long> _ptr__3549(_3549 ? _3549->raw() : nullptr,_3549 ? _3549->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3550 = mosek::fusion::p_WorkStack::_get_impl(_3520)->f64;
      _checked_ptr_1<double> _ptr__3550(_3550 ? _3550->raw() : nullptr,_3550 ? _3550->size(0) : 0);
      if (_3542)
      {
        {
          int _8369 = (int)0;
          int _8370 = _3540;
          for (int _3551 = _8369; _3551 < _8370; ++_3551)
          {
            {
              ++ _ptr__3548[safe_add( safe_add( _3529,(_ptr__3549[safe_add( _3544,_3551 )] / _3538) ),(int)1 )];
            }
          }
          int _8371 = (int)0;
          int _8372 = _3539;
          for (int _3552 = _8371; _3552 < _8372; ++_3552)
          {
            {
              _ptr__3548[safe_add( safe_add( _3529,_3552 ),(int)1 )] += _ptr__3548[safe_add( _3529,_3552 )];
            }
          }
          int _3553 = (int)0;
          int _3554 = (int)0;
          int _8373 = (int)0;
          int _8374 = _3539;
          for (int _3555 = _8373; _3555 < _8374; ++_3555)
          {
            {
              int _8375 = (int)0;
              int _8376 = mdim1;
              for (int _3556 = _8375; _3556 < _8376; ++_3556)
              {
                {
                  bool _3557 = false;
                  int _3558 = _ptr__3548[safe_add( safe_add( _3529,_3555 ),(int)1 )];
                  int _3559 = _ptr__3548[safe_add( _3529,_3555 )];
                  int _3560 = _ptr__3548[safe_add( safe_add( _3527,_3556 ),(int)1 )];
                  int _3561 = _ptr__3548[safe_add( _3527,_3556 )];
                  while ( ((_3559 < _3558) && (_3561 < _3560)) )
                  {
                    {
                      int _3562 = _ptr__3548[safe_add( _3528,_3561 )];
                      if (((_ptr__3549[safe_add( _3544,_3559 )] % _3538) < ((*msubi)(_3562))))
                      {
                        {
                          ++ _3559;
                        }
                      }
                      else if(((_ptr__3549[safe_add( _3544,_3559 )] % _3538) > ((*msubi)(_3562))))
                      {
                        {
                          ++ _3561;
                        }
                      }
                      else
                      {
                        {
                          _3554 += (_ptr__3548[safe_add( safe_add( _3543,_3559 ),(int)1 )] - _ptr__3548[safe_add( _3543,_3559 )]);
                          ++ _3559;
                          ++ _3561;
                          _3557 = true;
                        }
                      }
                    }
                  }
                  if (_3557)
                  {
                    {
                      ++ _3553;
                    }
                  }
                  {}
                }
              }
            }
          }
          bool _3563 = (_3553 < safe_mul( _3539,mdim1 ));
          _3519->alloc_expr((int)2,_3553,_3554,_3563);
          int _3564 = mosek::fusion::p_WorkStack::_get_impl(_3519)->ptr_base;
          int _3565 = mosek::fusion::p_WorkStack::_get_impl(_3519)->nidxs_base;
          int _8377;
          bool _8378 = _3563;
          if (_8378)
          {
            _8377 = mosek::fusion::p_WorkStack::_get_impl(_3519)->sp_base;
          }
          else
          {
            _8377 = _3519->alloci64(_3553);
          }
          int _3566 = _8377;
          int _3567 = mosek::fusion::p_WorkStack::_get_impl(_3519)->cof_base;
          int _3568 = mosek::fusion::p_WorkStack::_get_impl(_3519)->bfix_base;
          int _3569 = mosek::fusion::p_WorkStack::_get_impl(_3519)->shape_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3570 = mosek::fusion::p_WorkStack::_get_impl(_3519)->i32;
          _checked_ptr_1<int> _ptr__3570(_3570 ? _3570->raw() : nullptr,_3570 ? _3570->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3571 = mosek::fusion::p_WorkStack::_get_impl(_3519)->i64;
          _checked_ptr_1<long long> _ptr__3571(_3571 ? _3571->raw() : nullptr,_3571 ? _3571->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3572 = mosek::fusion::p_WorkStack::_get_impl(_3519)->f64;
          _checked_ptr_1<double> _ptr__3572(_3572 ? _3572->raw() : nullptr,_3572 ? _3572->size(0) : 0);
          _ptr__3570[_3569] = _3539;
          _ptr__3570[safe_add( _3569,(int)1 )] = mdim1;
          int _3573 = (int)0;
          int _3574 = (int)0;
          _ptr__3570[_3564] = (int)0;
          int _8379 = (int)0;
          int _8380 = _3539;
          for (int _3575 = _8379; _3575 < _8380; ++_3575)
          {
            {
              int _8381 = (int)0;
              int _8382 = mdim1;
              for (int _3576 = _8381; _3576 < _8382; ++_3576)
              {
                {
                  bool _3577 = false;
                  double _3578 = 0.0;
                  int _3579 = _ptr__3548[safe_add( safe_add( _3529,_3575 ),(int)1 )];
                  int _3580 = _ptr__3548[safe_add( _3529,_3575 )];
                  int _3581 = _ptr__3548[safe_add( safe_add( _3527,_3576 ),(int)1 )];
                  int _3582 = _ptr__3548[safe_add( _3527,_3576 )];
                  while ( ((_3580 < _3579) && (_3582 < _3581)) )
                  {
                    {
                      int _3583 = _ptr__3548[safe_add( _3528,_3582 )];
                      if (((_ptr__3549[safe_add( _3544,_3580 )] % _3538) < ((*msubi)(_3583))))
                      {
                        {
                          ++ _3580;
                        }
                      }
                      else if(((_ptr__3549[safe_add( _3544,_3580 )] % _3538) > ((*msubi)(_3583))))
                      {
                        {
                          ++ _3582;
                        }
                      }
                      else
                      {
                        {
                          int _3584 = (_ptr__3548[safe_add( safe_add( _3543,_3580 ),(int)1 )] - _ptr__3548[safe_add( _3543,_3580 )]);
                          _3578 += (((*mval)(_3583)) * _ptr__3550[safe_add( _3546,_3580 )]);
                          int _8383 = (int)0;
                          int _8384 = _3584;
                          for (int _3585 = _8383; _3585 < _8384; ++_3585)
                          {
                            {
                              _ptr__3571[safe_add( safe_add( _3565,_3574 ),_3585 )] = _ptr__3549[safe_add( safe_add( _3545,_ptr__3548[safe_add( _3543,_3580 )] ),_3585 )];
                            }
                          }
                          int _8385 = (int)0;
                          int _8386 = _3584;
                          for (int _3586 = _8385; _3586 < _8386; ++_3586)
                          {
                            {
                              _ptr__3572[safe_add( safe_add( _3567,_3574 ),_3586 )] = (_ptr__3550[safe_add( safe_add( _3547,_ptr__3548[safe_add( _3543,_3580 )] ),_3586 )] * ((*mval)(_3583)));
                            }
                          }
                          _3574 += _3584;
                          ++ _3580;
                          ++ _3582;
                          _3577 = true;
                        }
                      }
                      if (_3577)
                      {
                        {
                          _ptr__3570[safe_add( safe_add( _3564,_3573 ),(int)1 )] = _3574;
                          _ptr__3572[safe_add( _3568,_3573 )] = _3578;
                          _ptr__3571[safe_add( _3566,_3573 )] = safe_add( safe_mul( _3575,mdim1 ),_3576 );
                          ++ _3573;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          if ((!_3563))
          {
            {
              _3519->popi64(_3553);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _3587 = safe_mul( _3539,mdim1 );
          int _3588 = (int)0;
          int _8387 = (int)0;
          int _8388 = _3539;
          for (int _3589 = _8387; _3589 < _8388; ++_3589)
          {
            {
              int _8389 = (int)0;
              int _8390 = mdim1;
              for (int _3590 = _8389; _3590 < _8390; ++_3590)
              {
                {
                  int _8391 = _ptr__3548[safe_add( _3527,_3590 )];
                  int _8392 = _ptr__3548[safe_add( safe_add( _3527,_3590 ),(int)1 )];
                  for (int _3591 = _8391; _3591 < _8392; ++_3591)
                  {
                    {
                      int _3592 = _ptr__3548[safe_add( _3528,_3591 )];
                      int _3593 = safe_add( safe_mul( _3589,_3538 ),((*msubi)(_3592)) );
                      _3588 += (_ptr__3548[safe_add( safe_add( _3543,_3593 ),(int)1 )] - _ptr__3548[safe_add( _3543,_3593 )]);
                    }
                  }
                }
              }
            }
          }
          bool _3594 = (_3587 < safe_mul( _3539,mdim1 ));
          int _3595 = _3519->alloci32(safe_add( _3587,(int)1 ));
          int _8393;
          bool _8394 = _3594;
          if (_8394)
          {
            _8393 = (int)1;
          }
          else
          {
            _8393 = (int)0;
          }
          _3519->pushi32(_8393);
          _3519->pushi32(_3588);
          _3519->pushi32(_3587);
          _3519->pushi32(_3539);
          _3519->pushi32(mdim1);
          _3519->pushi32((int)2);
          int _3596 = _3519->alloci64(_3588);
          int _3597 = _3519->alloci64(_3587);
          int _3598 = _3519->allocf64(_3588);
          int _3599 = _3519->allocf64(_3587);
          std::shared_ptr< monty::ndarray< int,1 > > _3600 = mosek::fusion::p_WorkStack::_get_impl(_3519)->i32;
          _checked_ptr_1<int> _ptr__3600(_3600 ? _3600->raw() : nullptr,_3600 ? _3600->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3601 = mosek::fusion::p_WorkStack::_get_impl(_3519)->i64;
          _checked_ptr_1<long long> _ptr__3601(_3601 ? _3601->raw() : nullptr,_3601 ? _3601->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3602 = mosek::fusion::p_WorkStack::_get_impl(_3519)->f64;
          _checked_ptr_1<double> _ptr__3602(_3602 ? _3602->raw() : nullptr,_3602 ? _3602->size(0) : 0);
          int _3603 = (int)0;
          int _3604 = (int)0;
          _ptr__3600[_3595] = (int)0;
          int _8395 = (int)0;
          int _8396 = _3539;
          for (int _3605 = _8395; _3605 < _8396; ++_3605)
          {
            {
              int _8397 = (int)0;
              int _8398 = mdim1;
              for (int _3606 = _8397; _3606 < _8398; ++_3606)
              {
                {
                  int _3607 = safe_mul( _3605,_3538 );
                  double _3608 = 0.0;
                  int _8399 = _ptr__3548[safe_add( _3527,_3606 )];
                  int _8400 = _ptr__3548[safe_add( safe_add( _3527,_3606 ),(int)1 )];
                  for (int _3609 = _8399; _3609 < _8400; ++_3609)
                  {
                    {
                      int _3610 = _ptr__3548[safe_add( _3528,_3609 )];
                      int _3611 = safe_add( _3607,((*msubi)(_3610)) );
                      int _3612 = _ptr__3548[safe_add( _3543,_3611 )];
                      int _3613 = (_ptr__3548[safe_add( safe_add( _3543,_3611 ),(int)1 )] - _ptr__3548[safe_add( _3543,_3611 )]);
                      int _8401 = (int)0;
                      int _8402 = _3613;
                      for (int _3614 = _8401; _3614 < _8402; ++_3614)
                      {
                        {
                          _ptr__3601[safe_add( safe_add( _3596,_3604 ),_3614 )] = _ptr__3549[safe_add( safe_add( _3545,_3612 ),_3614 )];
                        }
                      }
                      int _8403 = (int)0;
                      int _8404 = _3613;
                      for (int _3615 = _8403; _3615 < _8404; ++_3615)
                      {
                        {
                          _ptr__3602[safe_add( safe_add( _3598,_3604 ),_3615 )] = (_ptr__3550[safe_add( safe_add( _3547,_3612 ),_3615 )] * ((*mval)(_3610)));
                        }
                      }
                      _3608 += (_ptr__3550[safe_add( safe_add( _3546,_3607 ),((*msubi)(_3610)) )] * ((*mval)(_3610)));
                      _3604 += _3613;
                    }
                  }
                  _ptr__3600[safe_add( safe_add( _3595,_3603 ),(int)1 )] = _3604;
                  _ptr__3602[safe_add( _3599,_3603 )] = _3608;
                  _ptr__3601[safe_add( _3597,_3603 )] = safe_add( safe_mul( _3605,mdim1 ),_3606 );
                  ++ _3603;
                }
              }
            }
          }
          if ((!_3594))
          {
            {
              _3519->popi64(_3587);
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _3616 = _3520->alloci32(safe_add( _3526,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3617 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i32;
      _checked_ptr_1<int> _ptr__3617(_3617 ? _3617->raw() : nullptr,_3617 ? _3617->size(0) : 0);
      int _8405 = (int)0;
      int _8406 = safe_add( _3526,(int)1 );
      for (int _3618 = _8405; _3618 < _8406; ++_3618)
      {
        {
          _ptr__3617[safe_add( _3616,_3618 )] = (int)0;
        }
      }
      _3520->popi32(safe_add( _3526,(int)1 ));
      int _3619 = _3520->popi32();
      if ((_3619 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      int _3620 = _3520->popi32();
      int _3621 = _3520->popi32();
      int _3622 = _3520->popi32();
      int _3623 = _3520->popi32();
      bool _3624 = (_3520->popi32() != (int)0);
      int _3625 = _3520->popi32(safe_add( _3622,(int)1 ));
      int _8407;
      bool _8408 = _3624;
      if (_8408)
      {
        _8407 = _3520->popi64(_3622);
      }
      else
      {
        _8407 = (int)999999;
      }
      int _3626 = _8407;
      int _3627 = _3520->popi64(_3623);
      int _3628 = _3520->popf64(_3622);
      int _3629 = _3520->popf64(_3623);
      std::shared_ptr< monty::ndarray< int,1 > > _3630 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i32;
      _checked_ptr_1<int> _ptr__3630(_3630 ? _3630->raw() : nullptr,_3630 ? _3630->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3631 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i64;
      _checked_ptr_1<long long> _ptr__3631(_3631 ? _3631->raw() : nullptr,_3631 ? _3631->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3632 = mosek::fusion::p_WorkStack::_get_impl(_3520)->f64;
      _checked_ptr_1<double> _ptr__3632(_3632 ? _3632->raw() : nullptr,_3632 ? _3632->size(0) : 0);
      int _3633 = safe_mul( _3621,mdim1 );
      int _3634 = safe_mul( _3623,mdim1 );
      bool _3635 = false;
      int _3636 = _3519->alloci32(safe_add( _3633,(int)1 ));
      _3519->pushi32((int)0);
      _3519->pushi32(_3634);
      _3519->pushi32(_3633);
      _3519->pushi32(_3621);
      _3519->pushi32(mdim1);
      _3519->pushi32((int)2);
      int _3637 = _3519->alloci64(_3634);
      int _3638 = _3519->allocf64(_3634);
      int _3639 = _3519->allocf64(_3633);
      std::shared_ptr< monty::ndarray< int,1 > > _3640 = mosek::fusion::p_WorkStack::_get_impl(_3519)->i32;
      _checked_ptr_1<int> _ptr__3640(_3640 ? _3640->raw() : nullptr,_3640 ? _3640->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3641 = mosek::fusion::p_WorkStack::_get_impl(_3519)->i64;
      _checked_ptr_1<long long> _ptr__3641(_3641 ? _3641->raw() : nullptr,_3641 ? _3641->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3642 = mosek::fusion::p_WorkStack::_get_impl(_3519)->f64;
      _checked_ptr_1<double> _ptr__3642(_3642 ? _3642->raw() : nullptr,_3642 ? _3642->size(0) : 0);
      int _3643 = (int)0;
      int _3644 = (int)0;
      _ptr__3640[_3636] = (int)0;
      if (_3624)
      {
        {
          int _8409 = (int)0;
          int _8410 = _3622;
          for (int _3645 = _8409; _3645 < _8410; ++_3645)
          {
            {
              ++ _ptr__3630[safe_add( safe_add( _3616,(_ptr__3631[safe_add( _3626,_3645 )] / _3620) ),(int)1 )];
            }
          }
          int _8411 = (int)0;
          int _8412 = _3621;
          for (int _3646 = _8411; _3646 < _8412; ++_3646)
          {
            {
              _ptr__3630[safe_add( safe_add( _3616,_3646 ),(int)1 )] += _ptr__3630[safe_add( _3616,_3646 )];
            }
          }
          int _8413 = (int)0;
          int _8414 = _3621;
          for (int _3647 = _8413; _3647 < _8414; ++_3647)
          {
            {
              int _8415 = (int)0;
              int _8416 = mdim1;
              for (int _3648 = _8415; _3648 < _8416; ++_3648)
              {
                {
                  double _3649 = 0.0;
                  int _3650 = (int)0;
                  int _8417 = _ptr__3630[safe_add( _3616,_3647 )];
                  int _8418 = _ptr__3630[safe_add( safe_add( _3616,_3647 ),(int)1 )];
                  for (int _3651 = _8417; _3651 < _8418; ++_3651)
                  {
                    {
                      long long _3652 = safe_add( _3648,safe_mul( (_ptr__3631[safe_add( _3626,_3651 )] % _3620),mdim1 ) );
                      _3649 += (_ptr__3631[safe_add( _3628,_3651 )] * ((*mval)(_3652)));
                      int _8419 = _ptr__3630[safe_add( _3625,_3651 )];
                      int _8420 = _ptr__3630[safe_add( safe_add( _3625,_3651 ),(int)1 )];
                      for (int _3653 = _8419; _3653 < _8420; ++_3653)
                      {
                        {
                          _ptr__3641[safe_add( safe_add( _3637,_3643 ),_3650 )] = _ptr__3631[safe_add( _3627,_3653 )];
                          _ptr__3642[safe_add( safe_add( _3638,_3643 ),_3650 )] = (_ptr__3631[safe_add( _3629,_3653 )] * ((*mval)(_3652)));
                          ++ _3650;
                        }
                      }
                    }
                  }
                  _3643 += _3650;
                  _ptr__3640[safe_add( safe_add( _3636,_3644 ),(int)1 )] = _3643;
                  _ptr__3642[safe_add( _3639,_3644 )] = _3649;
                  ++ _3644;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _8421 = (int)0;
          int _8422 = _3621;
          for (int _3654 = _8421; _3654 < _8422; ++_3654)
          {
            {
              int _8423 = (int)0;
              int _8424 = mdim1;
              for (int _3655 = _8423; _3655 < _8424; ++_3655)
              {
                {
                  double _3656 = 0.0;
                  int _3657 = (int)0;
                  int _8425 = (int)0;
                  int _8426 = _3620;
                  for (int _3658 = _8425; _3658 < _8426; ++_3658)
                  {
                    {
                      int _3659 = safe_add( safe_mul( _3654,_3620 ),_3658 );
                      int _3660 = safe_add( _3655,safe_mul( _3658,mdim1 ) );
                      _3656 += (_ptr__3632[safe_add( _3628,_3659 )] * ((*mval)(_3660)));
                      int _8427 = _ptr__3630[safe_add( _3625,_3659 )];
                      int _8428 = _ptr__3630[safe_add( safe_add( _3625,_3659 ),(int)1 )];
                      for (int _3661 = _8427; _3661 < _8428; ++_3661)
                      {
                        {
                          _ptr__3641[safe_add( safe_add( _3637,_3643 ),_3657 )] = _ptr__3631[safe_add( _3627,_3661 )];
                          _ptr__3642[safe_add( safe_add( _3638,_3643 ),_3657 )] = (_ptr__3632[safe_add( _3629,_3661 )] * ((*mval)(_3660)));
                          ++ _3657;
                        }
                      }
                    }
                  }
                  _3643 += _3657;
                  _ptr__3640[safe_add( safe_add( _3636,_3644 ),(int)1 )] = _3643;
                  _ptr__3642[safe_add( _3639,_3644 )] = _3656;
                  ++ _3644;
                }
              }
            }
          }
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulRight::computeshape(int _3662,std::shared_ptr< monty::ndarray< int,1 > > _3663){
  _checked_ptr_1<int> _ptr__3663(_3663 ? _3663->raw() : nullptr, _3663 ? _3663->size(0) : 0);
  if (((int)((_3663)->size(0)) == (int)1))
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_3662)});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__3663[(int)0]),(int)(_3662)});
    }
  }
}
int mosek::fusion::p_ExprMulRight::validate(int _3664,int _3665,std::shared_ptr< monty::ndarray< int,1 > > _3666,std::shared_ptr< monty::ndarray< int,1 > > _3667,std::shared_ptr< monty::ndarray< double,1 > > _3668,monty::rc_ptr< ::mosek::fusion::Expression > _3669){
  _checked_ptr_1<int> _ptr__3666(_3666 ? _3666->raw() : nullptr, _3666 ? _3666->size(0) : 0);
  _checked_ptr_1<int> _ptr__3667(_3667 ? _3667->raw() : nullptr, _3667 ? _3667->size(0) : 0);
  _checked_ptr_1<double> _ptr__3668(_3668 ? _3668->raw() : nullptr, _3668 ? _3668->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3670 = _3669->getShape();
  _checked_ptr_1<int> _ptr__3670(_3670 ? _3670->raw() : nullptr,_3670 ? _3670->size(0) : 0);
  if (((int)((_3670)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3671 = _ptr__3670[(int)0];
  int _3672 = _ptr__3670[(int)1];
  if (((_3664 < (int)0) || ((_3665 < (int)0) || ((_3671 < (int)0) || (_3672 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3664 != _3672))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3666)->size(0)) != (int)((_3667)->size(0))) || ((int)((_3666)->size(0)) != (int)((_3668)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3673 = (int)((_3666)->size(0));
  int _8429 = (int)0;
  int _8430 = _3673;
  for (int _3674 = _8429; _3674 < _8430; ++_3674)
  {
    {
      if (((_ptr__3666[_3674] < (int)0) || ((_ptr__3666[_3674] >= _3664) || ((_ptr__3667[_3674] < (int)0) || (_ptr__3667[_3674] >= _3665)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8431 = (int)0;
  int _8432 = (_3673 - (int)1);
  for (int _3675 = _8431; _3675 < _8432; ++_3675)
  {
    {
      if (((_ptr__3666[_3675] > _ptr__3666[safe_add( _3675,(int)1 )]) || ((_ptr__3666[_3675] == _ptr__3666[safe_add( _3675,(int)1 )]) && (_ptr__3667[_3675] >= _ptr__3667[safe_add( _3675,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8433 = (int)0;
  int _8434 = _3673;
  for (int _3676 = _8433; _3676 < _8434; ++_3676)
  {
    {
      if (((_ptr__3666[_3676] < (int)0) || ((_ptr__3666[_3676] >= _3664) || ((_ptr__3667[_3676] < (int)0) || (_ptr__3667[_3676] >= _3665)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulRight :: toString() { return mosek::fusion::p_ExprMulRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulRight(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulRight::destroy() { mosek::fusion::p_ExprMulRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulLeft::ExprMulLeft(mosek::fusion::p_ExprMulLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulLeft()" << this << std::endl; */ }mosek::fusion::ExprMulLeft::~ExprMulLeft() {  /* std::cout << "~ExprMulLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulLeft::p_ExprMulLeft  (::mosek::fusion::ExprMulLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3677,    int _3678,    std::shared_ptr< monty::ndarray< int,1 > > _3679,    std::shared_ptr< monty::ndarray< int,1 > > _3680,    std::shared_ptr< monty::ndarray< double,1 > > _3681,    monty::rc_ptr< ::mosek::fusion::Expression > _3682,    int _3683){ return new mosek::fusion::ExprMulLeft(_3677,_3678,_3679,_3680,_3681,_3682,_3683); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3677,    int _3678,    std::shared_ptr< monty::ndarray< int,1 > > _3679,    std::shared_ptr< monty::ndarray< int,1 > > _3680,    std::shared_ptr< monty::ndarray< double,1 > > _3681,    monty::rc_ptr< ::mosek::fusion::Expression > _3682,    int _3683) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3677,_3678,_3679,_3680,_3681,_3682,_3683); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3677,    int _3678,    std::shared_ptr< monty::ndarray< int,1 > > _3679,    std::shared_ptr< monty::ndarray< int,1 > > _3680,    std::shared_ptr< monty::ndarray< double,1 > > _3681,    monty::rc_ptr< ::mosek::fusion::Expression > _3682,    int _3683){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3679(_3679 ? _3679->raw() : nullptr, _3679 ? _3679->size(0) : 0);
    _checked_ptr_1<int> _ptr__3680(_3680 ? _3680->raw() : nullptr, _3680 ? _3680->size(0) : 0);
    _checked_ptr_1<double> _ptr__3681(_3681 ? _3681->raw() : nullptr, _3681 ? _3681->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulLeft::computeshape(_3677,_3678,_3682->getShape()));
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim0 = _3677;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim1 = _3678;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubi = _3679;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubj = _3680;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mval = _3681;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr = _3682;
  }
}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3684,    int _3685,    std::shared_ptr< monty::ndarray< int,1 > > _3686,    std::shared_ptr< monty::ndarray< int,1 > > _3687,    std::shared_ptr< monty::ndarray< double,1 > > _3688,    monty::rc_ptr< ::mosek::fusion::Expression > _3689){ return new mosek::fusion::ExprMulLeft(_3684,_3685,_3686,_3687,_3688,_3689); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3684,    int _3685,    std::shared_ptr< monty::ndarray< int,1 > > _3686,    std::shared_ptr< monty::ndarray< int,1 > > _3687,    std::shared_ptr< monty::ndarray< double,1 > > _3688,    monty::rc_ptr< ::mosek::fusion::Expression > _3689) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3684,_3685,_3686,_3687,_3688,_3689); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3684,    int _3685,    std::shared_ptr< monty::ndarray< int,1 > > _3686,    std::shared_ptr< monty::ndarray< int,1 > > _3687,    std::shared_ptr< monty::ndarray< double,1 > > _3688,    monty::rc_ptr< ::mosek::fusion::Expression > _3689){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3686(_3686 ? _3686->raw() : nullptr, _3686 ? _3686->size(0) : 0);
    _checked_ptr_1<int> _ptr__3687(_3687 ? _3687->raw() : nullptr, _3687 ? _3687->size(0) : 0);
    _checked_ptr_1<double> _ptr__3688(_3688 ? _3688->raw() : nullptr, _3688 ? _3688->size(0) : 0);
    mosek::fusion::p_ExprMulLeft::_initialize(_3684,_3685,_3686,_3687,_3688,_3689,::mosek::fusion::p_ExprMulLeft::validate(_3684,_3685,_3686,_3687,_3688,_3689));
  }
}void mosek::fusion::ExprMulLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3690,monty::rc_ptr< ::mosek::fusion::WorkStack > _3691,monty::rc_ptr< ::mosek::fusion::WorkStack > _3692) { mosek::fusion::p_ExprMulLeft::_get_impl(this)->eval(_3690,_3691,_3692); }void mosek::fusion::p_ExprMulLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3690,monty::rc_ptr< ::mosek::fusion::WorkStack > _3691,monty::rc_ptr< ::mosek::fusion::WorkStack > _3692){
  mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr->eval(_3691,_3690,_3692);
  _3691->pop_expr();
  int _3693 = mosek::fusion::p_WorkStack::_get_impl(_3691)->nd;
  int _3694 = mosek::fusion::p_WorkStack::_get_impl(_3691)->nnz;
  int _3695 = mosek::fusion::p_WorkStack::_get_impl(_3691)->nelem;
  bool _3696 = mosek::fusion::p_WorkStack::_get_impl(_3691)->hassp;
  int _3697 = mosek::fusion::p_WorkStack::_get_impl(_3691)->shape_base;
  int _3698 = mosek::fusion::p_WorkStack::_get_impl(_3691)->ptr_base;
  int _3699 = mosek::fusion::p_WorkStack::_get_impl(_3691)->sp_base;
  int _3700 = mosek::fusion::p_WorkStack::_get_impl(_3691)->nidxs_base;
  int _3701 = mosek::fusion::p_WorkStack::_get_impl(_3691)->bfix_base;
  int _3702 = mosek::fusion::p_WorkStack::_get_impl(_3691)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _3703 = mosek::fusion::p_WorkStack::_get_impl(_3691)->i32;
  _checked_ptr_1<int> _ptr__3703(_3703 ? _3703->raw() : nullptr,_3703 ? _3703->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3704 = mosek::fusion::p_WorkStack::_get_impl(_3691)->i64;
  _checked_ptr_1<long long> _ptr__3704(_3704 ? _3704->raw() : nullptr,_3704 ? _3704->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3705 = mosek::fusion::p_WorkStack::_get_impl(_3691)->f64;
  _checked_ptr_1<double> _ptr__3705(_3705 ? _3705->raw() : nullptr,_3705 ? _3705->size(0) : 0);
  if ((_3693 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3706 = (int)9999;
  int _3707 = (int)9999;
  int _3708 = (int)9999;
  std::shared_ptr< monty::ndarray< int,1 > > _3709 = mosek::fusion::p_WorkStack::_get_impl(_3692)->i32;
  _checked_ptr_1<int> _ptr__3709(_3709 ? _3709->raw() : nullptr,_3709 ? _3709->size(0) : 0);
  int _3710 = _ptr__3703[_3697];
  int _3711 = _ptr__3703[safe_add( _3697,(int)1 )];
  int _3712 = (int)((msubi)->size(0));
  bool _3713 = (_3712 < safe_mul( mdim0,mdim1 ));
  bool _3714 = false;
  int _3715 = (int)0;
  int _3716 = (int)0;
  if (_3696)
  {
    {
      _3706 = _3692->alloci32(_3695);
      _3707 = _3692->alloci32(_3695);
      _3708 = _3692->alloci32(safe_add( ((*mosek::fusion::p_WorkStack::_get_impl(_3690)->i32)(safe_add( _3697,(int)1 ))),(int)1 ));
      int _8435 = (int)0;
      int _8436 = safe_add( _3711,(int)1 );
      for (int _3717 = _8435; _3717 < _8436; ++_3717)
      {
        {
          _ptr__3709[safe_add( _3708,_3717 )] = (int)0;
        }
      }
      int _8437 = (int)0;
      int _8438 = _3695;
      for (int _3718 = _8437; _3718 < _8438; ++_3718)
      {
        {
          ++ _ptr__3709[safe_add( safe_add( _3708,(_ptr__3704[safe_add( _3699,_3718 )] % _3711) ),(int)1 )];
        }
      }
      int _8439 = (int)0;
      int _8440 = _3711;
      for (int _3719 = _8439; _3719 < _8440; ++_3719)
      {
        {
          _ptr__3709[safe_add( safe_add( _3708,_3719 ),(int)1 )] += _ptr__3709[safe_add( _3708,_3719 )];
        }
      }
      int _8441 = (int)0;
      int _8442 = _3695;
      for (int _3720 = _8441; _3720 < _8442; ++_3720)
      {
        {
          long long _3721 = (_ptr__3704[safe_add( _3699,_3720 )] % _3711);
          _ptr__3709[safe_add( _3706,_ptr__3709[safe_add( _3708,_3721 )] )] = _3720;
          ++ _ptr__3709[safe_add( _3708,_3721 )];
        }
      }
      int _8443 = (int)0;
      int _8444 = _3711;
      for (int _3722 = _8443; _3722 < _8444; ++_3722)
      {
        {
          _ptr__3709[(safe_add( _3708,_3711 ) - _3722)] = _ptr__3709[((safe_add( _3708,_3711 ) - _3722) - (int)1)];
        }
      }
      _ptr__3709[_3708] = (int)0;
      if (_3713)
      {
        {
          int _3723 = (int)0;
          while ( (_3723 < _3712) )
          {
            {
              int _3724 = ((*msubi)(_3723));
              int _3725 = safe_add( _3723,(int)1 );
              while ( ((_3725 < _3712) && (((*msubi)(_3725)) == ((*msubi)(_3723)))) )
              {
                {
                  ++ _3725;
                }
              }
              int _8445 = (int)0;
              int _8446 = _3711;
              for (int _3726 = _8445; _3726 < _8446; ++_3726)
              {
                {
                  bool _3727 = false;
                  int _3728 = _3725;
                  int _3729 = _3723;
                  int _3730 = _ptr__3709[safe_add( safe_add( _3708,_3726 ),(int)1 )];
                  int _3731 = _ptr__3709[safe_add( _3708,_3726 )];
                  while ( ((_3729 < _3728) && (_3731 < _3730)) )
                  {
                    {
                      int _3732 = _ptr__3709[safe_add( _3706,_3731 )];
                      if ((((*msubj)(_3729)) < (_ptr__3704[safe_add( _3699,_3732 )] / _3711)))
                      {
                        {
                          ++ _3729;
                        }
                      }
                      else if((((*msubj)(_3729)) > (_ptr__3704[safe_add( _3699,_3732 )] / _3711)))
                      {
                        {
                          ++ _3731;
                        }
                      }
                      else
                      {
                        {
                          _3727 = true;
                          _3716 += (_ptr__3703[safe_add( safe_add( _3698,_3732 ),(int)1 )] - _ptr__3703[safe_add( _3698,_3732 )]);
                          ++ _3731;
                          ++ _3729;
                        }
                      }
                    }
                  }
                  if (_3727)
                  {
                    {
                      ++ _3715;
                    }
                  }
                  {}
                }
              }
              _3723 = _3725;
            }
          }
        }
      }
      else
      {
        {
          _3715 = safe_mul( mdim0,_3711 );
          _3716 = safe_mul( _3694,mdim0 );
        }
      }
    }
  }
  else
  {
    {
      if (_3713)
      {
        {
          int _3733 = (int)0;
          while ( (_3733 < _3712) )
          {
            {
              int _3734 = safe_add( _3733,(int)1 );
              while ( ((_3734 < _3712) && (((*msubi)(_3733)) == ((*msubi)(_3734)))) )
              {
                {
                  ++ _3734;
                }
              }
              int _3735 = ((*msubi)(_3733));
              int _8447 = (int)0;
              int _8448 = _3711;
              for (int _3736 = _8447; _3736 < _8448; ++_3736)
              {
                {
                  bool _3737 = false;
                  int _8449 = _3733;
                  int _8450 = _3734;
                  for (int _3738 = _8449; _3738 < _8450; ++_3738)
                  {
                    {
                      int _3739 = safe_add( safe_mul( ((*msubj)(_3738)),_3711 ),_3736 );
                      _3716 += (_ptr__3703[safe_add( safe_add( _3698,_3739 ),(int)1 )] - _ptr__3703[safe_add( _3698,_3739 )]);
                      _3737 = true;
                    }
                  }
                  if (_3737)
                  {
                    {
                      ++ _3715;
                    }
                  }
                  {}
                }
              }
              _3733 = _3734;
            }
          }
        }
      }
      else
      {
        {
          _3716 = safe_mul( _3694,mdim0 );
          _3715 = safe_mul( mdim0,_3711 );
        }
      }
    }
  }
  _3714 = (_3715 < safe_mul( mdim0,_3711 ));
  int _3740 = (int)2;
  _3690->alloc_expr(_3740,_3715,_3716,_3714);
  int _3741 = mosek::fusion::p_WorkStack::_get_impl(_3690)->ptr_base;
  int _3742 = mosek::fusion::p_WorkStack::_get_impl(_3690)->nidxs_base;
  int _8451;
  bool _8452 = _3714;
  if (_8452)
  {
    _8451 = mosek::fusion::p_WorkStack::_get_impl(_3690)->sp_base;
  }
  else
  {
    _8451 = _3690->alloci64(_3715);
  }
  int _3743 = _8451;
  int _3744 = mosek::fusion::p_WorkStack::_get_impl(_3690)->cof_base;
  int _3745 = mosek::fusion::p_WorkStack::_get_impl(_3690)->bfix_base;
  int _3746 = mosek::fusion::p_WorkStack::_get_impl(_3690)->shape_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3747 = mosek::fusion::p_WorkStack::_get_impl(_3690)->i64;
  _checked_ptr_1<long long> _ptr__3747(_3747 ? _3747->raw() : nullptr,_3747 ? _3747->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3748 = mosek::fusion::p_WorkStack::_get_impl(_3690)->f64;
  _checked_ptr_1<double> _ptr__3748(_3748 ? _3748->raw() : nullptr,_3748 ? _3748->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3749 = mosek::fusion::p_WorkStack::_get_impl(_3690)->i32;
  _checked_ptr_1<int> _ptr__3749(_3749 ? _3749->raw() : nullptr,_3749 ? _3749->size(0) : 0);
  _ptr__3749[_3746] = mdim0;
  _ptr__3749[safe_add( _3746,(int)1 )] = _3711;
  if (_3696)
  {
    {
      _ptr__3749[_3741] = (int)0;
      if (_3713)
      {
        {
          int _3750 = (int)0;
          int _3751 = (int)0;
          int _3752 = (int)0;
          while ( (_3752 < _3712) )
          {
            {
              int _3753 = ((*msubi)(_3752));
              int _3754 = safe_add( _3752,(int)1 );
              while ( ((_3754 < _3712) && (((*msubi)(_3754)) == ((*msubi)(_3752)))) )
              {
                {
                  ++ _3754;
                }
              }
              int _8453 = (int)0;
              int _8454 = _3711;
              for (int _3755 = _8453; _3755 < _8454; ++_3755)
              {
                {
                  bool _3756 = false;
                  double _3757 = 0.0;
                  int _3758 = _3754;
                  int _3759 = _3752;
                  int _3760 = _ptr__3709[safe_add( safe_add( _3708,_3755 ),(int)1 )];
                  int _3761 = _ptr__3709[safe_add( _3708,_3755 )];
                  while ( ((_3759 < _3758) && (_3761 < _3760)) )
                  {
                    {
                      int _3762 = _ptr__3709[safe_add( _3706,_3761 )];
                      if ((((*msubj)(_3759)) < (_ptr__3704[safe_add( _3699,_3762 )] / _3711)))
                      {
                        {
                          ++ _3759;
                        }
                      }
                      else if((((*msubj)(_3759)) > (_ptr__3704[safe_add( _3699,_3762 )] / _3711)))
                      {
                        {
                          ++ _3761;
                        }
                      }
                      else
                      {
                        {
                          _3756 = true;
                          _3757 += (_ptr__3705[safe_add( _3701,_3762 )] * ((*mval)(_3759)));
                          int _3763 = (_ptr__3703[safe_add( safe_add( _3698,_3762 ),(int)1 )] - _ptr__3703[safe_add( _3698,_3762 )]);
                          int _8455 = (int)0;
                          int _8456 = _3763;
                          for (int _3764 = _8455; _3764 < _8456; ++_3764)
                          {
                            {
                              _ptr__3747[safe_add( safe_add( _3742,_3751 ),_3764 )] = _ptr__3704[safe_add( safe_add( _3700,_ptr__3703[safe_add( _3698,_3762 )] ),_3764 )];
                            }
                          }
                          int _8457 = (int)0;
                          int _8458 = _3763;
                          for (int _3765 = _8457; _3765 < _8458; ++_3765)
                          {
                            {
                              _ptr__3748[safe_add( safe_add( _3744,_3751 ),_3765 )] = (_ptr__3705[safe_add( safe_add( _3702,_ptr__3703[safe_add( _3698,_3762 )] ),_3765 )] * ((*mval)(_3759)));
                            }
                          }
                          ++ _3759;
                          ++ _3761;
                          _3751 += _3763;
                        }
                      }
                    }
                  }
                  if (_3756)
                  {
                    {
                      _ptr__3749[safe_add( safe_add( _3741,_3750 ),(int)1 )] = _3751;
                      _ptr__3747[safe_add( _3743,_3750 )] = safe_add( safe_mul( _3753,_3711 ),_3755 );
                      _ptr__3748[safe_add( _3745,_3750 )] = _3757;
                      ++ _3750;
                    }
                  }
                  {}
                }
              }
              _3752 = _3754;
            }
          }
        }
      }
      else
      {
        {
          int _3766 = (int)0;
          int _3767 = (int)0;
          int _8459 = (int)0;
          int _8460 = mdim0;
          for (int _3768 = _8459; _3768 < _8460; ++_3768)
          {
            {
              int _8461 = (int)0;
              int _8462 = _3711;
              for (int _3769 = _8461; _3769 < _8462; ++_3769)
              {
                {
                  double _3770 = 0.0;
                  int _8463 = _ptr__3709[safe_add( _3708,_3769 )];
                  int _8464 = _ptr__3709[safe_add( safe_add( _3708,_3769 ),(int)1 )];
                  for (int _3771 = _8463; _3771 < _8464; ++_3771)
                  {
                    {
                      int _3772 = _ptr__3709[safe_add( _3706,_3771 )];
                      long long _3773 = safe_add( safe_mul( _3768,mdim1 ),(_ptr__3704[safe_add( _3699,_3772 )] / _3711) );
                      _3770 += (_ptr__3705[safe_add( _3701,_3772 )] * ((*mval)(_3773)));
                      int _3774 = (_ptr__3703[safe_add( safe_add( _3698,_3772 ),(int)1 )] - _ptr__3703[safe_add( _3698,_3772 )]);
                      int _8465 = (int)0;
                      int _8466 = _3774;
                      for (int _3775 = _8465; _3775 < _8466; ++_3775)
                      {
                        {
                          _ptr__3747[safe_add( safe_add( _3742,_3767 ),_3775 )] = _ptr__3704[safe_add( safe_add( _3700,_ptr__3703[safe_add( _3698,_3772 )] ),_3775 )];
                          _ptr__3748[safe_add( safe_add( _3744,_3767 ),_3775 )] = (_ptr__3705[safe_add( safe_add( _3702,_ptr__3703[safe_add( _3698,_3772 )] ),_3775 )] * ((*mval)(_3773)));
                        }
                      }
                      _3767 += _3774;
                    }
                  }
                  _ptr__3749[safe_add( safe_add( _3741,_3766 ),(int)1 )] = _3767;
                  _ptr__3748[safe_add( _3745,_3766 )] = _3770;
                  ++ _3766;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _ptr__3749[_3741] = (int)0;
      int _3776 = (int)0;
      int _3777 = (int)0;
      int _3778 = (int)0;
      while ( (_3776 < _3712) )
      {
        {
          int _3779 = safe_add( _3776,(int)1 );
          while ( ((_3779 < _3712) && (((*msubi)(_3776)) == ((*msubi)(_3779)))) )
          {
            {
              ++ _3779;
            }
          }
          int _3780 = ((*msubi)(_3776));
          int _8467 = (int)0;
          int _8468 = _3711;
          for (int _3781 = _8467; _3781 < _8468; ++_3781)
          {
            {
              double _3782 = 0.0;
              bool _3783 = false;
              int _8469 = _3776;
              int _8470 = _3779;
              for (int _3784 = _8469; _3784 < _8470; ++_3784)
              {
                {
                  int _3785 = safe_add( safe_mul( ((*msubj)(_3784)),_3711 ),_3781 );
                  int _3786 = (_ptr__3703[safe_add( safe_add( _3698,_3785 ),(int)1 )] - _ptr__3703[safe_add( _3698,_3785 )]);
                  int _8471 = (int)0;
                  int _8472 = _3786;
                  for (int _3787 = _8471; _3787 < _8472; ++_3787)
                  {
                    {
                      _ptr__3747[safe_add( safe_add( _3742,_3778 ),_3787 )] = _ptr__3704[safe_add( safe_add( _3700,_ptr__3703[safe_add( _3698,_3785 )] ),_3787 )];
                    }
                  }
                  int _8473 = (int)0;
                  int _8474 = _3786;
                  for (int _3788 = _8473; _3788 < _8474; ++_3788)
                  {
                    {
                      _ptr__3748[safe_add( safe_add( _3744,_3778 ),_3788 )] = (_ptr__3705[safe_add( safe_add( _3702,_ptr__3703[safe_add( _3698,_3785 )] ),_3788 )] * ((*mval)(_3784)));
                    }
                  }
                  _3782 += (_ptr__3705[safe_add( _3701,_3785 )] * ((*mval)(_3784)));
                  _3783 = true;
                  _3778 += _3786;
                }
              }
              if (_3783)
              {
                {
                  _ptr__3747[safe_add( _3743,_3777 )] = safe_add( safe_mul( _3780,_3711 ),_3781 );
                  _ptr__3748[safe_add( _3745,_3777 )] = _3782;
                  _ptr__3749[safe_add( safe_add( _3741,_3777 ),(int)1 )] = _3778;
                  ++ _3777;
                }
              }
              {}
            }
          }
          _3776 = _3779;
        }
      }
    }
  }
  _3690->peek_expr();
  if ((!_3714))
  {
    {
      _3690->popi64(_3715);
    }
  }
  {}
  _3692->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulLeft::computeshape(int _3789,int _3790,std::shared_ptr< monty::ndarray< int,1 > > _3791){
  _checked_ptr_1<int> _ptr__3791(_3791 ? _3791->raw() : nullptr, _3791 ? _3791->size(0) : 0);
  if (((int)((_3791)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  else if((_3790 != _ptr__3791[(int)0]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3789),(int)(_ptr__3791[(int)1])});
}
int mosek::fusion::p_ExprMulLeft::validate(int _3792,int _3793,std::shared_ptr< monty::ndarray< int,1 > > _3794,std::shared_ptr< monty::ndarray< int,1 > > _3795,std::shared_ptr< monty::ndarray< double,1 > > _3796,monty::rc_ptr< ::mosek::fusion::Expression > _3797){
  _checked_ptr_1<int> _ptr__3794(_3794 ? _3794->raw() : nullptr, _3794 ? _3794->size(0) : 0);
  _checked_ptr_1<int> _ptr__3795(_3795 ? _3795->raw() : nullptr, _3795 ? _3795->size(0) : 0);
  _checked_ptr_1<double> _ptr__3796(_3796 ? _3796->raw() : nullptr, _3796 ? _3796->size(0) : 0);
  if ((_3797->getND() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3798 = _3797->getDim((int)0);
  int _3799 = _3797->getDim((int)0);
  if (((_3792 < (int)0) || (_3793 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3793 != _3798))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3794)->size(0)) != (int)((_3795)->size(0))) || ((int)((_3794)->size(0)) != (int)((_3796)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3800 = (int)((_3794)->size(0));
  int _8475 = (int)0;
  int _8476 = _3800;
  for (int _3801 = _8475; _3801 < _8476; ++_3801)
  {
    {
      if (((_ptr__3794[_3801] < (int)0) || ((_ptr__3794[_3801] >= _3792) || ((_ptr__3795[_3801] < (int)0) || (_ptr__3795[_3801] >= _3793)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8477 = (int)0;
  int _8478 = (_3800 - (int)1);
  for (int _3802 = _8477; _3802 < _8478; ++_3802)
  {
    {
      if (((_ptr__3794[_3802] > _ptr__3794[safe_add( _3802,(int)1 )]) || ((_ptr__3794[_3802] == _ptr__3794[safe_add( _3802,(int)1 )]) && (_ptr__3795[_3802] >= _ptr__3795[safe_add( _3802,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8479 = (int)0;
  int _8480 = _3800;
  for (int _3803 = _8479; _3803 < _8480; ++_3803)
  {
    {
      if (((_ptr__3794[_3803] < (int)0) || ((_ptr__3794[_3803] >= _3792) || ((_ptr__3795[_3803] < (int)0) || (_ptr__3795[_3803] >= _3793)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulLeft :: toString() { return mosek::fusion::p_ExprMulLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulLeft(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim0)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulLeft::destroy() { mosek::fusion::p_ExprMulLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVar::ExprMulVar(mosek::fusion::p_ExprMulVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVar()" << this << std::endl; */ }mosek::fusion::ExprMulVar::~ExprMulVar() {  /* std::cout << "~ExprMulVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVar::p_ExprMulVar  (::mosek::fusion::ExprMulVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3804,    int _3805,    int _3806,    std::shared_ptr< monty::ndarray< int,1 > > _3807,    std::shared_ptr< monty::ndarray< int,1 > > _3808,    std::shared_ptr< monty::ndarray< double,1 > > _3809,    monty::rc_ptr< ::mosek::fusion::Variable > _3810){ return new mosek::fusion::ExprMulVar(_3804,_3805,_3806,_3807,_3808,_3809,_3810); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3804,    int _3805,    int _3806,    std::shared_ptr< monty::ndarray< int,1 > > _3807,    std::shared_ptr< monty::ndarray< int,1 > > _3808,    std::shared_ptr< monty::ndarray< double,1 > > _3809,    monty::rc_ptr< ::mosek::fusion::Variable > _3810) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3804,_3805,_3806,_3807,_3808,_3809,_3810); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3804,    int _3805,    int _3806,    std::shared_ptr< monty::ndarray< int,1 > > _3807,    std::shared_ptr< monty::ndarray< int,1 > > _3808,    std::shared_ptr< monty::ndarray< double,1 > > _3809,    monty::rc_ptr< ::mosek::fusion::Variable > _3810){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3807(_3807 ? _3807->raw() : nullptr, _3807 ? _3807->size(0) : 0);
    _checked_ptr_1<int> _ptr__3808(_3808 ? _3808->raw() : nullptr, _3808 ? _3808->size(0) : 0);
    _checked_ptr_1<double> _ptr__3809(_3809 ? _3809->raw() : nullptr, _3809 ? _3809->size(0) : 0);
    mosek::fusion::p_ExprMulVar::_initialize(_3804,_3805,_3806,_3807,_3808,_3809,_3810,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3811 = _3810->getShape();
    _checked_ptr_1<int> _ptr__3811(_3811 ? _3811->raw() : nullptr,_3811 ? _3811->size(0) : 0);
    int _3812 = (int)((_3811)->size(0));
    if ((_3812 != (int)2))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if((_3804 && (_ptr__3811[(int)0] != _3806)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if(((!_3804) && (_ptr__3811[(int)1] != _3805)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
    if ((((int)((_3807)->size(0)) != (int)((_3808)->size(0))) || ((int)((_3807)->size(0)) != (int)((_3809)->size(0)))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching matrix data lengths"));
      }
    }
    {}
    validate(_3805,_3806,_3807,_3808,_3809);
  }
}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3813,    int _3814,    int _3815,    std::shared_ptr< monty::ndarray< int,1 > > _3816,    std::shared_ptr< monty::ndarray< int,1 > > _3817,    std::shared_ptr< monty::ndarray< double,1 > > _3818,    monty::rc_ptr< ::mosek::fusion::Variable > _3819,    int _3820){ return new mosek::fusion::ExprMulVar(_3813,_3814,_3815,_3816,_3817,_3818,_3819,_3820); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3813,    int _3814,    int _3815,    std::shared_ptr< monty::ndarray< int,1 > > _3816,    std::shared_ptr< monty::ndarray< int,1 > > _3817,    std::shared_ptr< monty::ndarray< double,1 > > _3818,    monty::rc_ptr< ::mosek::fusion::Variable > _3819,    int _3820) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3813,_3814,_3815,_3816,_3817,_3818,_3819,_3820); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3813,    int _3814,    int _3815,    std::shared_ptr< monty::ndarray< int,1 > > _3816,    std::shared_ptr< monty::ndarray< int,1 > > _3817,    std::shared_ptr< monty::ndarray< double,1 > > _3818,    monty::rc_ptr< ::mosek::fusion::Variable > _3819,    int _3820){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3816(_3816 ? _3816->raw() : nullptr, _3816 ? _3816->size(0) : 0);
    _checked_ptr_1<int> _ptr__3817(_3817 ? _3817->raw() : nullptr, _3817 ? _3817->size(0) : 0);
    _checked_ptr_1<double> _ptr__3818(_3818 ? _3818->raw() : nullptr, _3818 ? _3818->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulVar::resshape(_3814,_3815,_3819->getShape(),_3813));
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->left = _3813;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->x = _3819;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi = _3814;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj = _3815;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi = ::mosek::fusion::Utils::Tools::arraycopy(_3816);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj = ::mosek::fusion::Utils::Tools::arraycopy(_3817);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof = ::mosek::fusion::Utils::Tools::arraycopy(_3818);
  }
}void mosek::fusion::ExprMulVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3821,monty::rc_ptr< ::mosek::fusion::WorkStack > _3822,monty::rc_ptr< ::mosek::fusion::WorkStack > _3823) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval(_3821,_3822,_3823); }void mosek::fusion::p_ExprMulVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3821,monty::rc_ptr< ::mosek::fusion::WorkStack > _3822,monty::rc_ptr< ::mosek::fusion::WorkStack > _3823){
  if (left)
  {
    {
      _pubthis->eval_left(_3821,_3822,_3823);
    }
  }
  else
  {
    {
      _pubthis->eval_right(_3821,_3822,_3823);
    }
  }
}
void mosek::fusion::ExprMulVar :: eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3824,monty::rc_ptr< ::mosek::fusion::WorkStack > _3825,monty::rc_ptr< ::mosek::fusion::WorkStack > _3826) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_right(_3824,_3825,_3826); }void mosek::fusion::p_ExprMulVar::eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3824,monty::rc_ptr< ::mosek::fusion::WorkStack > _3825,monty::rc_ptr< ::mosek::fusion::WorkStack > _3826){
  int _3827 = mosek::fusion::p_WorkStack::_get_impl(_3825)->pi32;
  int _3828 = mosek::fusion::p_WorkStack::_get_impl(_3825)->pi64;
  int _3829 = x->numInst();
  int _3830 = _3825->alloci64(_3829);
  int _3831 = _3825->alloci64(_3829);
  int _3832 = _3825->alloci32(_3829);
  int _3833 = _3825->alloci32(_3829);
  std::shared_ptr< monty::ndarray< int,1 > > _3834 = x->getShape();
  _checked_ptr_1<int> _ptr__3834(_3834 ? _3834->raw() : nullptr,_3834 ? _3834->size(0) : 0);
  int _3835 = (int)((_3834)->size(0));
  long long _3836 = safe_mul( _ptr__3834[(int)0],_ptr__3834[(int)1] );
  int _3837 = _ptr__3834[(int)1];
  int _3838 = _ptr__3834[(int)0];
  int _3839 = _3825->alloci32(safe_add( _3838,(int)1 ));
  int _3840 = (int)((mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _3841 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3841(_3841 ? _3841->raw() : nullptr,_3841 ? _3841->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3842 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3842(_3842 ? _3842->raw() : nullptr,_3842 ? _3842->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3843 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3843(_3843 ? _3843->raw() : nullptr,_3843 ? _3843->size(0) : 0);
  int _3844 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3845 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  bool _3846 = ((_3840 / _3844) == _3845);
  int _3847 = _3825->alloci32(_3840);
  int _3848 = _3825->alloci32(safe_add( mdimj,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3849 = mosek::fusion::p_WorkStack::_get_impl(_3825)->i32;
  _checked_ptr_1<int> _ptr__3849(_3849 ? _3849->raw() : nullptr,_3849 ? _3849->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3850 = mosek::fusion::p_WorkStack::_get_impl(_3825)->i64;
  _checked_ptr_1<long long> _ptr__3850(_3850 ? _3850->raw() : nullptr,_3850 ? _3850->size(0) : 0);
  int _3851 = (int)0;
  int _3852 = (int)0;
  x->inst(_3831,_3850,_3830,_3850);
  if (_3846)
  {
    {
      int _3853 = (int)0;
      if ((_3829 > (int)0))
      {
        {
          _3853 = (int)1;
          if ((_3838 > (int)1))
          {
            {
              if ((_3837 == (int)1))
              {
                {
                  int _8481 = (int)1;
                  int _8482 = _3829;
                  for (int _3854 = _8481; _3854 < _8482; ++_3854)
                  {
                    {
                      if ((_ptr__3850[safe_add( _3831,_3854 )] > _ptr__3850[(safe_add( _3831,_3854 ) - (int)1)]))
                      {
                        {
                          ++ _3853;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              else
              {
                {
                  int _8483 = (int)1;
                  int _8484 = _3829;
                  for (int _3855 = _8483; _3855 < _8484; ++_3855)
                  {
                    {
                      if (((_ptr__3850[safe_add( _3831,_3855 )] / _3837) > (_ptr__3850[(safe_add( _3831,_3855 ) - (int)1)] / _3837)))
                      {
                        {
                          ++ _3853;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          {}
        }
      }
      {}
      _3852 = safe_mul( _3853,_3845 );
      _3851 = safe_mul( _3829,_3845 );
      bool _3856 = (_3853 < _3838);
      int _3857 = _3824->alloci32(safe_add( _3852,(int)1 ));
      int _8485;
      bool _8486 = _3856;
      if (_8486)
      {
        _8485 = (int)1;
      }
      else
      {
        _8485 = (int)0;
      }
      _3824->pushi32(_8485);
      _3824->pushi32(_3851);
      _3824->pushi32(_3852);
      _3824->pushi32(_3838);
      _3824->pushi32(_3845);
      _3824->pushi32((int)2);
      int _3858 = _3824->alloci64(_3851);
      int _3859 = _3824->alloci64(_3852);
      int _3860 = _3824->allocf64(_3851);
      int _3861 = _3824->allocf64(_3852);
      std::shared_ptr< monty::ndarray< int,1 > > _3862 = mosek::fusion::p_WorkStack::_get_impl(_3824)->i32;
      _checked_ptr_1<int> _ptr__3862(_3862 ? _3862->raw() : nullptr,_3862 ? _3862->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3863 = mosek::fusion::p_WorkStack::_get_impl(_3824)->i64;
      _checked_ptr_1<long long> _ptr__3863(_3863 ? _3863->raw() : nullptr,_3863 ? _3863->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3864 = mosek::fusion::p_WorkStack::_get_impl(_3824)->f64;
      _checked_ptr_1<double> _ptr__3864(_3864 ? _3864->raw() : nullptr,_3864 ? _3864->size(0) : 0);
      {
        int _3865 = (int)0;
        int _3866 = (int)0;
        int _3867 = (int)0;
        _ptr__3862[_3857] = (int)0;
        while ( (_3865 < _3829) )
        {
          {
            int _3868 = _3865;
            ++ _3865;
            while ( ((_3865 < _3829) && ((_ptr__3850[safe_add( _3831,_3865 )] / _3837) == (_ptr__3850[safe_add( _3831,_3868 )] / _3837))) )
            {
              {
                ++ _3865;
              }
            }
            long long _3869 = (_ptr__3850[safe_add( _3831,_3868 )] / _3837);
            int _8487 = (int)0;
            int _8488 = _3845;
            for (int _3870 = _8487; _3870 < _8488; ++_3870)
            {
              {
                int _8489 = _3868;
                int _8490 = _3865;
                for (int _3871 = _8489; _3871 < _8490; ++_3871)
                {
                  {
                    long long _3872 = (_ptr__3850[safe_add( _3831,_3871 )] % _3837);
                    _ptr__3863[safe_add( _3858,_3867 )] = _ptr__3850[safe_add( _3830,_3871 )];
                    _ptr__3864[safe_add( _3860,_3867 )] = _ptr__3843[safe_add( safe_mul( _3872,_3845 ),_3870 )];
                    ++ _3867;
                  }
                }
                _ptr__3862[safe_add( safe_add( _3857,_3866 ),(int)1 )] = _3867;
                _ptr__3864[safe_add( _3861,_3866 )] = 0.0;
                _ptr__3863[safe_add( _3859,_3866 )] = safe_add( safe_mul( _3869,_3845 ),_3870 );
                ++ _3866;
              }
            }
          }
        }
      }
      if ((!_3856))
      {
        {
          _3824->popi64(_3852);
        }
      }
      {}
    }
  }
  else
  {
    {
      {
        if ((_3845 == (int)1))
        {
          {
            int _8491 = (int)0;
            int _8492 = _3840;
            for (int _3873 = _8491; _3873 < _8492; ++_3873)
            {
              {
                _ptr__3849[safe_add( _3847,_3873 )] = _3873;
              }
            }
            _ptr__3849[_3848] = (int)0;
            _ptr__3849[safe_add( _3848,(int)1 )] = _3840;
          }
        }
        else
        {
          {
            _ptr__3849[_3848] = (int)0;
            int _8493 = (int)0;
            int _8494 = safe_add( _3845,(int)1 );
            for (int _3874 = _8493; _3874 < _8494; ++_3874)
            {
              {
                _ptr__3849[safe_add( _3848,_3874 )] = (int)0;
              }
            }
            int _8495 = (int)0;
            int _8496 = _3840;
            for (int _3875 = _8495; _3875 < _8496; ++_3875)
            {
              {
                ++ _ptr__3849[safe_add( safe_add( _3848,_ptr__3842[_3875] ),(int)1 )];
              }
            }
            int _8497 = (int)0;
            int _8498 = mdimj;
            for (int _3876 = _8497; _3876 < _8498; ++_3876)
            {
              {
                _ptr__3849[safe_add( safe_add( _3848,_3876 ),(int)1 )] += _ptr__3849[safe_add( _3848,_3876 )];
              }
            }
            int _8499 = (int)0;
            int _8500 = _3840;
            for (int _3877 = _8499; _3877 < _8500; ++_3877)
            {
              {
                _ptr__3849[safe_add( _3847,_ptr__3849[safe_add( _3848,_ptr__3842[_3877] )] )] = _3877;
                ++ _ptr__3849[safe_add( _3848,_ptr__3842[_3877] )];
              }
            }
            int _8501 = (int)0;
            int _8502 = _3845;
            for (int _3878 = _8501; _3878 < _8502; ++_3878)
            {
              {
                _ptr__3849[(safe_add( _3848,_3845 ) - _3878)] = _ptr__3849[((safe_add( _3848,_3845 ) - _3878) - (int)1)];
              }
            }
            _ptr__3849[_3848] = (int)0;
          }
        }
      }
      if (((_3829 / _3838) == _3837))
      {
        {
          int _3879 = (int)0;
          {
            int _3880 = (int)0;
            while ( (_3880 < _3840) )
            {
              {
                ++ _3880;
                while ( ((_3880 < _3840) && (_ptr__3842[_ptr__3849[(safe_add( _3847,_3880 ) - (int)1)]] == _ptr__3842[_ptr__3849[safe_add( _3847,_3880 )]])) )
                {
                  {
                    ++ _3880;
                  }
                }
                ++ _3879;
              }
            }
          }
          _3852 = safe_mul( _3879,_3838 );
          _3851 = safe_mul( _3840,_3838 );
          bool _3881 = (_3879 < _3845);
          int _3882 = _3824->alloci32(safe_add( _3852,(int)1 ));
          int _8503;
          bool _8504 = _3881;
          if (_8504)
          {
            _8503 = (int)1;
          }
          else
          {
            _8503 = (int)0;
          }
          _3824->pushi32(_8503);
          _3824->pushi32(_3851);
          _3824->pushi32(_3852);
          _3824->pushi32(_3838);
          _3824->pushi32(_3845);
          _3824->pushi32((int)2);
          int _3883 = _3824->alloci64(_3851);
          int _3884 = _3824->alloci64(_3852);
          int _3885 = _3824->allocf64(_3851);
          int _3886 = _3824->allocf64(_3852);
          std::shared_ptr< monty::ndarray< int,1 > > _3887 = mosek::fusion::p_WorkStack::_get_impl(_3824)->i32;
          _checked_ptr_1<int> _ptr__3887(_3887 ? _3887->raw() : nullptr,_3887 ? _3887->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3888 = mosek::fusion::p_WorkStack::_get_impl(_3824)->i64;
          _checked_ptr_1<long long> _ptr__3888(_3888 ? _3888->raw() : nullptr,_3888 ? _3888->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3889 = mosek::fusion::p_WorkStack::_get_impl(_3824)->f64;
          _checked_ptr_1<double> _ptr__3889(_3889 ? _3889->raw() : nullptr,_3889 ? _3889->size(0) : 0);
          _ptr__3887[_3882] = (int)0;
          int _3890 = (int)0;
          int _3891 = (int)0;
          int _8505 = (int)0;
          int _8506 = _3838;
          for (int _3892 = _8505; _3892 < _8506; ++_3892)
          {
            {
              int _3893 = (int)0;
              while ( (_3893 < _3840) )
              {
                {
                  int _3894 = _3893;
                  ++ _3893;
                  while ( ((_3893 < _3840) && (_ptr__3842[_ptr__3849[safe_add( _3847,_3894 )]] == _ptr__3842[_ptr__3849[safe_add( _3847,_3893 )]])) )
                  {
                    {
                      ++ _3893;
                    }
                  }
                  int _3895 = _ptr__3842[_ptr__3849[safe_add( _3847,_3894 )]];
                  int _8507 = _3894;
                  int _8508 = _3893;
                  for (int _3896 = _8507; _3896 < _8508; ++_3896)
                  {
                    {
                      int _3897 = _ptr__3841[_ptr__3849[safe_add( _3847,_3896 )]];
                      _ptr__3888[safe_add( _3883,_3891 )] = _ptr__3850[safe_add( safe_add( _3830,safe_mul( _3892,_3837 ) ),_3897 )];
                      _ptr__3889[safe_add( _3885,_3891 )] = _ptr__3843[_ptr__3849[safe_add( _3847,_3896 )]];
                      ++ _3891;
                    }
                  }
                  _ptr__3889[safe_add( _3886,_3890 )] = 0.0;
                  _ptr__3888[safe_add( _3884,_3890 )] = safe_add( safe_mul( _3892,_3845 ),_3895 );
                  _ptr__3887[safe_add( safe_add( _3882,_3890 ),(int)1 )] = _3891;
                  ++ _3890;
                }
              }
            }
          }
          if ((!_3881))
          {
            {
              _3824->popi64(_3852);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _8509 = (int)0;
          int _8510 = safe_add( _3838,(int)1 );
          for (int _3898 = _8509; _3898 < _8510; ++_3898)
          {
            {
              _ptr__3849[safe_add( _3839,_3898 )] = (int)0;
            }
          }
          if ((_3835 == (int)1))
          {
            {
              int _8511 = (int)0;
              int _8512 = _3829;
              for (int _3899 = _8511; _3899 < _8512; ++_3899)
              {
                {
                  _ptr__3849[safe_add( _3832,_3899 )] = (int)0;
                }
              }
              int _8513 = (int)0;
              int _8514 = _3829;
              for (int _3900 = _8513; _3900 < _8514; ++_3900)
              {
                {
                  _ptr__3849[safe_add( _3833,_3900 )] = (int)_ptr__3850[safe_add( _3831,_3900 )];
                }
              }
              _ptr__3849[_3839] = (int)0;
              _ptr__3849[safe_add( _3839,(int)1 )] = _3829;
            }
          }
          else
          {
            {
              int _8515 = (int)0;
              int _8516 = _3829;
              for (int _3901 = _8515; _3901 < _8516; ++_3901)
              {
                {
                  _ptr__3849[safe_add( _3832,_3901 )] = (int)(_ptr__3850[safe_add( _3831,_3901 )] / _ptr__3834[(int)1]);
                }
              }
              int _8517 = (int)0;
              int _8518 = _3829;
              for (int _3902 = _8517; _3902 < _8518; ++_3902)
              {
                {
                  _ptr__3849[safe_add( _3833,_3902 )] = (int)(_ptr__3850[safe_add( _3831,_3902 )] % _ptr__3834[(int)1]);
                }
              }
              _ptr__3849[_3839] = (int)0;
              int _8519 = (int)0;
              int _8520 = _3829;
              for (int _3903 = _8519; _3903 < _8520; ++_3903)
              {
                {
                  ++ _ptr__3849[safe_add( safe_add( _3839,_ptr__3849[safe_add( _3832,_3903 )] ),(int)1 )];
                }
              }
              int _8521 = (int)0;
              int _8522 = _3838;
              for (int _3904 = _8521; _3904 < _8522; ++_3904)
              {
                {
                  _ptr__3849[safe_add( safe_add( _3839,_3904 ),(int)1 )] += _ptr__3849[safe_add( _3839,_3904 )];
                }
              }
            }
          }
          int _8523 = (int)0;
          int _8524 = _3838;
          for (int _3905 = _8523; _3905 < _8524; ++_3905)
          {
            {
              int _8525 = (int)0;
              int _8526 = mdimj;
              for (int _3906 = _8525; _3906 < _8526; ++_3906)
              {
                {
                  int _3907 = (int)0;
                  int _3908 = _ptr__3849[safe_add( safe_add( _3839,_3905 ),(int)1 )];
                  int _3909 = _ptr__3849[safe_add( safe_add( _3848,_3906 ),(int)1 )];
                  int _3910 = _ptr__3849[safe_add( _3839,_3905 )];
                  int _3911 = _ptr__3849[safe_add( _3848,_3906 )];
                  while ( ((_3911 < _3909) && (_3910 < _3908)) )
                  {
                    {
                      if ((_ptr__3841[_ptr__3849[safe_add( _3847,_3911 )]] < _ptr__3849[safe_add( _3833,_3910 )]))
                      {
                        {
                          ++ _3911;
                        }
                      }
                      else if((_ptr__3841[_ptr__3849[safe_add( _3847,_3911 )]] > _ptr__3849[safe_add( _3833,_3910 )]))
                      {
                        {
                          ++ _3910;
                        }
                      }
                      else
                      {
                        {
                          ++ _3907;
                          ++ _3911;
                          ++ _3910;
                        }
                      }
                    }
                  }
                  if ((_3907 > (int)0))
                  {
                    {
                      _3851 += _3907;
                      ++ _3852;
                    }
                  }
                  {}
                }
              }
            }
          }
          int _3912 = _3824->alloci32(safe_add( _3852,(int)1 ));
          bool _8527;
          bool _8528 = (_3852 < safe_mul( _3837,mdimi ));
          if (_8528)
          {
            _8527 = true;
          }
          else
          {
            _8527 = false;
          }
          bool _3913 = _8527;
          int _8529;
          bool _8530 = _3913;
          if (_8530)
          {
            _8529 = (int)1;
          }
          else
          {
            _8529 = (int)0;
          }
          _3824->pushi32(_8529);
          _3824->pushi32(_3851);
          _3824->pushi32(_3852);
          _3824->pushi32(_3838);
          _3824->pushi32(mdimj);
          _3824->pushi32((int)2);
          int _3914 = _3824->alloci64(_3851);
          int _3915 = _3824->alloci64(_3852);
          int _3916 = _3824->allocf64(_3851);
          int _3917 = _3824->allocf64(_3852);
          std::shared_ptr< monty::ndarray< int,1 > > _3918 = mosek::fusion::p_WorkStack::_get_impl(_3824)->i32;
          _checked_ptr_1<int> _ptr__3918(_3918 ? _3918->raw() : nullptr,_3918 ? _3918->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3919 = mosek::fusion::p_WorkStack::_get_impl(_3824)->i64;
          _checked_ptr_1<long long> _ptr__3919(_3919 ? _3919->raw() : nullptr,_3919 ? _3919->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3920 = mosek::fusion::p_WorkStack::_get_impl(_3824)->f64;
          _checked_ptr_1<double> _ptr__3920(_3920 ? _3920->raw() : nullptr,_3920 ? _3920->size(0) : 0);
          {
            int _3921 = (int)0;
            int _3922 = (int)0;
            int _3923 = (int)0;
            _ptr__3918[_3912] = (int)0;
            int _8531 = (int)0;
            int _8532 = _3852;
            for (int _3924 = _8531; _3924 < _8532; ++_3924)
            {
              {
                _ptr__3920[safe_add( _3917,_3924 )] = 0.0;
              }
            }
            int _8533 = (int)0;
            int _8534 = _3838;
            for (int _3925 = _8533; _3925 < _8534; ++_3925)
            {
              {
                int _8535 = (int)0;
                int _8536 = mdimj;
                for (int _3926 = _8535; _3926 < _8536; ++_3926)
                {
                  {
                    int _3927 = (int)0;
                    int _3928 = _ptr__3849[safe_add( safe_add( _3839,_3925 ),(int)1 )];
                    int _3929 = _ptr__3849[safe_add( safe_add( _3848,_3926 ),(int)1 )];
                    int _3930 = _ptr__3849[safe_add( _3839,_3925 )];
                    int _3931 = _ptr__3849[safe_add( _3848,_3926 )];
                    while ( ((_3931 < _3929) && (_3930 < _3928)) )
                    {
                      {
                        if ((_ptr__3841[_ptr__3849[safe_add( _3847,_3931 )]] < _ptr__3849[safe_add( _3833,_3930 )]))
                        {
                          {
                            ++ _3931;
                          }
                        }
                        else if((_ptr__3841[_ptr__3849[safe_add( _3847,_3931 )]] > _ptr__3849[safe_add( _3833,_3930 )]))
                        {
                          {
                            ++ _3930;
                          }
                        }
                        else
                        {
                          {
                            _ptr__3919[safe_add( _3914,_3923 )] = _ptr__3850[safe_add( _3830,_3930 )];
                            _ptr__3920[safe_add( _3916,_3923 )] = _ptr__3843[_ptr__3849[safe_add( _3847,_3931 )]];
                            ++ _3927;
                            ++ _3923;
                            ++ _3931;
                            ++ _3930;
                          }
                        }
                      }
                    }
                    if ((_3927 > (int)0))
                    {
                      {
                        _ptr__3918[safe_add( safe_add( _3912,_3922 ),(int)1 )] = _3923;
                        _ptr__3919[safe_add( _3915,_3922 )] = _3921;
                        ++ _3922;
                      }
                    }
                    {}
                    ++ _3921;
                  }
                }
              }
            }
          }
          if ((!_3913))
          {
            {
              _3824->popi64(_3852);
            }
          }
          {}
        }
      }
    }
  }
  mosek::fusion::p_WorkStack::_get_impl(_3825)->pi32 = _3827;
  mosek::fusion::p_WorkStack::_get_impl(_3825)->pi64 = _3828;
}
void mosek::fusion::ExprMulVar :: eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3932,monty::rc_ptr< ::mosek::fusion::WorkStack > _3933,monty::rc_ptr< ::mosek::fusion::WorkStack > _3934) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_left(_3932,_3933,_3934); }void mosek::fusion::p_ExprMulVar::eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3932,monty::rc_ptr< ::mosek::fusion::WorkStack > _3933,monty::rc_ptr< ::mosek::fusion::WorkStack > _3934){
  int _3935 = x->numInst();
  std::shared_ptr< monty::ndarray< int,1 > > _3936 = x->getShape();
  _checked_ptr_1<int> _ptr__3936(_3936 ? _3936->raw() : nullptr,_3936 ? _3936->size(0) : 0);
  int _3937 = (int)((_3936)->size(0));
  int _3938 = _3934->alloci64(_3935);
  int _3939 = _3934->alloci64(_3935);
  int _3940 = _3934->alloci32(_3935);
  int _3941 = _3934->alloci32(_3935);
  int _3942 = _3934->alloci32(_3935);
  int _3943 = _3934->alloci32(safe_add( mdimi,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3944 = x->getShape();
  _checked_ptr_1<int> _ptr__3944(_3944 ? _3944->raw() : nullptr,_3944 ? _3944->size(0) : 0);
  int _3945 = (int)((_3944)->size(0));
  int _8537;
  bool _8538 = (_3945 == (int)1);
  if (_8538)
  {
    _8537 = (int)1;
  }
  else
  {
    _8537 = _ptr__3944[(int)1];
  }
  int _3946 = _8537;
  int _3947 = _ptr__3944[(int)0];
  int _3948 = _3934->alloci32(safe_add( _3946,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3949 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3949(_3949 ? _3949->raw() : nullptr,_3949 ? _3949->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3950 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3950(_3950 ? _3950->raw() : nullptr,_3950 ? _3950->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3951 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3951(_3951 ? _3951->raw() : nullptr,_3951 ? _3951->size(0) : 0);
  int _3952 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3953 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  int _3954 = (int)0;
  int _3955 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _3956 = mosek::fusion::p_WorkStack::_get_impl(_3934)->i32;
  _checked_ptr_1<int> _ptr__3956(_3956 ? _3956->raw() : nullptr,_3956 ? _3956->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3957 = mosek::fusion::p_WorkStack::_get_impl(_3934)->i64;
  _checked_ptr_1<long long> _ptr__3957(_3957 ? _3957->raw() : nullptr,_3957 ? _3957->size(0) : 0);
  x->inst(_3939,_3957,_3938,_3957);
  {
    int _8539 = (int)0;
    int _8540 = safe_add( _3952,(int)1 );
    for (int _3958 = _8539; _3958 < _8540; ++_3958)
    {
      {
        _ptr__3956[safe_add( _3943,_3958 )] = (int)0;
      }
    }
    int _8541 = (int)0;
    int _8542 = (int)((_3949)->size(0));
    for (int _3959 = _8541; _3959 < _8542; ++_3959)
    {
      {
        ++ _ptr__3956[safe_add( safe_add( _3943,_ptr__3949[_3959] ),(int)1 )];
      }
    }
    int _8543 = (int)0;
    int _8544 = _3952;
    for (int _3960 = _8543; _3960 < _8544; ++_3960)
    {
      {
        _ptr__3956[safe_add( safe_add( _3943,_3960 ),(int)1 )] += _ptr__3956[safe_add( _3943,_3960 )];
      }
    }
    if ((_3945 == (int)1))
    {
      {
        int _8545 = (int)0;
        int _8546 = _3935;
        for (int _3961 = _8545; _3961 < _8546; ++_3961)
        {
          {
            _ptr__3956[safe_add( _3940,_3961 )] = (int)_ptr__3957[safe_add( _3939,_3961 )];
          }
        }
        int _8547 = (int)0;
        int _8548 = _3935;
        for (int _3962 = _8547; _3962 < _8548; ++_3962)
        {
          {
            _ptr__3956[safe_add( _3941,_3962 )] = (int)0;
          }
        }
      }
    }
    else
    {
      {
        int _8549 = (int)0;
        int _8550 = _3935;
        for (int _3963 = _8549; _3963 < _8550; ++_3963)
        {
          {
            _ptr__3956[safe_add( _3940,_3963 )] = (int)(_ptr__3957[safe_add( _3939,_3963 )] / _3946);
          }
        }
        int _8551 = (int)0;
        int _8552 = _3935;
        for (int _3964 = _8551; _3964 < _8552; ++_3964)
        {
          {
            _ptr__3956[safe_add( _3941,_3964 )] = (int)(_ptr__3957[safe_add( _3939,_3964 )] % _3946);
          }
        }
      }
    }
    if ((_3945 > (int)1))
    {
      {
        int _8553 = (int)0;
        int _8554 = safe_add( _3946,(int)1 );
        for (int _3965 = _8553; _3965 < _8554; ++_3965)
        {
          {
            _ptr__3956[safe_add( _3948,_3965 )] = (int)0;
          }
        }
        int _8555 = (int)0;
        int _8556 = _3935;
        for (int _3966 = _8555; _3966 < _8556; ++_3966)
        {
          {
            ++ _ptr__3956[safe_add( safe_add( _3948,_ptr__3956[safe_add( _3941,_3966 )] ),(int)1 )];
          }
        }
        int _8557 = (int)0;
        int _8558 = _3946;
        for (int _3967 = _8557; _3967 < _8558; ++_3967)
        {
          {
            _ptr__3956[safe_add( safe_add( _3948,_3967 ),(int)1 )] += _ptr__3956[safe_add( _3948,_3967 )];
          }
        }
        int _8559 = (int)0;
        int _8560 = _3935;
        for (int _3968 = _8559; _3968 < _8560; ++_3968)
        {
          {
            _ptr__3956[safe_add( _3942,_ptr__3956[safe_add( _3948,_ptr__3956[safe_add( _3941,_3968 )] )] )] = _3968;
            ++ _ptr__3956[safe_add( _3948,_ptr__3956[safe_add( _3941,_3968 )] )];
          }
        }
        int _8561 = (int)0;
        int _8562 = _3946;
        for (int _3969 = _8561; _3969 < _8562; ++_3969)
        {
          {
            _ptr__3956[(safe_add( _3948,_3946 ) - _3969)] = _ptr__3956[((safe_add( _3948,_3946 ) - _3969) - (int)1)];
          }
        }
        _ptr__3956[_3948] = (int)0;
      }
    }
    else
    {
      {
        _ptr__3956[_3948] = (int)0;
        _ptr__3956[safe_add( _3948,(int)1 )] = _3935;
        int _8563 = (int)0;
        int _8564 = _3935;
        for (int _3970 = _8563; _3970 < _8564; ++_3970)
        {
          {
            _ptr__3956[safe_add( _3942,_3970 )] = _3970;
          }
        }
      }
    }
    int _8565 = (int)0;
    int _8566 = _3952;
    for (int _3971 = _8565; _3971 < _8566; ++_3971)
    {
      {
        int _8567 = (int)0;
        int _8568 = _3946;
        for (int _3972 = _8567; _3972 < _8568; ++_3972)
        {
          {
            int _3973 = (int)0;
            int _3974 = _ptr__3956[safe_add( safe_add( _3948,_3972 ),(int)1 )];
            int _3975 = _ptr__3956[safe_add( safe_add( _3943,_3971 ),(int)1 )];
            int _3976 = _ptr__3956[safe_add( _3948,_3972 )];
            int _3977 = _ptr__3956[safe_add( _3943,_3971 )];
            while ( ((_3977 < _3975) && (_3976 < _3974)) )
            {
              {
                if ((_ptr__3950[_3977] < _ptr__3956[safe_add( _3940,_ptr__3956[safe_add( _3942,_3976 )] )]))
                {
                  {
                    ++ _3977;
                  }
                }
                else if((_ptr__3950[_3977] > _ptr__3956[safe_add( _3940,_ptr__3956[safe_add( _3942,_3976 )] )]))
                {
                  {
                    ++ _3976;
                  }
                }
                else
                {
                  {
                    ++ _3973;
                    ++ _3977;
                    ++ _3976;
                  }
                }
              }
            }
            if ((_3973 > (int)0))
            {
              {
                _3954 += _3973;
                ++ _3955;
              }
            }
            {}
          }
        }
      }
    }
  }
  bool _8569;
  bool _8570 = (_3955 < safe_mul( _3946,_3952 ));
  if (_8570)
  {
    _8569 = true;
  }
  else
  {
    _8569 = false;
  }
  bool _3978 = _8569;
  int _3979 = _3945;
  _3932->alloc_expr(_3979,_3955,_3954,_3978);
  int _3980 = mosek::fusion::p_WorkStack::_get_impl(_3932)->ptr_base;
  int _3981 = mosek::fusion::p_WorkStack::_get_impl(_3932)->shape_base;
  int _3982 = mosek::fusion::p_WorkStack::_get_impl(_3932)->nidxs_base;
  int _8571;
  bool _8572 = _3978;
  if (_8572)
  {
    _8571 = mosek::fusion::p_WorkStack::_get_impl(_3932)->sp_base;
  }
  else
  {
    _8571 = _3932->alloci64(_3955);
  }
  int _3983 = _8571;
  int _3984 = mosek::fusion::p_WorkStack::_get_impl(_3932)->cof_base;
  int _3985 = mosek::fusion::p_WorkStack::_get_impl(_3932)->bfix_base;
  std::shared_ptr< monty::ndarray< int,1 > > _3986 = mosek::fusion::p_WorkStack::_get_impl(_3932)->i32;
  _checked_ptr_1<int> _ptr__3986(_3986 ? _3986->raw() : nullptr,_3986 ? _3986->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3987 = mosek::fusion::p_WorkStack::_get_impl(_3932)->i64;
  _checked_ptr_1<long long> _ptr__3987(_3987 ? _3987->raw() : nullptr,_3987 ? _3987->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3988 = mosek::fusion::p_WorkStack::_get_impl(_3932)->f64;
  _checked_ptr_1<double> _ptr__3988(_3988 ? _3988->raw() : nullptr,_3988 ? _3988->size(0) : 0);
  _ptr__3986[_3981] = _3952;
  if ((_3945 > (int)1))
  {
    {
      _ptr__3986[safe_add( _3981,(int)1 )] = _3946;
    }
  }
  {}
  {
    int _3989 = (int)0;
    int _3990 = (int)0;
    int _3991 = (int)0;
    _ptr__3986[_3980] = (int)0;
    int _8573 = (int)0;
    int _8574 = _3955;
    for (int _3992 = _8573; _3992 < _8574; ++_3992)
    {
      {
        _ptr__3988[safe_add( _3985,_3992 )] = 0.0;
      }
    }
    int _8575 = (int)0;
    int _8576 = _3952;
    for (int _3993 = _8575; _3993 < _8576; ++_3993)
    {
      {
        int _8577 = (int)0;
        int _8578 = _3946;
        for (int _3994 = _8577; _3994 < _8578; ++_3994)
        {
          {
            int _3995 = (int)0;
            int _3996 = _ptr__3956[safe_add( safe_add( _3948,_3994 ),(int)1 )];
            int _3997 = _ptr__3956[safe_add( safe_add( _3943,_3993 ),(int)1 )];
            int _3998 = _ptr__3956[safe_add( _3948,_3994 )];
            int _3999 = _ptr__3956[safe_add( _3943,_3993 )];
            while ( ((_3999 < _3997) && (_3998 < _3996)) )
            {
              {
                if ((_ptr__3950[_3999] < _ptr__3956[safe_add( _3940,_ptr__3956[safe_add( _3942,_3998 )] )]))
                {
                  {
                    ++ _3999;
                  }
                }
                else if((_ptr__3950[_3999] > _ptr__3956[safe_add( _3940,_ptr__3956[safe_add( _3942,_3998 )] )]))
                {
                  {
                    ++ _3998;
                  }
                }
                else
                {
                  {
                    _ptr__3987[safe_add( _3982,_3991 )] = _ptr__3957[safe_add( _3938,_ptr__3956[safe_add( _3942,_3998 )] )];
                    _ptr__3988[safe_add( _3984,_3991 )] = _ptr__3951[_3999];
                    ++ _3995;
                    ++ _3991;
                    ++ _3999;
                    ++ _3998;
                  }
                }
              }
            }
            if ((_3995 > (int)0))
            {
              {
                _ptr__3986[safe_add( safe_add( _3980,_3990 ),(int)1 )] = _3991;
                _ptr__3987[safe_add( _3983,_3990 )] = _3989;
                ++ _3990;
              }
            }
            {}
            ++ _3989;
          }
        }
      }
    }
  }
  if ((!_3978))
  {
    {
      _3932->popi64(_3955);
    }
  }
  {}
  _3934->clear();
}
void mosek::fusion::p_ExprMulVar::validate(int _4000,int _4001,std::shared_ptr< monty::ndarray< int,1 > > _4002,std::shared_ptr< monty::ndarray< int,1 > > _4003,std::shared_ptr< monty::ndarray< double,1 > > _4004){
  _checked_ptr_1<int> _ptr__4002(_4002 ? _4002->raw() : nullptr, _4002 ? _4002->size(0) : 0);
  _checked_ptr_1<int> _ptr__4003(_4003 ? _4003->raw() : nullptr, _4003 ? _4003->size(0) : 0);
  _checked_ptr_1<double> _ptr__4004(_4004 ? _4004->raw() : nullptr, _4004 ? _4004->size(0) : 0);
  bool _4005 = true;
  {
    int _8579 = (int)0;
    int _8580 = (int)((_4002)->size(0));
    for (int _4006 = _8579; _4006 < _8580; ++_4006)
    {
      {
        if (((_ptr__4002[_4006] < (int)0) || ((_ptr__4002[_4006] >= _4000) || ((_ptr__4003[_4006] < (int)0) || (_ptr__4003[_4006] >= _4001)))))
        {
          {
            _4005 = false;
          }
        }
        {}
      }
    }
    int _8581 = (int)1;
    int _8582 = (int)((_4002)->size(0));
    for (int _4007 = _8581; _4007 < _8582; ++_4007)
    {
      {
        if (((_ptr__4002[(_4007 - (int)1)] > _ptr__4002[_4007]) || ((_ptr__4002[(_4007 - (int)1)] == _ptr__4002[_4007]) && (_ptr__4003[(_4007 - (int)1)] >= _ptr__4003[_4007]))))
        {
          {
            _4005 = false;
          }
        }
        {}
      }
    }
  }
  if ((!_4005))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulVar::resshape(int _4008,int _4009,std::shared_ptr< monty::ndarray< int,1 > > _4010,bool _4011){
  _checked_ptr_1<int> _ptr__4010(_4010 ? _4010->raw() : nullptr, _4010 ? _4010->size(0) : 0);
  if (_4011)
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4008),(int)(_ptr__4010[(int)1])});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__4010[(int)0]),(int)(_4009)});
    }
  }
}
std::string mosek::fusion::ExprMulVar :: toString() { return mosek::fusion::p_ExprMulVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVar::toString(){
  if (left)
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
    }
  }
  else
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",M)"))->toString();
    }
  }
}
void mosek::fusion::p_ExprMulVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulVar::destroy() { mosek::fusion::p_ExprMulVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar(mosek::fusion::p_ExprMulScalarVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarVar()" << this << std::endl; */ }mosek::fusion::ExprMulScalarVar::~ExprMulScalarVar() {  /* std::cout << "~ExprMulScalarVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarVar::p_ExprMulScalarVar  (::mosek::fusion::ExprMulScalarVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4012,    int _4013,    std::shared_ptr< monty::ndarray< int,1 > > _4014,    std::shared_ptr< monty::ndarray< int,1 > > _4015,    std::shared_ptr< monty::ndarray< double,1 > > _4016,    monty::rc_ptr< ::mosek::fusion::Variable > _4017){ return new mosek::fusion::ExprMulScalarVar(_4012,_4013,_4014,_4015,_4016,_4017); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4012,    int _4013,    std::shared_ptr< monty::ndarray< int,1 > > _4014,    std::shared_ptr< monty::ndarray< int,1 > > _4015,    std::shared_ptr< monty::ndarray< double,1 > > _4016,    monty::rc_ptr< ::mosek::fusion::Variable > _4017) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4012,_4013,_4014,_4015,_4016,_4017); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4012,    int _4013,    std::shared_ptr< monty::ndarray< int,1 > > _4014,    std::shared_ptr< monty::ndarray< int,1 > > _4015,    std::shared_ptr< monty::ndarray< double,1 > > _4016,    monty::rc_ptr< ::mosek::fusion::Variable > _4017){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4014(_4014 ? _4014->raw() : nullptr, _4014 ? _4014->size(0) : 0);
    _checked_ptr_1<int> _ptr__4015(_4015 ? _4015->raw() : nullptr, _4015 ? _4015->size(0) : 0);
    _checked_ptr_1<double> _ptr__4016(_4016 ? _4016->raw() : nullptr, _4016 ? _4016->size(0) : 0);
    mosek::fusion::p_ExprMulScalarVar::_initialize(_4012,_4013,::mosek::fusion::Utils::Tools::arraycopy(_4014),::mosek::fusion::Utils::Tools::arraycopy(_4015),::mosek::fusion::Utils::Tools::arraycopy(_4016),_4017,(int)1);
    if ((_4017->getND() != (int)0))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid Variable size"));
      }
    }
    {}
    if (((_4012 < (int)0) || ((_4013 < (int)0) || (((int)((_4014)->size(0)) != (int)((_4015)->size(0))) || ((int)((_4014)->size(0)) != (int)((_4016)->size(0)))))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    int _8583 = (int)0;
    int _8584 = (int)((_4014)->size(0));
    for (int _4018 = _8583; _4018 < _8584; ++_4018)
    {
      {
        if (((_ptr__4014[_4018] < (int)0) || ((_ptr__4014[_4018] >= _4012) || ((_ptr__4015[_4018] < (int)0) || (_ptr__4015[_4018] >= _4013)))))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Invalid Matrix data"));
          }
        }
        {}
      }
    }
    int _8585 = (int)1;
    int _8586 = (int)((_4014)->size(0));
    for (int _4019 = _8585; _4019 < _8586; ++_4019)
    {
      {
        if (((_ptr__4014[_4019] < _ptr__4014[(_4019 - (int)1)]) || ((_ptr__4014[_4019] == _ptr__4014[(_4019 - (int)1)]) && (_ptr__4015[_4019] <= _ptr__4015[(_4019 - (int)1)]))))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Matrix data not correctly sorted"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4020,    int _4021,    std::shared_ptr< monty::ndarray< int,1 > > _4022,    std::shared_ptr< monty::ndarray< int,1 > > _4023,    std::shared_ptr< monty::ndarray< double,1 > > _4024,    monty::rc_ptr< ::mosek::fusion::Variable > _4025,    int _4026){ return new mosek::fusion::ExprMulScalarVar(_4020,_4021,_4022,_4023,_4024,_4025,_4026); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4020,    int _4021,    std::shared_ptr< monty::ndarray< int,1 > > _4022,    std::shared_ptr< monty::ndarray< int,1 > > _4023,    std::shared_ptr< monty::ndarray< double,1 > > _4024,    monty::rc_ptr< ::mosek::fusion::Variable > _4025,    int _4026) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4020,_4021,_4022,_4023,_4024,_4025,_4026); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4020,    int _4021,    std::shared_ptr< monty::ndarray< int,1 > > _4022,    std::shared_ptr< monty::ndarray< int,1 > > _4023,    std::shared_ptr< monty::ndarray< double,1 > > _4024,    monty::rc_ptr< ::mosek::fusion::Variable > _4025,    int _4026){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4022(_4022 ? _4022->raw() : nullptr, _4022 ? _4022->size(0) : 0);
    _checked_ptr_1<int> _ptr__4023(_4023 ? _4023->raw() : nullptr, _4023 ? _4023->size(0) : 0);
    _checked_ptr_1<double> _ptr__4024(_4024 ? _4024->raw() : nullptr, _4024 ? _4024->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4020),(int)(_4021)}));
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimi = _4020;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimj = _4021;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubi = _4022;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubj = _4023;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mcof = _4024;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->x = _4025;
  }
}void mosek::fusion::ExprMulScalarVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4027,monty::rc_ptr< ::mosek::fusion::WorkStack > _4028,monty::rc_ptr< ::mosek::fusion::WorkStack > _4029) { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->eval(_4027,_4028,_4029); }void mosek::fusion::p_ExprMulScalarVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4027,monty::rc_ptr< ::mosek::fusion::WorkStack > _4028,monty::rc_ptr< ::mosek::fusion::WorkStack > _4029){
  if ((x->numInst() == (int)0))
  {
    {
      _4027->alloc_expr((int)2,(int)0,(int)0,false);
      ((*mosek::fusion::p_WorkStack::_get_impl(_4027)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4027)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4027)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4027)->shape_base,(int)1 ))) = mdimj;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _4030 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1)));
      _checked_ptr_1<long long> _ptr__4030(_4030 ? _4030->raw() : nullptr,_4030 ? _4030->size(0) : 0);
      x->inst((int)0,_4030);
      long long _4031 = _ptr__4030[(int)0];
      int _4032 = (int)((msubi)->size(0));
      int _4033 = _4032;
      bool _4034 = (_4032 < safe_mul( mdimi,mdimj ));
      _4027->alloc_expr((int)2,_4032,_4033,_4034);
      int _4035 = mosek::fusion::p_WorkStack::_get_impl(_4027)->ptr_base;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4027)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4027)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4027)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4027)->shape_base,(int)1 ))) = mdimj;
      int _4036 = mosek::fusion::p_WorkStack::_get_impl(_4027)->nidxs_base;
      int _4037 = mosek::fusion::p_WorkStack::_get_impl(_4027)->sp_base;
      int _4038 = mosek::fusion::p_WorkStack::_get_impl(_4027)->cof_base;
      int _4039 = mosek::fusion::p_WorkStack::_get_impl(_4027)->bfix_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4040 = mosek::fusion::p_WorkStack::_get_impl(_4027)->i32;
      _checked_ptr_1<int> _ptr__4040(_4040 ? _4040->raw() : nullptr,_4040 ? _4040->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4041 = mosek::fusion::p_WorkStack::_get_impl(_4027)->i64;
      _checked_ptr_1<long long> _ptr__4041(_4041 ? _4041->raw() : nullptr,_4041 ? _4041->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4042 = mosek::fusion::p_WorkStack::_get_impl(_4027)->f64;
      _checked_ptr_1<double> _ptr__4042(_4042 ? _4042->raw() : nullptr,_4042 ? _4042->size(0) : 0);
      {
        int _8587 = (int)0;
        int _8588 = _4032;
        for (int _4043 = _8587; _4043 < _8588; ++_4043)
        {
          {
            _ptr__4042[safe_add( _4039,_4043 )] = (int)0;
          }
        }
        int _8589 = (int)0;
        int _8590 = _4033;
        for (int _4044 = _8589; _4044 < _8590; ++_4044)
        {
          {
            _ptr__4042[safe_add( _4038,_4044 )] = ((*mcof)(_4044));
          }
        }
        int _8591 = (int)0;
        int _8592 = _4033;
        for (int _4045 = _8591; _4045 < _8592; ++_4045)
        {
          {
            _ptr__4041[safe_add( _4036,_4045 )] = _4031;
          }
        }
        if (_4034)
        {
          {
            int _8593 = (int)0;
            int _8594 = _4032;
            for (int _4046 = _8593; _4046 < _8594; ++_4046)
            {
              {
                _ptr__4041[safe_add( _4037,_4046 )] = safe_add( safe_mul( ((*msubi)(_4046)),mdimj ),((*msubj)(_4046)) );
              }
            }
          }
        }
        {}
        int _8595 = (int)0;
        int _8596 = safe_add( _4032,(int)1 );
        for (int _4047 = _8595; _4047 < _8596; ++_4047)
        {
          {
            _ptr__4040[safe_add( _4035,_4047 )] = _4047;
          }
        }
      }
    }
  }
}
std::string mosek::fusion::ExprMulScalarVar :: toString() { return mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulScalarVar(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("), "))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulScalarVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulScalarVar::destroy() { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst(mosek::fusion::p_ExprMulVarScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVarScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulVarScalarConst::~ExprMulVarScalarConst() {  /* std::cout << "~ExprMulVarScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVarScalarConst::p_ExprMulVarScalarConst  (::mosek::fusion::ExprMulVarScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVarScalarConst::t mosek::fusion::p_ExprMulVarScalarConst::_new_ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4048,    double _4049){ return new mosek::fusion::ExprMulVarScalarConst(_4048,_4049); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4048,    double _4049) :    ExprMulVarScalarConst(new mosek::fusion::p_ExprMulVarScalarConst(this)){ mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->_initialize(_4048,_4049); }void mosek::fusion::p_ExprMulVarScalarConst::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4048,    double _4049){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4048->getShape());
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->x = _4048;
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->c = _4049;
  }
}void mosek::fusion::ExprMulVarScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4050,monty::rc_ptr< ::mosek::fusion::WorkStack > _4051,monty::rc_ptr< ::mosek::fusion::WorkStack > _4052) { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->eval(_4050,_4051,_4052); }void mosek::fusion::p_ExprMulVarScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4050,monty::rc_ptr< ::mosek::fusion::WorkStack > _4051,monty::rc_ptr< ::mosek::fusion::WorkStack > _4052){
  int _4053 = x->numInst();
  int _4054 = _4053;
  std::shared_ptr< monty::ndarray< int,1 > > _4055 = x->getShape();
  _checked_ptr_1<int> _ptr__4055(_4055 ? _4055->raw() : nullptr,_4055 ? _4055->size(0) : 0);
  int _4056 = (int)((_4055)->size(0));
  int _4057 = _4050->alloci32(safe_add( _4054,(int)1 ));
  int _4058 = _4050->alloci64(_4053);
  bool _4059 = (::mosek::fusion::p_Set::size(_4055) > _4054);
  int _8597;
  bool _8598 = _4059;
  if (_8598)
  {
    _8597 = _4050->alloci64(_4054);
  }
  else
  {
    _8597 = (int)0;
  }
  int _4060 = _8597;
  int _4061 = _4050->allocf64(_4053);
  int _4062 = _4050->allocf64(_4054);
  if (_4059)
  {
    {
      x->inst(_4060,mosek::fusion::p_WorkStack::_get_impl(_4050)->i64,_4058,mosek::fusion::p_WorkStack::_get_impl(_4050)->i64);
    }
  }
  else
  {
    {
      x->inst(_4058,mosek::fusion::p_WorkStack::_get_impl(_4050)->i64);
    }
  }
  int _8599;
  bool _8600 = _4059;
  if (_8600)
  {
    _8599 = (int)1;
  }
  else
  {
    _8599 = (int)0;
  }
  _4050->pushi32(_8599);
  _4050->pushi32(_4054);
  _4050->pushi32(_4053);
  int _8601 = (int)0;
  int _8602 = _4056;
  for (int _4063 = _8601; _4063 < _8602; ++_4063)
  {
    {
      _4050->pushi32(_ptr__4055[_4063]);
    }
  }
  _4050->pushi32(_4056);
  std::shared_ptr< monty::ndarray< int,1 > > _4064 = mosek::fusion::p_WorkStack::_get_impl(_4050)->i32;
  _checked_ptr_1<int> _ptr__4064(_4064 ? _4064->raw() : nullptr,_4064 ? _4064->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4065 = mosek::fusion::p_WorkStack::_get_impl(_4050)->i64;
  _checked_ptr_1<long long> _ptr__4065(_4065 ? _4065->raw() : nullptr,_4065 ? _4065->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4066 = mosek::fusion::p_WorkStack::_get_impl(_4050)->f64;
  _checked_ptr_1<double> _ptr__4066(_4066 ? _4066->raw() : nullptr,_4066 ? _4066->size(0) : 0);
  {
    int _8603 = (int)0;
    int _8604 = safe_add( _4054,(int)1 );
    for (int _4067 = _8603; _4067 < _8604; ++_4067)
    {
      {
        _ptr__4064[safe_add( _4057,_4067 )] = _4067;
      }
    }
    int _8605 = (int)0;
    int _8606 = _4053;
    for (int _4068 = _8605; _4068 < _8606; ++_4068)
    {
      {
        _ptr__4066[safe_add( _4061,_4068 )] = 1.0;
      }
    }
    int _8607 = (int)0;
    int _8608 = _4054;
    for (int _4069 = _8607; _4069 < _8608; ++_4069)
    {
      {
        _ptr__4066[safe_add( _4062,_4069 )] = 0.0;
      }
    }
  }
}
std::string mosek::fusion::ExprMulVarScalarConst :: toString() { return mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVarScalarConst::toString(){
  return std::string ("ExprMulVarScalarConst()");
}
void mosek::fusion::p_ExprMulVarScalarConst::destroy(){x.reset();}void mosek::fusion::ExprMulVarScalarConst::destroy() { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprAdd::ExprAdd(mosek::fusion::p_ExprAdd *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprAdd()" << this << std::endl; */ }mosek::fusion::ExprAdd::~ExprAdd() {  /* std::cout << "~ExprAdd()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprAdd::p_ExprAdd  (::mosek::fusion::ExprAdd * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprAdd::t mosek::fusion::p_ExprAdd::_new_ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4070,    monty::rc_ptr< ::mosek::fusion::Expression > _4071,    double _4072,    double _4073){ return new mosek::fusion::ExprAdd(_4070,_4071,_4072,_4073); }mosek::fusion::ExprAdd::ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4070,    monty::rc_ptr< ::mosek::fusion::Expression > _4071,    double _4072,    double _4073) :    ExprAdd(new mosek::fusion::p_ExprAdd(this)){ mosek::fusion::p_ExprAdd::_get_impl(this)->_initialize(_4070,_4071,_4072,_4073); }void mosek::fusion::p_ExprAdd::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4070,    monty::rc_ptr< ::mosek::fusion::Expression > _4071,    double _4072,    double _4073){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4070->getShape());
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e1 = _4070;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e2 = _4071;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1 = _4072;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2 = _4073;
    if ((_4070->getND() != _4071->getND()))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
      }
    }
    {}
    int _8609 = (int)0;
    int _8610 = _4070->getND();
    for (int _4074 = _8609; _4074 < _8610; ++_4074)
    {
      {
        if ((_4070->getDim(_4074) != _4071->getDim(_4074)))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
          }
        }
        {}
      }
    }
  }
}void mosek::fusion::ExprAdd :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4075,monty::rc_ptr< ::mosek::fusion::WorkStack > _4076,monty::rc_ptr< ::mosek::fusion::WorkStack > _4077) { mosek::fusion::p_ExprAdd::_get_impl(this)->eval(_4075,_4076,_4077); }void mosek::fusion::p_ExprAdd::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4075,monty::rc_ptr< ::mosek::fusion::WorkStack > _4076,monty::rc_ptr< ::mosek::fusion::WorkStack > _4077){
  e1->eval(_4076,_4075,_4077);
  e2->eval(_4076,_4075,_4077);
  _4076->pop_expr();
  int _4078 = mosek::fusion::p_WorkStack::_get_impl(_4076)->nd;
  int _4079 = mosek::fusion::p_WorkStack::_get_impl(_4076)->shape_base;
  int _4080 = mosek::fusion::p_WorkStack::_get_impl(_4076)->nelem;
  int _4081 = mosek::fusion::p_WorkStack::_get_impl(_4076)->nnz;
  bool _4082 = mosek::fusion::p_WorkStack::_get_impl(_4076)->hassp;
  int _4083 = mosek::fusion::p_WorkStack::_get_impl(_4076)->ptr_base;
  int _4084 = mosek::fusion::p_WorkStack::_get_impl(_4076)->sp_base;
  int _4085 = mosek::fusion::p_WorkStack::_get_impl(_4076)->nidxs_base;
  int _4086 = mosek::fusion::p_WorkStack::_get_impl(_4076)->bfix_base;
  int _4087 = mosek::fusion::p_WorkStack::_get_impl(_4076)->cof_base;
  _4076->pop_expr();
  int _4088 = mosek::fusion::p_WorkStack::_get_impl(_4076)->nd;
  int _4089 = mosek::fusion::p_WorkStack::_get_impl(_4076)->shape_base;
  int _4090 = mosek::fusion::p_WorkStack::_get_impl(_4076)->nelem;
  int _4091 = mosek::fusion::p_WorkStack::_get_impl(_4076)->nnz;
  bool _4092 = mosek::fusion::p_WorkStack::_get_impl(_4076)->hassp;
  int _4093 = mosek::fusion::p_WorkStack::_get_impl(_4076)->ptr_base;
  int _4094 = mosek::fusion::p_WorkStack::_get_impl(_4076)->sp_base;
  int _4095 = mosek::fusion::p_WorkStack::_get_impl(_4076)->nidxs_base;
  int _4096 = mosek::fusion::p_WorkStack::_get_impl(_4076)->bfix_base;
  int _4097 = mosek::fusion::p_WorkStack::_get_impl(_4076)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4098 = mosek::fusion::p_WorkStack::_get_impl(_4076)->i32;
  _checked_ptr_1<int> _ptr__4098(_4098 ? _4098->raw() : nullptr,_4098 ? _4098->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4099 = mosek::fusion::p_WorkStack::_get_impl(_4076)->i64;
  _checked_ptr_1<long long> _ptr__4099(_4099 ? _4099->raw() : nullptr,_4099 ? _4099->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4100 = mosek::fusion::p_WorkStack::_get_impl(_4076)->f64;
  _checked_ptr_1<double> _ptr__4100(_4100 ? _4100->raw() : nullptr,_4100 ? _4100->size(0) : 0);
  if ((_4088 != _4078))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
  {}
  int _8611 = (int)0;
  int _8612 = _4088;
  for (int _4101 = _8611; _4101 < _8612; ++_4101)
  {
    {
      if ((_ptr__4098[safe_add( _4089,_4101 )] != _ptr__4098[safe_add( _4079,_4101 )]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      {}
    }
  }
  if (((!_4092) && (!_4082)))
  {
    {
      int _4102 = _4090;
      int _4103 = safe_add( _4091,_4081 );
      int _4104 = _4088;
      _4075->alloc_expr(_4104,_4102,_4103,false);
      int _4105 = mosek::fusion::p_WorkStack::_get_impl(_4075)->shape_base;
      int _4106 = mosek::fusion::p_WorkStack::_get_impl(_4075)->ptr_base;
      int _4107 = mosek::fusion::p_WorkStack::_get_impl(_4075)->sp_base;
      int _4108 = mosek::fusion::p_WorkStack::_get_impl(_4075)->nidxs_base;
      int _4109 = mosek::fusion::p_WorkStack::_get_impl(_4075)->bfix_base;
      int _4110 = mosek::fusion::p_WorkStack::_get_impl(_4075)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4111 = mosek::fusion::p_WorkStack::_get_impl(_4075)->i32;
      _checked_ptr_1<int> _ptr__4111(_4111 ? _4111->raw() : nullptr,_4111 ? _4111->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4112 = mosek::fusion::p_WorkStack::_get_impl(_4075)->i64;
      _checked_ptr_1<long long> _ptr__4112(_4112 ? _4112->raw() : nullptr,_4112 ? _4112->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4113 = mosek::fusion::p_WorkStack::_get_impl(_4075)->f64;
      _checked_ptr_1<double> _ptr__4113(_4113 ? _4113->raw() : nullptr,_4113 ? _4113->size(0) : 0);
      int _8613 = (int)0;
      int _8614 = _4104;
      for (int _4114 = _8613; _4114 < _8614; ++_4114)
      {
        {
          _ptr__4111[safe_add( _4105,_4114 )] = _ptr__4098[safe_add( _4089,_4114 )];
        }
      }
      int _4115 = (int)0;
      _ptr__4111[_4106] = (int)0;
      int _8615 = (int)0;
      int _8616 = _4102;
      for (int _4116 = _8615; _4116 < _8616; ++_4116)
      {
        {
          int _8617 = _ptr__4098[safe_add( _4093,_4116 )];
          int _8618 = _ptr__4098[safe_add( safe_add( _4093,_4116 ),(int)1 )];
          for (int _4117 = _8617; _4117 < _8618; ++_4117)
          {
            {
              _ptr__4112[safe_add( _4108,_4115 )] = _ptr__4099[safe_add( _4095,_4117 )];
              _ptr__4113[safe_add( _4110,_4115 )] = (_ptr__4100[safe_add( _4097,_4117 )] * m1);
              ++ _4115;
            }
          }
          int _8619 = _ptr__4098[safe_add( _4083,_4116 )];
          int _8620 = _ptr__4098[safe_add( safe_add( _4083,_4116 ),(int)1 )];
          for (int _4118 = _8619; _4118 < _8620; ++_4118)
          {
            {
              _ptr__4112[safe_add( _4108,_4115 )] = _ptr__4099[safe_add( _4085,_4118 )];
              _ptr__4113[safe_add( _4110,_4115 )] = (_ptr__4100[safe_add( _4087,_4118 )] * m2);
              ++ _4115;
            }
          }
          _ptr__4111[safe_add( safe_add( _4106,_4116 ),(int)1 )] = _4115;
          _ptr__4113[safe_add( _4109,_4116 )] = ((_ptr__4100[safe_add( _4096,_4116 )] * m1) + (_ptr__4100[safe_add( _4086,_4116 )] * m2));
        }
      }
    }
  }
  else if(((!_4092) || (!_4082)))
  {
    {
      if ((!_4082))
      {
        {
          int _4119 = _4080;
          int _4120 = _4081;
          int _4121 = _4083;
          int _4122 = _4084;
          int _4123 = _4085;
          int _4124 = _4086;
          int _4125 = _4087;
          _4080 = _4090;
          _4081 = _4091;
          _4083 = _4093;
          _4084 = _4094;
          _4085 = _4095;
          _4086 = _4096;
          _4087 = _4097;
          _4090 = _4119;
          _4091 = _4120;
          _4093 = _4121;
          _4094 = _4122;
          _4095 = _4123;
          _4096 = _4124;
          _4097 = _4125;
        }
      }
      {}
      double _8621;
      bool _8622 = (!_4092);
      if (_8622)
      {
        _8621 = m1;
      }
      else
      {
        _8621 = m2;
      }
      double _4126 = _8621;
      double _8623;
      bool _8624 = (!_4092);
      if (_8624)
      {
        _8623 = m2;
      }
      else
      {
        _8623 = _4126;
      }
      double _4127 = _8623;
      int _4128 = _4090;
      int _4129 = safe_add( _4091,_4081 );
      int _4130 = _4088;
      _4075->alloc_expr(_4130,_4128,_4129,false);
      int _4131 = mosek::fusion::p_WorkStack::_get_impl(_4075)->shape_base;
      int _4132 = mosek::fusion::p_WorkStack::_get_impl(_4075)->ptr_base;
      int _4133 = mosek::fusion::p_WorkStack::_get_impl(_4075)->sp_base;
      int _4134 = mosek::fusion::p_WorkStack::_get_impl(_4075)->nidxs_base;
      int _4135 = mosek::fusion::p_WorkStack::_get_impl(_4075)->bfix_base;
      int _4136 = mosek::fusion::p_WorkStack::_get_impl(_4075)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4137 = mosek::fusion::p_WorkStack::_get_impl(_4075)->i32;
      _checked_ptr_1<int> _ptr__4137(_4137 ? _4137->raw() : nullptr,_4137 ? _4137->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4138 = mosek::fusion::p_WorkStack::_get_impl(_4075)->i64;
      _checked_ptr_1<long long> _ptr__4138(_4138 ? _4138->raw() : nullptr,_4138 ? _4138->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4139 = mosek::fusion::p_WorkStack::_get_impl(_4075)->f64;
      _checked_ptr_1<double> _ptr__4139(_4139 ? _4139->raw() : nullptr,_4139 ? _4139->size(0) : 0);
      {
        int _4140 = (int)0;
        int _8625 = (int)0;
        int _8626 = _4130;
        for (int _4141 = _8625; _4141 < _8626; ++_4141)
        {
          {
            _ptr__4137[safe_add( _4131,_4141 )] = _ptr__4098[safe_add( _4089,_4141 )];
          }
        }
        int _8627 = (int)0;
        int _8628 = safe_add( _4128,(int)1 );
        for (int _4142 = _8627; _4142 < _8628; ++_4142)
        {
          {
            _ptr__4137[safe_add( _4132,_4142 )] = (int)0;
          }
        }
        int _8629 = (int)0;
        int _8630 = _4090;
        for (int _4143 = _8629; _4143 < _8630; ++_4143)
        {
          {
            _ptr__4137[safe_add( safe_add( _4132,_4143 ),(int)1 )] += (_ptr__4098[safe_add( safe_add( _4093,_4143 ),(int)1 )] - _ptr__4098[safe_add( _4093,_4143 )]);
          }
        }
        int _8631 = (int)0;
        int _8632 = _4080;
        for (int _4144 = _8631; _4144 < _8632; ++_4144)
        {
          {
            long long _4145 = _ptr__4099[safe_add( _4084,_4144 )];
            _ptr__4137[safe_add( safe_add( _4132,_4145 ),(int)1 )] += (_ptr__4098[safe_add( safe_add( _4083,_4144 ),(int)1 )] - _ptr__4098[safe_add( _4083,_4144 )]);
          }
        }
        int _8633 = (int)0;
        int _8634 = _4128;
        for (int _4146 = _8633; _4146 < _8634; ++_4146)
        {
          {
            _ptr__4137[safe_add( safe_add( _4132,_4146 ),(int)1 )] += _ptr__4137[safe_add( _4132,_4146 )];
          }
        }
        int _8635 = (int)0;
        int _8636 = _4090;
        for (int _4147 = _8635; _4147 < _8636; ++_4147)
        {
          {
            int _4148 = _ptr__4137[safe_add( _4132,_4147 )];
            int _4149 = _ptr__4098[safe_add( _4093,_4147 )];
            int _4150 = (_ptr__4098[safe_add( safe_add( _4093,_4147 ),(int)1 )] - _ptr__4098[safe_add( _4093,_4147 )]);
            int _8637 = (int)0;
            int _8638 = _4150;
            for (int _4151 = _8637; _4151 < _8638; ++_4151)
            {
              {
                _ptr__4138[safe_add( safe_add( _4134,_4148 ),_4151 )] = _ptr__4099[safe_add( safe_add( _4095,_4149 ),_4151 )];
                _ptr__4139[safe_add( safe_add( _4136,_4148 ),_4151 )] = (_ptr__4100[safe_add( safe_add( _4097,_4149 ),_4151 )] * _4126);
              }
            }
            _ptr__4137[safe_add( _4132,_4147 )] += _4150;
            _ptr__4139[safe_add( _4135,_4147 )] = (_ptr__4100[safe_add( _4096,_4147 )] * _4126);
          }
        }
        int _8639 = (int)0;
        int _8640 = _4080;
        for (int _4152 = _8639; _4152 < _8640; ++_4152)
        {
          {
            long long _4153 = _ptr__4099[safe_add( _4084,_4152 )];
            int _4154 = _ptr__4137[safe_add( _4132,_4153 )];
            int _4155 = _ptr__4098[safe_add( _4083,_4152 )];
            int _4156 = (_ptr__4098[safe_add( safe_add( _4083,_4152 ),(int)1 )] - _ptr__4098[safe_add( _4083,_4152 )]);
            int _8641 = (int)0;
            int _8642 = _4156;
            for (int _4157 = _8641; _4157 < _8642; ++_4157)
            {
              {
                _ptr__4138[safe_add( safe_add( _4134,_4154 ),_4157 )] = _ptr__4099[safe_add( safe_add( _4085,_4155 ),_4157 )];
                _ptr__4139[safe_add( safe_add( _4136,_4154 ),_4157 )] = (_ptr__4100[safe_add( safe_add( _4087,_4155 ),_4157 )] * _4127);
              }
            }
            _ptr__4137[safe_add( _4132,_4153 )] += _4156;
            _ptr__4139[safe_add( _4135,_4153 )] += (_ptr__4100[safe_add( _4086,_4152 )] * _4127);
          }
        }
        int _8643 = (int)0;
        int _8644 = _4128;
        for (int _4158 = _8643; _4158 < _8644; ++_4158)
        {
          {
            _ptr__4137[(safe_add( _4132,_4128 ) - _4158)] = _ptr__4137[((safe_add( _4132,_4128 ) - _4158) - (int)1)];
          }
        }
        _ptr__4137[_4132] = (int)0;
      }
    }
  }
  else
  {
    {
      int _4159 = safe_add( _4091,_4081 );
      int _4160 = (int)0;
      int _4161 = _4088;
      long long _4162 = (long long)1;
      int _8645 = (int)0;
      int _8646 = _4161;
      for (int _4163 = _8645; _4163 < _8646; ++_4163)
      {
        {
          _4162 *= _ptr__4098[safe_add( _4089,_4163 )];
        }
      }
      {
        int _4164 = (int)0;
        int _4165 = (int)0;
        while ( ((_4165 < _4090) && (_4164 < _4080)) )
        {
          {
            if ((_ptr__4099[safe_add( _4094,_4165 )] < _ptr__4099[safe_add( _4084,_4164 )]))
            {
              {
                ++ _4160;
                ++ _4165;
              }
            }
            else if((_ptr__4099[safe_add( _4094,_4165 )] > _ptr__4099[safe_add( _4084,_4164 )]))
            {
              {
                ++ _4160;
                ++ _4164;
              }
            }
            else
            {
              {
                ++ _4160;
                ++ _4165;
                ++ _4164;
              }
            }
          }
        }
        _4160 += (safe_add( (_4090 - _4165),_4080 ) - _4164);
      }
      bool _4166 = (_4160 < _4162);
      _4075->alloc_expr(_4161,_4160,_4159,_4166);
      int _4167 = mosek::fusion::p_WorkStack::_get_impl(_4075)->shape_base;
      int _4168 = mosek::fusion::p_WorkStack::_get_impl(_4075)->ptr_base;
      int _8647;
      bool _8648 = _4166;
      if (_8648)
      {
        _8647 = mosek::fusion::p_WorkStack::_get_impl(_4075)->sp_base;
      }
      else
      {
        _8647 = _4075->alloci64(_4160);
      }
      int _4169 = _8647;
      int _4170 = mosek::fusion::p_WorkStack::_get_impl(_4075)->nidxs_base;
      int _4171 = mosek::fusion::p_WorkStack::_get_impl(_4075)->bfix_base;
      int _4172 = mosek::fusion::p_WorkStack::_get_impl(_4075)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4173 = mosek::fusion::p_WorkStack::_get_impl(_4075)->i32;
      _checked_ptr_1<int> _ptr__4173(_4173 ? _4173->raw() : nullptr,_4173 ? _4173->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4174 = mosek::fusion::p_WorkStack::_get_impl(_4075)->i64;
      _checked_ptr_1<long long> _ptr__4174(_4174 ? _4174->raw() : nullptr,_4174 ? _4174->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4175 = mosek::fusion::p_WorkStack::_get_impl(_4075)->f64;
      _checked_ptr_1<double> _ptr__4175(_4175 ? _4175->raw() : nullptr,_4175 ? _4175->size(0) : 0);
      int _8649 = (int)0;
      int _8650 = _4161;
      for (int _4176 = _8649; _4176 < _8650; ++_4176)
      {
        {
          _ptr__4173[safe_add( _4167,_4176 )] = _ptr__4098[safe_add( _4089,_4176 )];
        }
      }
      {
        _ptr__4173[_4168] = (int)0;
        int _4177 = (int)0;
        int _4178 = (int)0;
        int _4179 = (int)0;
        int _4180 = (int)0;
        while ( ((_4180 < _4090) && (_4179 < _4080)) )
        {
          {
            if ((_ptr__4099[safe_add( _4094,_4180 )] < _ptr__4099[safe_add( _4084,_4179 )]))
            {
              {
                int _8651 = _ptr__4098[safe_add( _4093,_4180 )];
                int _8652 = _ptr__4098[safe_add( safe_add( _4093,_4180 ),(int)1 )];
                for (int _4181 = _8651; _4181 < _8652; ++_4181)
                {
                  {
                    _ptr__4174[safe_add( _4170,_4178 )] = _ptr__4099[safe_add( _4095,_4181 )];
                    _ptr__4175[safe_add( _4172,_4178 )] = (m1 * _ptr__4100[safe_add( _4097,_4181 )]);
                    ++ _4178;
                  }
                }
                _ptr__4175[safe_add( _4171,_4177 )] = (m1 * _ptr__4100[safe_add( _4096,_4180 )]);
                _ptr__4174[safe_add( _4169,_4177 )] = _ptr__4099[safe_add( _4094,_4180 )];
                _ptr__4173[safe_add( safe_add( _4168,_4177 ),(int)1 )] = _4178;
                ++ _4177;
                ++ _4180;
              }
            }
            else if((_ptr__4099[safe_add( _4084,_4179 )] < _ptr__4099[safe_add( _4094,_4180 )]))
            {
              {
                int _8653 = _ptr__4098[safe_add( _4083,_4179 )];
                int _8654 = _ptr__4098[safe_add( safe_add( _4083,_4179 ),(int)1 )];
                for (int _4182 = _8653; _4182 < _8654; ++_4182)
                {
                  {
                    _ptr__4174[safe_add( _4170,_4178 )] = _ptr__4099[safe_add( _4085,_4182 )];
                    _ptr__4175[safe_add( _4172,_4178 )] = (m2 * _ptr__4100[safe_add( _4087,_4182 )]);
                    ++ _4178;
                  }
                }
                _ptr__4175[safe_add( _4171,_4177 )] = (m1 * _ptr__4100[safe_add( _4086,_4180 )]);
                _ptr__4174[safe_add( _4169,_4177 )] = _ptr__4099[safe_add( _4084,_4179 )];
                _ptr__4173[safe_add( safe_add( _4168,_4177 ),(int)1 )] = _4178;
                ++ _4177;
                ++ _4179;
              }
            }
            else
            {
              {
                int _8655 = _ptr__4098[safe_add( _4093,_4180 )];
                int _8656 = _ptr__4098[safe_add( safe_add( _4093,_4180 ),(int)1 )];
                for (int _4183 = _8655; _4183 < _8656; ++_4183)
                {
                  {
                    _ptr__4174[safe_add( _4170,_4178 )] = _ptr__4099[safe_add( _4095,_4183 )];
                    _ptr__4175[safe_add( _4172,_4178 )] = (m1 * _ptr__4100[safe_add( _4097,_4183 )]);
                    ++ _4178;
                  }
                }
                int _8657 = _ptr__4098[safe_add( _4083,_4179 )];
                int _8658 = _ptr__4098[safe_add( safe_add( _4083,_4179 ),(int)1 )];
                for (int _4184 = _8657; _4184 < _8658; ++_4184)
                {
                  {
                    _ptr__4174[safe_add( _4170,_4178 )] = _ptr__4099[safe_add( _4085,_4184 )];
                    _ptr__4175[safe_add( _4172,_4178 )] = (m2 * _ptr__4100[safe_add( _4087,_4184 )]);
                    ++ _4178;
                  }
                }
                _ptr__4175[safe_add( _4171,_4177 )] = ((m1 * _ptr__4100[safe_add( _4096,_4180 )]) + (m2 * _ptr__4100[safe_add( _4086,_4179 )]));
                _ptr__4174[safe_add( _4169,_4177 )] = _ptr__4099[safe_add( _4094,_4180 )];
                _ptr__4173[safe_add( safe_add( _4168,_4177 ),(int)1 )] = _4178;
                ++ _4177;
                ++ _4180;
                ++ _4179;
              }
            }
          }
        }
        while ( (_4180 < _4090) )
        {
          {
            int _8659 = _ptr__4098[safe_add( _4093,_4180 )];
            int _8660 = _ptr__4098[safe_add( safe_add( _4093,_4180 ),(int)1 )];
            for (int _4185 = _8659; _4185 < _8660; ++_4185)
            {
              {
                _ptr__4174[safe_add( _4170,_4178 )] = _ptr__4099[safe_add( _4095,_4185 )];
                _ptr__4175[safe_add( _4172,_4178 )] = (m1 * _ptr__4100[safe_add( _4097,_4185 )]);
                ++ _4178;
              }
            }
            _ptr__4175[safe_add( _4171,_4177 )] = (m1 * _ptr__4100[safe_add( _4096,_4180 )]);
            _ptr__4174[safe_add( _4169,_4177 )] = _ptr__4099[safe_add( _4094,_4180 )];
            _ptr__4173[safe_add( safe_add( _4168,_4177 ),(int)1 )] = _4178;
            ++ _4177;
            ++ _4180;
          }
        }
        while ( (_4179 < _4080) )
        {
          {
            int _8661 = _ptr__4098[safe_add( _4083,_4179 )];
            int _8662 = _ptr__4098[safe_add( safe_add( _4083,_4179 ),(int)1 )];
            for (int _4186 = _8661; _4186 < _8662; ++_4186)
            {
              {
                _ptr__4174[safe_add( _4170,_4178 )] = _ptr__4099[safe_add( _4085,_4186 )];
                _ptr__4175[safe_add( _4172,_4178 )] = (m2 * _ptr__4100[safe_add( _4087,_4186 )]);
                ++ _4178;
              }
            }
            _ptr__4175[safe_add( _4171,_4177 )] = (m1 * _ptr__4100[safe_add( _4086,_4179 )]);
            _ptr__4174[safe_add( _4169,_4177 )] = _ptr__4099[safe_add( _4084,_4179 )];
            _ptr__4173[safe_add( safe_add( _4168,_4177 ),(int)1 )] = _4178;
            ++ _4177;
            ++ _4179;
          }
        }
      }
      if ((!_4166))
      {
        {
          _4075->popi64(_4160);
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprAdd :: toString() { return mosek::fusion::p_ExprAdd::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprAdd::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprAdd("))->__mosek_2fusion_2Utils_2StringBuffer__a(e1->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e2->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprAdd::destroy(){e2.reset();e1.reset();}void mosek::fusion::ExprAdd::destroy() { mosek::fusion::p_ExprAdd::_get_impl(this)->destroy(); }mosek::fusion::ExprWSum::ExprWSum(mosek::fusion::p_ExprWSum *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprWSum()" << this << std::endl; */ }mosek::fusion::ExprWSum::~ExprWSum() {  /* std::cout << "~ExprWSum()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprWSum::p_ExprWSum  (::mosek::fusion::ExprWSum * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprWSum::t mosek::fusion::p_ExprWSum::_new_ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4187,    std::shared_ptr< monty::ndarray< double,1 > > _4188){ return new mosek::fusion::ExprWSum(_4187,_4188); }mosek::fusion::ExprWSum::ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4187,    std::shared_ptr< monty::ndarray< double,1 > > _4188) :    ExprWSum(new mosek::fusion::p_ExprWSum(this)){ mosek::fusion::p_ExprWSum::_get_impl(this)->_initialize(_4187,_4188); }void mosek::fusion::p_ExprWSum::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4187,    std::shared_ptr< monty::ndarray< double,1 > > _4188){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__4188(_4188 ? _4188->raw() : nullptr, _4188 ? _4188->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(((*_4187)((int)0))->getShape());
    if (((int)((_4188)->size(0)) != (int)((_4187)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching weights and expressions array lengths"));
      }
    }
    {}
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->w = ::mosek::fusion::Utils::Tools::arraycopy(_4188);
    std::shared_ptr< monty::ndarray< int,1 > > _4189 = ((*_4187)((int)0))->getShape();
    _checked_ptr_1<int> _ptr__4189(_4189 ? _4189->raw() : nullptr,_4189 ? _4189->size(0) : 0);
    int _4190 = (int)((_4189)->size(0));
    int _8663 = (int)1;
    int _8664 = (int)((_4187)->size(0));
    for (int _4191 = _8663; _4191 < _8664; ++_4191)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4192 = ((*_4187)(_4191))->getShape();
        _checked_ptr_1<int> _ptr__4192(_4192 ? _4192->raw() : nullptr,_4192 ? _4192->size(0) : 0);
        if ((_4190 != (int)((_4192)->size(0))))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
          }
        }
        else
        {
          {
            int _8665 = (int)0;
            int _8666 = _4190;
            for (int _4193 = _8665; _4193 < _8666; ++_4193)
            {
              {
                if ((_ptr__4189[_4193] != _ptr__4192[_4193]))
                {
                  {
                    throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8667;
    for (int _4194 = (int)0, _8668 = (int)((_4187)->size(0)); _4194 < _8668 ; ++_4194)
    {
      _8667.push_back(((*_4187)(_4194)));
    }
    auto _8669 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8667.size()),_8667.begin(),_8667.end()));
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->es = _8669;
  }
}void mosek::fusion::ExprWSum :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4195,monty::rc_ptr< ::mosek::fusion::WorkStack > _4196,monty::rc_ptr< ::mosek::fusion::WorkStack > _4197) { mosek::fusion::p_ExprWSum::_get_impl(this)->eval(_4195,_4196,_4197); }void mosek::fusion::p_ExprWSum::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4195,monty::rc_ptr< ::mosek::fusion::WorkStack > _4196,monty::rc_ptr< ::mosek::fusion::WorkStack > _4197){
  int _4198 = (int)((es)->size(0));
  int _8670 = (int)0;
  int _8671 = _4198;
  for (int _4199 = _8670; _4199 < _8671; ++_4199)
  {
    {
      ((*es)(_4199))->eval(_4196,_4195,_4197);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4200 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4198)));
  _checked_ptr_1<int> _ptr__4200(_4200 ? _4200->raw() : nullptr,_4200 ? _4200->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4201 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4198)));
  _checked_ptr_1<int> _ptr__4201(_4201 ? _4201->raw() : nullptr,_4201 ? _4201->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4202 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4198)));
  _checked_ptr_1<int> _ptr__4202(_4202 ? _4202->raw() : nullptr,_4202 ? _4202->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4203 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4198)));
  _checked_ptr_1<int> _ptr__4203(_4203 ? _4203->raw() : nullptr,_4203 ? _4203->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4204 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4198)));
  _checked_ptr_1<int> _ptr__4204(_4204 ? _4204->raw() : nullptr,_4204 ? _4204->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4205 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4198)));
  _checked_ptr_1<int> _ptr__4205(_4205 ? _4205->raw() : nullptr,_4205 ? _4205->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4206 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4198)));
  _checked_ptr_1<int> _ptr__4206(_4206 ? _4206->raw() : nullptr,_4206 ? _4206->size(0) : 0);
  int _4207 = _4196->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4208 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4207)));
  _checked_ptr_1<int> _ptr__4208(_4208 ? _4208->raw() : nullptr,_4208 ? _4208->size(0) : 0);
  _4196->popi32(_4207,_4208,(int)0);
  {
    _ptr__4200[(_4198 - (int)1)] = _4196->popi32();
    _ptr__4201[(_4198 - (int)1)] = _4196->popi32();
    bool _4209 = (_4196->popi32() != (int)0);
    _ptr__4202[(_4198 - (int)1)] = _4196->popi32(safe_add( _ptr__4200[(_4198 - (int)1)],(int)1 ));
    int _8672;
    bool _8673 = _4209;
    if (_8673)
    {
      _8672 = _4196->popi64(_ptr__4200[(_4198 - (int)1)]);
    }
    else
    {
      _8672 = (-(int)1);
    }
    _ptr__4204[(_4198 - (int)1)] = _8672;
    _ptr__4203[(_4198 - (int)1)] = _4196->popi64(_ptr__4201[(_4198 - (int)1)]);
    _ptr__4206[(_4198 - (int)1)] = _4196->popf64(_ptr__4200[(_4198 - (int)1)]);
    _ptr__4205[(_4198 - (int)1)] = _4196->popf64(_ptr__4201[(_4198 - (int)1)]);
  }
  int _8674 = (int)1;
  int _8675 = _4198;
  for (int _4210 = _8674; _4210 < _8675; ++_4210)
  {
    {
      int _4211 = ((_4198 - _4210) - (int)1);
      _4196->popi32();
      _4196->popi32(_4207);
      _ptr__4200[_4211] = _4196->popi32();
      _ptr__4201[_4211] = _4196->popi32();
      bool _4212 = (_4196->popi32() != (int)0);
      _ptr__4202[_4211] = _4196->popi32(safe_add( _ptr__4200[_4211],(int)1 ));
      int _8676;
      bool _8677 = _4212;
      if (_8677)
      {
        _8676 = _4196->popi64(_ptr__4200[_4211]);
      }
      else
      {
        _8676 = (-(int)1);
      }
      _ptr__4204[_4211] = _8676;
      _ptr__4203[_4211] = _4196->popi64(_ptr__4201[_4211]);
      _ptr__4206[_4211] = _4196->popf64(_ptr__4200[_4211]);
      _ptr__4205[_4211] = _4196->popf64(_ptr__4201[_4211]);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4213 = mosek::fusion::p_WorkStack::_get_impl(_4196)->i32;
  _checked_ptr_1<int> _ptr__4213(_4213 ? _4213->raw() : nullptr,_4213 ? _4213->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4214 = mosek::fusion::p_WorkStack::_get_impl(_4196)->i64;
  _checked_ptr_1<long long> _ptr__4214(_4214 ? _4214->raw() : nullptr,_4214 ? _4214->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4215 = mosek::fusion::p_WorkStack::_get_impl(_4196)->f64;
  _checked_ptr_1<double> _ptr__4215(_4215 ? _4215->raw() : nullptr,_4215 ? _4215->size(0) : 0);
  bool _4216 = false;
  int _8678 = (int)0;
  int _8679 = _4198;
  for (int _4217 = _8678; _4217 < _8679; ++_4217)
  {
    {
      if ((_ptr__4204[_4217] < (int)0))
      {
        {
          _4216 = true;
        }
      }
      {}
    }
  }
  int _4218 = (int)0;
  int _4219 = (int)0;
  if (_4216)
  {
    {
      _4218 = (int)::mosek::fusion::p_Set::size(_4208);
      int _8680 = (int)0;
      int _8681 = _4198;
      for (int _4220 = _8680; _4220 < _8681; ++_4220)
      {
        {
          _4219 += _ptr__4201[_4220];
        }
      }
    }
  }
  else
  {
    {
      bool _4221 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4222 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4198)));
      _checked_ptr_1<int> _ptr__4222(_4222 ? _4222->raw() : nullptr,_4222 ? _4222->size(0) : 0);
      int _8682 = (int)0;
      int _8683 = _4198;
      for (int _4223 = _8682; _4223 < _8683; ++_4223)
      {
        {
          _4219 += _ptr__4201[_4223];
        }
      }
      while ( (!_4221) )
      {
        {
          long long _4224 = (-(int)1);
          int _8684 = (int)0;
          int _8685 = _4198;
          for (int _4225 = _8684; _4225 < _8685; ++_4225)
          {
            {
              if (((_ptr__4222[_4225] < _ptr__4200[_4225]) && ((_4224 < (int)0) || (_ptr__4214[safe_add( _ptr__4204[_4225],_ptr__4222[_4225] )] < _4224))))
              {
                {
                  _4224 = _ptr__4214[safe_add( _ptr__4204[_4225],_ptr__4222[_4225] )];
                }
              }
              {}
            }
          }
          if ((_4224 < (int)0))
          {
            {
              _4221 = true;
            }
          }
          else
          {
            {
              int _8686 = (int)0;
              int _8687 = _4198;
              for (int _4226 = _8686; _4226 < _8687; ++_4226)
              {
                {
                  if (((_ptr__4222[_4226] < _ptr__4200[_4226]) && (_4224 == _ptr__4214[safe_add( _ptr__4204[_4226],_ptr__4222[_4226] )])))
                  {
                    {
                      ++ _ptr__4222[_4226];
                    }
                  }
                  {}
                }
              }
              ++ _4218;
            }
          }
        }
      }
    }
  }
  int _4227 = _4195->alloci32(safe_add( _4218,(int)1 ));
  int _4228 = _4195->alloci64(_4219);
  int _8688;
  bool _8689 = (!_4216);
  if (_8689)
  {
    _8688 = _4195->alloci64(_4218);
  }
  else
  {
    _8688 = (-(int)1);
  }
  int _4229 = _8688;
  int _4230 = _4195->allocf64(_4219);
  int _4231 = _4195->allocf64(_4218);
  int _8690;
  bool _8691 = _4216;
  if (_8691)
  {
    _8690 = (int)0;
  }
  else
  {
    _8690 = (int)1;
  }
  _4195->pushi32(_8690);
  _4195->pushi32(_4219);
  _4195->pushi32(_4218);
  int _8692 = (int)0;
  int _8693 = _4207;
  for (int _4232 = _8692; _4232 < _8693; ++_4232)
  {
    {
      _4195->pushi32(_ptr__4208[_4232]);
    }
  }
  _4195->pushi32(_4207);
  std::shared_ptr< monty::ndarray< int,1 > > _4233 = mosek::fusion::p_WorkStack::_get_impl(_4195)->i32;
  _checked_ptr_1<int> _ptr__4233(_4233 ? _4233->raw() : nullptr,_4233 ? _4233->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4234 = mosek::fusion::p_WorkStack::_get_impl(_4195)->i64;
  _checked_ptr_1<long long> _ptr__4234(_4234 ? _4234->raw() : nullptr,_4234 ? _4234->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4235 = mosek::fusion::p_WorkStack::_get_impl(_4195)->f64;
  _checked_ptr_1<double> _ptr__4235(_4235 ? _4235->raw() : nullptr,_4235 ? _4235->size(0) : 0);
  _ptr__4233[_4227] = (int)0;
  int _8694 = (int)0;
  int _8695 = _4218;
  for (int _4236 = _8694; _4236 < _8695; ++_4236)
  {
    {
      _ptr__4235[safe_add( _4231,_4236 )] = 0.0;
    }
  }
  int _8696 = (int)0;
  int _8697 = safe_add( _4218,(int)1 );
  for (int _4237 = _8696; _4237 < _8697; ++_4237)
  {
    {
      _ptr__4233[safe_add( _4227,_4237 )] = (int)0;
    }
  }
  if (_4216)
  {
    {
      int _8698 = (int)0;
      int _8699 = _4198;
      for (int _4238 = _8698; _4238 < _8699; ++_4238)
      {
        {
          if ((_ptr__4204[_4238] >= (int)0))
          {
            {
              int _8700 = (int)0;
              int _8701 = _ptr__4200[_4238];
              for (int _4239 = _8700; _4239 < _8701; ++_4239)
              {
                {
                  _ptr__4233[safe_add( safe_add( _4227,_ptr__4214[safe_add( _ptr__4204[_4238],_4239 )] ),(int)1 )] += (_ptr__4213[safe_add( safe_add( _ptr__4202[_4238],_4239 ),(int)1 )] - _ptr__4213[safe_add( _ptr__4202[_4238],_4239 )]);
                }
              }
            }
          }
          else
          {
            {
              int _8702 = (int)0;
              int _8703 = _ptr__4200[_4238];
              for (int _4240 = _8702; _4240 < _8703; ++_4240)
              {
                {
                  _ptr__4233[safe_add( safe_add( _4227,_4240 ),(int)1 )] += (_ptr__4213[safe_add( safe_add( _ptr__4202[_4238],_4240 ),(int)1 )] - _ptr__4213[safe_add( _ptr__4202[_4238],_4240 )]);
                }
              }
            }
          }
        }
      }
      int _8704 = (int)0;
      int _8705 = _4218;
      for (int _4241 = _8704; _4241 < _8705; ++_4241)
      {
        {
          _ptr__4233[safe_add( safe_add( _4227,_4241 ),(int)1 )] += _ptr__4233[safe_add( _4227,_4241 )];
        }
      }
      int _8706 = (int)0;
      int _8707 = _4198;
      for (int _4242 = _8706; _4242 < _8707; ++_4242)
      {
        {
          if ((_ptr__4204[_4242] >= (int)0))
          {
            {
              int _8708 = (int)0;
              int _8709 = _ptr__4200[_4242];
              for (int _4243 = _8708; _4243 < _8709; ++_4243)
              {
                {
                  int _4244 = _ptr__4213[safe_add( _ptr__4202[_4242],_4243 )];
                  int _4245 = _ptr__4213[safe_add( safe_add( _ptr__4202[_4242],_4243 ),(int)1 )];
                  long long _4246 = _ptr__4214[safe_add( _ptr__4204[_4242],_4243 )];
                  int _4247 = _ptr__4233[safe_add( _4227,_4246 )];
                  int _8710 = _4244;
                  int _8711 = _4245;
                  for (int _4248 = _8710; _4248 < _8711; ++_4248)
                  {
                    {
                      _ptr__4234[safe_add( _4228,_4247 )] = _ptr__4214[safe_add( _ptr__4203[_4242],_4248 )];
                      _ptr__4235[safe_add( _4230,_4247 )] = (((*w)(_4242)) * _ptr__4215[safe_add( _ptr__4205[_4242],_4248 )]);
                      ++ _4247;
                    }
                  }
                  _ptr__4235[safe_add( _4231,_4246 )] += (((*w)(_4242)) * _ptr__4215[safe_add( _ptr__4206[_4242],_4243 )]);
                  _ptr__4233[safe_add( _4227,_4246 )] += (_4245 - _4244);
                }
              }
            }
          }
          else
          {
            {
              int _8712 = (int)0;
              int _8713 = _ptr__4200[_4242];
              for (int _4249 = _8712; _4249 < _8713; ++_4249)
              {
                {
                  int _4250 = _ptr__4213[safe_add( _ptr__4202[_4242],_4249 )];
                  int _4251 = _ptr__4213[safe_add( safe_add( _ptr__4202[_4242],_4249 ),(int)1 )];
                  int _4252 = _4249;
                  int _4253 = _ptr__4233[safe_add( _4227,_4252 )];
                  int _8714 = _4250;
                  int _8715 = _4251;
                  for (int _4254 = _8714; _4254 < _8715; ++_4254)
                  {
                    {
                      _ptr__4234[safe_add( _4228,_4253 )] = _ptr__4214[safe_add( _ptr__4203[_4242],_4254 )];
                      _ptr__4235[safe_add( _4230,_4253 )] = (((*w)(_4242)) * _ptr__4215[safe_add( _ptr__4205[_4242],_4254 )]);
                      ++ _4253;
                    }
                  }
                  _ptr__4235[safe_add( _4231,_4252 )] += (((*w)(_4242)) * _ptr__4215[safe_add( _ptr__4206[_4242],_4249 )]);
                  _ptr__4233[safe_add( _4227,_4252 )] += (_4251 - _4250);
                }
              }
            }
          }
        }
      }
      int _8716 = (int)0;
      int _8717 = _4218;
      for (int _4255 = _8716; _4255 < _8717; ++_4255)
      {
        {
          _ptr__4233[(safe_add( _4227,_4218 ) - _4255)] = _ptr__4233[((safe_add( _4227,_4218 ) - _4255) - (int)1)];
        }
      }
      _ptr__4233[_4227] = (int)0;
    }
  }
  else
  {
    {
      bool _4256 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4257 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4198)));
      _checked_ptr_1<int> _ptr__4257(_4257 ? _4257->raw() : nullptr,_4257 ? _4257->size(0) : 0);
      int _4258 = (int)0;
      int _4259 = (int)0;
      while ( (!_4256) )
      {
        {
          long long _4260 = (-(int)1);
          int _8718 = (int)0;
          int _8719 = _4198;
          for (int _4261 = _8718; _4261 < _8719; ++_4261)
          {
            {
              if (((_ptr__4257[_4261] < _ptr__4200[_4261]) && ((_4260 < (int)0) || (_ptr__4214[safe_add( _ptr__4204[_4261],_ptr__4257[_4261] )] < _4260))))
              {
                {
                  _4260 = _ptr__4214[safe_add( _ptr__4204[_4261],_ptr__4257[_4261] )];
                }
              }
              {}
            }
          }
          if ((_4260 < (int)0))
          {
            {
              _4256 = true;
            }
          }
          else
          {
            {
              int _8720 = (int)0;
              int _8721 = _4198;
              for (int _4262 = _8720; _4262 < _8721; ++_4262)
              {
                {
                  if (((_ptr__4257[_4262] < _ptr__4200[_4262]) && (_4260 == _ptr__4214[safe_add( _ptr__4204[_4262],_ptr__4257[_4262] )])))
                  {
                    {
                      int _8722 = _ptr__4213[safe_add( _ptr__4202[_4262],_ptr__4257[_4262] )];
                      int _8723 = _ptr__4213[safe_add( safe_add( _ptr__4202[_4262],_ptr__4257[_4262] ),(int)1 )];
                      for (int _4263 = _8722; _4263 < _8723; ++_4263)
                      {
                        {
                          _ptr__4234[safe_add( _4228,_4259 )] = _ptr__4214[safe_add( _ptr__4203[_4262],_4263 )];
                          _ptr__4235[safe_add( _4230,_4259 )] = (((*w)(_4262)) * _ptr__4215[safe_add( _ptr__4205[_4262],_4263 )]);
                          ++ _4259;
                        }
                      }
                      _ptr__4235[safe_add( _4231,_4258 )] += (((*w)(_4262)) * _ptr__4215[safe_add( _ptr__4206[_4262],_ptr__4257[_4262] )]);
                      ++ _ptr__4257[_4262];
                    }
                  }
                  {}
                }
              }
              _ptr__4233[safe_add( safe_add( _4227,_4258 ),(int)1 )] = _4259;
              _ptr__4234[safe_add( _4229,_4258 )] = _4260;
            }
          }
          ++ _4258;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprWSum :: toString() { return mosek::fusion::p_ExprWSum::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprWSum::toString(){
  return std::string ("ExprWSum()");
}
void mosek::fusion::p_ExprWSum::destroy(){w.reset();es.reset();}void mosek::fusion::ExprWSum::destroy() { mosek::fusion::p_ExprWSum::_get_impl(this)->destroy(); }mosek::fusion::ExprSumReduce::ExprSumReduce(mosek::fusion::p_ExprSumReduce *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSumReduce()" << this << std::endl; */ }mosek::fusion::ExprSumReduce::~ExprSumReduce() {  /* std::cout << "~ExprSumReduce()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSumReduce::p_ExprSumReduce  (::mosek::fusion::ExprSumReduce * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSumReduce::t mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce  (int _4264,    monty::rc_ptr< ::mosek::fusion::Expression > _4265){ return new mosek::fusion::ExprSumReduce(_4264,_4265); }mosek::fusion::ExprSumReduce::ExprSumReduce  (int _4264,    monty::rc_ptr< ::mosek::fusion::Expression > _4265) :    ExprSumReduce(new mosek::fusion::p_ExprSumReduce(this)){ mosek::fusion::p_ExprSumReduce::_get_impl(this)->_initialize(_4264,_4265); }void mosek::fusion::p_ExprSumReduce::_initialize  (int _4264,    monty::rc_ptr< ::mosek::fusion::Expression > _4265){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSumReduce::computeShape(_4264,_4265->getShape()));
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->expr = _4265;
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->dim = _4264;
    std::shared_ptr< monty::ndarray< int,1 > > _4266 = _4265->getShape();
    _checked_ptr_1<int> _ptr__4266(_4266 ? _4266->raw() : nullptr,_4266 ? _4266->size(0) : 0);
    if (((int)((_4266)->size(0)) <= _4264))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid summing dimension"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSumReduce :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4267,monty::rc_ptr< ::mosek::fusion::WorkStack > _4268,monty::rc_ptr< ::mosek::fusion::WorkStack > _4269) { mosek::fusion::p_ExprSumReduce::_get_impl(this)->eval(_4267,_4268,_4269); }void mosek::fusion::p_ExprSumReduce::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4267,monty::rc_ptr< ::mosek::fusion::WorkStack > _4268,monty::rc_ptr< ::mosek::fusion::WorkStack > _4269){
  expr->eval(_4268,_4267,_4269);
  _4268->pop_expr();
  int _4270 = mosek::fusion::p_WorkStack::_get_impl(_4268)->nd;
  int _4271 = mosek::fusion::p_WorkStack::_get_impl(_4268)->shape_base;
  int _4272 = mosek::fusion::p_WorkStack::_get_impl(_4268)->nelem;
  int _4273 = mosek::fusion::p_WorkStack::_get_impl(_4268)->nnz;
  bool _4274 = mosek::fusion::p_WorkStack::_get_impl(_4268)->hassp;
  int _4275 = mosek::fusion::p_WorkStack::_get_impl(_4268)->ptr_base;
  int _4276 = mosek::fusion::p_WorkStack::_get_impl(_4268)->sp_base;
  int _4277 = mosek::fusion::p_WorkStack::_get_impl(_4268)->nidxs_base;
  int _4278 = mosek::fusion::p_WorkStack::_get_impl(_4268)->bfix_base;
  int _4279 = mosek::fusion::p_WorkStack::_get_impl(_4268)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4280 = mosek::fusion::p_WorkStack::_get_impl(_4268)->i32;
  _checked_ptr_1<int> _ptr__4280(_4280 ? _4280->raw() : nullptr,_4280 ? _4280->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4281 = mosek::fusion::p_WorkStack::_get_impl(_4268)->i64;
  _checked_ptr_1<long long> _ptr__4281(_4281 ? _4281->raw() : nullptr,_4281 ? _4281->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4282 = mosek::fusion::p_WorkStack::_get_impl(_4268)->f64;
  _checked_ptr_1<double> _ptr__4282(_4282 ? _4282->raw() : nullptr,_4282 ? _4282->size(0) : 0);
  int _4283 = (int)99999;
  int _4284 = (int)99999;
  int _4285 = (int)99999;
  if (_4274)
  {
    {
      int _4286 = (int)0;
      int _8724 = (int)0;
      int _8725 = _4270;
      for (int _4287 = _8724; _4287 < _8725; ++_4287)
      {
        {
          if ((_4286 < _ptr__4280[safe_add( _4271,_4287 )]))
          {
            {
              _4286 = _ptr__4280[safe_add( _4271,_4287 )];
            }
          }
          {}
        }
      }
      _4283 = _4269->alloci32(safe_add( _4286,(int)1 ));
      _4284 = _4269->alloci32(_4272);
      _4285 = _4269->alloci32(_4272);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _4288 = mosek::fusion::p_WorkStack::_get_impl(_4269)->i32;
  _checked_ptr_1<int> _ptr__4288(_4288 ? _4288->raw() : nullptr,_4288 ? _4288->size(0) : 0);
  if (_4274)
  {
    {
      int _4289 = _4284;
      int _4290 = _4285;
      int _8726 = (int)0;
      int _8727 = _4272;
      for (int _4291 = _8726; _4291 < _8727; ++_4291)
      {
        {
          _ptr__4288[safe_add( _4289,_4291 )] = _4291;
        }
      }
      if ((dim < (_4270 - (int)1)))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _4292 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4270)));
          _checked_ptr_1<long long> _ptr__4292(_4292 ? _4292->raw() : nullptr,_4292 ? _4292->size(0) : 0);
          _ptr__4292[(_4270 - (int)1)] = (int)1;
          int _8728 = (int)1;
          int _8729 = _4270;
          for (int _4293 = _8728; _4293 < _8729; ++_4293)
          {
            {
              _ptr__4292[((_4270 - _4293) - (int)1)] = safe_mul( _ptr__4292[(_4270 - _4293)],_ptr__4280[(safe_add( _4271,_4270 ) - _4293)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _4294 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((_4270 - (int)1))));
          _checked_ptr_1<int> _ptr__4294(_4294 ? _4294->raw() : nullptr,_4294 ? _4294->size(0) : 0);
          int _8730 = (int)0;
          int _8731 = dim;
          for (int _4295 = _8730; _4295 < _8731; ++_4295)
          {
            {
              _ptr__4294[((_4270 - _4295) - (int)2)] = _4295;
            }
          }
          int _8732 = safe_add( dim,(int)1 );
          int _8733 = _4270;
          for (int _4296 = _8732; _4296 < _8733; ++_4296)
          {
            {
              _ptr__4294[((_4270 - _4296) - (int)1)] = _4296;
            }
          }
          int _8734 = (int)0;
          int _8735 = (_4270 - (int)1);
          for (int _4297 = _8734; _4297 < _8735; ++_4297)
          {
            {
              int _4298 = _ptr__4294[_4297];
              int _4299 = _ptr__4280[safe_add( _4271,_4298 )];
              int _8736 = (int)0;
              int _8737 = safe_add( _4299,(int)1 );
              for (int _4300 = _8736; _4300 < _8737; ++_4300)
              {
                {
                  _ptr__4288[safe_add( _4283,_4300 )] = (int)0;
                }
              }
              int _8738 = (int)0;
              int _8739 = _4272;
              for (int _4301 = _8738; _4301 < _8739; ++_4301)
              {
                {
                  ++ _ptr__4288[safe_add( safe_add( _4283,(int)1 ),((_ptr__4281[safe_add( _4276,_4301 )] / _ptr__4292[_4298]) % _4299) )];
                }
              }
              int _8740 = (int)0;
              int _8741 = _4299;
              for (int _4302 = _8740; _4302 < _8741; ++_4302)
              {
                {
                  _ptr__4288[safe_add( safe_add( _4283,_4302 ),(int)1 )] += _ptr__4288[safe_add( _4283,_4302 )];
                }
              }
              int _8742 = (int)0;
              int _8743 = _4272;
              for (int _4303 = _8742; _4303 < _8743; ++_4303)
              {
                {
                  int _4304 = _ptr__4288[safe_add( _4289,_4303 )];
                  long long _4305 = ((_ptr__4281[safe_add( _4276,_4304 )] / _ptr__4292[_4298]) % _4299);
                  _ptr__4288[safe_add( _4290,_ptr__4288[safe_add( _4283,_4305 )] )] = _4304;
                  ++ _ptr__4288[safe_add( _4283,_4305 )];
                }
              }
              int _4306 = _4290;
              _4290 = _4289;
              _4289 = _4306;
            }
          }
        }
      }
      {}
      int _4307 = (int)1;
      int _8744 = (int)0;
      int _8745 = dim;
      for (int _4308 = _8744; _4308 < _8745; ++_4308)
      {
        {
          _4307 *= _ptr__4280[safe_add( _4271,_4308 )];
        }
      }
      int _4309 = _ptr__4280[safe_add( _4271,dim )];
      int _4310 = (int)1;
      int _8746 = safe_add( dim,(int)1 );
      int _8747 = _4270;
      for (int _4311 = _8746; _4311 < _8747; ++_4311)
      {
        {
          _4310 *= _ptr__4280[safe_add( _4271,_4311 )];
        }
      }
      int _4312 = safe_mul( _4310,_4309 );
      int _4313 = _4310;
      int _4314 = (int)1;
      int _4315 = (int)0;
      long long _4316 = (-(int)1);
      long long _4317 = (-(int)1);
      int _8748 = (int)0;
      int _8749 = _4272;
      for (int _4318 = _8748; _4318 < _8749; ++_4318)
      {
        {
          int _4319 = _ptr__4288[safe_add( _4289,_4318 )];
          long long _4320 = ((_ptr__4281[safe_add( _4276,_4319 )] / _4312) % _4307);
          long long _4321 = (_ptr__4281[safe_add( _4276,_4319 )] % _4310);
          if (((_4317 != _4320) || (_4316 != _4321)))
          {
            {
              _4317 = _4320;
              _4316 = _4321;
              ++ _4315;
            }
          }
          {}
        }
      }
      int _4322 = (_4270 - (int)1);
      bool _4323 = (_4315 < safe_mul( _4307,_4310 ));
      int _4324 = _4273;
      _4267->alloc_expr(_4322,_4315,_4324,_4323);
      int _4325 = mosek::fusion::p_WorkStack::_get_impl(_4267)->ptr_base;
      int _4326 = mosek::fusion::p_WorkStack::_get_impl(_4267)->nidxs_base;
      int _8750;
      bool _8751 = _4323;
      if (_8751)
      {
        _8750 = mosek::fusion::p_WorkStack::_get_impl(_4267)->sp_base;
      }
      else
      {
        _8750 = _4267->alloci64(_4315);
      }
      int _4327 = _8750;
      int _4328 = mosek::fusion::p_WorkStack::_get_impl(_4267)->cof_base;
      int _4329 = mosek::fusion::p_WorkStack::_get_impl(_4267)->bfix_base;
      int _4330 = mosek::fusion::p_WorkStack::_get_impl(_4267)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4331 = mosek::fusion::p_WorkStack::_get_impl(_4267)->i32;
      _checked_ptr_1<int> _ptr__4331(_4331 ? _4331->raw() : nullptr,_4331 ? _4331->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4332 = mosek::fusion::p_WorkStack::_get_impl(_4267)->i64;
      _checked_ptr_1<long long> _ptr__4332(_4332 ? _4332->raw() : nullptr,_4332 ? _4332->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4333 = mosek::fusion::p_WorkStack::_get_impl(_4267)->f64;
      _checked_ptr_1<double> _ptr__4333(_4333 ? _4333->raw() : nullptr,_4333 ? _4333->size(0) : 0);
      int _8752 = (int)0;
      int _8753 = dim;
      for (int _4334 = _8752; _4334 < _8753; ++_4334)
      {
        {
          _ptr__4331[safe_add( _4330,_4334 )] = _ptr__4280[safe_add( _4271,_4334 )];
        }
      }
      int _8754 = safe_add( dim,(int)1 );
      int _8755 = _4270;
      for (int _4335 = _8754; _4335 < _8755; ++_4335)
      {
        {
          _ptr__4331[(safe_add( _4330,_4335 ) - (int)1)] = _ptr__4280[safe_add( _4271,_4335 )];
        }
      }
      _ptr__4331[_4325] = (int)0;
      int _4336 = (int)0;
      int _4337 = (int)0;
      int _4338 = (int)0;
      while ( (_4338 < _4272) )
      {
        {
          int _4339 = _4338;
          long long _4340 = ((_ptr__4281[safe_add( _4276,_ptr__4288[safe_add( _4289,_4339 )] )] / _4312) % _4307);
          long long _4341 = (_ptr__4281[safe_add( _4276,_ptr__4288[safe_add( _4289,_4339 )] )] % _4310);
          ++ _4338;
          while ( ((_4338 < _4272) && ((_4340 == ((_ptr__4281[safe_add( _4276,_ptr__4288[safe_add( _4289,_4338 )] )] / _4312) % _4307)) && (_4341 == (_ptr__4281[safe_add( _4276,_ptr__4288[safe_add( _4289,_4338 )] )] % _4310)))) )
          {
            {
              ++ _4338;
            }
          }
          double _4342 = 0.0;
          int _8756 = _4339;
          int _8757 = _4338;
          for (int _4343 = _8756; _4343 < _8757; ++_4343)
          {
            {
              int _4344 = _ptr__4288[safe_add( _4289,_4343 )];
              int _8758 = _ptr__4280[safe_add( _4275,_4344 )];
              int _8759 = _ptr__4280[safe_add( safe_add( _4275,_4344 ),(int)1 )];
              for (int _4345 = _8758; _4345 < _8759; ++_4345)
              {
                {
                  _ptr__4332[safe_add( _4326,_4337 )] = _ptr__4281[safe_add( _4277,_4345 )];
                  _ptr__4333[safe_add( _4328,_4337 )] = _ptr__4282[safe_add( _4279,_4345 )];
                  ++ _4337;
                }
              }
              _4342 += _ptr__4282[safe_add( _4278,_4344 )];
            }
          }
          _ptr__4332[safe_add( _4327,_4336 )] = safe_add( safe_mul( _4340,_4310 ),_4341 );
          _ptr__4331[safe_add( safe_add( _4325,_4336 ),(int)1 )] = _4337;
          _ptr__4333[safe_add( _4329,_4336 )] = _4342;
          ++ _4336;
        }
      }
      if ((!_4323))
      {
        {
          _4267->popi64(_4315);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _4346 = (int)1;
      int _8760 = (int)0;
      int _8761 = dim;
      for (int _4347 = _8760; _4347 < _8761; ++_4347)
      {
        {
          _4346 *= _ptr__4280[safe_add( _4271,_4347 )];
        }
      }
      int _4348 = _ptr__4280[safe_add( _4271,dim )];
      int _4349 = (int)1;
      int _8762 = safe_add( dim,(int)1 );
      int _8763 = _4270;
      for (int _4350 = _8762; _4350 < _8763; ++_4350)
      {
        {
          _4349 *= _ptr__4280[safe_add( _4271,_4350 )];
        }
      }
      int _4351 = safe_mul( _4349,_4348 );
      int _4352 = _4349;
      int _4353 = (int)1;
      int _4354 = safe_mul( _4346,_4349 );
      int _4355 = _4267->alloci32(safe_add( _4354,(int)1 ));
      int _4356 = _4267->alloci64(_4273);
      int _4357 = _4267->allocf64(_4273);
      int _4358 = _4267->allocf64(_4354);
      _4267->pushi32((int)0);
      _4267->pushi32(_4273);
      _4267->pushi32(_4354);
      int _4359 = _4267->alloci32((_4270 - (int)1));
      _4267->pushi32((_4270 - (int)1));
      std::shared_ptr< monty::ndarray< int,1 > > _4360 = mosek::fusion::p_WorkStack::_get_impl(_4267)->i32;
      _checked_ptr_1<int> _ptr__4360(_4360 ? _4360->raw() : nullptr,_4360 ? _4360->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4361 = mosek::fusion::p_WorkStack::_get_impl(_4267)->i64;
      _checked_ptr_1<long long> _ptr__4361(_4361 ? _4361->raw() : nullptr,_4361 ? _4361->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4362 = mosek::fusion::p_WorkStack::_get_impl(_4267)->f64;
      _checked_ptr_1<double> _ptr__4362(_4362 ? _4362->raw() : nullptr,_4362 ? _4362->size(0) : 0);
      int _8764 = (int)0;
      int _8765 = dim;
      for (int _4363 = _8764; _4363 < _8765; ++_4363)
      {
        {
          _ptr__4360[safe_add( _4359,_4363 )] = _ptr__4280[safe_add( _4271,_4363 )];
        }
      }
      int _8766 = safe_add( dim,(int)1 );
      int _8767 = _4270;
      for (int _4364 = _8766; _4364 < _8767; ++_4364)
      {
        {
          _ptr__4360[(safe_add( _4359,_4364 ) - (int)1)] = _ptr__4280[safe_add( _4271,_4364 )];
        }
      }
      int _4365 = (int)0;
      int _4366 = (int)0;
      _ptr__4360[_4355] = (int)0;
      int _8768 = (int)0;
      int _8769 = _4346;
      for (int _4367 = _8768; _4367 < _8769; ++_4367)
      {
        {
          int _8770 = (int)0;
          int _8771 = _4349;
          for (int _4368 = _8770; _4368 < _8771; ++_4368)
          {
            {
              double _4369 = 0.0;
              int _8772 = (int)0;
              int _8773 = _4348;
              for (int _4370 = _8772; _4370 < _8773; ++_4370)
              {
                {
                  int _4371 = safe_add( safe_add( safe_mul( _4367,_4351 ),safe_mul( _4370,_4352 ) ),_4368 );
                  int _8774 = _ptr__4280[safe_add( _4275,_4371 )];
                  int _8775 = _ptr__4280[safe_add( safe_add( _4275,_4371 ),(int)1 )];
                  for (int _4372 = _8774; _4372 < _8775; ++_4372)
                  {
                    {
                      _ptr__4361[safe_add( _4356,_4366 )] = _ptr__4281[safe_add( _4277,_4372 )];
                      _ptr__4362[safe_add( _4357,_4366 )] = _ptr__4282[safe_add( _4279,_4372 )];
                      ++ _4366;
                    }
                  }
                  _4369 += _ptr__4282[safe_add( _4278,_4371 )];
                }
              }
              _ptr__4360[safe_add( safe_add( _4355,_4365 ),(int)1 )] = _4366;
              _ptr__4362[safe_add( _4358,_4365 )] = _4369;
              ++ _4365;
            }
          }
        }
      }
    }
  }
  _4269->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSumReduce::computeShape(int _4373,std::shared_ptr< monty::ndarray< int,1 > > _4374){
  _checked_ptr_1<int> _ptr__4374(_4374 ? _4374->raw() : nullptr, _4374 ? _4374->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4375 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(((int)((_4374)->size(0)) - (int)1))));
  _checked_ptr_1<int> _ptr__4375(_4375 ? _4375->raw() : nullptr,_4375 ? _4375->size(0) : 0);
  int _8776 = (int)0;
  int _8777 = _4373;
  for (int _4376 = _8776; _4376 < _8777; ++_4376)
  {
    {
      _ptr__4375[_4376] = _ptr__4374[_4376];
    }
  }
  int _8778 = safe_add( _4373,(int)1 );
  int _8779 = (int)((_4374)->size(0));
  for (int _4377 = _8778; _4377 < _8779; ++_4377)
  {
    {
      _ptr__4375[(_4377 - (int)1)] = _ptr__4374[_4377];
    }
  }
  return _4375;
}
std::string mosek::fusion::ExprSumReduce :: toString() { return mosek::fusion::p_ExprSumReduce::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSumReduce::toString(){
  return std::string ("ExprSumReduce()");
}
void mosek::fusion::p_ExprSumReduce::destroy(){expr.reset();}void mosek::fusion::ExprSumReduce::destroy() { mosek::fusion::p_ExprSumReduce::_get_impl(this)->destroy(); }mosek::fusion::ExprDenseTril::ExprDenseTril(mosek::fusion::p_ExprDenseTril *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDenseTril()" << this << std::endl; */ }mosek::fusion::ExprDenseTril::~ExprDenseTril() {  /* std::cout << "~ExprDenseTril()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDenseTril::p_ExprDenseTril  (::mosek::fusion::ExprDenseTril * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4378,    int _4379,    monty::rc_ptr< ::mosek::fusion::Expression > _4380,    int _4381){ return new mosek::fusion::ExprDenseTril(_4378,_4379,_4380,_4381); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4378,    int _4379,    monty::rc_ptr< ::mosek::fusion::Expression > _4380,    int _4381) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4378,_4379,_4380,_4381); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4378,    int _4379,    monty::rc_ptr< ::mosek::fusion::Expression > _4380,    int _4381){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4380->getShape());
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->expr = _4380;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim0 = _4378;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim1 = _4379;
  }
}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4382,    int _4383,    monty::rc_ptr< ::mosek::fusion::Expression > _4384){ return new mosek::fusion::ExprDenseTril(_4382,_4383,_4384); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4382,    int _4383,    monty::rc_ptr< ::mosek::fusion::Expression > _4384) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4382,_4383,_4384); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4382,    int _4383,    monty::rc_ptr< ::mosek::fusion::Expression > _4384){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprDenseTril::_initialize(_4382,_4383,_4384,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4385 = _4384->getShape();
    _checked_ptr_1<int> _ptr__4385(_4385 ? _4385->raw() : nullptr,_4385 ? _4385->size(0) : 0);
    if (((dim0 == dim1) || ((dim0 < (int)0) || ((dim0 >= (int)((_4385)->size(0))) || ((dim1 < (int)0) || ((dim1 >= (int)((_4385)->size(0))) || (_ptr__4385[dim0] != _ptr__4385[dim1])))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprDenseTril :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4386,monty::rc_ptr< ::mosek::fusion::WorkStack > _4387,monty::rc_ptr< ::mosek::fusion::WorkStack > _4388) { mosek::fusion::p_ExprDenseTril::_get_impl(this)->eval(_4386,_4387,_4388); }void mosek::fusion::p_ExprDenseTril::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4386,monty::rc_ptr< ::mosek::fusion::WorkStack > _4387,monty::rc_ptr< ::mosek::fusion::WorkStack > _4388){
  expr->eval(_4387,_4386,_4388);
  std::shared_ptr< monty::ndarray< int,1 > > _4389 = mosek::fusion::p_WorkStack::_get_impl(_4387)->i32;
  _checked_ptr_1<int> _ptr__4389(_4389 ? _4389->raw() : nullptr,_4389 ? _4389->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4390 = mosek::fusion::p_WorkStack::_get_impl(_4387)->i64;
  _checked_ptr_1<long long> _ptr__4390(_4390 ? _4390->raw() : nullptr,_4390 ? _4390->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4391 = mosek::fusion::p_WorkStack::_get_impl(_4387)->f64;
  _checked_ptr_1<double> _ptr__4391(_4391 ? _4391->raw() : nullptr,_4391 ? _4391->size(0) : 0);
  int _8780;
  bool _8781 = (dim0 < dim1);
  if (_8781)
  {
    _8780 = dim0;
  }
  else
  {
    _8780 = dim1;
  }
  int _4392 = _8780;
  int _8782;
  bool _8783 = (dim0 > dim1);
  if (_8783)
  {
    _8782 = dim0;
  }
  else
  {
    _8782 = dim1;
  }
  int _4393 = _8782;
  bool _4394 = (dim0 < dim1);
  int _4395 = _4387->popi32();
  int _4396 = _4387->popi32(_4395);
  int _4397 = _4387->popi32();
  int _4398 = _4387->popi32();
  bool _4399 = (_4387->popi32() != (int)0);
  int _4400 = _4387->popi32(safe_add( _4397,(int)1 ));
  int _8784;
  bool _8785 = _4399;
  if (_8785)
  {
    _8784 = _4387->popi64(_4397);
  }
  else
  {
    _8784 = (-(int)1);
  }
  int _4401 = _8784;
  int _4402 = _4387->popi64(_4398);
  int _4403 = _4387->popf64(_4397);
  int _4404 = _4387->popf64(_4398);
  std::vector<int> _8786;
  for (int _4406 = (int)0, _8787 = (int)5; _4406 < _8787 ; ++_4406)
  {
    _8786.push_back((int)1);
  }
  auto _8788 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8786.size()),_8786.begin(),_8786.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4405 = _8788;
  _checked_ptr_1<int> _ptr__4405(_4405 ? _4405->raw() : nullptr,_4405 ? _4405->size(0) : 0);
  int _8789 = (int)0;
  int _8790 = _4392;
  for (int _4407 = _8789; _4407 < _8790; ++_4407)
  {
    {
      _ptr__4405[(int)0] *= _ptr__4389[safe_add( _4396,_4407 )];
    }
  }
  _ptr__4405[(int)1] = _ptr__4389[safe_add( _4396,_4392 )];
  int _8791 = safe_add( _4392,(int)1 );
  int _8792 = _4393;
  for (int _4408 = _8791; _4408 < _8792; ++_4408)
  {
    {
      _ptr__4405[(int)2] *= _ptr__4389[safe_add( _4396,_4408 )];
    }
  }
  _ptr__4405[(int)3] = _ptr__4389[safe_add( _4396,_4393 )];
  int _8793 = safe_add( _4393,(int)1 );
  int _8794 = _4395;
  for (int _4409 = _8793; _4409 < _8794; ++_4409)
  {
    {
      _ptr__4405[(int)4] *= _ptr__4389[safe_add( _4396,_4409 )];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4410 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__4410(_4410 ? _4410->raw() : nullptr,_4410 ? _4410->size(0) : 0);
  _ptr__4410[(int)4] = (int)1;
  int _8795 = (int)1;
  int _8796 = (int)5;
  for (int _4411 = _8795; _4411 < _8796; ++_4411)
  {
    {
      _ptr__4410[(((int)5 - _4411) - (int)1)] = safe_mul( _ptr__4410[((int)5 - _4411)],_ptr__4405[((int)5 - _4411)] );
    }
  }
  int _4412 = (int)0;
  int _4413 = (int)0;
  {
    if (_4399)
    {
      {
        if (_4394)
        {
          {
            int _8797 = (int)0;
            int _8798 = _4397;
            for (int _4414 = _8797; _4414 < _8798; ++_4414)
            {
              {
                long long _4415 = ((_ptr__4390[safe_add( _4401,_4414 )] / _ptr__4410[(int)1]) % _ptr__4405[(int)1]);
                long long _4416 = ((_ptr__4390[safe_add( _4401,_4414 )] / _ptr__4410[(int)3]) % _ptr__4405[(int)3]);
                if ((_4415 >= _4416))
                {
                  {
                    _4412 += (_ptr__4389[safe_add( safe_add( _4400,_4414 ),(int)1 )] - _ptr__4389[safe_add( _4400,_4414 )]);
                    ++ _4413;
                  }
                }
                {}
              }
            }
          }
        }
        else
        {
          {
            int _8799 = (int)0;
            int _8800 = _4397;
            for (int _4417 = _8799; _4417 < _8800; ++_4417)
            {
              {
                long long _4418 = ((_ptr__4390[safe_add( _4401,_4417 )] / _ptr__4410[(int)1]) % _ptr__4405[(int)1]);
                long long _4419 = ((_ptr__4390[safe_add( _4401,_4417 )] / _ptr__4410[(int)3]) % _ptr__4405[(int)3]);
                if ((_4418 <= _4419))
                {
                  {
                    _4412 += (_ptr__4389[safe_add( safe_add( _4400,_4417 ),(int)1 )] - _ptr__4389[safe_add( _4400,_4417 )]);
                    ++ _4413;
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    else
    {
      {
        _4413 = safe_mul( safe_mul( safe_mul( _ptr__4405[(int)0],_ptr__4405[(int)2] ),_ptr__4405[(int)4] ),(safe_mul( _ptr__4405[(int)1],safe_add( _ptr__4405[(int)1],(int)1 ) ) / (int)2) );
        if (_4394)
        {
          {
            int _8801 = (int)0;
            int _8802 = _ptr__4405[(int)0];
            for (int _4420 = _8801; _4420 < _8802; ++_4420)
            {
              {
                int _8803 = (int)0;
                int _8804 = _ptr__4405[(int)1];
                for (int _4421 = _8803; _4421 < _8804; ++_4421)
                {
                  {
                    int _8805 = (int)0;
                    int _8806 = _ptr__4405[(int)2];
                    for (int _4422 = _8805; _4422 < _8806; ++_4422)
                    {
                      {
                        int _8807 = (int)0;
                        int _8808 = safe_add( _4421,(int)1 );
                        for (int _4423 = _8807; _4423 < _8808; ++_4423)
                        {
                          {
                            int _8809 = (int)0;
                            int _8810 = _ptr__4405[(int)4];
                            for (int _4424 = _8809; _4424 < _8810; ++_4424)
                            {
                              {
                                int _4425 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4420,_ptr__4410[(int)0] ),safe_mul( _4421,_ptr__4410[(int)1] ) ),safe_mul( _4422,_ptr__4410[(int)2] ) ),safe_mul( _4423,_ptr__4410[(int)3] ) ),safe_mul( _4424,_ptr__4410[(int)4] ) );
                                _4412 += (_ptr__4389[safe_add( safe_add( _4400,_4425 ),(int)1 )] - _ptr__4389[safe_add( _4400,_4425 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        else
        {
          {
            int _8811 = (int)0;
            int _8812 = _ptr__4405[(int)0];
            for (int _4426 = _8811; _4426 < _8812; ++_4426)
            {
              {
                int _8813 = (int)0;
                int _8814 = _ptr__4405[(int)1];
                for (int _4427 = _8813; _4427 < _8814; ++_4427)
                {
                  {
                    int _8815 = (int)0;
                    int _8816 = _ptr__4405[(int)2];
                    for (int _4428 = _8815; _4428 < _8816; ++_4428)
                    {
                      {
                        int _8817 = _4427;
                        int _8818 = _ptr__4405[(int)3];
                        for (int _4429 = _8817; _4429 < _8818; ++_4429)
                        {
                          {
                            int _8819 = (int)0;
                            int _8820 = _ptr__4405[(int)4];
                            for (int _4430 = _8819; _4430 < _8820; ++_4430)
                            {
                              {
                                int _4431 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4426,_ptr__4410[(int)0] ),safe_mul( _4427,_ptr__4410[(int)1] ) ),safe_mul( _4428,_ptr__4410[(int)2] ) ),safe_mul( _4429,_ptr__4410[(int)3] ) ),safe_mul( _4430,_ptr__4410[(int)4] ) );
                                _4412 += (_ptr__4389[safe_add( safe_add( _4400,_4431 ),(int)1 )] - _ptr__4389[safe_add( _4400,_4431 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _4432 = (safe_mul( safe_mul( safe_mul( safe_mul( _ptr__4405[(int)0],_ptr__4405[(int)2] ),_ptr__4405[(int)4] ),_ptr__4405[(int)1] ),safe_add( _ptr__4405[(int)1],(int)1 ) ) / (int)2);
  int _4433 = _4386->alloci32(safe_add( _4432,(int)1 ));
  _4386->pushi32((int)1);
  _4386->pushi32(_4412);
  _4386->pushi32(_4432);
  int _8821 = (int)0;
  int _8822 = _4395;
  for (int _4434 = _8821; _4434 < _8822; ++_4434)
  {
    {
      _4386->pushi32(_ptr__4389[safe_add( _4396,_4434 )]);
    }
  }
  _4386->pushi32(_4395);
  int _4435 = _4386->alloci64(_4412);
  int _4436 = _4386->alloci64(_4432);
  int _4437 = _4386->allocf64(_4412);
  int _4438 = _4386->allocf64(_4432);
  std::shared_ptr< monty::ndarray< int,1 > > _4439 = mosek::fusion::p_WorkStack::_get_impl(_4386)->i32;
  _checked_ptr_1<int> _ptr__4439(_4439 ? _4439->raw() : nullptr,_4439 ? _4439->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4440 = mosek::fusion::p_WorkStack::_get_impl(_4386)->i64;
  _checked_ptr_1<long long> _ptr__4440(_4440 ? _4440->raw() : nullptr,_4440 ? _4440->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4441 = mosek::fusion::p_WorkStack::_get_impl(_4386)->f64;
  _checked_ptr_1<double> _ptr__4441(_4441 ? _4441->raw() : nullptr,_4441 ? _4441->size(0) : 0);
  _ptr__4439[_4433] = (int)0;
  if (_4394)
  {
    {
      int _4442 = (int)0;
      int _8823 = (int)0;
      int _8824 = _ptr__4405[(int)0];
      for (int _4443 = _8823; _4443 < _8824; ++_4443)
      {
        {
          int _8825 = (int)0;
          int _8826 = _ptr__4405[(int)1];
          for (int _4444 = _8825; _4444 < _8826; ++_4444)
          {
            {
              int _8827 = (int)0;
              int _8828 = _ptr__4405[(int)2];
              for (int _4445 = _8827; _4445 < _8828; ++_4445)
              {
                {
                  int _8829 = (int)0;
                  int _8830 = safe_add( _4444,(int)1 );
                  for (int _4446 = _8829; _4446 < _8830; ++_4446)
                  {
                    {
                      int _8831 = (int)0;
                      int _8832 = _ptr__4405[(int)4];
                      for (int _4447 = _8831; _4447 < _8832; ++_4447)
                      {
                        {
                          _ptr__4440[safe_add( _4436,_4442 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4443,_ptr__4410[(int)0] ),safe_mul( _4444,_ptr__4410[(int)1] ) ),safe_mul( _4445,_ptr__4410[(int)2] ) ),safe_mul( _4446,_ptr__4410[(int)3] ) ),safe_mul( _4447,_ptr__4410[(int)4] ) );
                          ++ _4442;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _4448 = (int)0;
      int _8833 = (int)0;
      int _8834 = _ptr__4405[(int)0];
      for (int _4449 = _8833; _4449 < _8834; ++_4449)
      {
        {
          int _8835 = (int)0;
          int _8836 = _ptr__4405[(int)1];
          for (int _4450 = _8835; _4450 < _8836; ++_4450)
          {
            {
              int _8837 = (int)0;
              int _8838 = _ptr__4405[(int)2];
              for (int _4451 = _8837; _4451 < _8838; ++_4451)
              {
                {
                  int _8839 = _4450;
                  int _8840 = _ptr__4405[(int)3];
                  for (int _4452 = _8839; _4452 < _8840; ++_4452)
                  {
                    {
                      int _8841 = (int)0;
                      int _8842 = _ptr__4405[(int)4];
                      for (int _4453 = _8841; _4453 < _8842; ++_4453)
                      {
                        {
                          _ptr__4440[safe_add( _4436,_4448 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4449,_ptr__4410[(int)0] ),safe_mul( _4450,_ptr__4410[(int)1] ) ),safe_mul( _4451,_ptr__4410[(int)2] ) ),safe_mul( _4452,_ptr__4410[(int)3] ) ),safe_mul( _4453,_ptr__4410[(int)4] ) );
                          ++ _4448;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  {
    int _4454 = (int)0;
    if (_4399)
    {
      {
        int _4455 = (int)0;
        int _4456 = (int)0;
        while ( ((_4456 < _4397) && (_4455 < _4432)) )
        {
          {
            if ((_ptr__4390[safe_add( _4401,_4456 )] < _ptr__4440[safe_add( _4436,_4455 )]))
            {
              {
                ++ _4456;
              }
            }
            else if((_ptr__4390[safe_add( _4401,_4456 )] > _ptr__4440[safe_add( _4436,_4455 )]))
            {
              {
                _ptr__4441[safe_add( _4438,_4455 )] = 0.0;
                _ptr__4439[safe_add( safe_add( _4433,_4455 ),(int)1 )] = _4454;
                ++ _4455;
              }
            }
            else
            {
              {
                int _8843 = _ptr__4389[safe_add( _4400,_4456 )];
                int _8844 = _ptr__4389[safe_add( safe_add( _4400,_4456 ),(int)1 )];
                for (int _4457 = _8843; _4457 < _8844; ++_4457)
                {
                  {
                    _ptr__4440[safe_add( _4435,_4454 )] = _ptr__4390[safe_add( _4402,_4457 )];
                    _ptr__4441[safe_add( _4437,_4454 )] = _ptr__4391[safe_add( _4404,_4457 )];
                    ++ _4454;
                  }
                }
                _ptr__4441[safe_add( _4438,_4455 )] = _ptr__4391[safe_add( _4403,_4456 )];
                _ptr__4439[safe_add( safe_add( _4433,_4455 ),(int)1 )] = _4454;
                ++ _4456;
                ++ _4455;
              }
            }
          }
        }
        while ( (_4455 < _4432) )
        {
          {
            _ptr__4439[safe_add( safe_add( _4433,_4455 ),(int)1 )] = _4454;
            _ptr__4441[safe_add( _4438,_4455 )] = 0.0;
            ++ _4455;
          }
        }
      }
    }
    else
    {
      {
        int _8845 = (int)0;
        int _8846 = _4432;
        for (int _4458 = _8845; _4458 < _8846; ++_4458)
        {
          {
            long long _4459 = _ptr__4440[safe_add( _4436,_4458 )];
            _ptr__4441[safe_add( _4438,_4458 )] = _ptr__4391[safe_add( _4403,_4459 )];
            int _8847 = _ptr__4389[safe_add( _4400,_4459 )];
            int _8848 = _ptr__4389[safe_add( safe_add( _4400,_4459 ),(int)1 )];
            for (int _4460 = _8847; _4460 < _8848; ++_4460)
            {
              {
                _ptr__4440[safe_add( _4435,_4454 )] = _ptr__4390[safe_add( _4402,_4460 )];
                _ptr__4441[safe_add( _4437,_4454 )] = _ptr__4391[safe_add( _4404,_4460 )];
                ++ _4454;
              }
            }
            _ptr__4439[safe_add( safe_add( _4433,_4458 ),(int)1 )] = _4454;
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprDenseTril::destroy(){expr.reset();}void mosek::fusion::ExprDenseTril::destroy() { mosek::fusion::p_ExprDenseTril::_get_impl(this)->destroy(); }mosek::fusion::ExprDense::ExprDense(mosek::fusion::p_ExprDense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDense()" << this << std::endl; */ }mosek::fusion::ExprDense::~ExprDense() {  /* std::cout << "~ExprDense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDense::p_ExprDense  (::mosek::fusion::ExprDense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDense::t mosek::fusion::p_ExprDense::_new_ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4461){ return new mosek::fusion::ExprDense(_4461); }mosek::fusion::ExprDense::ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4461) :    ExprDense(new mosek::fusion::p_ExprDense(this)){ mosek::fusion::p_ExprDense::_get_impl(this)->_initialize(_4461); }void mosek::fusion::p_ExprDense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4461){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4461->getShape());
    mosek::fusion::p_ExprDense::_get_impl(::mosek::fusion::ExprDense::t(_pubthis))->expr = _4461;
  }
}void mosek::fusion::ExprDense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4462,monty::rc_ptr< ::mosek::fusion::WorkStack > _4463,monty::rc_ptr< ::mosek::fusion::WorkStack > _4464) { mosek::fusion::p_ExprDense::_get_impl(this)->eval(_4462,_4463,_4464); }void mosek::fusion::p_ExprDense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4462,monty::rc_ptr< ::mosek::fusion::WorkStack > _4463,monty::rc_ptr< ::mosek::fusion::WorkStack > _4464){
  expr->eval(_4462,_4463,_4464);
  _4462->peek_expr();
  if (mosek::fusion::p_WorkStack::_get_impl(_4462)->hassp)
  {
    {
      int _4465 = mosek::fusion::p_WorkStack::_get_impl(_4462)->nd;
      int _4466 = mosek::fusion::p_WorkStack::_get_impl(_4462)->nnz;
      int _4467 = mosek::fusion::p_WorkStack::_get_impl(_4462)->nelem;
      int _4468 = mosek::fusion::p_WorkStack::_get_impl(_4462)->sp_base;
      std::vector<int> _8849;
      for (int _4470 = (int)0, _8850 = _4465; _4470 < _8850 ; ++_4470)
      {
        _8849.push_back(((*mosek::fusion::p_WorkStack::_get_impl(_4462)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4462)->shape_base,_4470 ))));
      }
      auto _8851 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8849.size()),_8849.begin(),_8849.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _4469 = _8851;
      _checked_ptr_1<int> _ptr__4469(_4469 ? _4469->raw() : nullptr,_4469 ? _4469->size(0) : 0);
      int _4471 = (int)::mosek::fusion::p_Set::size(_4469);
      _4462->popi32(safe_add( (int)4,_4465 ));
      if ((_4471 == _4467))
      {
        {
          _4462->popi64(_4467);
          _4462->pushi32((int)0);
          _4462->pushi32(_4466);
          _4462->pushi32(_4467);
          int _4472 = _4462->alloci32(_4465);
          int _8852 = (int)0;
          int _8853 = _4465;
          for (int _4473 = _8852; _4473 < _8853; ++_4473)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_4462)->i32)(safe_add( _4472,_4473 ))) = _ptr__4469[_4473];
            }
          }
          _4462->pushi32(_4465);
          _4462->peek_expr();
        }
      }
      else
      {
        {
          int _4474 = _4464->alloci32(safe_add( _4471,(int)1 ));
          int _4475 = _4464->allocf64(_4471);
          std::shared_ptr< monty::ndarray< int,1 > > _4476 = mosek::fusion::p_WorkStack::_get_impl(_4464)->i32;
          _checked_ptr_1<int> _ptr__4476(_4476 ? _4476->raw() : nullptr,_4476 ? _4476->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4477 = mosek::fusion::p_WorkStack::_get_impl(_4464)->f64;
          _checked_ptr_1<double> _ptr__4477(_4477 ? _4477->raw() : nullptr,_4477 ? _4477->size(0) : 0);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4462)->f64,mosek::fusion::p_WorkStack::_get_impl(_4462)->bfix_base,_4477,_4475,_4467);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4462)->i32,mosek::fusion::p_WorkStack::_get_impl(_4462)->ptr_base,_4476,_4474,safe_add( _4467,(int)1 ));
          _4462->popi32(safe_add( _4467,(int)1 ));
          _4462->popf64(_4467);
          int _4478 = _4462->alloci32(safe_add( _4471,(int)1 ));
          int _4479 = _4462->allocf64(_4471);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _4480 = mosek::fusion::p_WorkStack::_get_impl(_4462)->i32;
            _checked_ptr_1<int> _ptr__4480(_4480 ? _4480->raw() : nullptr,_4480 ? _4480->size(0) : 0);
            std::shared_ptr< monty::ndarray< long long,1 > > _4481 = mosek::fusion::p_WorkStack::_get_impl(_4462)->i64;
            _checked_ptr_1<long long> _ptr__4481(_4481 ? _4481->raw() : nullptr,_4481 ? _4481->size(0) : 0);
            std::shared_ptr< monty::ndarray< double,1 > > _4482 = mosek::fusion::p_WorkStack::_get_impl(_4462)->f64;
            _checked_ptr_1<double> _ptr__4482(_4482 ? _4482->raw() : nullptr,_4482 ? _4482->size(0) : 0);
            _ptr__4480[_4478] = (int)0;
            int _4483 = (int)0;
            if ((_4467 > (int)0))
            {
              {
                int _8854 = (int)0;
                int _8855 = _4471;
                for (int _4484 = _8854; _4484 < _8855; ++_4484)
                {
                  {
                    if ((_ptr__4481[safe_add( _4468,_4483 )] == _4484))
                    {
                      {
                        _ptr__4482[safe_add( _4479,_4484 )] = _ptr__4477[safe_add( _4475,_4483 )];
                        ++ _4483;
                      }
                    }
                    else
                    {
                      {
                        _ptr__4482[safe_add( _4479,_4484 )] = (int)0;
                      }
                    }
                    _ptr__4480[safe_add( safe_add( _4478,_4484 ),(int)1 )] = _ptr__4476[safe_add( _4474,_4483 )];
                  }
                }
              }
            }
            else
            {
              {
                int _8856 = (int)0;
                int _8857 = _4471;
                for (int _4485 = _8856; _4485 < _8857; ++_4485)
                {
                  {
                    _ptr__4482[safe_add( _4479,_4485 )] = (int)0;
                    _ptr__4480[safe_add( safe_add( _4478,_4485 ),(int)1 )] = (int)0;
                  }
                }
              }
            }
          }
          _4462->popi64(_4467);
          _4462->pushi32((int)0);
          _4462->pushi32(_4466);
          _4462->pushi32(_4471);
          int _8858 = (int)0;
          int _8859 = _4465;
          for (int _4486 = _8858; _4486 < _8859; ++_4486)
          {
            {
              _4462->pushi32(_ptr__4469[_4486]);
            }
          }
          _4462->pushi32(_4465);
        }
      }
      _4462->peek_expr();
    }
  }
  {}
  _4464->clear();
}
std::string mosek::fusion::ExprDense :: toString() { return mosek::fusion::p_ExprDense::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprDense::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprDense("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprDense::destroy(){expr.reset();}void mosek::fusion::ExprDense::destroy() { mosek::fusion::p_ExprDense::_get_impl(this)->destroy(); }mosek::fusion::ExprSymmetrize::ExprSymmetrize(mosek::fusion::p_ExprSymmetrize *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSymmetrize()" << this << std::endl; */ }mosek::fusion::ExprSymmetrize::~ExprSymmetrize() {  /* std::cout << "~ExprSymmetrize()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSymmetrize::p_ExprSymmetrize  (::mosek::fusion::ExprSymmetrize * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4487,    int _4488,    monty::rc_ptr< ::mosek::fusion::Expression > _4489,    int _4490){ return new mosek::fusion::ExprSymmetrize(_4487,_4488,_4489,_4490); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4487,    int _4488,    monty::rc_ptr< ::mosek::fusion::Expression > _4489,    int _4490) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4487,_4488,_4489,_4490); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4487,    int _4488,    monty::rc_ptr< ::mosek::fusion::Expression > _4489,    int _4490){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4489->getShape());
    mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->expr = _4489;
    if ((_4487 < _4488))
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4487;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4488;
      }
    }
    else
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4488;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4487;
      }
    }
  }
}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4491,    int _4492,    monty::rc_ptr< ::mosek::fusion::Expression > _4493){ return new mosek::fusion::ExprSymmetrize(_4491,_4492,_4493); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4491,    int _4492,    monty::rc_ptr< ::mosek::fusion::Expression > _4493) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4491,_4492,_4493); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4491,    int _4492,    monty::rc_ptr< ::mosek::fusion::Expression > _4493){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprSymmetrize::_initialize(_4491,_4492,_4493,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4494 = _4493->getShape();
    _checked_ptr_1<int> _ptr__4494(_4494 ? _4494->raw() : nullptr,_4494 ? _4494->size(0) : 0);
    if (((dim0 < (int)0) || ((dim0 == dim1) || ((dim1 >= (int)((_4494)->size(0))) || (_ptr__4494[dim0] != _ptr__4494[dim1])))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSymmetrize :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4495,monty::rc_ptr< ::mosek::fusion::WorkStack > _4496,monty::rc_ptr< ::mosek::fusion::WorkStack > _4497) { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->eval(_4495,_4496,_4497); }void mosek::fusion::p_ExprSymmetrize::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4495,monty::rc_ptr< ::mosek::fusion::WorkStack > _4496,monty::rc_ptr< ::mosek::fusion::WorkStack > _4497){
  expr->eval(_4496,_4495,_4497);
  int _4498 = (int)0;
  int _4499 = _4496->peeki32();
  int _4500 = _4496->peeki32(safe_add( _4499,(int)3 ));
  int _4501 = _4496->peeki32(safe_add( _4499,(int)2 ));
  int _8860 = (int)0;
  int _8861 = _4499;
  for (int _4502 = _8860; _4502 < _8861; ++_4502)
  {
    {
      int _4503 = _4496->peeki32(safe_add( _4502,(int)1 ));
      if ((_4503 > _4498))
      {
        {
          _4503 = _4498;
        }
      }
      {}
    }
  }
  int _4504 = _4496->alloci32(_4501);
  int _4505 = _4496->alloci32(_4501);
  int _4506 = _4496->alloci32(safe_add( _4498,(int)1 ));
  int _4507 = _4496->alloci64(_4501);
  _4496->popi32(safe_add( safe_add( safe_mul( (int)2,_4501 ),_4498 ),(int)1 ));
  _4496->popi64(_4501);
  int _4508 = _4496->popi32();
  int _4509 = _4496->popi32(_4508);
  int _4510 = _4496->popi32();
  int _4511 = _4496->popi32();
  bool _4512 = (_4496->popi32() != (int)0);
  int _4513 = _4496->popi32(safe_add( _4510,(int)1 ));
  int _8862;
  bool _8863 = _4512;
  if (_8863)
  {
    _8862 = _4496->popi64(_4510);
  }
  else
  {
    _8862 = (-(int)1);
  }
  int _4514 = _8862;
  int _4515 = _4496->popi64(_4511);
  int _4516 = _4496->popf64(_4510);
  int _4517 = _4496->popf64(_4511);
  int _4518 = (int)0;
  int _4519 = (int)0;
  std::vector<int> _8864;
  for (int _4521 = (int)0, _8865 = (int)5; _4521 < _8865 ; ++_4521)
  {
    _8864.push_back((int)1);
  }
  auto _8866 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8864.size()),_8864.begin(),_8864.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4520 = _8866;
  _checked_ptr_1<int> _ptr__4520(_4520 ? _4520->raw() : nullptr,_4520 ? _4520->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4522 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)5)));
  _checked_ptr_1<long long> _ptr__4522(_4522 ? _4522->raw() : nullptr,_4522 ? _4522->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4523 = mosek::fusion::p_WorkStack::_get_impl(_4496)->i32;
  _checked_ptr_1<int> _ptr__4523(_4523 ? _4523->raw() : nullptr,_4523 ? _4523->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4524 = mosek::fusion::p_WorkStack::_get_impl(_4496)->i64;
  _checked_ptr_1<long long> _ptr__4524(_4524 ? _4524->raw() : nullptr,_4524 ? _4524->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4525 = mosek::fusion::p_WorkStack::_get_impl(_4496)->f64;
  _checked_ptr_1<double> _ptr__4525(_4525 ? _4525->raw() : nullptr,_4525 ? _4525->size(0) : 0);
  int _8867 = (int)0;
  int _8868 = dim0;
  for (int _4526 = _8867; _4526 < _8868; ++_4526)
  {
    {
      _ptr__4520[(int)0] *= _ptr__4523[safe_add( _4509,_4526 )];
    }
  }
  _ptr__4520[(int)1] = _ptr__4523[safe_add( _4509,dim0 )];
  int _8869 = safe_add( dim0,(int)1 );
  int _8870 = dim1;
  for (int _4527 = _8869; _4527 < _8870; ++_4527)
  {
    {
      _ptr__4520[(int)2] *= _ptr__4523[safe_add( _4509,_4527 )];
    }
  }
  _ptr__4520[(int)3] = _ptr__4523[safe_add( _4509,dim1 )];
  int _8871 = safe_add( dim1,(int)1 );
  int _8872 = _4508;
  for (int _4528 = _8871; _4528 < _8872; ++_4528)
  {
    {
      _ptr__4520[(int)4] *= _ptr__4523[safe_add( _4509,_4528 )];
    }
  }
  _ptr__4522[(int)4] = (int)1;
  int _8873 = (int)1;
  int _8874 = (int)5;
  for (int _4529 = _8873; _4529 < _8874; ++_4529)
  {
    {
      _ptr__4522[(((int)5 - _4529) - (int)1)] = safe_mul( _ptr__4522[((int)5 - _4529)],_ptr__4520[((int)5 - _4529)] );
    }
  }
  if (_4512)
  {
    {
      int _4530 = _4504;
      int _8875 = (int)0;
      int _8876 = _4510;
      for (int _4531 = _8875; _4531 < _8876; ++_4531)
      {
        {
          _ptr__4523[safe_add( _4530,_4531 )] = _4531;
        }
      }
      int _4532 = _4505;
      std::shared_ptr< monty::ndarray< int,1 > > _4533 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)2),(int)((int)3),(int)((int)0)});
      _checked_ptr_1<int> _ptr__4533(_4533 ? _4533->raw() : nullptr,_4533 ? _4533->size(0) : 0);
      int _8877 = (int)0;
      int _8878 = (int)4;
      for (int _4534 = _8877; _4534 < _8878; ++_4534)
      {
        {
          long long _4535 = _ptr__4522[_ptr__4533[_4534]];
          int _4536 = _ptr__4520[_ptr__4533[_4534]];
          if ((_4536 > (int)1))
          {
            {
              int _8879 = (int)0;
              int _8880 = safe_add( _4536,(int)1 );
              for (int _4537 = _8879; _4537 < _8880; ++_4537)
              {
                {
                  _ptr__4523[safe_add( _4506,_4537 )] = (int)0;
                }
              }
              int _8881 = (int)0;
              int _8882 = _4510;
              for (int _4538 = _8881; _4538 < _8882; ++_4538)
              {
                {
                  ++ _ptr__4523[safe_add( safe_add( _4506,((_ptr__4524[safe_add( _4514,_ptr__4523[safe_add( _4530,_4538 )] )] / _4535) % _4536) ),(int)1 )];
                }
              }
              int _8883 = (int)0;
              int _8884 = _ptr__4520[(int)3];
              for (int _4539 = _8883; _4539 < _8884; ++_4539)
              {
                {
                  _ptr__4523[safe_add( safe_add( _4506,_4539 ),(int)1 )] += _ptr__4523[safe_add( _4506,_4539 )];
                }
              }
              int _8885 = (int)0;
              int _8886 = _4510;
              for (int _4540 = _8885; _4540 < _8886; ++_4540)
              {
                {
                  int _4541 = _ptr__4523[safe_add( _4530,_4540 )];
                  long long _4542 = ((_ptr__4524[safe_add( _4514,_4541 )] / _4535) % _4536);
                  _ptr__4523[safe_add( _4532,_ptr__4523[safe_add( _4506,_4542 )] )] = _4541;
                  ++ _ptr__4523[safe_add( _4506,_4542 )];
                }
              }
              int _4543 = _4530;
              _4530 = _4532;
              _4532 = _4543;
            }
          }
          {}
        }
      }
      int _8887 = (int)0;
      int _8888 = _4510;
      for (int _4544 = _8887; _4544 < _8888; ++_4544)
      {
        {
          _ptr__4524[safe_add( _4507,_4544 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( ((_ptr__4524[safe_add( _4514,_4544 )] / _ptr__4522[(int)0]) % _ptr__4520[(int)0]),_ptr__4522[(int)0] ),safe_mul( ((_ptr__4524[safe_add( _4514,_4544 )] / _ptr__4522[(int)1]) % _ptr__4520[(int)1]),_ptr__4522[(int)3] ) ),safe_mul( ((_ptr__4524[safe_add( _4514,_4544 )] / _ptr__4522[(int)2]) % _ptr__4520[(int)2]),_ptr__4522[(int)2] ) ),safe_mul( ((_ptr__4524[safe_add( _4514,_4544 )] / _ptr__4522[(int)3]) % _ptr__4520[(int)3]),_ptr__4522[(int)1] ) ),safe_mul( ((_ptr__4524[safe_add( _4514,_4544 )] / _ptr__4522[(int)4]) % _ptr__4520[(int)4]),_ptr__4522[(int)4] ) );
        }
      }
      {
        int _4545 = (int)0;
        int _4546 = (int)0;
        while ( ((_4546 < _4510) && (_4545 < _4510)) )
        {
          {
            int _4547 = _ptr__4523[safe_add( _4530,_4545 )];
            if ((_ptr__4524[safe_add( _4514,_4546 )] < _ptr__4524[safe_add( _4507,_4547 )]))
            {
              {
                _4519 += (_ptr__4523[safe_add( safe_add( _4513,_4546 ),(int)1 )] - _ptr__4523[safe_add( _4513,_4546 )]);
                ++ _4518;
                ++ _4546;
              }
            }
            else if((_ptr__4524[safe_add( _4514,_4546 )] > _ptr__4524[safe_add( _4507,_4547 )]))
            {
              {
                _4519 += (_ptr__4523[safe_add( safe_add( _4513,_4547 ),(int)1 )] - _ptr__4523[safe_add( _4513,_4547 )]);
                ++ _4518;
                ++ _4545;
              }
            }
            else if((_ptr__4524[safe_add( _4514,_4546 )] != _ptr__4524[safe_add( _4514,_4547 )]))
            {
              {
                _4519 += (_ptr__4523[safe_add( safe_add( _4513,_4546 ),(int)1 )] - _ptr__4523[safe_add( _4513,_4546 )]);
                _4519 += (_ptr__4523[safe_add( safe_add( _4513,_4547 ),(int)1 )] - _ptr__4523[safe_add( _4513,_4547 )]);
                ++ _4518;
                ++ _4545;
                ++ _4546;
              }
            }
            else
            {
              {
                _4519 += (_ptr__4523[safe_add( safe_add( _4513,_4546 ),(int)1 )] - _ptr__4523[safe_add( _4513,_4546 )]);
                ++ _4518;
                ++ _4545;
                ++ _4546;
              }
            }
          }
        }
        while ( (_4546 < _4510) )
        {
          {
            _4519 += (_ptr__4523[safe_add( safe_add( _4513,_4546 ),(int)1 )] - _ptr__4523[safe_add( _4513,_4546 )]);
            ++ _4518;
            ++ _4546;
          }
        }
        while ( (_4545 < _4510) )
        {
          {
            int _4548 = _ptr__4523[safe_add( _4530,_4545 )];
            _4519 += (_ptr__4523[safe_add( safe_add( _4513,_4548 ),(int)1 )] - _ptr__4523[safe_add( _4513,_4548 )]);
            ++ _4518;
            ++ _4545;
          }
        }
      }
      int _4549 = _4495->alloci32(safe_add( _4518,(int)1 ));
      _4495->pushi32((int)1);
      _4495->pushi32(_4519);
      _4495->pushi32(_4518);
      int _8889 = (int)0;
      int _8890 = _4508;
      for (int _4550 = _8889; _4550 < _8890; ++_4550)
      {
        {
          _4495->pushi32(_ptr__4523[safe_add( _4509,_4550 )]);
        }
      }
      _4495->pushi32(_4508);
      int _4551 = _4495->alloci64(_4519);
      int _4552 = _4495->alloci64(_4518);
      int _4553 = _4495->allocf64(_4519);
      int _4554 = _4495->allocf64(_4518);
      std::shared_ptr< monty::ndarray< int,1 > > _4555 = mosek::fusion::p_WorkStack::_get_impl(_4495)->i32;
      _checked_ptr_1<int> _ptr__4555(_4555 ? _4555->raw() : nullptr,_4555 ? _4555->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4556 = mosek::fusion::p_WorkStack::_get_impl(_4495)->i64;
      _checked_ptr_1<long long> _ptr__4556(_4556 ? _4556->raw() : nullptr,_4556 ? _4556->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4557 = mosek::fusion::p_WorkStack::_get_impl(_4495)->f64;
      _checked_ptr_1<double> _ptr__4557(_4557 ? _4557->raw() : nullptr,_4557 ? _4557->size(0) : 0);
      _ptr__4555[_4549] = (int)0;
      {
        int _4558 = (int)0;
        int _4559 = (int)0;
        int _4560 = (int)0;
        int _4561 = (int)0;
        _ptr__4523[_4549] = (int)0;
        while ( ((_4561 < _4510) && (_4560 < _4510)) )
        {
          {
            int _4562 = _ptr__4523[safe_add( _4530,_4560 )];
            if ((_ptr__4524[safe_add( _4514,_4561 )] < _ptr__4524[safe_add( _4507,_4562 )]))
            {
              {
                int _8891 = _ptr__4523[safe_add( _4513,_4561 )];
                int _8892 = _ptr__4523[safe_add( safe_add( _4513,_4561 ),(int)1 )];
                for (int _4563 = _8891; _4563 < _8892; ++_4563)
                {
                  {
                    _ptr__4556[safe_add( _4551,_4558 )] = _ptr__4524[safe_add( _4515,_4563 )];
                    _ptr__4557[safe_add( _4553,_4558 )] = (_ptr__4525[safe_add( _4517,_4563 )] * 0.5);
                    ++ _4558;
                  }
                }
                _ptr__4557[safe_add( _4554,_4559 )] = (_ptr__4525[safe_add( _4516,_4561 )] * 0.5);
                _ptr__4556[safe_add( _4552,_4559 )] = _ptr__4524[safe_add( _4514,_4561 )];
                _ptr__4555[safe_add( safe_add( _4549,_4559 ),(int)1 )] = _4558;
                ++ _4559;
                ++ _4561;
              }
            }
            else if((_ptr__4524[safe_add( _4514,_4561 )] > _ptr__4524[safe_add( _4507,_4562 )]))
            {
              {
                int _8893 = _ptr__4523[safe_add( _4513,_4562 )];
                int _8894 = _ptr__4523[safe_add( safe_add( _4513,_4562 ),(int)1 )];
                for (int _4564 = _8893; _4564 < _8894; ++_4564)
                {
                  {
                    _ptr__4556[safe_add( _4551,_4558 )] = _ptr__4524[safe_add( _4515,_4564 )];
                    _ptr__4557[safe_add( _4553,_4558 )] = (_ptr__4525[safe_add( _4517,_4564 )] * 0.5);
                    ++ _4558;
                  }
                }
                _ptr__4557[safe_add( _4554,_4559 )] = (_ptr__4525[safe_add( _4516,_4562 )] * 0.5);
                _ptr__4556[safe_add( _4552,_4559 )] = _ptr__4524[safe_add( _4507,_4562 )];
                _ptr__4555[safe_add( safe_add( _4549,_4559 ),(int)1 )] = _4558;
                ++ _4559;
                ++ _4560;
              }
            }
            else if((_ptr__4524[safe_add( _4514,_4561 )] != _ptr__4524[safe_add( _4514,_4562 )]))
            {
              {
                int _8895 = _ptr__4523[safe_add( _4513,_4561 )];
                int _8896 = _ptr__4523[safe_add( safe_add( _4513,_4561 ),(int)1 )];
                for (int _4565 = _8895; _4565 < _8896; ++_4565)
                {
                  {
                    _ptr__4556[safe_add( _4551,_4558 )] = _ptr__4524[safe_add( _4515,_4565 )];
                    _ptr__4557[safe_add( _4553,_4558 )] = (_ptr__4525[safe_add( _4517,_4565 )] * 0.5);
                    ++ _4558;
                  }
                }
                int _8897 = _ptr__4523[safe_add( _4513,_4562 )];
                int _8898 = _ptr__4523[safe_add( safe_add( _4513,_4562 ),(int)1 )];
                for (int _4566 = _8897; _4566 < _8898; ++_4566)
                {
                  {
                    _ptr__4556[safe_add( _4551,_4558 )] = _ptr__4524[safe_add( _4515,_4566 )];
                    _ptr__4557[safe_add( _4553,_4558 )] = (_ptr__4525[safe_add( _4517,_4566 )] * 0.5);
                    ++ _4558;
                  }
                }
                _ptr__4557[safe_add( _4554,_4559 )] = (0.5 * (_ptr__4525[safe_add( _4516,_4561 )] + _ptr__4525[safe_add( _4516,_4562 )]));
                _ptr__4556[safe_add( _4552,_4559 )] = _ptr__4524[safe_add( _4514,_4561 )];
                _ptr__4555[safe_add( safe_add( _4549,_4559 ),(int)1 )] = _4558;
                ++ _4559;
                ++ _4560;
                ++ _4561;
              }
            }
            else
            {
              {
                int _8899 = _ptr__4523[safe_add( _4513,_4561 )];
                int _8900 = _ptr__4523[safe_add( safe_add( _4513,_4561 ),(int)1 )];
                for (int _4567 = _8899; _4567 < _8900; ++_4567)
                {
                  {
                    _ptr__4556[safe_add( _4551,_4558 )] = _ptr__4524[safe_add( _4515,_4567 )];
                    _ptr__4557[safe_add( _4553,_4558 )] = _ptr__4525[safe_add( _4517,_4567 )];
                    ++ _4558;
                  }
                }
                _ptr__4557[safe_add( _4554,_4559 )] = _ptr__4525[safe_add( _4516,_4561 )];
                _ptr__4556[safe_add( _4552,_4559 )] = _ptr__4524[safe_add( _4514,_4561 )];
                _ptr__4555[safe_add( safe_add( _4549,_4559 ),(int)1 )] = _4558;
                ++ _4559;
                ++ _4560;
                ++ _4561;
              }
            }
          }
        }
        while ( (_4561 < _4510) )
        {
          {
            int _8901 = _ptr__4523[safe_add( _4513,_4561 )];
            int _8902 = _ptr__4523[safe_add( safe_add( _4513,_4561 ),(int)1 )];
            for (int _4568 = _8901; _4568 < _8902; ++_4568)
            {
              {
                _ptr__4556[safe_add( _4551,_4558 )] = _ptr__4524[safe_add( _4515,_4568 )];
                _ptr__4557[safe_add( _4553,_4558 )] = (_ptr__4525[safe_add( _4517,_4568 )] * 0.5);
                ++ _4558;
              }
            }
            _ptr__4557[safe_add( _4554,_4559 )] = (_ptr__4525[safe_add( _4516,_4561 )] * 0.5);
            _ptr__4556[safe_add( _4552,_4559 )] = _ptr__4524[safe_add( _4514,_4561 )];
            _ptr__4555[safe_add( safe_add( _4549,_4559 ),(int)1 )] = _4558;
            ++ _4559;
            ++ _4561;
          }
        }
        while ( (_4560 < _4510) )
        {
          {
            int _4569 = _ptr__4523[safe_add( _4530,_4560 )];
            int _8903 = _ptr__4523[safe_add( _4513,_4569 )];
            int _8904 = _ptr__4523[safe_add( safe_add( _4513,_4569 ),(int)1 )];
            for (int _4570 = _8903; _4570 < _8904; ++_4570)
            {
              {
                _ptr__4556[safe_add( _4551,_4558 )] = _ptr__4524[safe_add( _4515,_4570 )];
                _ptr__4557[safe_add( _4553,_4558 )] = (_ptr__4525[safe_add( _4517,_4570 )] * 0.5);
                ++ _4558;
              }
            }
            _ptr__4557[safe_add( _4554,_4559 )] = (_ptr__4525[safe_add( _4516,_4569 )] * 0.5);
            _ptr__4556[safe_add( _4552,_4559 )] = _ptr__4524[safe_add( _4507,_4569 )];
            _ptr__4555[safe_add( safe_add( _4549,_4559 ),(int)1 )] = _4558;
            ++ _4559;
            ++ _4560;
          }
        }
      }
    }
  }
  else
  {
    {
      _4518 = _4510;
      _4519 = safe_mul( _4511,(int)2 );
      int _8905 = (int)0;
      int _8906 = _ptr__4520[(int)0];
      for (int _4571 = _8905; _4571 < _8906; ++_4571)
      {
        {
          int _8907 = (int)0;
          int _8908 = _ptr__4520[(int)2];
          for (int _4572 = _8907; _4572 < _8908; ++_4572)
          {
            {
              int _8909 = (int)0;
              int _8910 = _ptr__4520[(int)4];
              for (int _4573 = _8909; _4573 < _8910; ++_4573)
              {
                {
                  int _8911 = (int)0;
                  int _8912 = _ptr__4520[(int)1];
                  for (int _4574 = _8911; _4574 < _8912; ++_4574)
                  {
                    {
                      long long _4575 = safe_add( safe_add( safe_add( safe_add( safe_mul( _ptr__4522[(int)0],_4571 ),safe_mul( _ptr__4522[(int)1],_4574 ) ),safe_mul( _ptr__4522[(int)2],_4572 ) ),safe_mul( _ptr__4522[(int)3],_4574 ) ),safe_mul( _ptr__4522[(int)4],_4573 ) );
                      _4519 -= (_ptr__4523[safe_add( safe_add( _4513,_4575 ),(int)1 )] - _ptr__4523[safe_add( _4513,_4575 )]);
                    }
                  }
                }
              }
            }
          }
        }
      }
      int _4576 = _4495->alloci32(safe_add( _4518,(int)1 ));
      _4495->pushi32((int)0);
      _4495->pushi32(_4519);
      _4495->pushi32(_4518);
      int _8913 = (int)0;
      int _8914 = _4508;
      for (int _4577 = _8913; _4577 < _8914; ++_4577)
      {
        {
          _4495->pushi32(_ptr__4523[safe_add( _4509,_4577 )]);
        }
      }
      _4495->pushi32(_4508);
      int _4578 = _4495->alloci64(_4519);
      int _4579 = _4495->allocf64(_4519);
      int _4580 = _4495->allocf64(_4518);
      std::shared_ptr< monty::ndarray< int,1 > > _4581 = mosek::fusion::p_WorkStack::_get_impl(_4495)->i32;
      _checked_ptr_1<int> _ptr__4581(_4581 ? _4581->raw() : nullptr,_4581 ? _4581->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4582 = mosek::fusion::p_WorkStack::_get_impl(_4495)->i64;
      _checked_ptr_1<long long> _ptr__4582(_4582 ? _4582->raw() : nullptr,_4582 ? _4582->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4583 = mosek::fusion::p_WorkStack::_get_impl(_4495)->f64;
      _checked_ptr_1<double> _ptr__4583(_4583 ? _4583->raw() : nullptr,_4583 ? _4583->size(0) : 0);
      int _4584 = (int)0;
      int _4585 = (int)0;
      _ptr__4581[_4576] = (int)0;
      int _4586 = (int)0;
      int _8915 = (int)0;
      int _8916 = _ptr__4520[(int)0];
      for (int _4587 = _8915; _4587 < _8916; ++_4587)
      {
        {
          int _8917 = (int)0;
          int _8918 = _ptr__4520[(int)1];
          for (int _4588 = _8917; _4588 < _8918; ++_4588)
          {
            {
              int _8919 = (int)0;
              int _8920 = _ptr__4520[(int)2];
              for (int _4589 = _8919; _4589 < _8920; ++_4589)
              {
                {
                  int _8921 = (int)0;
                  int _8922 = _ptr__4520[(int)3];
                  for (int _4590 = _8921; _4590 < _8922; ++_4590)
                  {
                    {
                      int _8923 = (int)0;
                      int _8924 = _ptr__4520[(int)4];
                      for (int _4591 = _8923; _4591 < _8924; ++_4591)
                      {
                        {
                          if ((_4588 == _4590))
                          {
                            {
                              int _8925 = _ptr__4523[safe_add( _4513,_4586 )];
                              int _8926 = _ptr__4523[safe_add( safe_add( _4513,_4586 ),(int)1 )];
                              for (int _4592 = _8925; _4592 < _8926; ++_4592)
                              {
                                {
                                  _ptr__4582[safe_add( _4578,_4584 )] = _ptr__4524[safe_add( _4515,_4592 )];
                                  _ptr__4583[safe_add( _4579,_4584 )] = _ptr__4525[safe_add( _4517,_4592 )];
                                  ++ _4584;
                                }
                              }
                              _ptr__4583[safe_add( _4580,_4585 )] = _ptr__4525[safe_add( _4516,_4587 )];
                              _ptr__4581[safe_add( safe_add( _4576,_4585 ),(int)1 )] = _4584;
                              ++ _4586;
                            }
                          }
                          else
                          {
                            {
                              long long _4593 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4587,_ptr__4522[(int)0] ),safe_mul( _4590,_ptr__4522[(int)1] ) ),safe_mul( _4589,_ptr__4522[(int)2] ) ),safe_mul( _4588,_ptr__4522[(int)3] ) ),_4591 );
                              int _8927 = _ptr__4523[safe_add( _4513,_4586 )];
                              int _8928 = _ptr__4523[safe_add( safe_add( _4513,_4586 ),(int)1 )];
                              for (int _4594 = _8927; _4594 < _8928; ++_4594)
                              {
                                {
                                  _ptr__4582[safe_add( _4578,_4584 )] = _ptr__4524[safe_add( _4515,_4594 )];
                                  _ptr__4583[safe_add( _4579,_4584 )] = (_ptr__4525[safe_add( _4517,_4594 )] * 0.5);
                                  ++ _4584;
                                }
                              }
                              int _8929 = _ptr__4523[safe_add( _4513,_4593 )];
                              int _8930 = _ptr__4523[safe_add( safe_add( _4513,_4593 ),(int)1 )];
                              for (int _4595 = _8929; _4595 < _8930; ++_4595)
                              {
                                {
                                  _ptr__4582[safe_add( _4578,_4584 )] = _ptr__4524[safe_add( _4515,_4595 )];
                                  _ptr__4583[safe_add( _4579,_4584 )] = (_ptr__4525[safe_add( _4517,_4595 )] * 0.5);
                                  ++ _4584;
                                }
                              }
                              _ptr__4583[safe_add( _4580,_4585 )] = (0.5 * (_ptr__4525[safe_add( _4516,_4586 )] + _ptr__4525[safe_add( _4516,_4593 )]));
                              _ptr__4581[safe_add( safe_add( _4576,_4585 ),(int)1 )] = _4584;
                              ++ _4586;
                            }
                          }
                          ++ _4585;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprSymmetrize::destroy(){expr.reset();}void mosek::fusion::ExprSymmetrize::destroy() { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->destroy(); }mosek::fusion::ExprCompress::ExprCompress(mosek::fusion::p_ExprCompress *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCompress()" << this << std::endl; */ }mosek::fusion::ExprCompress::~ExprCompress() {  /* std::cout << "~ExprCompress()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCompress::p_ExprCompress  (::mosek::fusion::ExprCompress * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4596){ return new mosek::fusion::ExprCompress(_4596); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4596) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4596); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4596){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4596->getShape());
    eps = 0.0;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4596;
  }
}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4597,    double _4598){ return new mosek::fusion::ExprCompress(_4597,_4598); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4597,    double _4598) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4597,_4598); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4597,    double _4598){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4597->getShape());
    eps = _4598;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4597;
  }
}void mosek::fusion::ExprCompress :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4599,monty::rc_ptr< ::mosek::fusion::WorkStack > _4600,monty::rc_ptr< ::mosek::fusion::WorkStack > _4601) { mosek::fusion::p_ExprCompress::_get_impl(this)->eval(_4599,_4600,_4601); }void mosek::fusion::p_ExprCompress::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4599,monty::rc_ptr< ::mosek::fusion::WorkStack > _4600,monty::rc_ptr< ::mosek::fusion::WorkStack > _4601){
  expr->eval(_4600,_4599,_4601);
  _4600->pop_expr();
  int _4602 = mosek::fusion::p_WorkStack::_get_impl(_4600)->nd;
  int _4603 = mosek::fusion::p_WorkStack::_get_impl(_4600)->shape_base;
  int _4604 = mosek::fusion::p_WorkStack::_get_impl(_4600)->nelem;
  int _4605 = mosek::fusion::p_WorkStack::_get_impl(_4600)->nnz;
  bool _4606 = mosek::fusion::p_WorkStack::_get_impl(_4600)->hassp;
  int _4607 = mosek::fusion::p_WorkStack::_get_impl(_4600)->ptr_base;
  int _4608 = mosek::fusion::p_WorkStack::_get_impl(_4600)->sp_base;
  int _4609 = mosek::fusion::p_WorkStack::_get_impl(_4600)->nidxs_base;
  int _4610 = mosek::fusion::p_WorkStack::_get_impl(_4600)->bfix_base;
  int _4611 = mosek::fusion::p_WorkStack::_get_impl(_4600)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4612 = mosek::fusion::p_WorkStack::_get_impl(_4600)->i32;
  _checked_ptr_1<int> _ptr__4612(_4612 ? _4612->raw() : nullptr,_4612 ? _4612->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4613 = mosek::fusion::p_WorkStack::_get_impl(_4600)->i64;
  _checked_ptr_1<long long> _ptr__4613(_4613 ? _4613->raw() : nullptr,_4613 ? _4613->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4614 = mosek::fusion::p_WorkStack::_get_impl(_4600)->f64;
  _checked_ptr_1<double> _ptr__4614(_4614 ? _4614->raw() : nullptr,_4614 ? _4614->size(0) : 0);
  std::vector<int> _8931;
  for (int _4616 = (int)0, _8932 = _4602; _4616 < _8932 ; ++_4616)
  {
    _8931.push_back(_ptr__4612[safe_add( _4603,_4616 )]);
  }
  auto _8933 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8931.size()),_8931.begin(),_8931.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4615 = _8933;
  _checked_ptr_1<int> _ptr__4615(_4615 ? _4615->raw() : nullptr,_4615 ? _4615->size(0) : 0);
  bool _4617 = true;
  int _8934 = (int)0;
  int _8935 = _4604;
  for (int _4618 = _8934; _4618 < _8935; ++_4618)
  {
    {
      int _8936 = safe_add( _ptr__4612[safe_add( _4607,_4618 )],(int)1 );
      int _8937 = _ptr__4612[safe_add( safe_add( _4607,_4618 ),(int)1 )];
      for (int _4619 = _8936; _4619 < _8937; ++_4619)
      {
        {
          _4617 = (_4617 && (_ptr__4613[(safe_add( _4609,_4619 ) - (int)1)] < _ptr__4613[safe_add( _4609,_4619 )]));
        }
      }
    }
  }
  if (_4617)
  {
    {
      int _8938 = (int)0;
      int _8939 = _4605;
      for (int _4620 = _8938; _4620 < _8939; ++_4620)
      {
        {
          _4617 = (_4617 && ((_ptr__4614[safe_add( _4611,_4620 )] <= (0.0 - eps)) || ((0.0 + eps) <= _ptr__4614[safe_add( _4611,_4620 )])));
        }
      }
    }
  }
  {}
  if (_4617)
  {
    {
      _4599->alloc_expr(_4602,_4604,_4605,_4606);
      int _4621 = mosek::fusion::p_WorkStack::_get_impl(_4599)->ptr_base;
      int _4622 = mosek::fusion::p_WorkStack::_get_impl(_4599)->nidxs_base;
      int _4623 = mosek::fusion::p_WorkStack::_get_impl(_4599)->sp_base;
      int _4624 = mosek::fusion::p_WorkStack::_get_impl(_4599)->cof_base;
      int _4625 = mosek::fusion::p_WorkStack::_get_impl(_4599)->bfix_base;
      int _4626 = mosek::fusion::p_WorkStack::_get_impl(_4599)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4627 = mosek::fusion::p_WorkStack::_get_impl(_4599)->i32;
      _checked_ptr_1<int> _ptr__4627(_4627 ? _4627->raw() : nullptr,_4627 ? _4627->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4628 = mosek::fusion::p_WorkStack::_get_impl(_4599)->i64;
      _checked_ptr_1<long long> _ptr__4628(_4628 ? _4628->raw() : nullptr,_4628 ? _4628->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4629 = mosek::fusion::p_WorkStack::_get_impl(_4599)->f64;
      _checked_ptr_1<double> _ptr__4629(_4629 ? _4629->raw() : nullptr,_4629 ? _4629->size(0) : 0);
      {
        int _8940 = (int)0;
        int _8941 = _4602;
        for (int _4630 = _8940; _4630 < _8941; ++_4630)
        {
          {
            _ptr__4627[safe_add( _4626,_4630 )] = _ptr__4615[_4630];
          }
        }
        int _8942 = (int)0;
        int _8943 = safe_add( _4604,(int)1 );
        for (int _4631 = _8942; _4631 < _8943; ++_4631)
        {
          {
            _ptr__4627[safe_add( _4621,_4631 )] = _ptr__4612[safe_add( _4607,_4631 )];
          }
        }
        if (_4606)
        {
          {
            int _8944 = (int)0;
            int _8945 = _4604;
            for (int _4632 = _8944; _4632 < _8945; ++_4632)
            {
              {
                _ptr__4628[safe_add( _4623,_4632 )] = _ptr__4613[safe_add( _4608,_4632 )];
              }
            }
          }
        }
        {}
        int _8946 = (int)0;
        int _8947 = _4604;
        for (int _4633 = _8946; _4633 < _8947; ++_4633)
        {
          {
            _ptr__4629[safe_add( _4625,_4633 )] = _ptr__4614[safe_add( _4610,_4633 )];
          }
        }
        int _8948 = (int)0;
        int _8949 = _4605;
        for (int _4634 = _8948; _4634 < _8949; ++_4634)
        {
          {
            _ptr__4628[safe_add( _4622,_4634 )] = _ptr__4613[safe_add( _4609,_4634 )];
          }
        }
        int _8950 = (int)0;
        int _8951 = _4605;
        for (int _4635 = _8950; _4635 < _8951; ++_4635)
        {
          {
            _ptr__4629[safe_add( _4624,_4635 )] = _ptr__4614[safe_add( _4611,_4635 )];
          }
        }
      }
    }
  }
  else
  {
    {
      int _4636 = _4601->alloci32(_4605);
      ::mosek::fusion::p_ExprCompress::arg_sort(_4600,_4601,_4636,_4604,_4605,_4607,_4609);
      std::shared_ptr< monty::ndarray< int,1 > > _4637 = mosek::fusion::p_WorkStack::_get_impl(_4601)->i32;
      _checked_ptr_1<int> _ptr__4637(_4637 ? _4637->raw() : nullptr,_4637 ? _4637->size(0) : 0);
      int _4638 = (int)0;
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4639 = mosek::fusion::p_WorkStack::_get_impl(_4599)->i32;
        _checked_ptr_1<int> _ptr__4639(_4639 ? _4639->raw() : nullptr,_4639 ? _4639->size(0) : 0);
        {
          int _8952 = (int)0;
          int _8953 = _4604;
          for (int _4640 = _8952; _4640 < _8953; ++_4640)
          {
            {
              int _4641 = _ptr__4612[safe_add( safe_add( _4607,_4640 ),(int)1 )];
              int _4642 = _ptr__4612[safe_add( _4607,_4640 )];
              if ((_4642 < _4641))
              {
                {
                  int _4643 = _4642;
                  while ( (_4643 < _4641) )
                  {
                    {
                      double _4644 = 0.0;
                      long long _4645 = _ptr__4613[safe_add( _4609,_ptr__4637[safe_add( _4636,_4643 )] )];
                      while ( ((_4643 < _4641) && (_ptr__4613[safe_add( _4609,_ptr__4637[safe_add( _4636,_4643 )] )] == _4645)) )
                      {
                        {
                          _4644 += _ptr__4614[safe_add( _4611,_ptr__4637[safe_add( _4636,_4643 )] )];
                          ++ _4643;
                        }
                      }
                      {
                      }
                      if (((_4645 != (int)0) && ((_4644 < (-eps)) || (eps < _4644))))
                      {
                        {
                          ++ _4638;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
            }
          }
        }
      }
      _4599->alloc_expr(_4602,_4604,_4638,_4606);
      int _4646 = mosek::fusion::p_WorkStack::_get_impl(_4599)->nidxs_base;
      int _4647 = mosek::fusion::p_WorkStack::_get_impl(_4599)->shape_base;
      int _4648 = mosek::fusion::p_WorkStack::_get_impl(_4599)->sp_base;
      int _4649 = mosek::fusion::p_WorkStack::_get_impl(_4599)->cof_base;
      int _4650 = mosek::fusion::p_WorkStack::_get_impl(_4599)->bfix_base;
      int _4651 = mosek::fusion::p_WorkStack::_get_impl(_4599)->ptr_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4652 = mosek::fusion::p_WorkStack::_get_impl(_4599)->i32;
      _checked_ptr_1<int> _ptr__4652(_4652 ? _4652->raw() : nullptr,_4652 ? _4652->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4653 = mosek::fusion::p_WorkStack::_get_impl(_4599)->i64;
      _checked_ptr_1<long long> _ptr__4653(_4653 ? _4653->raw() : nullptr,_4653 ? _4653->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4654 = mosek::fusion::p_WorkStack::_get_impl(_4599)->f64;
      _checked_ptr_1<double> _ptr__4654(_4654 ? _4654->raw() : nullptr,_4654 ? _4654->size(0) : 0);
      int _8954 = (int)0;
      int _8955 = _4602;
      for (int _4655 = _8954; _4655 < _8955; ++_4655)
      {
        {
          _ptr__4652[safe_add( _4647,_4655 )] = _ptr__4615[_4655];
        }
      }
      {
        int _8956 = (int)0;
        int _8957 = _4604;
        for (int _4656 = _8956; _4656 < _8957; ++_4656)
        {
          {
            _ptr__4654[safe_add( _4649,_4656 )] = 0.0;
          }
        }
        int _8958 = (int)0;
        int _8959 = _4604;
        for (int _4657 = _8958; _4657 < _8959; ++_4657)
        {
          {
            _ptr__4654[safe_add( _4650,_4657 )] = _ptr__4614[safe_add( _4610,_4657 )];
          }
        }
        if (_4606)
        {
          {
            int _8960 = (int)0;
            int _8961 = _4604;
            for (int _4658 = _8960; _4658 < _8961; ++_4658)
            {
              {
                _ptr__4653[safe_add( _4648,_4658 )] = _ptr__4613[safe_add( _4648,_4658 )];
              }
            }
          }
        }
        {}
        int _4659 = (int)0;
        {
          int _4660 = (_4649 - _4646);
          _ptr__4652[_4651] = (int)0;
          int _8962 = (int)0;
          int _8963 = _4604;
          for (int _4661 = _8962; _4661 < _8963; ++_4661)
          {
            {
              int _4662 = _ptr__4612[safe_add( safe_add( _4607,_4661 ),(int)1 )];
              int _4663 = _ptr__4612[safe_add( _4607,_4661 )];
              if ((_4663 < _4662))
              {
                {
                  int _4664 = _4663;
                  while ( (_4664 < _4662) )
                  {
                    {
                      double _4665 = 0.0;
                      long long _4666 = _ptr__4613[safe_add( _4609,_ptr__4637[safe_add( _4636,_4664 )] )];
                      while ( ((_4664 < _4662) && (_ptr__4613[safe_add( _4609,_ptr__4637[safe_add( _4636,_4664 )] )] == _4666)) )
                      {
                        {
                          _4665 += _ptr__4614[safe_add( _4611,_ptr__4637[safe_add( _4636,_4664 )] )];
                          ++ _4664;
                        }
                      }
                      {
                      }
                      if (((_4666 != (int)0) && ((_4665 < (-eps)) || (eps < _4665))))
                      {
                        {
                          _ptr__4653[safe_add( _4646,_4659 )] = _4666;
                          _ptr__4654[safe_add( _4649,_4659 )] = _4665;
                          ++ _4659;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
              _ptr__4652[safe_add( safe_add( _4651,_4661 ),(int)1 )] = _4659;
            }
          }
        }
      }
    }
  }
  _4601->clear();
}
void mosek::fusion::ExprCompress::arg_sort  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4667,    monty::rc_ptr< ::mosek::fusion::WorkStack > _4668,    int _4669,    int _4670,    int _4671,    int _4672,    int _4673) { mosek::fusion::p_ExprCompress::arg_sort(_4667,_4668,_4669,_4670,_4671,_4672,_4673); }void mosek::fusion::p_ExprCompress::arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4667,monty::rc_ptr< ::mosek::fusion::WorkStack > _4668,int _4669,int _4670,int _4671,int _4672,int _4673){
  int _4674 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _4675 = mosek::fusion::p_WorkStack::_get_impl(_4667)->i32;
  _checked_ptr_1<int> _ptr__4675(_4675 ? _4675->raw() : nullptr,_4675 ? _4675->size(0) : 0);
  int _8964 = (int)0;
  int _8965 = _4670;
  for (int _4676 = _8964; _4676 < _8965; ++_4676)
  {
    {
      if (((_ptr__4675[safe_add( safe_add( _4672,_4676 ),(int)1 )] - _ptr__4675[safe_add( _4672,_4676 )]) > _4674))
      {
        {
          _4674 = (_ptr__4675[safe_add( safe_add( _4672,_4676 ),(int)1 )] - _ptr__4675[safe_add( _4672,_4676 )]);
        }
      }
      {}
    }
  }
  int _8966;
  bool _8967 = (_4674 > (int)2);
  if (_8967)
  {
    _8966 = _4668->alloci32(safe_mul( _4674,(int)2 ));
  }
  else
  {
    _8966 = (int)99999;
  }
  int _4677 = _8966;
  std::shared_ptr< monty::ndarray< int,1 > > _4678 = mosek::fusion::p_WorkStack::_get_impl(_4668)->i32;
  _checked_ptr_1<int> _ptr__4678(_4678 ? _4678->raw() : nullptr,_4678 ? _4678->size(0) : 0);
  _4675 = mosek::fusion::p_WorkStack::_get_impl(_4667)->i32;
  _ptr__4675.update(_4675 ? _4675->raw() : nullptr, _4675 ? _4675->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4679 = mosek::fusion::p_WorkStack::_get_impl(_4667)->i64;
  _checked_ptr_1<long long> _ptr__4679(_4679 ? _4679->raw() : nullptr,_4679 ? _4679->size(0) : 0);
  int _8968 = (int)0;
  int _8969 = _4670;
  for (int _4680 = _8968; _4680 < _8969; ++_4680)
  {
    {
      int _4681 = _ptr__4675[safe_add( _4672,_4680 )];
      int _4682 = _ptr__4675[safe_add( safe_add( _4672,_4680 ),(int)1 )];
      int _4683 = (_4682 - _4681);
      if ((_4683 == (int)0))
      {
        {
        }
      }
      else if((_4683 == (int)1))
      {
        {
          _ptr__4678[safe_add( _4669,_4681 )] = _4681;
        }
      }
      else if((_4683 == (int)2))
      {
        {
          if ((_ptr__4679[safe_add( _4673,_4681 )] <= _ptr__4679[safe_add( safe_add( _4673,_4681 ),(int)1 )]))
          {
            {
              _ptr__4678[safe_add( _4669,_4681 )] = _4681;
              _ptr__4678[safe_add( safe_add( _4669,_4681 ),(int)1 )] = safe_add( _4681,(int)1 );
            }
          }
          else
          {
            {
              _ptr__4678[safe_add( _4669,_4681 )] = safe_add( _4681,(int)1 );
              _ptr__4678[safe_add( safe_add( _4669,_4681 ),(int)1 )] = _4681;
            }
          }
        }
      }
      else
      {
        {
          long long _4684 = _ptr__4679[safe_add( _4673,_4681 )];
          long long _4685 = _ptr__4679[safe_add( _4673,_4681 )];
          bool _4686 = false;
          int _8970 = safe_add( _4681,(int)1 );
          int _8971 = _4682;
          for (int _4687 = _8970; _4687 < _8971; ++_4687)
          {
            {
              _4686 = (_4686 && (_ptr__4679[(safe_add( _4673,_4687 ) - (int)1)] <= _ptr__4679[safe_add( _4673,_4687 )]));
              if ((_4684 > _ptr__4679[safe_add( _4673,_4687 )]))
              {
                {
                  _4684 = _ptr__4679[safe_add( _4673,_4687 )];
                }
              }
              {}
              if ((_4685 < _ptr__4679[safe_add( _4673,_4687 )]))
              {
                {
                  _4685 = _ptr__4679[safe_add( _4673,_4687 )];
                }
              }
              {}
            }
          }
          if (_4686)
          {
            {
              int _8972 = _4681;
              int _8973 = _4682;
              for (int _4688 = _8972; _4688 < _8973; ++_4688)
              {
                {
                  _ptr__4678[safe_add( _4669,_4688 )] = _4688;
                }
              }
            }
          }
          else if((safe_add( (_4685 - _4684),(int)1 ) <= _4683))
          {
            {
              long long _4689 = safe_add( (_4685 - _4684),(int)1 );
              int _8974 = (int)0;
              long long _8975 = safe_add( _4689,(int)1 );
              for (long long _4690 = _8974; _4690 < _8975; ++_4690)
              {
                {
                  _ptr__4678[safe_add( _4677,_4690 )] = (int)0;
                }
              }
              int _8976 = _4681;
              int _8977 = _4682;
              for (int _4691 = _8976; _4691 < _8977; ++_4691)
              {
                {
                  ++ _ptr__4678[safe_add( (safe_add( _4677,_ptr__4679[safe_add( _4673,_4691 )] ) - _4684),(int)1 )];
                }
              }
              int _8978 = (int)0;
              long long _8979 = _4689;
              for (long long _4692 = _8978; _4692 < _8979; ++_4692)
              {
                {
                  _ptr__4678[safe_add( safe_add( _4677,_4692 ),(int)1 )] += _ptr__4678[safe_add( _4677,_4692 )];
                }
              }
              int _8980 = _4681;
              int _8981 = _4682;
              for (int _4693 = _8980; _4693 < _8981; ++_4693)
              {
                {
                  _ptr__4678[safe_add( safe_add( _4669,_4681 ),_ptr__4678[(safe_add( _4677,_ptr__4679[safe_add( _4673,_4693 )] ) - _4684)] )] = _4693;
                  ++ _ptr__4678[(safe_add( _4677,_ptr__4679[safe_add( _4673,_4693 )] ) - _4684)];
                }
              }
            }
          }
          else
          {
            {
              int _4694 = (int)1;
              int _4695 = _4677;
              int _4696 = safe_add( _4677,_4683 );
              int _8982 = (int)0;
              int _8983 = _4683;
              for (int _4697 = _8982; _4697 < _8983; ++_4697)
              {
                {
                  _ptr__4678[safe_add( _4695,_4697 )] = _4697;
                }
              }
              while ( (_4694 < _4683) )
              {
                {
                  int _4698 = safe_mul( _4694,(int)2 );
                  int _4699 = (_4683 / _4698);
                  if ((safe_add( safe_mul( _4699,_4698 ),_4694 ) < _4683))
                  {
                    {
                      ++ _4699;
                    }
                  }
                  {}
                  int _4700 = (int)0;
                  int _8984 = (int)0;
                  int _8985 = _4699;
                  for (int _4701 = _8984; _4701 < _8985; ++_4701)
                  {
                    {
                      int _4702 = safe_mul( _4701,_4698 );
                      int _4703 = safe_add( _4702,_4694 );
                      int _4704 = _4703;
                      int _4705 = safe_add( _4704,_4694 );
                      if ((_4705 > _4683))
                      {
                        {
                          _4705 = _4683;
                        }
                      }
                      {}
                      while ( ((_4702 < _4703) && (_4704 < _4705)) )
                      {
                        {
                          if ((_ptr__4679[safe_add( safe_add( _4673,_ptr__4678[safe_add( _4695,_4702 )] ),_4681 )] <= _ptr__4679[safe_add( safe_add( _4673,_ptr__4678[safe_add( _4695,_4704 )] ),_4681 )]))
                          {
                            {
                              _ptr__4678[safe_add( _4696,_4700 )] = _ptr__4678[safe_add( _4695,_4702 )];
                              ++ _4700;
                              ++ _4702;
                            }
                          }
                          else
                          {
                            {
                              _ptr__4678[safe_add( _4696,_4700 )] = _ptr__4678[safe_add( _4695,_4704 )];
                              ++ _4700;
                              ++ _4704;
                            }
                          }
                        }
                      }
                      while ( (_4702 < _4703) )
                      {
                        {
                          _ptr__4678[safe_add( _4696,_4700 )] = _ptr__4678[safe_add( _4695,_4702 )];
                          ++ _4700;
                          ++ _4702;
                        }
                      }
                      while ( (_4704 < _4705) )
                      {
                        {
                          _ptr__4678[safe_add( _4696,_4700 )] = _ptr__4678[safe_add( _4695,_4704 )];
                          ++ _4700;
                          ++ _4704;
                        }
                      }
                    }
                  }
                  if ((safe_mul( _4699,_4698 ) < _4683))
                  {
                    {
                      int _4706 = safe_mul( _4699,_4698 );
                      while ( (_4706 < _4683) )
                      {
                        {
                          _ptr__4678[safe_add( _4696,_4700 )] = _ptr__4678[safe_add( _4695,_4706 )];
                          ++ _4706;
                          ++ _4700;
                        }
                      }
                    }
                  }
                  {}
                  int _4707 = _4695;
                  _4695 = _4696;
                  _4696 = _4707;
                  _4694 *= (int)2;
                }
              }
              int _8986 = (int)0;
              int _8987 = _4683;
              for (int _4708 = _8986; _4708 < _8987; ++_4708)
              {
                {
                  _ptr__4678[safe_add( safe_add( _4669,_4681 ),_4708 )] = safe_add( _ptr__4678[safe_add( _4695,_4708 )],_4681 );
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::ExprCompress::merge_sort  ( int _4709,    int _4710,    int _4711,    int _4712,    int _4713,    int _4714,    std::shared_ptr< monty::ndarray< int,1 > > _4715,    std::shared_ptr< monty::ndarray< long long,1 > > _4716) { mosek::fusion::p_ExprCompress::merge_sort(_4709,_4710,_4711,_4712,_4713,_4714,_4715,_4716); }void mosek::fusion::p_ExprCompress::merge_sort(int _4709,int _4710,int _4711,int _4712,int _4713,int _4714,std::shared_ptr< monty::ndarray< int,1 > > _4715,std::shared_ptr< monty::ndarray< long long,1 > > _4716){
  _checked_ptr_1<int> _ptr__4715(_4715 ? _4715->raw() : nullptr, _4715 ? _4715->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4716(_4716 ? _4716->raw() : nullptr, _4716 ? _4716->size(0) : 0);
  int _4717 = _4709;
  int _4718 = _4710;
  int _8988 = (int)0;
  int _8989 = _4712;
  for (int _4719 = _8988; _4719 < _8989; ++_4719)
  {
    {
      _ptr__4715[safe_add( _4717,_4719 )] = _4719;
    }
  }
  int _8990 = (int)0;
  int _8991 = _4711;
  for (int _4720 = _8990; _4720 < _8991; ++_4720)
  {
    {
      _4717 = _4709;
      _4718 = _4710;
      int _4721 = _ptr__4715[safe_add( safe_add( _4713,_4720 ),(int)1 )];
      int _4722 = _ptr__4715[safe_add( _4713,_4720 )];
      if ((safe_add( _4722,(int)1 ) < _4721))
      {
        {
          int _4723 = (_4721 - _4722);
          int _4724 = (int)0;
          while ( (_4723 > (int)1) )
          {
            {
              ++ _4724;
              _4723 /= (int)2;
            }
          }
          _4723 = (_4721 - _4722);
          int _4725 = (int)1;
          int _8992 = (int)0;
          int _8993 = safe_add( _4724,(int)1 );
          for (int _4726 = _8992; _4726 < _8993; ++_4726)
          {
            {
              int _4727 = ((safe_add( _4723,_4725 ) - (int)1) / _4725);
              int _4728 = (_4727 / (int)2);
              int _4729 = _4722;
              int _8994 = (int)0;
              int _8995 = _4728;
              for (int _4730 = _8994; _4730 < _8995; ++_4730)
              {
                {
                  int _4731 = safe_mul( safe_mul( _4730,_4725 ),(int)2 );
                  int _8996;
                  bool _8997 = (safe_add( safe_add( _4722,_4731 ),safe_mul( (int)2,_4725 ) ) < _4721);
                  if (_8997)
                  {
                    _8996 = safe_add( safe_add( _4722,_4731 ),safe_mul( (int)2,_4725 ) );
                  }
                  else
                  {
                    _8996 = _4721;
                  }
                  int _4732 = _8996;
                  int _4733 = safe_add( safe_add( _4722,_4731 ),_4725 );
                  int _4734 = safe_add( safe_add( _4722,_4731 ),_4725 );
                  int _4735 = safe_add( _4722,_4731 );
                  while ( ((_4735 < _4734) && (_4733 < _4732)) )
                  {
                    {
                      if ((_ptr__4716[safe_add( _4714,_ptr__4715[safe_add( _4717,_4735 )] )] <= _ptr__4716[safe_add( _4714,_ptr__4715[safe_add( _4717,_4733 )] )]))
                      {
                        {
                          _ptr__4715[safe_add( _4718,_4729 )] = _ptr__4715[safe_add( _4717,_4735 )];
                          ++ _4729;
                          ++ _4735;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4715[safe_add( _4718,_4729 )] = _ptr__4715[safe_add( _4717,_4733 )];
                          ++ _4729;
                          ++ _4733;
                        }
                      }
                    }
                  }
                  while ( (_4735 < _4734) )
                  {
                    {
                      _ptr__4715[safe_add( _4718,_4729 )] = _ptr__4715[safe_add( _4717,_4735 )];
                      ++ _4729;
                      ++ _4735;
                    }
                  }
                  while ( (_4733 < _4732) )
                  {
                    {
                      _ptr__4715[safe_add( _4718,_4729 )] = _ptr__4715[safe_add( _4717,_4733 )];
                      ++ _4729;
                      ++ _4733;
                    }
                  }
                }
              }
              int _8998 = _4729;
              int _8999 = _4721;
              for (int _4736 = _8998; _4736 < _8999; ++_4736)
              {
                {
                  _ptr__4715[safe_add( _4718,_4736 )] = _ptr__4715[safe_add( _4717,_4736 )];
                }
              }
              int _4737 = _4717;
              _4717 = _4718;
              _4718 = _4737;
              _4725 *= (int)2;
            }
          }
        }
      }
      {}
      int _9000 = _4722;
      int _9001 = _4721;
      for (int _4738 = _9000; _4738 < _9001; ++_4738)
      {
        {
          _ptr__4715[safe_add( _4709,_4738 )] = _ptr__4715[safe_add( _4717,_4738 )];
        }
      }
    }
  }
}
std::string mosek::fusion::ExprCompress :: toString() { return mosek::fusion::p_ExprCompress::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprCompress::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprCompress("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprCompress::destroy(){expr.reset();}void mosek::fusion::ExprCompress::destroy() { mosek::fusion::p_ExprCompress::_get_impl(this)->destroy(); }mosek::fusion::ExprCondense::ExprCondense(mosek::fusion::p_ExprCondense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCondense()" << this << std::endl; */ }mosek::fusion::ExprCondense::~ExprCondense() {  /* std::cout << "~ExprCondense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCondense::p_ExprCondense  (::mosek::fusion::ExprCondense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCondense::t mosek::fusion::p_ExprCondense::_new_ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4739){ return new mosek::fusion::ExprCondense(_4739); }mosek::fusion::ExprCondense::ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4739) :    ExprCondense(new mosek::fusion::p_ExprCondense(this)){ mosek::fusion::p_ExprCondense::_get_impl(this)->_initialize(_4739); }void mosek::fusion::p_ExprCondense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4739){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4739->getShape());
    mosek::fusion::p_ExprCondense::_get_impl(::mosek::fusion::ExprCondense::t(_pubthis))->expr = _4739;
  }
}void mosek::fusion::ExprCondense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4740,monty::rc_ptr< ::mosek::fusion::WorkStack > _4741,monty::rc_ptr< ::mosek::fusion::WorkStack > _4742) { mosek::fusion::p_ExprCondense::_get_impl(this)->eval(_4740,_4741,_4742); }void mosek::fusion::p_ExprCondense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4740,monty::rc_ptr< ::mosek::fusion::WorkStack > _4741,monty::rc_ptr< ::mosek::fusion::WorkStack > _4742){
  expr->eval(_4740,_4741,_4742);
  int _4743 = _4740->popi32();
  long long _4744 = (int)1;
  int _9002 = (int)0;
  int _9003 = _4743;
  for (int _4745 = _9002; _4745 < _9003; ++_4745)
  {
    {
      _4744 *= _4740->popi32();
    }
  }
  int _4746 = _4740->popi32();
  int _4747 = _4740->popi32();
  bool _4748 = (_4740->popi32() != (int)0);
  if (_4748)
  {
    {
      _4740->popi64(_4746);
    }
  }
  {}
  _4740->pushi32((int)0);
  _4740->pushi32(_4747);
  _4740->pushi32(_4746);
  _4740->pushi32(_4746);
  _4740->pushi32((int)1);
}
void mosek::fusion::p_ExprCondense::destroy(){expr.reset();}void mosek::fusion::ExprCondense::destroy() { mosek::fusion::p_ExprCondense::_get_impl(this)->destroy(); }mosek::fusion::ExprFromVar::ExprFromVar(mosek::fusion::p_ExprFromVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprFromVar()" << this << std::endl; */ }mosek::fusion::ExprFromVar::~ExprFromVar() {  /* std::cout << "~ExprFromVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprFromVar::p_ExprFromVar  (::mosek::fusion::ExprFromVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprFromVar::t mosek::fusion::p_ExprFromVar::_new_ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4749){ return new mosek::fusion::ExprFromVar(_4749); }mosek::fusion::ExprFromVar::ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4749) :    ExprFromVar(new mosek::fusion::p_ExprFromVar(this)){ mosek::fusion::p_ExprFromVar::_get_impl(this)->_initialize(_4749); }void mosek::fusion::p_ExprFromVar::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4749){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4749->getShape());
    mosek::fusion::p_ExprFromVar::_get_impl(::mosek::fusion::ExprFromVar::t(_pubthis))->x = _4749;
  }
}void mosek::fusion::ExprFromVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4750,monty::rc_ptr< ::mosek::fusion::WorkStack > _4751,monty::rc_ptr< ::mosek::fusion::WorkStack > _4752) { mosek::fusion::p_ExprFromVar::_get_impl(this)->eval(_4750,_4751,_4752); }void mosek::fusion::p_ExprFromVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4750,monty::rc_ptr< ::mosek::fusion::WorkStack > _4751,monty::rc_ptr< ::mosek::fusion::WorkStack > _4752){
  std::shared_ptr< monty::ndarray< int,1 > > _4753 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4753(_4753 ? _4753->raw() : nullptr,_4753 ? _4753->size(0) : 0);
  long long _4754 = ::mosek::fusion::p_Set::size(_4753);
  int _4755 = x->numInst();
  int _4756 = _4755;
  bool _4757 = (_4754 > _4755);
  int _4758 = _4750->alloci32(safe_add( _4755,(int)1 ));
  int _4759 = _4750->alloci64(_4756);
  int _9004;
  bool _9005 = _4757;
  if (_9005)
  {
    _9004 = _4750->alloci64(_4755);
  }
  else
  {
    _9004 = (-(int)1);
  }
  int _4760 = _9004;
  int _4761 = _4750->allocf64(_4756);
  int _4762 = _4750->allocf64(_4755);
  int _9006;
  bool _9007 = _4757;
  if (_9007)
  {
    _9006 = (int)1;
  }
  else
  {
    _9006 = (int)0;
  }
  _4750->pushi32(_9006);
  _4750->pushi32(_4756);
  _4750->pushi32(_4755);
  int _9008 = (int)0;
  int _9009 = (int)((_4753)->size(0));
  for (int _4763 = _9008; _4763 < _9009; ++_4763)
  {
    {
      _4750->pushi32(_ptr__4753[_4763]);
    }
  }
  _4750->pushi32((int)((_4753)->size(0)));
  std::shared_ptr< monty::ndarray< int,1 > > _4764 = mosek::fusion::p_WorkStack::_get_impl(_4750)->i32;
  _checked_ptr_1<int> _ptr__4764(_4764 ? _4764->raw() : nullptr,_4764 ? _4764->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4765 = mosek::fusion::p_WorkStack::_get_impl(_4750)->i64;
  _checked_ptr_1<long long> _ptr__4765(_4765 ? _4765->raw() : nullptr,_4765 ? _4765->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4766 = mosek::fusion::p_WorkStack::_get_impl(_4750)->f64;
  _checked_ptr_1<double> _ptr__4766(_4766 ? _4766->raw() : nullptr,_4766 ? _4766->size(0) : 0);
  int _9010 = (int)0;
  int _9011 = safe_add( _4755,(int)1 );
  for (int _4767 = _9010; _4767 < _9011; ++_4767)
  {
    {
      _ptr__4764[safe_add( _4758,_4767 )] = _4767;
    }
  }
  int _9012 = (int)0;
  int _9013 = _4755;
  for (int _4768 = _9012; _4768 < _9013; ++_4768)
  {
    {
      _ptr__4766[safe_add( _4762,_4768 )] = 0.0;
    }
  }
  int _9014 = (int)0;
  int _9015 = _4756;
  for (int _4769 = _9014; _4769 < _9015; ++_4769)
  {
    {
      _ptr__4766[safe_add( _4761,_4769 )] = 1.0;
    }
  }
  if (_4757)
  {
    {
      x->inst(_4760,_4765,_4759,_4765);
    }
  }
  else
  {
    {
      x->inst(_4759,_4765);
    }
  }
}
std::string mosek::fusion::ExprFromVar :: toString() { return mosek::fusion::p_ExprFromVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprFromVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Expr("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprFromVar::destroy(){x.reset();}void mosek::fusion::ExprFromVar::destroy() { mosek::fusion::p_ExprFromVar::_get_impl(this)->destroy(); }mosek::fusion::ExprReshape::ExprReshape(mosek::fusion::p_ExprReshape *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprReshape()" << this << std::endl; */ }mosek::fusion::ExprReshape::~ExprReshape() {  /* std::cout << "~ExprReshape()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprReshape::p_ExprReshape  (::mosek::fusion::ExprReshape * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprReshape::t mosek::fusion::p_ExprReshape::_new_ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4770,    monty::rc_ptr< ::mosek::fusion::Expression > _4771){ return new mosek::fusion::ExprReshape(_4770,_4771); }mosek::fusion::ExprReshape::ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4770,    monty::rc_ptr< ::mosek::fusion::Expression > _4771) :    ExprReshape(new mosek::fusion::p_ExprReshape(this)){ mosek::fusion::p_ExprReshape::_get_impl(this)->_initialize(_4770,_4771); }void mosek::fusion::p_ExprReshape::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4770,    monty::rc_ptr< ::mosek::fusion::Expression > _4771){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4770(_4770 ? _4770->raw() : nullptr, _4770 ? _4770->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4770));
    long long _4772 = _4771->getSize();
    if ((::mosek::fusion::p_Set::size(_4770) != _4771->getSize()))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Cannot reshape to mismatching shape"));
      }
    }
    {}
    mosek::fusion::p_ExprReshape::_get_impl(::mosek::fusion::ExprReshape::t(_pubthis))->e = _4771;
  }
}void mosek::fusion::ExprReshape :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4773,monty::rc_ptr< ::mosek::fusion::WorkStack > _4774,monty::rc_ptr< ::mosek::fusion::WorkStack > _4775) { mosek::fusion::p_ExprReshape::_get_impl(this)->eval(_4773,_4774,_4775); }void mosek::fusion::p_ExprReshape::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4773,monty::rc_ptr< ::mosek::fusion::WorkStack > _4774,monty::rc_ptr< ::mosek::fusion::WorkStack > _4775){
  std::shared_ptr< monty::ndarray< int,1 > > _4776 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4776(_4776 ? _4776->raw() : nullptr,_4776 ? _4776->size(0) : 0);
  e->eval(_4773,_4774,_4775);
  _4773->peek_expr();
  int _4777 = _4773->popi32();
  long long _4778 = (int)1;
  int _9016 = (int)0;
  int _9017 = _4777;
  for (int _4779 = _9016; _4779 < _9017; ++_4779)
  {
    {
      _4778 *= _4773->popi32();
    }
  }
  if ((_4778 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("The two shapes have different sizes"));
    }
  }
  {}
  int _9018 = (int)0;
  int _9019 = (int)((_4776)->size(0));
  for (int _4780 = _9018; _4780 < _9019; ++_4780)
  {
    {
      _4773->pushi32(_ptr__4776[_4780]);
    }
  }
  _4773->pushi32((int)((_4776)->size(0)));
}
std::string mosek::fusion::ExprReshape :: toString() { return mosek::fusion::p_ExprReshape::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprReshape::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4781 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprReshape(("));
  if ((_pubthis->getND() > (int)0))
  {
    {
      _4781->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim((int)0));
      int _9020 = (int)1;
      int _9021 = _pubthis->getND();
      for (int _4782 = _9020; _4782 < _9021; ++_4782)
      {
        {
          _4781->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim(_4782));
        }
      }
    }
  }
  {}
  _4781->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _4781->toString();
}
void mosek::fusion::p_ExprReshape::destroy(){e.reset();}void mosek::fusion::ExprReshape::destroy() { mosek::fusion::p_ExprReshape::_get_impl(this)->destroy(); }mosek::fusion::BaseExpression::BaseExpression(mosek::fusion::p_BaseExpression *_impl) : _impl(_impl) { /*std::cout << "BaseExpression() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseExpression::~BaseExpression() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseExpression::p_BaseExpression  (::mosek::fusion::BaseExpression * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseExpression::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4783){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4783(_4783 ? _4783->raw() : nullptr, _4783 ? _4783->size(0) : 0);
    mosek::fusion::p_BaseExpression::_get_impl(::mosek::fusion::BaseExpression::t(_pubthis))->shape = _4783;
  }
}std::string mosek::fusion::BaseExpression :: toString() { return mosek::fusion::p_BaseExpression::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseExpression::toString(){
  return std::string ("Expression()");
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__eval() { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::eval() { return __mosek_2fusion_2BaseExpression__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__eval(){
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4784 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4785 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4786 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  _pubthis->eval(_4784,_4785,_4786);
  int _4787 = _4784->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4788 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4787)));
  _checked_ptr_1<int> _ptr__4788(_4788 ? _4788->raw() : nullptr,_4788 ? _4788->size(0) : 0);
  _4784->popi32(_4787,_4788,(int)0);
  int _4789 = _4784->popi32();
  int _4790 = _4784->popi32();
  int _4791 = (int)1;
  int _9022 = (int)0;
  int _9023 = _4787;
  for (int _4792 = _9022; _4792 < _9023; ++_4792)
  {
    {
      _4791 *= _ptr__4788[_4792];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _4793 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4790)));
  _checked_ptr_1<long long> _ptr__4793(_4793 ? _4793->raw() : nullptr,_4793 ? _4793->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4794 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _4789,(int)1 ))));
  _checked_ptr_1<int> _ptr__4794(_4794 ? _4794->raw() : nullptr,_4794 ? _4794->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4795 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4789)));
  _checked_ptr_1<double> _ptr__4795(_4795 ? _4795->raw() : nullptr,_4795 ? _4795->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4796 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4790)));
  _checked_ptr_1<double> _ptr__4796(_4796 ? _4796->raw() : nullptr,_4796 ? _4796->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4797 = nullptr;
  _checked_ptr_1<long long> _ptr__4797(_4797 ? _4797->raw() : nullptr,_4797 ? _4797->size(0) : 0);
  if ((_4791 < _4789))
  {
    {
      _4797 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4789)));
      _ptr__4797.update(_4797 ? _4797->raw() : nullptr, _4797 ? _4797->size(0) : 0);
      _4784->popi64(_4789,_4797,(int)0);
    }
  }
  {}
  _4784->popi32(_4789,_4794,(int)1);
  _4784->popi64(_4790,_4793,(int)0);
  _4784->popf64(_4789,_4795,(int)0);
  _4784->popf64(_4790,_4796,(int)0);
  std::vector<long long> _9024;
  for (int _4798 = (int)0, _9025 = safe_add( _4789,(int)1 ); _4798 < _9025 ; ++_4798)
  {
    _9024.push_back(_ptr__4794[_4798]);
  }
  auto _9026 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9024.size()),_9024.begin(),_9024.end()));
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_4795,_9026,_4793,_4796,_4788,_4797);
}
void mosek::fusion::BaseExpression::storeexpr  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4799,    std::shared_ptr< monty::ndarray< int,1 > > _4800,    std::shared_ptr< monty::ndarray< int,1 > > _4801,    std::shared_ptr< monty::ndarray< long long,1 > > _4802,    std::shared_ptr< monty::ndarray< long long,1 > > _4803,    std::shared_ptr< monty::ndarray< double,1 > > _4804,    std::shared_ptr< monty::ndarray< double,1 > > _4805) { mosek::fusion::p_BaseExpression::storeexpr(_4799,_4800,_4801,_4802,_4803,_4804,_4805); }void mosek::fusion::p_BaseExpression::storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4799,std::shared_ptr< monty::ndarray< int,1 > > _4800,std::shared_ptr< monty::ndarray< int,1 > > _4801,std::shared_ptr< monty::ndarray< long long,1 > > _4802,std::shared_ptr< monty::ndarray< long long,1 > > _4803,std::shared_ptr< monty::ndarray< double,1 > > _4804,std::shared_ptr< monty::ndarray< double,1 > > _4805){
  _checked_ptr_1<int> _ptr__4800(_4800 ? _4800->raw() : nullptr, _4800 ? _4800->size(0) : 0);
  _checked_ptr_1<int> _ptr__4801(_4801 ? _4801->raw() : nullptr, _4801 ? _4801->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4802(_4802 ? _4802->raw() : nullptr, _4802 ? _4802->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4803(_4803 ? _4803->raw() : nullptr, _4803 ? _4803->size(0) : 0);
  _checked_ptr_1<double> _ptr__4804(_4804 ? _4804->raw() : nullptr, _4804 ? _4804->size(0) : 0);
  _checked_ptr_1<double> _ptr__4805(_4805 ? _4805->raw() : nullptr, _4805 ? _4805->size(0) : 0);
  int _4806 = _ptr__4801[((int)((_4801)->size(0)) - (int)1)];
  int _4807 = ((int)((_4801)->size(0)) - (int)1);
  int _4808 = (int)((_4800)->size(0));
  {
    int _4809 = _4799->alloci32(safe_add( _4807,(int)1 ));
    ::mosek::fusion::Utils::Tools::arraycopy(_4801,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4799)->i32,_4809,safe_add( _4807,(int)1 ));
  }
  int _9027;
  bool _9028 = (NULL != _4802.get());
  if (_9028)
  {
    _9027 = (int)1;
  }
  else
  {
    _9027 = (int)0;
  }
  _4799->pushi32(_9027);
  _4799->pushi32(_4806);
  _4799->pushi32(_4807);
  {
    int _4810 = _4799->alloci32(_4808);
    ::mosek::fusion::Utils::Tools::arraycopy(_4800,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4799)->i32,_4810,_4808);
  }
  _4799->pushi32(_4808);
  {
    int _4811 = _4799->alloci64(_4806);
    ::mosek::fusion::Utils::Tools::arraycopy(_4803,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4799)->i64,_4811,_4806);
  }
  if ((NULL != _4802.get()))
  {
    {
      int _4812 = _4799->alloci64(_4807);
      ::mosek::fusion::Utils::Tools::arraycopy(_4802,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4799)->i64,_4812,_4807);
    }
  }
  {}
  {
    int _4813 = _4799->allocf64(_4806);
    ::mosek::fusion::Utils::Tools::arraycopy(_4804,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4799)->f64,_4813,_4806);
  }
  {
    int _4814 = _4799->allocf64(_4807);
    if ((NULL != _4805.get()))
    {
      {
        ::mosek::fusion::Utils::Tools::arraycopy(_4805,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4799)->f64,_4814,_4807);
      }
    }
    else
    {
      {
        int _9029 = (int)0;
        int _9030 = _4807;
        for (int _4815 = _9029; _4815 < _9030; ++_4815)
        {
          {
            ((*mosek::fusion::p_WorkStack::_get_impl(_4799)->f64)(safe_add( _4814,_4815 ))) = (int)0;
          }
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4819) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4819); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,2 > > _4819) { return __mosek_2fusion_2BaseExpression__pick(_4819); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4819) { return __mosek_2fusion_2BaseExpression__pick(_4819); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4819){
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4819)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4820) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4820); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,1 > > _4820) { return __mosek_2fusion_2BaseExpression__pick(_4820); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4820) { return __mosek_2fusion_2BaseExpression__pick(_4820); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4820){
  _checked_ptr_1<int> _ptr__4820(_4820 ? _4820->raw() : nullptr, _4820 ? _4820->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4821 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_4820)->size(0)),(int)1)));
  int _9031 = (int)0;
  int _9032 = (int)((_4820)->size(0));
  for (int _4822 = _9031; _4822 < _9032; ++_4822)
  {
    {
      ((*_4821)(_4822,(int)0)) = _ptr__4820[_4822];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4821)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4823) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4823); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(std::shared_ptr< monty::ndarray< int,1 > > _4823) { return __mosek_2fusion_2BaseExpression__index(_4823); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4823) { return __mosek_2fusion_2BaseExpression__index(_4823); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4823){
  _checked_ptr_1<int> _ptr__4823(_4823 ? _4823->raw() : nullptr, _4823 ? _4823->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4824 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_4823)->size(0)))));
  int _9033 = (int)0;
  int _9034 = (int)((_4823)->size(0));
  for (int _4825 = _9033; _4825 < _9034; ++_4825)
  {
    {
      ((*_4824)((int)0,_4825)) = _ptr__4823[_4825];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4824)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(int _4826) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4826); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(int _4826) { return __mosek_2fusion_2BaseExpression__index(_4826); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(int _4826) { return __mosek_2fusion_2BaseExpression__index(_4826); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(int _4826){
  std::shared_ptr< monty::ndarray< int,2 > > _4827 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)1)));
  ((*_4827)((int)0,(int)0)) = _4826;
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4827)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4828,std::shared_ptr< monty::ndarray< int,1 > > _4829) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4828,_4829); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(std::shared_ptr< monty::ndarray< int,1 > > _4828,std::shared_ptr< monty::ndarray< int,1 > > _4829) { return __mosek_2fusion_2BaseExpression__slice(_4828,_4829); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4828,std::shared_ptr< monty::ndarray< int,1 > > _4829) { return __mosek_2fusion_2BaseExpression__slice(_4828,_4829); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4828,std::shared_ptr< monty::ndarray< int,1 > > _4829){
  _checked_ptr_1<int> _ptr__4828(_4828 ? _4828->raw() : nullptr, _4828 ? _4828->size(0) : 0);
  _checked_ptr_1<int> _ptr__4829(_4829 ? _4829->raw() : nullptr, _4829 ? _4829->size(0) : 0);
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4828,_4829)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(int _4830,int _4831) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4830,_4831); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(int _4830,int _4831) { return __mosek_2fusion_2BaseExpression__slice(_4830,_4831); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(int _4830,int _4831) { return __mosek_2fusion_2BaseExpression__slice(_4830,_4831); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(int _4830,int _4831){
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4830)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4831)}))).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::BaseExpression :: getSize() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseExpression::getSize(){
  return ::mosek::fusion::p_Set::size(shape);
}
int mosek::fusion::BaseExpression :: getND() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getND(); }int mosek::fusion::p_BaseExpression::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseExpression :: getDim(int _4832) { return mosek::fusion::p_BaseExpression::_get_impl(this)->getDim(_4832); }int mosek::fusion::p_BaseExpression::getDim(int _4832){
  return ((*shape)(_4832));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseExpression :: getShape() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseExpression::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::p_BaseExpression::destroy(){shape.reset();}void mosek::fusion::BaseExpression::destroy() { mosek::fusion::p_BaseExpression::_get_impl(this)->destroy(); }mosek::fusion::WorkStack::WorkStack(mosek::fusion::p_WorkStack *_impl) : _impl(_impl) { /*std::cout << "WorkStack() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::WorkStack::~WorkStack() { delete _impl; _impl = nullptr; }mosek::fusion::p_WorkStack::p_WorkStack  (::mosek::fusion::WorkStack * _pubthis) :     _pubthis(_pubthis){}int mosek::fusion::WorkStack::get_cof_base() { return _impl->cof_base; }
void mosek::fusion::WorkStack::set_cof_base(int _val) { _impl->cof_base = _val; }
int mosek::fusion::WorkStack::get_bfix_base() { return _impl->bfix_base; }
void mosek::fusion::WorkStack::set_bfix_base(int _val) { _impl->bfix_base = _val; }
int mosek::fusion::WorkStack::get_nidxs_base() { return _impl->nidxs_base; }
void mosek::fusion::WorkStack::set_nidxs_base(int _val) { _impl->nidxs_base = _val; }
int mosek::fusion::WorkStack::get_sp_base() { return _impl->sp_base; }
void mosek::fusion::WorkStack::set_sp_base(int _val) { _impl->sp_base = _val; }
int mosek::fusion::WorkStack::get_shape_base() { return _impl->shape_base; }
void mosek::fusion::WorkStack::set_shape_base(int _val) { _impl->shape_base = _val; }
int mosek::fusion::WorkStack::get_ptr_base() { return _impl->ptr_base; }
void mosek::fusion::WorkStack::set_ptr_base(int _val) { _impl->ptr_base = _val; }
bool mosek::fusion::WorkStack::get_hassp() { return _impl->hassp; }
void mosek::fusion::WorkStack::set_hassp(bool _val) { _impl->hassp = _val; }
int mosek::fusion::WorkStack::get_nelem() { return _impl->nelem; }
void mosek::fusion::WorkStack::set_nelem(int _val) { _impl->nelem = _val; }
int mosek::fusion::WorkStack::get_nnz() { return _impl->nnz; }
void mosek::fusion::WorkStack::set_nnz(int _val) { _impl->nnz = _val; }
int mosek::fusion::WorkStack::get_nd() { return _impl->nd; }
void mosek::fusion::WorkStack::set_nd(int _val) { _impl->nd = _val; }
int mosek::fusion::WorkStack::get_pf64() { return _impl->pf64; }
void mosek::fusion::WorkStack::set_pf64(int _val) { _impl->pf64 = _val; }
int mosek::fusion::WorkStack::get_pi64() { return _impl->pi64; }
void mosek::fusion::WorkStack::set_pi64(int _val) { _impl->pi64 = _val; }
int mosek::fusion::WorkStack::get_pi32() { return _impl->pi32; }
void mosek::fusion::WorkStack::set_pi32(int _val) { _impl->pi32 = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::WorkStack::get_f64() { return _impl->f64; }
void mosek::fusion::WorkStack::set_f64(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->f64 = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::WorkStack::get_i64() { return _impl->i64; }
void mosek::fusion::WorkStack::set_i64(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->i64 = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::WorkStack::get_i32() { return _impl->i32; }
void mosek::fusion::WorkStack::set_i32(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->i32 = _val; }
mosek::fusion::WorkStack::t mosek::fusion::p_WorkStack::_new_WorkStack  (){ return new mosek::fusion::WorkStack(); }mosek::fusion::WorkStack::WorkStack  () :    WorkStack(new mosek::fusion::p_WorkStack(this)){ mosek::fusion::p_WorkStack::_get_impl(this)->_initialize(); }void mosek::fusion::p_WorkStack::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    i32 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)256)));
    i64 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)256)));
    f64 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)256)));
    pi32 = (int)0;
    pi64 = (int)0;
    pf64 = (int)0;
    nd = (int)0;
    nnz = (int)0;
    nelem = (int)0;
    hassp = false;
    ptr_base = (int)0;
    shape_base = (int)0;
    sp_base = (int)0;
    nidxs_base = (int)0;
    bfix_base = (int)0;
    cof_base = (int)0;
  }
}bool mosek::fusion::WorkStack :: peek_hassp() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_hassp(); }bool mosek::fusion::p_WorkStack::peek_hassp(){
  return (_pubthis->peeki32(safe_add( (int)3,_pubthis->peek_nd() )) != (int)0);
}
int mosek::fusion::WorkStack :: peek_nnz() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nnz(); }int mosek::fusion::p_WorkStack::peek_nnz(){
  return _pubthis->peeki32(safe_add( (int)2,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_nelem() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nelem(); }int mosek::fusion::p_WorkStack::peek_nelem(){
  return _pubthis->peeki32(safe_add( (int)1,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_dim(int _4833) { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_dim(_4833); }int mosek::fusion::p_WorkStack::peek_dim(int _4833){
  return _pubthis->peeki32(safe_add( _4833,(int)1 ));
}
int mosek::fusion::WorkStack :: peek_nd() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nd(); }int mosek::fusion::p_WorkStack::peek_nd(){
  return _pubthis->peeki32();
}
void mosek::fusion::WorkStack :: alloc_expr(int _4834,int _4835,int _4836,bool _4837) { mosek::fusion::p_WorkStack::_get_impl(this)->alloc_expr(_4834,_4835,_4836,_4837); }void mosek::fusion::p_WorkStack::alloc_expr(int _4834,int _4835,int _4836,bool _4837){
  cof_base = _pubthis->allocf64(_4836);
  bfix_base = _pubthis->allocf64(_4835);
  nidxs_base = _pubthis->alloci64(_4836);
  int _9035;
  bool _9036 = _4837;
  if (_9036)
  {
    _9035 = _pubthis->alloci64(_4835);
  }
  else
  {
    _9035 = (-(int)9999);
  }
  sp_base = _9035;
  ptr_base = _pubthis->alloci32(safe_add( _4835,(int)1 ));
  int _9037;
  bool _9038 = _4837;
  if (_9038)
  {
    _9037 = (int)1;
  }
  else
  {
    _9037 = (int)0;
  }
  _pubthis->pushi32(_9037);
  _pubthis->pushi32(_4836);
  _pubthis->pushi32(_4835);
  shape_base = _pubthis->alloci32(_4834);
  _pubthis->pushi32(_4834);
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nd = _4834;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nelem = _4835;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nnz = _4836;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->hassp = _4837;
}
void mosek::fusion::WorkStack :: move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4838) { mosek::fusion::p_WorkStack::_get_impl(this)->move_expr(_4838); }void mosek::fusion::p_WorkStack::move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4838){
  int _4839 = pi32;
  int _4840 = pi64;
  int _4841 = pf64;
  _pubthis->pop_expr();
  int _4842 = _4838->alloci32((_4839 - pi32));
  int _4843 = _4838->alloci64((_4840 - pi64));
  int _4844 = _4838->allocf64((_4841 - pf64));
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,mosek::fusion::p_WorkStack::_get_impl(_4838)->i32,_4842,(_4839 - pi32));
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,mosek::fusion::p_WorkStack::_get_impl(_4838)->i64,_4843,(_4840 - pi64));
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,mosek::fusion::p_WorkStack::_get_impl(_4838)->f64,_4844,(_4841 - pf64));
}
void mosek::fusion::WorkStack :: peek_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->peek_expr(); }void mosek::fusion::p_WorkStack::peek_expr(){
  int _4845 = pi32;
  int _4846 = pi64;
  int _4847 = pf64;
  _pubthis->pop_expr();
  pi32 = _4845;
  pi64 = _4846;
  pf64 = _4847;
}
void mosek::fusion::WorkStack :: pop_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->pop_expr(); }void mosek::fusion::p_WorkStack::pop_expr(){
  nd = _pubthis->popi32();
  shape_base = _pubthis->popi32(nd);
  nelem = _pubthis->popi32();
  nnz = _pubthis->popi32();
  hassp = (_pubthis->popi32() != (int)0);
  ptr_base = _pubthis->popi32(safe_add( nelem,(int)1 ));
  int _9039;
  bool _9040 = hassp;
  if (_9040)
  {
    _9039 = _pubthis->popi64(nelem);
  }
  else
  {
    _9039 = (-(int)9999);
  }
  sp_base = _9039;
  nidxs_base = _pubthis->popi64(nnz);
  bfix_base = _pubthis->popf64(nelem);
  cof_base = _pubthis->popf64(nnz);
}
void mosek::fusion::WorkStack :: ensure_sparsity() { mosek::fusion::p_WorkStack::_get_impl(this)->ensure_sparsity(); }void mosek::fusion::p_WorkStack::ensure_sparsity(){
  int _4848 = ((*i32)((pi32 - (int)1)));
  bool _4849 = (((*i32)(((pi32 - _4848) - (int)3))) != (int)0);
  int _4850 = ((*i32)(((pi32 - _4848) - (int)1)));
  if ((!_4849))
  {
    {
      ((*i32)(((pi32 - _4848) - (int)3))) = (int)1;
      int _4851 = _pubthis->alloci64(_4850);
      int _9041 = (int)0;
      int _9042 = _4850;
      for (int _4852 = _9041; _4852 < _9042; ++_4852)
      {
        {
          ((*i64)(_4851)) = _4852;
        }
      }
    }
  }
  {}
}
void mosek::fusion::WorkStack :: clear() { mosek::fusion::p_WorkStack::_get_impl(this)->clear(); }void mosek::fusion::p_WorkStack::clear(){
  pi32 = (int)0;
  pi64 = (int)0;
  pf64 = (int)0;
}
int mosek::fusion::WorkStack :: allocf64(int _4853) { return mosek::fusion::p_WorkStack::_get_impl(this)->allocf64(_4853); }int mosek::fusion::p_WorkStack::allocf64(int _4853){
  _pubthis->ensuref64(_4853);
  int _4854 = pf64;
  int _9043 = pf64;
  int _9044 = safe_add( pf64,_4853 );
  for (int _4855 = _9043; _4855 < _9044; ++_4855)
  {
    {
      ((*f64)(_4855)) = (int)99997;
    }
  }
  pf64 += _4853;
  return _4854;
}
int mosek::fusion::WorkStack :: alloci64(int _4856) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci64(_4856); }int mosek::fusion::p_WorkStack::alloci64(int _4856){
  _pubthis->ensurei64(_4856);
  int _4857 = pi64;
  int _9045 = pi64;
  int _9046 = safe_add( pi64,_4856 );
  for (int _4858 = _9045; _4858 < _9046; ++_4858)
  {
    {
      ((*i64)(_4858)) = (int)99998;
    }
  }
  pi64 += _4856;
  return _4857;
}
int mosek::fusion::WorkStack :: alloci32(int _4859) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci32(_4859); }int mosek::fusion::p_WorkStack::alloci32(int _4859){
  if ((_4859 > (int)0))
  {
    {
      _pubthis->ensurei32(_4859);
      int _4860 = pi32;
      int _9047 = pi32;
      int _9048 = safe_add( pi32,_4859 );
      for (int _4861 = _9047; _4861 < _9048; ++_4861)
      {
        {
          ((*i32)(_4861)) = (int)99999;
        }
      }
      pi32 += _4859;
      return _4860;
    }
  }
  else
  {
    {
      return (int)0;
    }
  }
}
void mosek::fusion::WorkStack :: pushf64(double _4862) { mosek::fusion::p_WorkStack::_get_impl(this)->pushf64(_4862); }void mosek::fusion::p_WorkStack::pushf64(double _4862){
  _pubthis->ensuref64((int)1);
  ((*f64)(pf64)) = _4862;
  ++ pf64;
}
void mosek::fusion::WorkStack :: pushi64(long long _4863) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi64(_4863); }void mosek::fusion::p_WorkStack::pushi64(long long _4863){
  _pubthis->ensurei64((int)1);
  ((*i64)(pi64)) = _4863;
  ++ pi64;
}
void mosek::fusion::WorkStack :: pushi32(int _4864) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi32(_4864); }void mosek::fusion::p_WorkStack::pushi32(int _4864){
  _pubthis->ensurei32((int)1);
  ((*i32)(pi32)) = _4864;
  ++ pi32;
}
void mosek::fusion::WorkStack :: ensuref64(int _4865) { mosek::fusion::p_WorkStack::_get_impl(this)->ensuref64(_4865); }void mosek::fusion::p_WorkStack::ensuref64(int _4865){
  if ((safe_add( pf64,_4865 ) > (int)((f64)->size(0))))
  {
    {
      int _9049;
      bool _9050 = (_4865 < (int)((f64)->size(0)));
      if (_9050)
      {
        _9049 = safe_mul( (int)((f64)->size(0)),(int)2 );
      }
      else
      {
        _9049 = safe_add( (int)((f64)->size(0)),_4865 );
      }
      int _4866 = _9049;
      std::shared_ptr< monty::ndarray< double,1 > > _4867 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4866)));
      _checked_ptr_1<double> _ptr__4867(_4867 ? _4867->raw() : nullptr,_4867 ? _4867->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(f64,(int)0,_4867,(int)0,pf64);
      f64 = _4867;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei64(int _4868) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei64(_4868); }void mosek::fusion::p_WorkStack::ensurei64(int _4868){
  if ((safe_add( pi64,_4868 ) > (int)((i64)->size(0))))
  {
    {
      int _9051;
      bool _9052 = (_4868 < (int)((i64)->size(0)));
      if (_9052)
      {
        _9051 = (int)((i64)->size(0));
      }
      else
      {
        _9051 = _4868;
      }
      int _4869 = safe_add( (int)((i64)->size(0)),_9051 );
      std::shared_ptr< monty::ndarray< long long,1 > > _4870 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4869)));
      _checked_ptr_1<long long> _ptr__4870(_4870 ? _4870->raw() : nullptr,_4870 ? _4870->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i64,(int)0,_4870,(int)0,pi64);
      i64 = _4870;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei32(int _4871) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei32(_4871); }void mosek::fusion::p_WorkStack::ensurei32(int _4871){
  if ((safe_add( pi32,_4871 ) > (int)((i32)->size(0))))
  {
    {
      int _9053;
      bool _9054 = (_4871 < (int)((i32)->size(0)));
      if (_9054)
      {
        _9053 = safe_mul( (int)((i32)->size(0)),(int)2 );
      }
      else
      {
        _9053 = safe_add( (int)((i32)->size(0)),_4871 );
      }
      int _4872 = _9053;
      std::shared_ptr< monty::ndarray< int,1 > > _4873 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4872)));
      _checked_ptr_1<int> _ptr__4873(_4873 ? _4873->raw() : nullptr,_4873 ? _4873->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i32,(int)0,_4873,(int)0,pi32);
      i32 = _4873;
    }
  }
  {}
}
int mosek::fusion::WorkStack :: popf64(int _4874) { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4874); }int mosek::fusion::p_WorkStack::popf64(int _4874){
  pf64 -= _4874;
  return pf64;
}
int mosek::fusion::WorkStack :: popi64(int _4875) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4875); }int mosek::fusion::p_WorkStack::popi64(int _4875){
  pi64 -= _4875;
  return pi64;
}
int mosek::fusion::WorkStack :: popi32(int _4876) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4876); }int mosek::fusion::p_WorkStack::popi32(int _4876){
  pi32 -= _4876;
  return pi32;
}
void mosek::fusion::WorkStack :: popf64(int _4877,std::shared_ptr< monty::ndarray< double,1 > > _4878,int _4879) { mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4877,_4878,_4879); }void mosek::fusion::p_WorkStack::popf64(int _4877,std::shared_ptr< monty::ndarray< double,1 > > _4878,int _4879){
  _checked_ptr_1<double> _ptr__4878(_4878 ? _4878->raw() : nullptr, _4878 ? _4878->size(0) : 0);
  pf64 -= _4877;
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,_4878,_4879,_4877);
}
void mosek::fusion::WorkStack :: popi64(int _4880,std::shared_ptr< monty::ndarray< long long,1 > > _4881,int _4882) { mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4880,_4881,_4882); }void mosek::fusion::p_WorkStack::popi64(int _4880,std::shared_ptr< monty::ndarray< long long,1 > > _4881,int _4882){
  _checked_ptr_1<long long> _ptr__4881(_4881 ? _4881->raw() : nullptr, _4881 ? _4881->size(0) : 0);
  pi64 -= _4880;
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,_4881,_4882,_4880);
}
void mosek::fusion::WorkStack :: popi32(int _4883,std::shared_ptr< monty::ndarray< int,1 > > _4884,int _4885) { mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4883,_4884,_4885); }void mosek::fusion::p_WorkStack::popi32(int _4883,std::shared_ptr< monty::ndarray< int,1 > > _4884,int _4885){
  _checked_ptr_1<int> _ptr__4884(_4884 ? _4884->raw() : nullptr, _4884 ? _4884->size(0) : 0);
  pi32 -= _4883;
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,_4884,_4885,_4883);
}
double mosek::fusion::WorkStack :: popf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(); }double mosek::fusion::p_WorkStack::popf64(){
  -- pf64;
  return ((*f64)(pf64));
}
long long mosek::fusion::WorkStack :: popi64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(); }long long mosek::fusion::p_WorkStack::popi64(){
  -- pi64;
  return ((*i64)(pi64));
}
int mosek::fusion::WorkStack :: popi32() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(); }int mosek::fusion::p_WorkStack::popi32(){
  -- pi32;
  return ((*i32)(pi32));
}
double mosek::fusion::WorkStack :: peekf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(); }double mosek::fusion::p_WorkStack::peekf64(){
  return ((*f64)((pf64 - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(); }long long mosek::fusion::p_WorkStack::peeki64(){
  return ((*i64)((pi64 - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(); }int mosek::fusion::p_WorkStack::peeki32(){
  return ((*i32)((pi32 - (int)1)));
}
double mosek::fusion::WorkStack :: peekf64(int _4886) { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(_4886); }double mosek::fusion::p_WorkStack::peekf64(int _4886){
  return ((*f64)(((pf64 - _4886) - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64(int _4887) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(_4887); }long long mosek::fusion::p_WorkStack::peeki64(int _4887){
  return ((*i64)(((pi64 - _4887) - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32(int _4888) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(_4888); }int mosek::fusion::p_WorkStack::peeki32(int _4888){
  return ((*i32)(((pi32 - _4888) - (int)1)));
}
void mosek::fusion::p_WorkStack::destroy(){f64.reset();i64.reset();i32.reset();}void mosek::fusion::WorkStack::destroy() { mosek::fusion::p_WorkStack::_get_impl(this)->destroy(); }mosek::fusion::SymmetricExpr::SymmetricExpr(mosek::fusion::p_SymmetricExpr *_impl) : _impl(_impl) { /*std::cout << "SymmetricExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricExpr::~SymmetricExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricExpr::p_SymmetricExpr  (::mosek::fusion::SymmetricExpr * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricExpr::t mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr  (int _4889,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4890,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4891,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4892){ return new mosek::fusion::SymmetricExpr(_4889,_4890,_4891,_4892); }mosek::fusion::SymmetricExpr::SymmetricExpr  (int _4889,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4890,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4891,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4892) :    SymmetricExpr(new mosek::fusion::p_SymmetricExpr(this)){ mosek::fusion::p_SymmetricExpr::_get_impl(this)->_initialize(_4889,_4890,_4891,_4892); }void mosek::fusion::p_SymmetricExpr::_initialize  (int _4889,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4890,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4891,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4892){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->n = _4889;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->Ms = _4890;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->xs = _4891;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->b = _4892;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4893,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4894){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4893)->n != _4894->getdim()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimension does not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9055;
  bool _9056 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4893)->b.get());
  if (_9056)
  {
    _9055 = mosek::fusion::p_SymmetricExpr::_get_impl(_4893)->b->__mosek_2fusion_2SymmetricMatrix__add(_4894);
  }
  else
  {
    _9055 = _4894;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4893)->n,mosek::fusion::p_SymmetricExpr::_get_impl(_4893)->Ms,mosek::fusion::p_SymmetricExpr::_get_impl(_4893)->xs,_9055);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4895,double _4896){
  std::vector<monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >> _9057;
  for (int _4897 = (int)0, _9058 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4895)->Ms)->size(0)); _4897 < _9058 ; ++_4897)
  {
    _9057.push_back(((*mosek::fusion::p_SymmetricExpr::_get_impl(_4895)->Ms)(_4897))->__mosek_2fusion_2SymmetricMatrix__mul(_4896));
  }
  auto _9059 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(_9057.size()),_9057.begin(),_9057.end()));
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9060;
  bool _9061 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4895)->b.get());
  if (_9061)
  {
    _9060 = mosek::fusion::p_SymmetricExpr::_get_impl(_4895)->b->__mosek_2fusion_2SymmetricMatrix__mul(_4896);
  }
  else
  {
    _9060 = nullptr;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4895)->n,_9059,mosek::fusion::p_SymmetricExpr::_get_impl(_4895)->xs,_9060);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4898,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4899){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->n != mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->n))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4900 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->Ms)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->Ms)->size(0)) ))));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4901 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->xs)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->xs)->size(0)) ))));
  int _4902 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->Ms)->size(0));
  int _9062 = (int)0;
  int _9063 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->Ms)->size(0));
  for (int _4903 = _9062; _4903 < _9063; ++_4903)
  {
    {
      ((*_4900)(_4903)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->Ms)(_4903));
    }
  }
  int _9064 = (int)0;
  int _9065 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->Ms)->size(0));
  for (int _4904 = _9064; _4904 < _9065; ++_4904)
  {
    {
      ((*_4900)(safe_add( _4904,_4902 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->Ms)(_4904));
    }
  }
  int _4905 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->xs)->size(0));
  int _9066 = (int)0;
  int _9067 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->xs)->size(0));
  for (int _4906 = _9066; _4906 < _9067; ++_4906)
  {
    {
      ((*_4901)(_4906)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->xs)(_4906));
    }
  }
  int _9068 = (int)0;
  int _9069 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->xs)->size(0));
  for (int _4907 = _9068; _4907 < _9069; ++_4907)
  {
    {
      ((*_4901)(safe_add( _4907,_4905 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->xs)(_4907));
    }
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9070;
  bool _9071 = ((NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->b.get()) && (NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->b.get()));
  if (_9071)
  {
    _9070 = nullptr;
  }
  else
  {
    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9072;
    bool _9073 = ((NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->b.get()) && (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->b.get()));
    if (_9073)
    {
      _9072 = mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->b->__mosek_2fusion_2SymmetricMatrix__add(mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->b);
    }
    else
    {
      monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9074;
      bool _9075 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->b.get());
      if (_9075)
      {
        _9074 = mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->b;
      }
      else
      {
        _9074 = mosek::fusion::p_SymmetricExpr::_get_impl(_4899)->b;
      }
      _9072 = _9074;
    }
    _9070 = _9072;
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4908 = _9070;
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4898)->n,_4900,_4901,_4908);
}
std::string mosek::fusion::SymmetricExpr :: toString() { return mosek::fusion::p_SymmetricExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_SymmetricExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4909 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _4909->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SymmetricExpr( ("))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _4909->toString();
}
void mosek::fusion::p_SymmetricExpr::destroy(){xs.reset();b.reset();Ms.reset();}void mosek::fusion::SymmetricExpr::destroy() { mosek::fusion::p_SymmetricExpr::_get_impl(this)->destroy(); }mosek::fusion::Expr::Expr(mosek::fusion::p_Expr *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "Expr()" << this << std::endl; */ }mosek::fusion::Expr::~Expr() {  /* std::cout << "~Expr()" << this << std::endl << std::flush; */ }mosek::fusion::p_Expr::p_Expr  (::mosek::fusion::Expr * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4910,    std::shared_ptr< monty::ndarray< long long,1 > > _4911,    std::shared_ptr< monty::ndarray< double,1 > > _4912,    std::shared_ptr< monty::ndarray< double,1 > > _4913,    std::shared_ptr< monty::ndarray< int,1 > > _4914,    std::shared_ptr< monty::ndarray< long long,1 > > _4915){ return new mosek::fusion::Expr(_4910,_4911,_4912,_4913,_4914,_4915); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4910,    std::shared_ptr< monty::ndarray< long long,1 > > _4911,    std::shared_ptr< monty::ndarray< double,1 > > _4912,    std::shared_ptr< monty::ndarray< double,1 > > _4913,    std::shared_ptr< monty::ndarray< int,1 > > _4914,    std::shared_ptr< monty::ndarray< long long,1 > > _4915) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4910,_4911,_4912,_4913,_4914,_4915); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _4910,    std::shared_ptr< monty::ndarray< long long,1 > > _4911,    std::shared_ptr< monty::ndarray< double,1 > > _4912,    std::shared_ptr< monty::ndarray< double,1 > > _4913,    std::shared_ptr< monty::ndarray< int,1 > > _4914,    std::shared_ptr< monty::ndarray< long long,1 > > _4915){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4910(_4910 ? _4910->raw() : nullptr, _4910 ? _4910->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4911(_4911 ? _4911->raw() : nullptr, _4911 ? _4911->size(0) : 0);
    _checked_ptr_1<double> _ptr__4912(_4912 ? _4912->raw() : nullptr, _4912 ? _4912->size(0) : 0);
    _checked_ptr_1<double> _ptr__4913(_4913 ? _4913->raw() : nullptr, _4913 ? _4913->size(0) : 0);
    _checked_ptr_1<int> _ptr__4914(_4914 ? _4914->raw() : nullptr, _4914 ? _4914->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4915(_4915 ? _4915->raw() : nullptr, _4915 ? _4915->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _9076;
    bool _9077 = (NULL != _4914.get());
    if (_9077)
    {
      _9076 = ::mosek::fusion::Utils::Tools::arraycopy(_4914);
    }
    else
    {
      _9076 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((int)((_4910)->size(0)) - (int)1))});
    }
    std::shared_ptr< monty::ndarray< long long,1 > > _9078;
    bool _9079 = (NULL != _4915.get());
    if (_9079)
    {
      _9078 = ::mosek::fusion::Utils::Tools::arraycopy(_4915);
    }
    else
    {
      _9078 = nullptr;
    }
    mosek::fusion::p_Expr::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4910),::mosek::fusion::Utils::Tools::arraycopy(_4911),::mosek::fusion::Utils::Tools::arraycopy(_4912),::mosek::fusion::Utils::Tools::arraycopy(_4913),_9076,_9078,(int)1);
    int _4916 = ((int)((_4910)->size(0)) - (int)1);
    if ((_4916 < (int)0))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    long long _4917 = _ptr__4910[_4916];
    if (((_4917 < (int)0) || ((_4917 != (int)((_4912)->size(0))) || (_4917 != (int)((_4911)->size(0))))))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb construction"));
      }
    }
    {}
    bool _4918 = true;
    bool _4919 = true;
    bool _4920 = true;
    std::shared_ptr< monty::ndarray< int,1 > > _4921 = mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape;
    _checked_ptr_1<int> _ptr__4921(_4921 ? _4921->raw() : nullptr,_4921 ? _4921->size(0) : 0);
    long long _4922 = ::mosek::fusion::p_Set::size(_4921);
    {
      int _9080 = (int)0;
      int _9081 = (int)((_4921)->size(0));
      for (int _4923 = _9080; _4923 < _9081; ++_4923)
      {
        {
          _4919 = (_4919 && (_ptr__4921[_4923] >= (int)0));
        }
      }
      int _9082 = (int)0;
      int _9083 = _4916;
      for (int _4924 = _9082; _4924 < _9083; ++_4924)
      {
        {
          _4918 = (_4918 && (_ptr__4910[_4924] <= _ptr__4910[safe_add( _4924,(int)1 )]));
        }
      }
      if (((NULL != _4915.get()) && ((int)((_4915)->size(0)) > (int)0)))
      {
        {
          _4920 = ((_ptr__4915[(int)0] >= (int)0) && (_ptr__4915[(_4916 - (int)1)] < _4922));
          int _9084 = (int)0;
          int _9085 = (_4916 - (int)1);
          for (int _4925 = _9084; _4925 < _9085; ++_4925)
          {
            {
              _4920 = (_4920 && (_ptr__4915[_4925] < _ptr__4915[safe_add( _4925,(int)1 )]));
            }
          }
        }
      }
      {}
    }
    if ((!_4919))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid shape"));
      }
    }
    {}
    if ((!_4918))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    if ((!_4920))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid sparsity pattern"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4926,    std::shared_ptr< monty::ndarray< long long,1 > > _4927,    std::shared_ptr< monty::ndarray< double,1 > > _4928,    std::shared_ptr< monty::ndarray< double,1 > > _4929,    std::shared_ptr< monty::ndarray< int,1 > > _4930,    std::shared_ptr< monty::ndarray< long long,1 > > _4931,    int _4932){ return new mosek::fusion::Expr(_4926,_4927,_4928,_4929,_4930,_4931,_4932); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4926,    std::shared_ptr< monty::ndarray< long long,1 > > _4927,    std::shared_ptr< monty::ndarray< double,1 > > _4928,    std::shared_ptr< monty::ndarray< double,1 > > _4929,    std::shared_ptr< monty::ndarray< int,1 > > _4930,    std::shared_ptr< monty::ndarray< long long,1 > > _4931,    int _4932) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4926,_4927,_4928,_4929,_4930,_4931,_4932); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _4926,    std::shared_ptr< monty::ndarray< long long,1 > > _4927,    std::shared_ptr< monty::ndarray< double,1 > > _4928,    std::shared_ptr< monty::ndarray< double,1 > > _4929,    std::shared_ptr< monty::ndarray< int,1 > > _4930,    std::shared_ptr< monty::ndarray< long long,1 > > _4931,    int _4932){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4926(_4926 ? _4926->raw() : nullptr, _4926 ? _4926->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4927(_4927 ? _4927->raw() : nullptr, _4927 ? _4927->size(0) : 0);
    _checked_ptr_1<double> _ptr__4928(_4928 ? _4928->raw() : nullptr, _4928 ? _4928->size(0) : 0);
    _checked_ptr_1<double> _ptr__4929(_4929 ? _4929->raw() : nullptr, _4929 ? _4929->size(0) : 0);
    _checked_ptr_1<int> _ptr__4930(_4930 ? _4930->raw() : nullptr, _4930 ? _4930->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4931(_4931 ? _4931->raw() : nullptr, _4931 ? _4931->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_4930);
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape = _4930;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->ptrb = _4926;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->subj = _4927;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->cof_v = _4928;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->bfix = _4929;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->inst = _4931;
    if ((NULL == mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _4933){ return new mosek::fusion::Expr(_4933); }mosek::fusion::Expr::Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _4933) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4933); }void mosek::fusion::p_Expr::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4933){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4933->getShape());
    monty::rc_ptr< ::mosek::fusion::Expression > _9086 = _4933;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::Expr*>(_9086.get()))
    {
      ::mosek::fusion::Expr::t _4934 (dynamic_cast<::mosek::fusion::Expr*>(_9086.get()));
      {
        shape = mosek::fusion::p_Expr::_get_impl(_4934)->shape;
        ptrb = mosek::fusion::p_Expr::_get_impl(_4934)->ptrb;
        subj = mosek::fusion::p_Expr::_get_impl(_4934)->subj;
        cof_v = mosek::fusion::p_Expr::_get_impl(_4934)->cof_v;
        bfix = mosek::fusion::p_Expr::_get_impl(_4934)->bfix;
        inst = mosek::fusion::p_Expr::_get_impl(_4934)->inst;
      }
    }
    else
    {
      mosek::fusion::Expression::t _4935 = _9086;
      {
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4936 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4937 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4938 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        _4935->eval(_4938,_4937,_4936);
        int _4939 = _4938->popi32();
        int _4940 = _4938->popi32(_4939);
        int _4941 = _4938->popi32();
        int _4942 = _4938->popi32();
        bool _4943 = (_4938->popi32() != (int)0);
        int _4944 = _4938->popi32(safe_add( _4941,(int)1 ));
        int _9087;
        bool _9088 = _4943;
        if (_9088)
        {
          _9087 = _4938->popi64(_4941);
        }
        else
        {
          _9087 = (int)0;
        }
        int _4945 = _9087;
        int _4946 = _4938->popi64(_4942);
        int _4947 = _4938->popf64(_4941);
        int _4948 = _4938->popf64(_4942);
        std::shared_ptr< monty::ndarray< int,1 > > _4949 = mosek::fusion::p_WorkStack::_get_impl(_4938)->i32;
        _checked_ptr_1<int> _ptr__4949(_4949 ? _4949->raw() : nullptr,_4949 ? _4949->size(0) : 0);
        std::shared_ptr< monty::ndarray< long long,1 > > _4950 = mosek::fusion::p_WorkStack::_get_impl(_4938)->i64;
        _checked_ptr_1<long long> _ptr__4950(_4950 ? _4950->raw() : nullptr,_4950 ? _4950->size(0) : 0);
        std::shared_ptr< monty::ndarray< double,1 > > _4951 = mosek::fusion::p_WorkStack::_get_impl(_4938)->f64;
        _checked_ptr_1<double> _ptr__4951(_4951 ? _4951->raw() : nullptr,_4951 ? _4951->size(0) : 0);
        std::vector<int> _9089;
        for (int _4952 = (int)0, _9090 = _4939; _4952 < _9090 ; ++_4952)
        {
          _9089.push_back(_ptr__4949[safe_add( _4940,_4952 )]);
        }
        auto _9091 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9089.size()),_9089.begin(),_9089.end()));
        shape = _9091;
        std::vector<long long> _9092;
        for (int _4953 = (int)0, _9093 = safe_add( _4941,(int)1 ); _4953 < _9093 ; ++_4953)
        {
          _9092.push_back(_ptr__4949[safe_add( _4944,_4953 )]);
        }
        auto _9094 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9092.size()),_9092.begin(),_9092.end()));
        ptrb = _9094;
        std::vector<long long> _9095;
        for (int _4954 = (int)0, _9096 = _4942; _4954 < _9096 ; ++_4954)
        {
          _9095.push_back(_ptr__4950[safe_add( _4946,_4954 )]);
        }
        auto _9097 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9095.size()),_9095.begin(),_9095.end()));
        subj = _9097;
        std::vector<double> _9098;
        for (int _4955 = (int)0, _9099 = _4942; _4955 < _9099 ; ++_4955)
        {
          _9098.push_back(_ptr__4951[safe_add( _4948,_4955 )]);
        }
        auto _9100 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9098.size()),_9098.begin(),_9098.end()));
        cof_v = _9100;
        std::vector<double> _9101;
        for (int _4956 = (int)0, _9102 = _4942; _4956 < _9102 ; ++_4956)
        {
          _9101.push_back(_ptr__4951[safe_add( _4947,_4956 )]);
        }
        auto _9103 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9101.size()),_9101.begin(),_9101.end()));
        bfix = _9103;
        std::shared_ptr< monty::ndarray< long long,1 > > _9104;
        bool _9105 = _4943;
        if (_9105)
        {
          std::vector<long long> _9106;
          for (int _4957 = (int)0, _9107 = _4942; _4957 < _9107 ; ++_4957)
          {
            _9106.push_back(_ptr__4950[safe_add( _4945,_4957 )]);
          }
          auto _9108 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9106.size()),_9106.begin(),_9106.end()));
          _9104 = _9108;
        }
        else
        {
          _9104 = nullptr;
        }
        inst = _9104;
      }
    }
    if ((NULL == shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}long long mosek::fusion::p_Expr::prod(std::shared_ptr< monty::ndarray< int,1 > > _4958){
  _checked_ptr_1<int> _ptr__4958(_4958 ? _4958->raw() : nullptr, _4958 ? _4958->size(0) : 0);
  int _4959 = (int)1;
  int _9109 = (int)0;
  int _9110 = (int)((_4958)->size(0));
  for (int _4960 = _9109; _4960 < _9110; ++_4960)
  {
    {
      _4959 *= _ptr__4958[_4960];
    }
  }
  return _4959;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _4961){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _9111;
  for (int _4962 = (int)0, _9112 = (int)((_4961)->size(0)); _4962 < _9112 ; ++_4962)
  {
    for (int _4963 = (int)0, _9113 = (int)((((*_4961)(_4962)))->size(0)); _4963 < _9113 ; ++_4963)
    {
      _9111.push_back(((*((*_4961)(_4962)))(_4963)));
    }
  }
  auto _9114 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_9111.size()),_9111.begin(),_9111.end()));
  return _9114;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4964,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4965){
  if ((NULL == _4964.get()))
  {
    {
      return _4965;
    }
  }
  else if((NULL == _4965.get()))
  {
    {
      return _4964;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4966 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((_4964)->size(0)),(int)((_4965)->size(0)) ))));
      int _9115 = (int)0;
      int _9116 = (int)((_4964)->size(0));
      for (int _4967 = _9115; _4967 < _9116; ++_4967)
      {
        {
          ((*_4966)(_4967)) = ((*_4964)(_4967));
        }
      }
      int _9117 = (int)0;
      int _9118 = (int)((_4965)->size(0));
      for (int _4968 = _9117; _4968 < _9118; ++_4968)
      {
        {
          ((*_4966)(safe_add( _4968,(int)((_4964)->size(0)) ))) = ((*_4965)(_4968));
        }
      }
      return _4966;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::condense  ( monty::rc_ptr< ::mosek::fusion::Expression > _4969) { return mosek::fusion::p_Expr::condense(_4969); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::condense(monty::rc_ptr< ::mosek::fusion::Expression > _4969){
  return (::mosek::fusion::p_ExprCondense::_new_ExprCondense(_4969)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::flatten  ( monty::rc_ptr< ::mosek::fusion::Expression > _4970) { return mosek::fusion::p_Expr::flatten(_4970); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::flatten(monty::rc_ptr< ::mosek::fusion::Expression > _4970){
  if ((NULL == _4970.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for flatten may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_4970,(int)_4970->getSize());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _4971,    int _4972,    int _4973) { return mosek::fusion::p_Expr::reshape(_4971,_4972,_4973); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _4971,int _4972,int _4973){
  if ((NULL == _4971.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_4971,::mosek::fusion::p_Set::make(_4972,_4973));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _4974,    int _4975) { return mosek::fusion::p_Expr::reshape(_4974,_4975); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _4974,int _4975){
  if ((NULL == _4974.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_4974,::mosek::fusion::p_Set::make(_4975));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _4976,    std::shared_ptr< monty::ndarray< int,1 > > _4977) { return mosek::fusion::p_Expr::reshape(_4976,_4977); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _4976,std::shared_ptr< monty::ndarray< int,1 > > _4977){
  _checked_ptr_1<int> _ptr__4977(_4977 ? _4977->raw() : nullptr, _4977 ? _4977->size(0) : 0);
  return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_4977,_4976)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: size() { return mosek::fusion::p_Expr::_get_impl(this)->size(); }long long mosek::fusion::p_Expr::size(){
  return ((long long)((ptrb)->size(0)) - (int)1);
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr :: __mosek_2fusion_2Expr__eval() { return mosek::fusion::p_Expr::_get_impl(this)->__mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::eval() { return __mosek_2fusion_2Expr__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::__mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_Expr::__mosek_2fusion_2Expr__eval(){
  std::shared_ptr< monty::ndarray< double,1 > > _9119;
  bool _9120 = (NULL == bfix.get());
  if (_9120)
  {
    _9119 = nullptr;
  }
  else
  {
    _9119 = ::mosek::fusion::Utils::Tools::arraycopy(bfix);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _4978 = _9119;
  _checked_ptr_1<double> _ptr__4978(_4978 ? _4978->raw() : nullptr,_4978 ? _4978->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9121;
  bool _9122 = (NULL == inst.get());
  if (_9122)
  {
    _9121 = nullptr;
  }
  else
  {
    _9121 = ::mosek::fusion::Utils::Tools::arraycopy(inst);
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _4979 = _9121;
  _checked_ptr_1<long long> _ptr__4979(_4979 ? _4979->raw() : nullptr,_4979 ? _4979->size(0) : 0);
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_4978,::mosek::fusion::Utils::Tools::arraycopy(ptrb),::mosek::fusion::Utils::Tools::arraycopy(subj),::mosek::fusion::Utils::Tools::arraycopy(cof_v),shape,inst);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( std::shared_ptr< monty::ndarray< int,1 > > _4980) { return mosek::fusion::p_Expr::zeros(_4980); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(std::shared_ptr< monty::ndarray< int,1 > > _4980){
  _checked_ptr_1<int> _ptr__4980(_4980 ? _4980->raw() : nullptr, _4980 ? _4980->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_4980,std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),(double)((int)0))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( int _4981) { return mosek::fusion::p_Expr::zeros(_4981); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(int _4981){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4981)}),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),(double)((int)0))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( ) { return mosek::fusion::p_Expr::ones(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(){
  return ::mosek::fusion::p_Expr::constTerm((double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _4982,    std::shared_ptr< monty::ndarray< int,2 > > _4983) { return mosek::fusion::p_Expr::ones(_4982,_4983); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _4982,std::shared_ptr< monty::ndarray< int,2 > > _4983){
  _checked_ptr_1<int> _ptr__4982(_4982 ? _4982->raw() : nullptr, _4982 ? _4982->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_4982,_4983,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _4984) { return mosek::fusion::p_Expr::ones(_4984); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _4984){
  _checked_ptr_1<int> _ptr__4984(_4984 ? _4984->raw() : nullptr, _4984 ? _4984->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_4984,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( int _4985) { return mosek::fusion::p_Expr::ones(_4985); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(int _4985){
  return ::mosek::fusion::p_Expr::constTerm(_4985,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _4986) { return mosek::fusion::p_Expr::constTerm(_4986); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _4986){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(mosek::fusion::p_NDSparseArray::_get_impl(_4986)->dims,mosek::fusion::p_NDSparseArray::_get_impl(_4986)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_4986)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _4987) { return mosek::fusion::p_Expr::constTerm(_4987); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _4987){
  int _4988 = _4987->numRows();
  int _4989 = _4987->numColumns();
  std::shared_ptr< monty::ndarray< int,1 > > _4990 = ::mosek::fusion::p_Set::make(_4988,_4989);
  _checked_ptr_1<int> _ptr__4990(_4990 ? _4990->raw() : nullptr,_4990 ? _4990->size(0) : 0);
  if (_4987->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _4991 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4987->numNonzeros())));
      _checked_ptr_1<double> _ptr__4991(_4991 ? _4991->raw() : nullptr,_4991 ? _4991->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4992 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4987->numNonzeros())));
      _checked_ptr_1<int> _ptr__4992(_4992 ? _4992->raw() : nullptr,_4992 ? _4992->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4993 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4987->numNonzeros())));
      _checked_ptr_1<int> _ptr__4993(_4993 ? _4993->raw() : nullptr,_4993 ? _4993->size(0) : 0);
      _4987->getDataAsTriplets(_4993,_4992,_4991);
      std::vector<long long> _9123;
      for (int _4995 = (int)0, _9124 = (int)((_4992)->size(0)); _4995 < _9124 ; ++_4995)
      {
        _9123.push_back(safe_add( safe_mul( _ptr__4993[_4995],_4989 ),_ptr__4992[_4995] ));
      }
      auto _9125 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9123.size()),_9123.begin(),_9123.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _4994 = _9125;
      _checked_ptr_1<long long> _ptr__4994(_4994 ? _4994->raw() : nullptr,_4994 ? _4994->size(0) : 0);
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_4990,_4994,_4991)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_4990,nullptr,_4987->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( double _4996) { return mosek::fusion::p_Expr::constTerm(_4996); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(double _4996){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,_4996)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _4997,    std::shared_ptr< monty::ndarray< int,2 > > _4998,    double _4999) { return mosek::fusion::p_Expr::constTerm(_4997,_4998,_4999); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _4997,std::shared_ptr< monty::ndarray< int,2 > > _4998,double _4999){
  _checked_ptr_1<int> _ptr__4997(_4997 ? _4997->raw() : nullptr, _4997 ? _4997->size(0) : 0);
  int _5000 = (int)((_4998)->size(0));
  int _5001 = (int)((_4997)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5002 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5000)));
  _checked_ptr_1<long long> _ptr__5002(_5002 ? _5002->raw() : nullptr,_5002 ? _5002->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5003 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5001)));
  _checked_ptr_1<long long> _ptr__5003(_5003 ? _5003->raw() : nullptr,_5003 ? _5003->size(0) : 0);
  _ptr__5003[(_5001 - (int)1)] = (int)1;
  int _9126 = (int)1;
  int _9127 = _5001;
  for (int _5004 = _9126; _5004 < _9127; ++_5004)
  {
    {
      _ptr__5003[((_5001 - _5004) - (int)1)] = safe_mul( _ptr__5003[(_5001 - _5004)],_ptr__4997[(_5001 - _5004)] );
    }
  }
  int _9128 = (int)0;
  int _9129 = _5000;
  for (int _5005 = _9128; _5005 < _9129; ++_5005)
  {
    {
      int _9130 = (int)0;
      int _9131 = _5001;
      for (int _5006 = _9130; _5006 < _9131; ++_5006)
      {
        {
          _ptr__5002[_5005] += safe_mul( _ptr__5003[_5006],((*_4998)(_5005,_5006)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_4997,_5002,_4999)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5007,    std::shared_ptr< monty::ndarray< int,2 > > _5008,    std::shared_ptr< monty::ndarray< double,1 > > _5009) { return mosek::fusion::p_Expr::constTerm(_5007,_5008,_5009); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5007,std::shared_ptr< monty::ndarray< int,2 > > _5008,std::shared_ptr< monty::ndarray< double,1 > > _5009){
  _checked_ptr_1<int> _ptr__5007(_5007 ? _5007->raw() : nullptr, _5007 ? _5007->size(0) : 0);
  _checked_ptr_1<double> _ptr__5009(_5009 ? _5009->raw() : nullptr, _5009 ? _5009->size(0) : 0);
  int _5010 = (int)((_5008)->size(0));
  int _5011 = (int)((_5007)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5012 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5010)));
  _checked_ptr_1<long long> _ptr__5012(_5012 ? _5012->raw() : nullptr,_5012 ? _5012->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5013 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5011)));
  _checked_ptr_1<long long> _ptr__5013(_5013 ? _5013->raw() : nullptr,_5013 ? _5013->size(0) : 0);
  _ptr__5013[(_5011 - (int)1)] = (int)1;
  int _9132 = (int)1;
  int _9133 = _5011;
  for (int _5014 = _9132; _5014 < _9133; ++_5014)
  {
    {
      _ptr__5013[((_5011 - _5014) - (int)1)] = safe_mul( _ptr__5013[(_5011 - _5014)],_ptr__5007[(_5011 - _5014)] );
    }
  }
  int _9134 = (int)0;
  int _9135 = _5010;
  for (int _5015 = _9134; _5015 < _9135; ++_5015)
  {
    {
      int _9136 = (int)0;
      int _9137 = _5011;
      for (int _5016 = _9136; _5016 < _9137; ++_5016)
      {
        {
          _ptr__5012[_5015] += safe_mul( _ptr__5013[_5016],((*_5008)(_5015,_5016)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5007,_5012,_5009)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5017,    double _5018) { return mosek::fusion::p_Expr::constTerm(_5017,_5018); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5017,double _5018){
  _checked_ptr_1<int> _ptr__5017(_5017 ? _5017->raw() : nullptr, _5017 ? _5017->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5017,nullptr,_5018)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( int _5019,    double _5020) { return mosek::fusion::p_Expr::constTerm(_5019,_5020); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(int _5019,double _5020){
  std::vector<double> _9138;
  for (int _5021 = (int)0, _9139 = _5019; _5021 < _9139 ; ++_5021)
  {
    _9138.push_back(_5020);
  }
  auto _9140 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9138.size()),_9138.begin(),_9138.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5019)}),nullptr,_9140)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,2 > > _5022) { return mosek::fusion::p_Expr::constTerm(_5022); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5022){
  std::vector<double> _9141;
  for (int _5023 = (int)0, _9142 = (int)((_5022)->size(0)); _5023 < _9142 ; ++_5023)
  {
    for (int _5024 = (int)0, _9143 = (int)((_5022)->size(1)); _5024 < _9143 ; ++_5024)
    {
      _9141.push_back(((*_5022)(_5023,_5024)));
    }
  }
  auto _9144 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9141.size()),_9141.begin(),_9141.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5022)->size(0))),(int)((int)((_5022)->size(1)))}),nullptr,_9144)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,1 > > _5025) { return mosek::fusion::p_Expr::constTerm(_5025); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5025){
  _checked_ptr_1<double> _ptr__5025(_5025 ? _5025->raw() : nullptr, _5025 ? _5025->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5025)->size(0)))}),nullptr,_5025)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: numNonzeros() { return mosek::fusion::p_Expr::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_Expr::numNonzeros(){
  return (long long)((cof_v)->size(0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5026,    int _5027) { return mosek::fusion::p_Expr::sum(_5026,_5027); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5026,int _5027){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce(_5027,_5026)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5028) { return mosek::fusion::p_Expr::sum(_5028); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5028){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce((int)0,::mosek::fusion::p_Expr::flatten(_5028))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::neg  ( monty::rc_ptr< ::mosek::fusion::Expression > _5029) { return mosek::fusion::p_Expr::neg(_5029); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::neg(monty::rc_ptr< ::mosek::fusion::Expression > _5029){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst((double)((-(int)1)),_5029)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(bool _5030,monty::rc_ptr< ::mosek::fusion::Matrix > _5031,monty::rc_ptr< ::mosek::fusion::Expression > _5032){
  long long _5033 = _5031->numNonzeros();
  int _5034 = _5031->numRows();
  int _5035 = _5031->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5036 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5033)));
  _checked_ptr_1<double> _ptr__5036(_5036 ? _5036->raw() : nullptr,_5036 ? _5036->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5037 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5033)));
  _checked_ptr_1<int> _ptr__5037(_5037 ? _5037->raw() : nullptr,_5037 ? _5037->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5038 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5033)));
  _checked_ptr_1<int> _ptr__5038(_5038 ? _5038->raw() : nullptr,_5038 ? _5038->size(0) : 0);
  _5031->getDataAsTriplets(_5038,_5037,_5036);
  if (_5030)
  {
    {
      return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft(_5034,_5035,_5038,_5037,_5036,_5032)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight(_5034,_5035,_5038,_5037,_5036,_5032)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5039,    monty::rc_ptr< ::mosek::fusion::Matrix > _5040) { return mosek::fusion::p_Expr::mulDiag(_5039,_5040); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5039,monty::rc_ptr< ::mosek::fusion::Matrix > _5040){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5040,_5039->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5041,    monty::rc_ptr< ::mosek::fusion::Variable > _5042) { return mosek::fusion::p_Expr::mulDiag(_5041,_5042); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5041,monty::rc_ptr< ::mosek::fusion::Variable > _5042){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5041,_5042->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5043,    monty::rc_ptr< ::mosek::fusion::Matrix > _5044) { return mosek::fusion::p_Expr::mulDiag(_5043,_5044); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5043,monty::rc_ptr< ::mosek::fusion::Matrix > _5044){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5044,_5043);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5045,    monty::rc_ptr< ::mosek::fusion::Expression > _5046) { return mosek::fusion::p_Expr::mulDiag(_5045,_5046); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5045,monty::rc_ptr< ::mosek::fusion::Expression > _5046){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5045,_5046);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5047,    std::shared_ptr< monty::ndarray< double,2 > > _5048) { return mosek::fusion::p_Expr::mulDiag(_5047,_5048); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5047,std::shared_ptr< monty::ndarray< double,2 > > _5048){
  std::vector<int> _9145;
  for (int _5049 = (int)0, _9146 = (int)((_5048)->size(0)); _5049 < _9146 ; ++_5049)
  {
    for (int _5050 = (int)0, _9147 = (int)((_5048)->size(1)); _5050 < _9147 ; ++_5050)
    {
      _9145.push_back(_5049);
    }
  }
  auto _9148 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9145.size()),_9145.begin(),_9145.end()));
  std::vector<int> _9149;
  for (int _5051 = (int)0, _9150 = (int)((_5048)->size(0)); _5051 < _9150 ; ++_5051)
  {
    for (int _5052 = (int)0, _9151 = (int)((_5048)->size(1)); _5052 < _9151 ; ++_5052)
    {
      _9149.push_back(_5052);
    }
  }
  auto _9152 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9149.size()),_9149.begin(),_9149.end()));
  std::vector<double> _9153;
  for (int _5053 = (int)0, _9154 = (int)((_5048)->size(0)); _5053 < _9154 ; ++_5053)
  {
    for (int _5054 = (int)0, _9155 = (int)((_5048)->size(1)); _5054 < _9155 ; ++_5054)
    {
      _9153.push_back(((*_5048)(_5053,_5054)));
    }
  }
  auto _9156 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9153.size()),_9153.begin(),_9153.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5048)->size(0)),(int)((_5048)->size(1)),_9148,_9152,_9156,_5047->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5055,    std::shared_ptr< monty::ndarray< double,2 > > _5056) { return mosek::fusion::p_Expr::mulDiag(_5055,_5056); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5055,std::shared_ptr< monty::ndarray< double,2 > > _5056){
  std::vector<int> _9157;
  for (int _5057 = (int)0, _9158 = (int)((_5056)->size(0)); _5057 < _9158 ; ++_5057)
  {
    for (int _5058 = (int)0, _9159 = (int)((_5056)->size(1)); _5058 < _9159 ; ++_5058)
    {
      _9157.push_back(_5057);
    }
  }
  auto _9160 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9157.size()),_9157.begin(),_9157.end()));
  std::vector<int> _9161;
  for (int _5059 = (int)0, _9162 = (int)((_5056)->size(0)); _5059 < _9162 ; ++_5059)
  {
    for (int _5060 = (int)0, _9163 = (int)((_5056)->size(1)); _5060 < _9163 ; ++_5060)
    {
      _9161.push_back(_5060);
    }
  }
  auto _9164 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9161.size()),_9161.begin(),_9161.end()));
  std::vector<double> _9165;
  for (int _5061 = (int)0, _9166 = (int)((_5056)->size(0)); _5061 < _9166 ; ++_5061)
  {
    for (int _5062 = (int)0, _9167 = (int)((_5056)->size(1)); _5062 < _9167 ; ++_5062)
    {
      _9165.push_back(((*_5056)(_5061,_5062)));
    }
  }
  auto _9168 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9165.size()),_9165.begin(),_9165.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5056)->size(0)),(int)((_5056)->size(1)),_9160,_9164,_9168,_5055)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5063,    monty::rc_ptr< ::mosek::fusion::Variable > _5064) { return mosek::fusion::p_Expr::mulDiag(_5063,_5064); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5063,monty::rc_ptr< ::mosek::fusion::Variable > _5064){
  std::vector<int> _9169;
  for (int _5065 = (int)0, _9170 = (int)((_5063)->size(0)); _5065 < _9170 ; ++_5065)
  {
    for (int _5066 = (int)0, _9171 = (int)((_5063)->size(1)); _5066 < _9171 ; ++_5066)
    {
      _9169.push_back(_5065);
    }
  }
  auto _9172 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9169.size()),_9169.begin(),_9169.end()));
  std::vector<int> _9173;
  for (int _5067 = (int)0, _9174 = (int)((_5063)->size(0)); _5067 < _9174 ; ++_5067)
  {
    for (int _5068 = (int)0, _9175 = (int)((_5063)->size(1)); _5068 < _9175 ; ++_5068)
    {
      _9173.push_back(_5068);
    }
  }
  auto _9176 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9173.size()),_9173.begin(),_9173.end()));
  std::vector<double> _9177;
  for (int _5069 = (int)0, _9178 = (int)((_5063)->size(0)); _5069 < _9178 ; ++_5069)
  {
    for (int _5070 = (int)0, _9179 = (int)((_5063)->size(1)); _5070 < _9179 ; ++_5070)
    {
      _9177.push_back(((*_5063)(_5069,_5070)));
    }
  }
  auto _9180 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9177.size()),_9177.begin(),_9177.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5063)->size(0)),(int)((_5063)->size(1)),_9172,_9176,_9180,_5064->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5071,    monty::rc_ptr< ::mosek::fusion::Expression > _5072) { return mosek::fusion::p_Expr::mulDiag(_5071,_5072); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5071,monty::rc_ptr< ::mosek::fusion::Expression > _5072){
  std::vector<int> _9181;
  for (int _5073 = (int)0, _9182 = (int)((_5071)->size(0)); _5073 < _9182 ; ++_5073)
  {
    for (int _5074 = (int)0, _9183 = (int)((_5071)->size(1)); _5074 < _9183 ; ++_5074)
    {
      _9181.push_back(_5073);
    }
  }
  auto _9184 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9181.size()),_9181.begin(),_9181.end()));
  std::vector<int> _9185;
  for (int _5075 = (int)0, _9186 = (int)((_5071)->size(0)); _5075 < _9186 ; ++_5075)
  {
    for (int _5076 = (int)0, _9187 = (int)((_5071)->size(1)); _5076 < _9187 ; ++_5076)
    {
      _9185.push_back(_5076);
    }
  }
  auto _9188 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9185.size()),_9185.begin(),_9185.end()));
  std::vector<double> _9189;
  for (int _5077 = (int)0, _9190 = (int)((_5071)->size(0)); _5077 < _9190 ; ++_5077)
  {
    for (int _5078 = (int)0, _9191 = (int)((_5071)->size(1)); _5078 < _9191 ; ++_5078)
    {
      _9189.push_back(((*_5071)(_5077,_5078)));
    }
  }
  auto _9192 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9189.size()),_9189.begin(),_9189.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5071)->size(0)),(int)((_5071)->size(1)),_9184,_9188,_9192,_5072)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5079,monty::rc_ptr< ::mosek::fusion::Expression > _5080){
  std::shared_ptr< monty::ndarray< int,1 > > _5081 = _5080->getShape();
  _checked_ptr_1<int> _ptr__5081(_5081 ? _5081->raw() : nullptr,_5081 ? _5081->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Expression > _5082 = _5080;
  if (((int)((_5081)->size(0)) == (int)1))
  {
    {
      _5081 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5081[(int)0]),(int)((int)1)});
      _ptr__5081.update(_5081 ? _5081->raw() : nullptr, _5081 ? _5081->size(0) : 0);
      _5082 = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5081,_5080)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5081)->size(0)) != (int)2) || ((_5079->numRows() != _ptr__5081[(int)0]) || (_5079->numColumns() != _ptr__5081[(int)1]))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  {}
  int _5083 = _5079->numColumns();
  long long _5084 = _5079->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5085 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5084)));
  _checked_ptr_1<int> _ptr__5085(_5085 ? _5085->raw() : nullptr,_5085 ? _5085->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5086 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5084)));
  _checked_ptr_1<int> _ptr__5086(_5086 ? _5086->raw() : nullptr,_5086 ? _5086->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5087 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5084)));
  _checked_ptr_1<double> _ptr__5087(_5087 ? _5087->raw() : nullptr,_5087 ? _5087->size(0) : 0);
  _5079->getDataAsTriplets(_5085,_5086,_5087);
  std::vector<long long> _9193;
  for (long long _5088 = (int)0, _9194 = _5084; _5088 < _9194 ; ++_5088)
  {
    _9193.push_back(safe_add( safe_mul( _ptr__5085[_5088],_5083 ),_ptr__5086[_5088] ));
  }
  auto _9195 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9193.size()),_9193.begin(),_9193.end()));
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5087,_9195,_5082,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5089,monty::rc_ptr< ::mosek::fusion::Expression > _5090){
  _checked_ptr_1<double> _ptr__5089(_5089 ? _5089->raw() : nullptr, _5089 ? _5089->size(0) : 0);
  if (((NULL == _5089.get()) || (NULL == _5090.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  if (((_5090->getND() == (int)0) && ((int)((_5089)->size(0)) == (int)1)))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_ptr__5089[(int)0],_5090)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_5090->getND() != (int)1) || (_5090->getDim((int)0) != (int)((_5089)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  else
  {
    {
      std::vector<long long> _9196;
      for (int _5091 = (int)0, _9197 = (int)((_5089)->size(0)); _5091 < _9197 ; ++_5091)
      {
        _9196.push_back(_5091);
      }
      auto _9198 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9196.size()),_9196.begin(),_9196.end()));
      return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5089,_9198,_5090)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5092,monty::rc_ptr< ::mosek::fusion::Expression > _5093){
  if (((NULL == _5092.get()) || (NULL == _5093.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _5094 = _5093->getShape();
  _checked_ptr_1<int> _ptr__5094(_5094 ? _5094->raw() : nullptr,_5094 ? _5094->size(0) : 0);
  if (((int)((_5094)->size(0)) != (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5092)->dims)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Dimension mismatch"));
    }
  }
  {}
  int _9199 = (int)0;
  int _9200 = (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5092)->dims)->size(0));
  for (int _5095 = _9199; _5095 < _9200; ++_5095)
  {
    {
      if ((((*mosek::fusion::p_NDSparseArray::_get_impl(_5092)->dims)(_5095)) != _ptr__5094[_5095]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(mosek::fusion::p_NDSparseArray::_get_impl(_5092)->cof,mosek::fusion::p_NDSparseArray::_get_impl(_5092)->inst,_5093)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5096,    double _5097) { return mosek::fusion::p_Expr::mul(_5096,_5097); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5096,double _5097){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5097,_5096)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( double _5098,    monty::rc_ptr< ::mosek::fusion::Expression > _5099) { return mosek::fusion::p_Expr::mul(_5098,_5099); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(double _5098,monty::rc_ptr< ::mosek::fusion::Expression > _5099){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5098,_5099)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5100,    std::shared_ptr< monty::ndarray< double,1 > > _5101) { return mosek::fusion::p_Expr::mul(_5100,_5101); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5100,std::shared_ptr< monty::ndarray< double,1 > > _5101){
  _checked_ptr_1<double> _ptr__5101(_5101 ? _5101->raw() : nullptr, _5101 ? _5101->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(false,_5101,_5100);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,1 > > _5102,    monty::rc_ptr< ::mosek::fusion::Expression > _5103) { return mosek::fusion::p_Expr::mul(_5102,_5103); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,1 > > _5102,monty::rc_ptr< ::mosek::fusion::Expression > _5103){
  _checked_ptr_1<double> _ptr__5102(_5102 ? _5102->raw() : nullptr, _5102 ? _5102->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(true,_5102,_5103);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5104,    std::shared_ptr< monty::ndarray< double,2 > > _5105) { return mosek::fusion::p_Expr::mul(_5104,_5105); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5104,std::shared_ptr< monty::ndarray< double,2 > > _5105){
  return ::mosek::fusion::p_Expr::mul(false,_5105,_5104);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,2 > > _5106,    monty::rc_ptr< ::mosek::fusion::Expression > _5107) { return mosek::fusion::p_Expr::mul(_5106,_5107); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,2 > > _5106,monty::rc_ptr< ::mosek::fusion::Expression > _5107){
  return ::mosek::fusion::p_Expr::mul(true,_5106,_5107);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5108,    monty::rc_ptr< ::mosek::fusion::Matrix > _5109) { return mosek::fusion::p_Expr::mul(_5108,_5109); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5108,monty::rc_ptr< ::mosek::fusion::Matrix > _5109){
  return ::mosek::fusion::p_Expr::mul(false,_5109,_5108);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5110,    monty::rc_ptr< ::mosek::fusion::Expression > _5111) { return mosek::fusion::p_Expr::mul(_5110,_5111); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5110,monty::rc_ptr< ::mosek::fusion::Expression > _5111){
  return ::mosek::fusion::p_Expr::mul(true,_5110,_5111);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5112,std::shared_ptr< monty::ndarray< double,1 > > _5113,monty::rc_ptr< ::mosek::fusion::Expression > _5114){
  _checked_ptr_1<double> _ptr__5113(_5113 ? _5113->raw() : nullptr, _5113 ? _5113->size(0) : 0);
  int _5115 = (int)((_5113)->size(0));
  int _5116 = _5115;
  std::shared_ptr< monty::ndarray< double,1 > > _5117 = ::mosek::fusion::Utils::Tools::arraycopy(_5113);
  _checked_ptr_1<double> _ptr__5117(_5117 ? _5117->raw() : nullptr,_5117 ? _5117->size(0) : 0);
  int _5118 = _5114->getND();
  if ((_5118 == (int)0))
  {
    {
      std::vector<int> _9201;
      for (int _5119 = (int)0, _9202 = _5115; _5119 < _9202 ; ++_5119)
      {
        _9201.push_back(_5119);
      }
      auto _9203 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9201.size()),_9201.begin(),_9201.end()));
      std::vector<int> _9204;
      for (int _5120 = (int)0, _9205 = _5115; _5120 < _9205 ; ++_5120)
      {
        _9204.push_back((int)0);
      }
      auto _9206 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9204.size()),_9204.begin(),_9204.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5115)}),(::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5115,(int)1,_9203,_9206,_5117,_5114,(int)1)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5118 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else if((_5112 && (_5114->getDim((int)0) == (int)((_5113)->size(0)))))
  {
    {
      std::vector<int> _9207;
      for (int _5121 = (int)0, _9208 = _5115; _5121 < _9208 ; ++_5121)
      {
        _9207.push_back((int)0);
      }
      auto _9209 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9207.size()),_9207.begin(),_9207.end()));
      std::vector<int> _9210;
      for (int _5122 = (int)0, _9211 = _5115; _5122 < _9211 ; ++_5122)
      {
        _9210.push_back(_5122);
      }
      auto _9212 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9210.size()),_9210.begin(),_9210.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5114->getDim((int)1))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft((int)1,_5115,_9209,_9212,_5117,_5114)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5112 && (_5114->getDim((int)0) == (int)1)))
  {
    {
      std::vector<int> _9213;
      for (int _5123 = (int)0, _9214 = _5115; _5123 < _9214 ; ++_5123)
      {
        _9213.push_back(_5123);
      }
      auto _9215 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9213.size()),_9213.begin(),_9213.end()));
      std::vector<int> _9216;
      for (int _5124 = (int)0, _9217 = _5115; _5124 < _9217 ; ++_5124)
      {
        _9216.push_back((int)0);
      }
      auto _9218 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9216.size()),_9216.begin(),_9216.end()));
      return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5115,(int)1,_9215,_9218,_5117,_5114,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5112) && (_5114->getDim((int)1) == _5115)))
  {
    {
      std::vector<int> _9219;
      for (int _5125 = (int)0, _9220 = _5115; _5125 < _9220 ; ++_5125)
      {
        _9219.push_back(_5125);
      }
      auto _9221 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9219.size()),_9219.begin(),_9219.end()));
      std::vector<int> _9222;
      for (int _5126 = (int)0, _9223 = _5115; _5126 < _9223 ; ++_5126)
      {
        _9222.push_back((int)0);
      }
      auto _9224 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9222.size()),_9222.begin(),_9222.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5114->getDim((int)0))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5115,(int)1,_9221,_9224,_5117,_5114)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5112) && (_5114->getDim((int)1) == (int)1)))
  {
    {
      std::vector<int> _9225;
      for (int _5127 = (int)0, _9226 = _5115; _5127 < _9226 ; ++_5127)
      {
        _9225.push_back((int)0);
      }
      auto _9227 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9225.size()),_9225.begin(),_9225.end()));
      std::vector<int> _9228;
      for (int _5128 = (int)0, _9229 = _5115; _5128 < _9229 ; ++_5128)
      {
        _9228.push_back(_5128);
      }
      auto _9230 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9228.size()),_9228.begin(),_9228.end()));
      return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight((int)1,_5115,_9227,_9230,_5117,_5114,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5129,std::shared_ptr< monty::ndarray< double,2 > > _5130,monty::rc_ptr< ::mosek::fusion::Expression > _5131){
  int _5132 = (int)((_5130)->size(0));
  int _5133 = (int)((_5130)->size(1));
  int _5134 = safe_mul( _5132,_5133 );
  std::vector<int> _9231;
  for (int _5136 = (int)0, _9232 = _5132; _5136 < _9232 ; ++_5136)
  {
    for (int _5137 = (int)0, _9233 = _5133; _5137 < _9233 ; ++_5137)
    {
      _9231.push_back(_5136);
    }
  }
  auto _9234 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9231.size()),_9231.begin(),_9231.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5135 = _9234;
  _checked_ptr_1<int> _ptr__5135(_5135 ? _5135->raw() : nullptr,_5135 ? _5135->size(0) : 0);
  std::vector<int> _9235;
  for (int _5139 = (int)0, _9236 = _5132; _5139 < _9236 ; ++_5139)
  {
    for (int _5140 = (int)0, _9237 = _5133; _5140 < _9237 ; ++_5140)
    {
      _9235.push_back(_5140);
    }
  }
  auto _9238 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9235.size()),_9235.begin(),_9235.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5138 = _9238;
  _checked_ptr_1<int> _ptr__5138(_5138 ? _5138->raw() : nullptr,_5138 ? _5138->size(0) : 0);
  std::vector<double> _9239;
  for (int _5142 = (int)0, _9240 = _5132; _5142 < _9240 ; ++_5142)
  {
    for (int _5143 = (int)0, _9241 = _5133; _5143 < _9241 ; ++_5143)
    {
      _9239.push_back(((*_5130)(_5142,_5143)));
    }
  }
  auto _9242 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9239.size()),_9239.begin(),_9239.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5141 = _9242;
  _checked_ptr_1<double> _ptr__5141(_5141 ? _5141->raw() : nullptr,_5141 ? _5141->size(0) : 0);
  long long _5144 = _5131->getSize();
  std::shared_ptr< monty::ndarray< int,1 > > _5145 = _5131->getShape();
  _checked_ptr_1<int> _ptr__5145(_5145 ? _5145->raw() : nullptr,_5145 ? _5145->size(0) : 0);
  if (((int)((_5145)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5132,_5133,_5135,_5138,_5141,_5131,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(_5129)
  {
    {
      if (((int)((_5145)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5130)->size(0)))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5132,_5133,_5135,_5138,_5141,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5145[(int)0]),(int)((int)1)}),_5131)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5145)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5132,_5133,_5135,_5138,_5141,_5131)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_5145)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5130)->size(1)))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5132,_5133,_5135,_5138,_5141,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5145[(int)0])}),_5131)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5145)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight((_5132 - (int)1),_5133,_5135,_5138,_5141,_5131)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5146,monty::rc_ptr< ::mosek::fusion::Matrix > _5147,monty::rc_ptr< ::mosek::fusion::Expression > _5148){
  long long _5149 = _5147->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5150 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5149)));
  _checked_ptr_1<int> _ptr__5150(_5150 ? _5150->raw() : nullptr,_5150 ? _5150->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5151 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5149)));
  _checked_ptr_1<int> _ptr__5151(_5151 ? _5151->raw() : nullptr,_5151 ? _5151->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5152 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5149)));
  _checked_ptr_1<double> _ptr__5152(_5152 ? _5152->raw() : nullptr,_5152 ? _5152->size(0) : 0);
  int _5153 = _5147->numRows();
  int _5154 = _5147->numColumns();
  _5147->getDataAsTriplets(_5150,_5151,_5152);
  int _5155 = _5148->getND();
  if ((_5155 == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5153,_5154,_5150,_5151,_5152,_5148)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5155 == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5156 = _5148->getShape();
      _checked_ptr_1<int> _ptr__5156(_5156 ? _5156->raw() : nullptr,_5156 ? _5156->size(0) : 0);
      if (_5146)
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5153)}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5153,_5154,_5150,_5151,_5152,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5156[(int)0]),(int)((int)1)}),_5148)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5154)}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5153,_5154,_5150,_5151,_5152,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5156[(int)0])}),_5148)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else if((_5155 == (int)2))
  {
    {
      if (_5146)
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5153,_5154,_5150,_5151,_5152,_5148)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5153,_5154,_5150,_5151,_5152,_5148)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions for multiplication"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Variable > _5157,    monty::rc_ptr< ::mosek::fusion::Matrix > _5158) { return mosek::fusion::p_Expr::mul(_5157,_5158); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Variable > _5157,monty::rc_ptr< ::mosek::fusion::Matrix > _5158){
  int _5159 = _5158->numRows();
  int _5160 = _5158->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5161 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5158->numNonzeros())));
  _checked_ptr_1<double> _ptr__5161(_5161 ? _5161->raw() : nullptr,_5161 ? _5161->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5162 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5158->numNonzeros())));
  _checked_ptr_1<int> _ptr__5162(_5162 ? _5162->raw() : nullptr,_5162 ? _5162->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5163 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5158->numNonzeros())));
  _checked_ptr_1<int> _ptr__5163(_5163 ? _5163->raw() : nullptr,_5163 ? _5163->size(0) : 0);
  _5158->getDataAsTriplets(_5163,_5162,_5161);
  return ::mosek::fusion::p_Expr::mul(false,_5159,_5160,_5163,_5162,_5161,_5157);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5164,    monty::rc_ptr< ::mosek::fusion::Variable > _5165) { return mosek::fusion::p_Expr::mul(_5164,_5165); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5164,monty::rc_ptr< ::mosek::fusion::Variable > _5165){
  int _5166 = _5164->numRows();
  int _5167 = _5164->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5168 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5164->numNonzeros())));
  _checked_ptr_1<double> _ptr__5168(_5168 ? _5168->raw() : nullptr,_5168 ? _5168->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5169 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5164->numNonzeros())));
  _checked_ptr_1<int> _ptr__5169(_5169 ? _5169->raw() : nullptr,_5169 ? _5169->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5170 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5164->numNonzeros())));
  _checked_ptr_1<int> _ptr__5170(_5170 ? _5170->raw() : nullptr,_5170 ? _5170->size(0) : 0);
  _5164->getDataAsTriplets(_5170,_5169,_5168);
  return ::mosek::fusion::p_Expr::mul(true,_5166,_5167,_5170,_5169,_5168,_5165);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5171,int _5172,int _5173,std::shared_ptr< monty::ndarray< int,1 > > _5174,std::shared_ptr< monty::ndarray< int,1 > > _5175,std::shared_ptr< monty::ndarray< double,1 > > _5176,monty::rc_ptr< ::mosek::fusion::Variable > _5177){
  _checked_ptr_1<int> _ptr__5174(_5174 ? _5174->raw() : nullptr, _5174 ? _5174->size(0) : 0);
  _checked_ptr_1<int> _ptr__5175(_5175 ? _5175->raw() : nullptr, _5175 ? _5175->size(0) : 0);
  _checked_ptr_1<double> _ptr__5176(_5176 ? _5176->raw() : nullptr, _5176 ? _5176->size(0) : 0);
  if ((_5177->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar(_5172,_5173,_5174,_5175,_5176,_5177)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5177->getND() == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5178 = _5177->getShape();
      _checked_ptr_1<int> _ptr__5178(_5178 ? _5178->raw() : nullptr,_5178 ? _5178->size(0) : 0);
      int _9243;
      bool _9244 = _5171;
      if (_9244)
      {
        _9243 = _5172;
      }
      else
      {
        _9243 = _5173;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _9245;
      bool _9246 = _5171;
      if (_9246)
      {
        _9245 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5178[(int)0]),(int)((int)1)});
      }
      else
      {
        _9245 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5178[(int)0])});
      }
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_9243)}),(::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5171,_5172,_5173,_5174,_5175,_5176,::mosek::fusion::p_Var::reshape(_5177,_9245))).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5171,_5172,_5173,_5174,_5175,_5176,_5177)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5179,    monty::rc_ptr< ::mosek::fusion::Matrix > _5180) { return mosek::fusion::p_Expr::dot(_5179,_5180); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5179,monty::rc_ptr< ::mosek::fusion::Matrix > _5180){
  long long _5181 = _5180->numNonzeros();
  if ((!_5180->isSparse()))
  {
    {
      std::vector<long long> _9247;
      for (long long _5182 = (int)0, _9248 = _5181; _5182 < _9248 ; ++_5182)
      {
        _9247.push_back(_5182);
      }
      auto _9249 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9247.size()),_9247.begin(),_9247.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5179,_9249,_5180->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5183 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5181)));
      _checked_ptr_1<int> _ptr__5183(_5183 ? _5183->raw() : nullptr,_5183 ? _5183->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5184 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5181)));
      _checked_ptr_1<int> _ptr__5184(_5184 ? _5184->raw() : nullptr,_5184 ? _5184->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5185 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5181)));
      _checked_ptr_1<double> _ptr__5185(_5185 ? _5185->raw() : nullptr,_5185 ? _5185->size(0) : 0);
      int _5186 = _5180->numColumns();
      _5180->getDataAsTriplets(_5183,_5184,_5185);
      std::vector<long long> _9250;
      for (int _5187 = (int)0, _9251 = (int)((_5183)->size(0)); _5187 < _9251 ; ++_5187)
      {
        _9250.push_back(safe_add( safe_mul( _ptr__5183[_5187],_5186 ),_ptr__5184[_5187] ));
      }
      auto _9252 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9250.size()),_9250.begin(),_9250.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5179,_9252,_5185)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5188,    std::shared_ptr< monty::ndarray< double,2 > > _5189) { return mosek::fusion::p_Expr::dot(_5188,_5189); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5188,std::shared_ptr< monty::ndarray< double,2 > > _5189){
  std::vector<long long> _9253;
  for (int _5190 = (int)0, _9254 = safe_mul( (int)((_5189)->size(0)),(int)((_5189)->size(1)) ); _5190 < _9254 ; ++_5190)
  {
    _9253.push_back(_5190);
  }
  auto _9255 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9253.size()),_9253.begin(),_9253.end()));
  std::vector<double> _9256;
  for (int _5191 = (int)0, _9257 = (int)((_5189)->size(0)); _5191 < _9257 ; ++_5191)
  {
    for (int _5192 = (int)0, _9258 = (int)((_5189)->size(1)); _5192 < _9258 ; ++_5192)
    {
      _9256.push_back(((*_5189)(_5191,_5192)));
    }
  }
  auto _9259 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9256.size()),_9256.begin(),_9256.end()));
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5188,_9255,_9259)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5193,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5194) { return mosek::fusion::p_Expr::dot(_5193,_5194); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5193,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5194){
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5193,mosek::fusion::p_NDSparseArray::_get_impl(_5194)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5194)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5195,    std::shared_ptr< monty::ndarray< double,1 > > _5196) { return mosek::fusion::p_Expr::dot(_5195,_5196); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5195,std::shared_ptr< monty::ndarray< double,1 > > _5196){
  _checked_ptr_1<double> _ptr__5196(_5196 ? _5196->raw() : nullptr, _5196 ? _5196->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5197 = _5195->getShape();
  _checked_ptr_1<int> _ptr__5197(_5197 ? _5197->raw() : nullptr,_5197 ? _5197->size(0) : 0);
  if (((_5195->getSize() == (int)((_5196)->size(0))) && ((int)((_5197)->size(0)) > (int)1)))
  {
    {
      int _5198 = (int)0;
      int _9260 = (int)0;
      int _9261 = (int)((_5197)->size(0));
      for (int _5199 = _9260; _5199 < _9261; ++_5199)
      {
        {
          if ((_ptr__5197[_5199] > (int)1))
          {
            {
              ++ _5198;
            }
          }
          {}
        }
      }
      if ((_5198 > (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5200 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)_5195->getSize())});
          _checked_ptr_1<int> _ptr__5200(_5200 ? _5200->raw() : nullptr,_5200 ? _5200->size(0) : 0);
          return (::mosek::fusion::p_ExprInner::_new_ExprInner((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5200,_5195)).as<::mosek::fusion::Expression>(),_5196)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5195,_5196)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5201,    monty::rc_ptr< ::mosek::fusion::Expression > _5202) { return mosek::fusion::p_Expr::dot(_5201,_5202); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5201,monty::rc_ptr< ::mosek::fusion::Expression > _5202){
  return ::mosek::fusion::p_Expr::dot(_5202,_5201);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5203,    monty::rc_ptr< ::mosek::fusion::Expression > _5204) { return mosek::fusion::p_Expr::dot(_5203,_5204); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5203,monty::rc_ptr< ::mosek::fusion::Expression > _5204){
  return ::mosek::fusion::p_Expr::dot(_5204,_5203);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,2 > > _5205,    monty::rc_ptr< ::mosek::fusion::Expression > _5206) { return mosek::fusion::p_Expr::dot(_5205,_5206); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,2 > > _5205,monty::rc_ptr< ::mosek::fusion::Expression > _5206){
  return ::mosek::fusion::p_Expr::dot(_5206,_5205);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,1 > > _5207,    monty::rc_ptr< ::mosek::fusion::Expression > _5208) { return mosek::fusion::p_Expr::dot(_5207,_5208); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,1 > > _5207,monty::rc_ptr< ::mosek::fusion::Expression > _5208){
  _checked_ptr_1<double> _ptr__5207(_5207 ? _5207->raw() : nullptr, _5207 ? _5207->size(0) : 0);
  return ::mosek::fusion::p_Expr::dot(_5208,_5207);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5209,    monty::rc_ptr< ::mosek::fusion::Expression > _5210) { return mosek::fusion::p_Expr::outer(_5209,_5210); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5209,monty::rc_ptr< ::mosek::fusion::Expression > _5210){
  _checked_ptr_1<double> _ptr__5209(_5209 ? _5209->raw() : nullptr, _5209 ? _5209->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5211 = _5210->getShape();
  _checked_ptr_1<int> _ptr__5211(_5211 ? _5211->raw() : nullptr,_5211 ? _5211->size(0) : 0);
  if (((int)((_5211)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  if ((_ptr__5211[(int)0] != (int)((_5209)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Argument lengths do not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5212 = _5210->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9262;
  for (int _5213 = (int)0, _9263 = (int)((_5209)->size(0)); _5213 < _9263 ; ++_5213)
  {
    _9262.push_back(_5213);
  }
  auto _9264 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9262.size()),_9262.begin(),_9262.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5212)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5212)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5212)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5212)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5212)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5212)->inst,_5209,_9264,(int)((_5209)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Expression > _5214,    std::shared_ptr< monty::ndarray< double,1 > > _5215) { return mosek::fusion::p_Expr::outer(_5214,_5215); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Expression > _5214,std::shared_ptr< monty::ndarray< double,1 > > _5215){
  _checked_ptr_1<double> _ptr__5215(_5215 ? _5215->raw() : nullptr, _5215 ? _5215->size(0) : 0);
  if (((_5214->getND() != (int)1) || (_5214->getND() != (int)1)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5216 = _5214->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9265;
  for (int _5217 = (int)0, _9266 = (int)((_5215)->size(0)); _5217 < _9266 ; ++_5217)
  {
    _9265.push_back(_5217);
  }
  auto _9267 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9265.size()),_9265.begin(),_9265.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5216)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5216)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5216)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5216)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5216)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5216)->inst,_5215,_9267,(int)((_5215)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5218,    monty::rc_ptr< ::mosek::fusion::Variable > _5219) { return mosek::fusion::p_Expr::outer(_5218,_5219); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5218,monty::rc_ptr< ::mosek::fusion::Variable > _5219){
  std::shared_ptr< monty::ndarray< int,1 > > _5220 = _5219->getShape();
  _checked_ptr_1<int> _ptr__5220(_5220 ? _5220->raw() : nullptr,_5220 ? _5220->size(0) : 0);
  if ((!(((int)((_5220)->size(0)) == (int)1) || (((int)((_5220)->size(0)) == (int)2) && (_ptr__5220[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5218)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9268 = _5218;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9268.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5221 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9268.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5219,_ptr__5220[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5221)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5221)->data)->size(0)),true);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5222 = _9268;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5223 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5222->numNonzeros())));
      _checked_ptr_1<double> _ptr__5223(_5223 ? _5223->raw() : nullptr,_5223 ? _5223->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5224 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5222->numNonzeros())));
      _checked_ptr_1<int> _ptr__5224(_5224 ? _5224->raw() : nullptr,_5224 ? _5224->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5225 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5222->numNonzeros())));
      _checked_ptr_1<int> _ptr__5225(_5225 ? _5225->raw() : nullptr,_5225 ? _5225->size(0) : 0);
      _5222->getDataAsTriplets(_5225,_5224,_5223);
      return ::mosek::fusion::p_Expr::outer_(_5219,_ptr__5220[(int)0],_5223,_5225,mosek::fusion::p_Matrix::_get_impl(_5222)->dimi,true);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5226,    monty::rc_ptr< ::mosek::fusion::Matrix > _5227) { return mosek::fusion::p_Expr::outer(_5226,_5227); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5226,monty::rc_ptr< ::mosek::fusion::Matrix > _5227){
  std::shared_ptr< monty::ndarray< int,1 > > _5228 = _5226->getShape();
  _checked_ptr_1<int> _ptr__5228(_5228 ? _5228->raw() : nullptr,_5228 ? _5228->size(0) : 0);
  if ((!((_5226->getND() == (int)1) || ((_5226->getND() == (int)2) && (_ptr__5228[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5227)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9269 = _5227;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9269.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5229 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9269.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5226,_ptr__5228[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5229)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5229)->data)->size(0)),false);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5230 = _9269;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5231 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5230->numNonzeros())));
      _checked_ptr_1<double> _ptr__5231(_5231 ? _5231->raw() : nullptr,_5231 ? _5231->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5232 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5230->numNonzeros())));
      _checked_ptr_1<int> _ptr__5232(_5232 ? _5232->raw() : nullptr,_5232 ? _5232->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5233 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5227->numNonzeros())));
      _checked_ptr_1<int> _ptr__5233(_5233 ? _5233->raw() : nullptr,_5233 ? _5233->size(0) : 0);
      _5230->getDataAsTriplets(_5233,_5232,_5231);
      return ::mosek::fusion::p_Expr::outer_(_5226,((*_5226->getShape())((int)0)),_5231,_5233,mosek::fusion::p_Matrix::_get_impl(_5230)->dimi,false);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5234,    monty::rc_ptr< ::mosek::fusion::Variable > _5235) { return mosek::fusion::p_Expr::outer(_5234,_5235); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5234,monty::rc_ptr< ::mosek::fusion::Variable > _5235){
  _checked_ptr_1<double> _ptr__5234(_5234 ? _5234->raw() : nullptr, _5234 ? _5234->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5236 = _5235->getShape();
  _checked_ptr_1<int> _ptr__5236(_5236 ? _5236->raw() : nullptr,_5236 ? _5236->size(0) : 0);
  if ((!((_5235->getND() == (int)1) || ((_5235->getND() == (int)2) && (_ptr__5236[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5235,_ptr__5236[(int)0],_5234,nullptr,(int)((_5234)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5237,    std::shared_ptr< monty::ndarray< double,1 > > _5238) { return mosek::fusion::p_Expr::outer(_5237,_5238); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5237,std::shared_ptr< monty::ndarray< double,1 > > _5238){
  _checked_ptr_1<double> _ptr__5238(_5238 ? _5238->raw() : nullptr, _5238 ? _5238->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5239 = _5237->getShape();
  _checked_ptr_1<int> _ptr__5239(_5239 ? _5239->raw() : nullptr,_5239 ? _5239->size(0) : 0);
  if ((!((_5237->getND() == (int)1) || ((_5237->getND() == (int)2) && (_ptr__5239[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5237,_ptr__5239[(int)0],_5238,nullptr,(int)((_5238)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(int _5240,std::shared_ptr< monty::ndarray< long long,1 > > _5241,std::shared_ptr< monty::ndarray< long long,1 > > _5242,std::shared_ptr< monty::ndarray< double,1 > > _5243,std::shared_ptr< monty::ndarray< double,1 > > _5244,std::shared_ptr< monty::ndarray< long long,1 > > _5245,std::shared_ptr< monty::ndarray< double,1 > > _5246,std::shared_ptr< monty::ndarray< int,1 > > _5247,int _5248,bool _5249){
  _checked_ptr_1<long long> _ptr__5241(_5241 ? _5241->raw() : nullptr, _5241 ? _5241->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5242(_5242 ? _5242->raw() : nullptr, _5242 ? _5242->size(0) : 0);
  _checked_ptr_1<double> _ptr__5243(_5243 ? _5243->raw() : nullptr, _5243 ? _5243->size(0) : 0);
  _checked_ptr_1<double> _ptr__5244(_5244 ? _5244->raw() : nullptr, _5244 ? _5244->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5245(_5245 ? _5245->raw() : nullptr, _5245 ? _5245->size(0) : 0);
  _checked_ptr_1<double> _ptr__5246(_5246 ? _5246->raw() : nullptr, _5246 ? _5246->size(0) : 0);
  _checked_ptr_1<int> _ptr__5247(_5247 ? _5247->raw() : nullptr, _5247 ? _5247->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9270;
  bool _9271 = (!_5249);
  if (_9271)
  {
    _9270 = ::mosek::fusion::p_Set::make(_5240,_5248);
  }
  else
  {
    _9270 = ::mosek::fusion::p_Set::make(_5248,_5240);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5250 = _9270;
  _checked_ptr_1<int> _ptr__5250(_5250 ? _5250->raw() : nullptr,_5250 ? _5250->size(0) : 0);
  int _5251 = safe_mul( (int)((_5246)->size(0)),(int)((_5245)->size(0)) );
  int _5252 = safe_mul( (int)((_5246)->size(0)),(int)((_5242)->size(0)) );
  std::shared_ptr< monty::ndarray< long long,1 > > _5253 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5251)));
  _checked_ptr_1<long long> _ptr__5253(_5253 ? _5253->raw() : nullptr,_5253 ? _5253->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9272;
  bool _9273 = (NULL != _5244.get());
  if (_9273)
  {
    _9272 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5251)));
  }
  else
  {
    _9272 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5254 = _9272;
  _checked_ptr_1<double> _ptr__5254(_5254 ? _5254->raw() : nullptr,_5254 ? _5254->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5255 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5252)));
  _checked_ptr_1<double> _ptr__5255(_5255 ? _5255->raw() : nullptr,_5255 ? _5255->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5256 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5252)));
  _checked_ptr_1<long long> _ptr__5256(_5256 ? _5256->raw() : nullptr,_5256 ? _5256->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5257 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5251,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5257(_5257 ? _5257->raw() : nullptr,_5257 ? _5257->size(0) : 0);
  int _5258 = (int)_ptr__5257[((int)((_5257)->size(0)) - (int)1)];
  if ((!_5249))
  {
    {
      long long _5259 = (long long)0;
      long long _5260 = (long long)0;
      int _9274 = (int)0;
      int _9275 = (int)((_5245)->size(0));
      for (int _5261 = _9274; _5261 < _9275; ++_5261)
      {
        {
          long long _5262 = (_ptr__5241[safe_add( _5261,(int)1 )] - _ptr__5241[_5261]);
          int _9276 = (int)0;
          int _9277 = (int)((_5246)->size(0));
          for (int _5263 = _9276; _5263 < _9277; ++_5263)
          {
            {
              _ptr__5245[_5259] = safe_add( safe_mul( _ptr__5245[_5261],_5248 ),_ptr__5247[_5263] );
              _ptr__5257[safe_add( _5259,(int)1 )] = safe_add( _ptr__5257[_5259],_5262 );
              ++ _5259;
              long long _9278 = _ptr__5241[_5261];
              long long _9279 = _ptr__5241[safe_add( _5261,(int)1 )];
              for (long long _5264 = _9278; _5264 < _9279; ++_5264)
              {
                {
                  _ptr__5256[_5260] = _ptr__5242[_5264];
                  _ptr__5255[_5260] = (_ptr__5243[_5264] * _ptr__5246[_5263]);
                  ++ _5260;
                }
              }
            }
          }
        }
      }
      if ((NULL != _5254.get()))
      {
        {
          int _5265 = (int)0;
          int _9280 = (int)0;
          int _9281 = (int)((_5245)->size(0));
          for (int _5266 = _9280; _5266 < _9281; ++_5266)
          {
            {
              int _9282 = (int)0;
              int _9283 = (int)((_5246)->size(0));
              for (int _5267 = _9282; _5267 < _9283; ++_5267)
              {
                {
                  _ptr__5254[_5265] = (_ptr__5246[_5267] * _ptr__5244[_5266]);
                  ++ _5265;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  else
  {
    {
      long long _5268 = (long long)0;
      long long _5269 = (long long)0;
      int _9284 = (int)0;
      int _9285 = (int)((_5246)->size(0));
      for (int _5270 = _9284; _5270 < _9285; ++_5270)
      {
        {
          double _5271 = _ptr__5246[_5270];
          ::mosek::fusion::Utils::Tools::arraycopy(_5242,(long long)((int)0),_5256,_5269,(long long)(_5258));
          int _9286 = (int)0;
          int _9287 = _5258;
          for (int _5272 = _9286; _5272 < _9287; ++_5272)
          {
            {
              _ptr__5255[safe_add( _5269,_5272 )] = (_ptr__5243[_5272] * _ptr__5246[_5270]);
            }
          }
          int _9288 = (int)0;
          int _9289 = (int)((_5245)->size(0));
          for (int _5273 = _9288; _5273 < _9289; ++_5273)
          {
            {
              long long _5274 = (_ptr__5241[safe_add( _5273,(int)1 )] - _ptr__5241[_5273]);
              _ptr__5245[_5268] = safe_add( safe_mul( _ptr__5245[_5273],_5248 ),_ptr__5247[_5270] );
              _ptr__5257[safe_add( _5268,(int)1 )] = safe_add( _ptr__5257[_5268],_5274 );
              ++ _5268;
            }
          }
          _5269 += _5258;
        }
      }
      if ((NULL != _5254.get()))
      {
        {
          int _5275 = (int)0;
          int _9290 = (int)0;
          int _9291 = (int)((_5246)->size(0));
          for (int _5276 = _9290; _5276 < _9291; ++_5276)
          {
            {
              double _5277 = _ptr__5246[_5276];
              int _9292 = (int)0;
              int _9293 = (int)((_5245)->size(0));
              for (int _5278 = _9292; _5278 < _9293; ++_5278)
              {
                {
                  _ptr__5254[_5275] = (_ptr__5244[_5278] * _5277);
                  ++ _5275;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5257,_5256,_5255,_5254,_5250,_5253)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5279,int _5280,std::shared_ptr< monty::ndarray< double,1 > > _5281,std::shared_ptr< monty::ndarray< int,1 > > _5282,int _5283,bool _5284){
  _checked_ptr_1<double> _ptr__5281(_5281 ? _5281->raw() : nullptr, _5281 ? _5281->size(0) : 0);
  _checked_ptr_1<int> _ptr__5282(_5282 ? _5282->raw() : nullptr, _5282 ? _5282->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9294;
  bool _9295 = (!_5284);
  if (_9295)
  {
    _9294 = ::mosek::fusion::p_Set::make(_5280,_5283);
  }
  else
  {
    _9294 = ::mosek::fusion::p_Set::make(_5283,_5280);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5285 = _9294;
  _checked_ptr_1<int> _ptr__5285(_5285 ? _5285->raw() : nullptr,_5285 ? _5285->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9296;
  bool _9297 = (_5283 == (int)((_5281)->size(0)));
  if (_9297)
  {
    _9296 = nullptr;
  }
  else
  {
    _9296 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5281)->size(0)),_5280 ))));
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5286 = _9296;
  _checked_ptr_1<long long> _ptr__5286(_5286 ? _5286->raw() : nullptr,_5286 ? _5286->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5287 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5281)->size(0)),_5280 ))));
  _checked_ptr_1<double> _ptr__5287(_5287 ? _5287->raw() : nullptr,_5287 ? _5287->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5288 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5281)->size(0)),_5280 ))));
  _checked_ptr_1<double> _ptr__5288(_5288 ? _5288->raw() : nullptr,_5288 ? _5288->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5289 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5281)->size(0)),_5280 ))));
  _checked_ptr_1<long long> _ptr__5289(_5289 ? _5289->raw() : nullptr,_5289 ? _5289->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5290 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( safe_mul( (int)((_5281)->size(0)),_5280 ),(int)1 ))));
  _checked_ptr_1<long long> _ptr__5290(_5290 ? _5290->raw() : nullptr,_5290 ? _5290->size(0) : 0);
  if ((_5283 == (int)((_5281)->size(0))))
  {
    {
      long long _5291 = (long long)0;
      if ((!_5284))
      {
        {
          int _9298 = (int)0;
          int _9299 = _5280;
          for (int _5292 = _9298; _5292 < _9299; ++_5292)
          {
            {
              int _9300 = (int)0;
              int _9301 = _5283;
              for (int _5293 = _9300; _5293 < _9301; ++_5293)
              {
                {
                  _ptr__5290[safe_add( _5291,(int)1 )] = safe_add( _5291,(int)1 );
                  _ptr__5289[_5291] = (long long)_5292;
                  _ptr__5288[_5291] = _ptr__5281[_5293];
                  ++ _5291;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9302 = (int)0;
          int _9303 = _5283;
          for (int _5294 = _9302; _5294 < _9303; ++_5294)
          {
            {
              int _9304 = (int)0;
              int _9305 = _5280;
              for (int _5295 = _9304; _5295 < _9305; ++_5295)
              {
                {
                  _ptr__5290[safe_add( _5291,(int)1 )] = safe_add( _5291,(int)1 );
                  _ptr__5289[_5291] = (long long)_5295;
                  _ptr__5288[_5291] = _ptr__5281[_5294];
                  ++ _5291;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      long long _5296 = (long long)0;
      if ((!_5284))
      {
        {
          int _9306 = (int)0;
          int _9307 = _5280;
          for (int _5297 = _9306; _5297 < _9307; ++_5297)
          {
            {
              int _9308 = (int)0;
              int _9309 = (int)((_5281)->size(0));
              for (int _5298 = _9308; _5298 < _9309; ++_5298)
              {
                {
                  _ptr__5290[safe_add( _5296,(int)1 )] = safe_add( _5296,(int)1 );
                  _ptr__5289[_5296] = (long long)_5297;
                  _ptr__5288[_5296] = _ptr__5281[_5298];
                  _ptr__5286[_5296] = safe_add( safe_mul( _5297,_5283 ),_ptr__5282[_5298] );
                  ++ _5296;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9310 = (int)0;
          int _9311 = (int)((_5281)->size(0));
          for (int _5299 = _9310; _5299 < _9311; ++_5299)
          {
            {
              int _9312 = (int)0;
              int _9313 = _5280;
              for (int _5300 = _9312; _5300 < _9313; ++_5300)
              {
                {
                  _ptr__5290[safe_add( _5296,(int)1 )] = safe_add( _5296,(int)1 );
                  _ptr__5289[_5296] = (long long)_5300;
                  _ptr__5288[_5296] = _ptr__5281[_5299];
                  _ptr__5286[_5296] = safe_add( safe_mul( _ptr__5282[_5299],_5280 ),_5300 );
                  ++ _5296;
                }
              }
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5290,_5289,_5288,_5287,_5285,_5286)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5301) { return mosek::fusion::p_Expr::stack(_5301); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5301){
  if ((NULL == _5301.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9314 = (int)0;
  int _9315 = (int)((_5301)->size(0));
  for (int _5302 = _9314; _5302 < _9315; ++_5302)
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5303 = ((*_5301)(_5302));
      if ((NULL == _5303.get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
        }
      }
      {}
      int _9316 = (int)0;
      int _9317 = (int)((_5303)->size(0));
      for (int _5304 = _9316; _5304 < _9317; ++_5304)
      {
        {
          if ((NULL == ((*_5303)(_5304)).get()))
          {
            {
              throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9318;
  for (int _5306 = (int)0, _9319 = (int)((_5301)->size(0)); _5306 < _9319 ; ++_5306)
  {
    _9318.push_back(::mosek::fusion::p_Expr::stack_(((*_5301)(_5306)),(int)1));
  }
  auto _9320 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9318.size()),_9318.begin(),_9318.end()));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5305 = _9320;
  return ::mosek::fusion::p_Expr::stack_(_5305,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5307,    double _5308,    double _5309) { return mosek::fusion::p_Expr::vstack(_5307,_5308,_5309); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5307,double _5308,double _5309){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5307).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5308).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5309).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5310,    double _5311,    monty::rc_ptr< ::mosek::fusion::Expression > _5312) { return mosek::fusion::p_Expr::vstack(_5310,_5311,_5312); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5310,double _5311,monty::rc_ptr< ::mosek::fusion::Expression > _5312){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5310).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5311).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5312.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5313,    monty::rc_ptr< ::mosek::fusion::Expression > _5314,    double _5315) { return mosek::fusion::p_Expr::vstack(_5313,_5314,_5315); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5313,monty::rc_ptr< ::mosek::fusion::Expression > _5314,double _5315){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5313).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5314.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5315).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5316,    monty::rc_ptr< ::mosek::fusion::Expression > _5317,    monty::rc_ptr< ::mosek::fusion::Expression > _5318) { return mosek::fusion::p_Expr::vstack(_5316,_5317,_5318); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5316,monty::rc_ptr< ::mosek::fusion::Expression > _5317,monty::rc_ptr< ::mosek::fusion::Expression > _5318){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5316).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5317.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5318.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5319,    double _5320,    double _5321) { return mosek::fusion::p_Expr::vstack(_5319,_5320,_5321); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5319,double _5320,double _5321){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5319.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5320).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5321).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5322,    double _5323,    monty::rc_ptr< ::mosek::fusion::Expression > _5324) { return mosek::fusion::p_Expr::vstack(_5322,_5323,_5324); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5322,double _5323,monty::rc_ptr< ::mosek::fusion::Expression > _5324){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5322.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5323).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5324.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5325,    monty::rc_ptr< ::mosek::fusion::Expression > _5326,    double _5327) { return mosek::fusion::p_Expr::vstack(_5325,_5326,_5327); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5325,monty::rc_ptr< ::mosek::fusion::Expression > _5326,double _5327){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5325.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5326.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5327).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5328,    monty::rc_ptr< ::mosek::fusion::Expression > _5329,    monty::rc_ptr< ::mosek::fusion::Expression > _5330) { return mosek::fusion::p_Expr::vstack(_5328,_5329,_5330); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5328,monty::rc_ptr< ::mosek::fusion::Expression > _5329,monty::rc_ptr< ::mosek::fusion::Expression > _5330){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5328.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5329.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5330.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5331,    monty::rc_ptr< ::mosek::fusion::Expression > _5332) { return mosek::fusion::p_Expr::vstack(_5331,_5332); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5331,monty::rc_ptr< ::mosek::fusion::Expression > _5332){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5331).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5332.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5333,    double _5334) { return mosek::fusion::p_Expr::vstack(_5333,_5334); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5333,double _5334){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5333.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5334).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5335,    monty::rc_ptr< ::mosek::fusion::Expression > _5336) { return mosek::fusion::p_Expr::vstack(_5335,_5336); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5335,monty::rc_ptr< ::mosek::fusion::Expression > _5336){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5335.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5336.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5337) { return mosek::fusion::p_Expr::vstack(_5337); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5337){
  if ((NULL == _5337.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9321 = (int)0;
  int _9322 = (int)((_5337)->size(0));
  for (int _5338 = _9321; _5338 < _9322; ++_5338)
  {
    {
      if ((NULL == ((*_5337)(_5338)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for vstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5337,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5339,    monty::rc_ptr< ::mosek::fusion::Expression > _5340,    monty::rc_ptr< ::mosek::fusion::Expression > _5341) { return mosek::fusion::p_Expr::hstack(_5339,_5340,_5341); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5339,monty::rc_ptr< ::mosek::fusion::Expression > _5340,monty::rc_ptr< ::mosek::fusion::Expression > _5341){
  if (((NULL == _5339.get()) || ((NULL == _5340.get()) || (NULL == _5341.get()))))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments e1, e2 and e3 may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5339.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5340.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5341.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5342,    monty::rc_ptr< ::mosek::fusion::Expression > _5343,    double _5344) { return mosek::fusion::p_Expr::hstack(_5342,_5343,_5344); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5342,monty::rc_ptr< ::mosek::fusion::Expression > _5343,double _5344){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5342.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5343.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5344).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5345,    double _5346,    monty::rc_ptr< ::mosek::fusion::Expression > _5347) { return mosek::fusion::p_Expr::hstack(_5345,_5346,_5347); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5345,double _5346,monty::rc_ptr< ::mosek::fusion::Expression > _5347){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5345.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5346).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5347.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5348,    double _5349,    double _5350) { return mosek::fusion::p_Expr::hstack(_5348,_5349,_5350); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5348,double _5349,double _5350){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5348.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5349).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5350).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5351,    monty::rc_ptr< ::mosek::fusion::Expression > _5352,    monty::rc_ptr< ::mosek::fusion::Expression > _5353) { return mosek::fusion::p_Expr::hstack(_5351,_5352,_5353); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5351,monty::rc_ptr< ::mosek::fusion::Expression > _5352,monty::rc_ptr< ::mosek::fusion::Expression > _5353){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5351).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5352.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5353.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5354,    monty::rc_ptr< ::mosek::fusion::Expression > _5355,    double _5356) { return mosek::fusion::p_Expr::hstack(_5354,_5355,_5356); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5354,monty::rc_ptr< ::mosek::fusion::Expression > _5355,double _5356){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5354).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5355.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5356).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5357,    double _5358,    monty::rc_ptr< ::mosek::fusion::Expression > _5359) { return mosek::fusion::p_Expr::hstack(_5357,_5358,_5359); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5357,double _5358,monty::rc_ptr< ::mosek::fusion::Expression > _5359){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5357).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5358).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5359.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5360,    monty::rc_ptr< ::mosek::fusion::Expression > _5361) { return mosek::fusion::p_Expr::hstack(_5360,_5361); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5360,monty::rc_ptr< ::mosek::fusion::Expression > _5361){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5360).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5361.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5362,    double _5363) { return mosek::fusion::p_Expr::hstack(_5362,_5363); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5362,double _5363){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5362.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5363).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5364,    monty::rc_ptr< ::mosek::fusion::Expression > _5365) { return mosek::fusion::p_Expr::hstack(_5364,_5365); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5364,monty::rc_ptr< ::mosek::fusion::Expression > _5365){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5364.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5365.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5366) { return mosek::fusion::p_Expr::hstack(_5366); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5366){
  if ((NULL == _5366.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9323 = (int)0;
  int _9324 = (int)((_5366)->size(0));
  for (int _5367 = _9323; _5367 < _9324; ++_5367)
  {
    {
      if ((NULL == ((*_5366)(_5367)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for hstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5366,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5368,    monty::rc_ptr< ::mosek::fusion::Expression > _5369,    monty::rc_ptr< ::mosek::fusion::Expression > _5370,    monty::rc_ptr< ::mosek::fusion::Expression > _5371) { return mosek::fusion::p_Expr::stack(_5368,_5369,_5370,_5371); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5368,monty::rc_ptr< ::mosek::fusion::Expression > _5369,monty::rc_ptr< ::mosek::fusion::Expression > _5370,monty::rc_ptr< ::mosek::fusion::Expression > _5371){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5369.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5370.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5371.get())}),_5368);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5372,    monty::rc_ptr< ::mosek::fusion::Expression > _5373,    monty::rc_ptr< ::mosek::fusion::Expression > _5374,    double _5375) { return mosek::fusion::p_Expr::stack(_5372,_5373,_5374,_5375); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5372,monty::rc_ptr< ::mosek::fusion::Expression > _5373,monty::rc_ptr< ::mosek::fusion::Expression > _5374,double _5375){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5373.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5374.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5375).get())}),_5372);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5376,    monty::rc_ptr< ::mosek::fusion::Expression > _5377,    double _5378,    monty::rc_ptr< ::mosek::fusion::Expression > _5379) { return mosek::fusion::p_Expr::stack(_5376,_5377,_5378,_5379); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5376,monty::rc_ptr< ::mosek::fusion::Expression > _5377,double _5378,monty::rc_ptr< ::mosek::fusion::Expression > _5379){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5377.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5378).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5379.get())}),_5376);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5380,    monty::rc_ptr< ::mosek::fusion::Expression > _5381,    double _5382,    double _5383) { return mosek::fusion::p_Expr::stack(_5380,_5381,_5382,_5383); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5380,monty::rc_ptr< ::mosek::fusion::Expression > _5381,double _5382,double _5383){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5381.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5382).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5383).get())}),_5380);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5384,    double _5385,    monty::rc_ptr< ::mosek::fusion::Expression > _5386,    monty::rc_ptr< ::mosek::fusion::Expression > _5387) { return mosek::fusion::p_Expr::stack(_5384,_5385,_5386,_5387); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5384,double _5385,monty::rc_ptr< ::mosek::fusion::Expression > _5386,monty::rc_ptr< ::mosek::fusion::Expression > _5387){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5385).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5386.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5387.get())}),_5384);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5388,    double _5389,    monty::rc_ptr< ::mosek::fusion::Expression > _5390,    double _5391) { return mosek::fusion::p_Expr::stack(_5388,_5389,_5390,_5391); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5388,double _5389,monty::rc_ptr< ::mosek::fusion::Expression > _5390,double _5391){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5389).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5390.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5391).get())}),_5388);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5392,    double _5393,    double _5394,    monty::rc_ptr< ::mosek::fusion::Expression > _5395) { return mosek::fusion::p_Expr::stack(_5392,_5393,_5394,_5395); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5392,double _5393,double _5394,monty::rc_ptr< ::mosek::fusion::Expression > _5395){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5393).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5394).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5395.get())}),_5392);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5396,    double _5397,    monty::rc_ptr< ::mosek::fusion::Expression > _5398) { return mosek::fusion::p_Expr::stack(_5396,_5397,_5398); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5396,double _5397,monty::rc_ptr< ::mosek::fusion::Expression > _5398){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5397).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5398.get())}),_5396);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5399,    monty::rc_ptr< ::mosek::fusion::Expression > _5400,    double _5401) { return mosek::fusion::p_Expr::stack(_5399,_5400,_5401); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5399,monty::rc_ptr< ::mosek::fusion::Expression > _5400,double _5401){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5400.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5401).get())}),_5399);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5402,    monty::rc_ptr< ::mosek::fusion::Expression > _5403,    monty::rc_ptr< ::mosek::fusion::Expression > _5404) { return mosek::fusion::p_Expr::stack(_5402,_5403,_5404); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5402,monty::rc_ptr< ::mosek::fusion::Expression > _5403,monty::rc_ptr< ::mosek::fusion::Expression > _5404){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5403.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5404.get())}),_5402);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5405,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5406) { return mosek::fusion::p_Expr::stack(_5405,_5406); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5405,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5406){
  return ::mosek::fusion::p_Expr::stack_(_5406,_5405);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5407,int _5408){
  if (((int)((_5407)->size(0)) == (int)1))
  {
    {
      return ((*_5407)((int)0));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprStack::_new_ExprStack(::mosek::fusion::p_Expr::promote(_5407,_5408),_5408)).as<::mosek::fusion::Expression>();
    }
  }
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > mosek::fusion::p_Expr::promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5409,int _5410){
  int _5411 = (int)((_5409)->size(0));
  std::vector<int> _9325;
  for (int _5413 = (int)0, _9326 = _5411; _5413 < _9326 ; ++_5413)
  {
    _9325.push_back(((*_5409)(_5413))->getND());
  }
  auto _9327 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9325.size()),_9325.begin(),_9325.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5412 = _9327;
  _checked_ptr_1<int> _ptr__5412(_5412 ? _5412->raw() : nullptr,_5412 ? _5412->size(0) : 0);
  int _5414 = _ptr__5412[(int)0];
  int _5415 = _ptr__5412[(int)0];
  int _9328 = (int)1;
  int _9329 = _5411;
  for (int _5416 = _9328; _5416 < _9329; ++_5416)
  {
    {
      if ((_ptr__5412[_5416] < _5415))
      {
        {
          _5415 = _ptr__5412[_5416];
        }
      }
      {}
      if ((_ptr__5412[_5416] > _5414))
      {
        {
          _5414 = _ptr__5412[_5416];
        }
      }
      {}
    }
  }
  if ((_5414 < _5410))
  {
    {
      _5414 = _5410;
    }
  }
  {}
  if ((_5415 < _5414))
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5417 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_5411)));
      std::shared_ptr< monty::ndarray< int,1 > > _5418 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5414)));
      _checked_ptr_1<int> _ptr__5418(_5418 ? _5418->raw() : nullptr,_5418 ? _5418->size(0) : 0);
      int _9330 = (int)0;
      int _9331 = _5411;
      for (int _5419 = _9330; _5419 < _9331; ++_5419)
      {
        {
          if ((((*_5409)(_5419))->getND() == _5414))
          {
            {
              ((*_5417)(_5419)) = ((*_5409)(_5419));
            }
          }
          else
          {
            {
              std::shared_ptr< monty::ndarray< int,1 > > _5420 = ((*_5409)(_5419))->getShape();
              _checked_ptr_1<int> _ptr__5420(_5420 ? _5420->raw() : nullptr,_5420 ? _5420->size(0) : 0);
              int _9332 = (int)0;
              int _9333 = (int)((_5420)->size(0));
              for (int _5421 = _9332; _5421 < _9333; ++_5421)
              {
                {
                  _ptr__5418[_5421] = _ptr__5420[_5421];
                }
              }
              int _9334 = (int)((_5420)->size(0));
              int _9335 = _5414;
              for (int _5422 = _9334; _5422 < _9335; ++_5422)
              {
                {
                  _ptr__5418[_5422] = (int)1;
                }
              }
              ((*_5417)(_5419)) = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5418,((*_5409)(_5419)))).as<::mosek::fusion::Expression>();
            }
          }
        }
      }
      return _5417;
    }
  }
  else
  {
    {
      return _5409;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::repeat  ( monty::rc_ptr< ::mosek::fusion::Expression > _5423,    int _5424,    int _5425) { return mosek::fusion::p_Expr::repeat(_5423,_5424,_5425); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5423,int _5424,int _5425){
  if ((_5424 <= (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Cannot repeat Expression 0 or less times"));
    }
  }
  {}
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9336;
  for (int _5426 = (int)0, _9337 = _5424; _5426 < _9337 ; ++_5426)
  {
    _9336.push_back(_5423);
  }
  auto _9338 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9336.size()),_9336.begin(),_9336.end()));
  return ::mosek::fusion::p_Expr::stack_(_9338,_5425);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5427) { return mosek::fusion::p_Expr::add(_5427); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5427){
  std::vector<double> _9339;
  for (int _5428 = (int)0, _9340 = (int)((_5427)->size(0)); _5428 < _9340 ; ++_5428)
  {
    _9339.push_back(1.0);
  }
  auto _9341 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9339.size()),_9339.begin(),_9339.end()));
  return (::mosek::fusion::p_ExprWSum::_new_ExprWSum(_5427,_9341)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5429) { return mosek::fusion::p_Expr::add(_5429); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5429){
  if ((NULL == _5429.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may not be null"));
    }
  }
  {}
  if (((int)((_5429)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_Expr::_new_Expr(std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >{(long long)((int)0)}),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),nullptr,::mosek::fusion::p_Set::make((int)0),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5429)->size(0)) > (int)0) && (NULL == ((*_5429)((int)0)).get())))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may contain null"));
    }
  }
  {}
  int _5430 = ((*_5429)((int)0))->getND();
  int _9342 = (int)1;
  int _9343 = (int)((_5429)->size(0));
  for (int _5431 = _9342; _5431 < _9343; ++_5431)
  {
    {
      if ((_5430 < ((*_5429)(_5431))->getND()))
      {
        {
          _5430 = ((*_5429)(_5431))->getND();
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,2 > > _5432 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_5429)->size(0)),_5430)));
  int _9344 = (int)0;
  int _9345 = (int)((_5429)->size(0));
  for (int _5433 = _9344; _5433 < _9345; ++_5433)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5434 = ((*_5429)(_5433))->getShape();
      _checked_ptr_1<int> _ptr__5434(_5434 ? _5434->raw() : nullptr,_5434 ? _5434->size(0) : 0);
      int _9346 = (int)0;
      int _9347 = (int)((_5434)->size(0));
      for (int _5435 = _9346; _5435 < _9347; ++_5435)
      {
        {
          ((*_5432)(_5433,_5435)) = _ptr__5434[_5435];
        }
      }
      int _9348 = (int)((_5434)->size(0));
      int _9349 = _5430;
      for (int _5436 = _9348; _5436 < _9349; ++_5436)
      {
        {
          ((*_5432)(_5433,_5436)) = (int)1;
        }
      }
    }
  }
  int _9350 = (int)1;
  int _9351 = (int)((_5429)->size(0));
  for (int _5437 = _9350; _5437 < _9351; ++_5437)
  {
    {
      int _9352 = (int)0;
      int _9353 = _5430;
      for (int _5438 = _9352; _5438 < _9353; ++_5438)
      {
        {
          if ((((*_5432)((int)0,_5438)) != ((*_5432)(_5437,_5438))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _9354;
  for (int _5440 = (int)0, _9355 = _5430; _5440 < _9355 ; ++_5440)
  {
    _9354.push_back(((*_5432)((int)0,_5440)));
  }
  auto _9356 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9354.size()),_9354.begin(),_9354.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5439 = _9356;
  _checked_ptr_1<int> _ptr__5439(_5439 ? _5439->raw() : nullptr,_5439 ? _5439->size(0) : 0);
  int _5441 = (int)1;
  int _9357 = (int)0;
  int _9358 = _5430;
  for (int _5442 = _9357; _5442 < _9358; ++_5442)
  {
    {
      _5441 *= _ptr__5439[_5442];
    }
  }
  int _5443 = (int)0;
  int _5444 = (int)0;
  int _9359 = (int)0;
  int _9360 = (int)((_5429)->size(0));
  for (int _5445 = _9359; _5445 < _9360; ++_5445)
  {
    {
      int _5446 = ((*_5429)(_5445))->numInst();
      _5443 += _5446;
      int _9361;
      bool _9362 = (_5444 > _5446);
      if (_9362)
      {
        _9361 = _5444;
      }
      else
      {
        _9361 = _5446;
      }
      _5444 = _9361;
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5447 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5441,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5447(_5447 ? _5447->raw() : nullptr,_5447 ? _5447->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5448 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5443)));
  _checked_ptr_1<long long> _ptr__5448(_5448 ? _5448->raw() : nullptr,_5448 ? _5448->size(0) : 0);
  std::vector<double> _9363;
  for (int _5450 = (int)0, _9364 = _5443; _5450 < _9364 ; ++_5450)
  {
    _9363.push_back(1.0);
  }
  auto _9365 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9363.size()),_9363.begin(),_9363.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5449 = _9365;
  _checked_ptr_1<double> _ptr__5449(_5449 ? _5449->raw() : nullptr,_5449 ? _5449->size(0) : 0);
  {
    std::shared_ptr< monty::ndarray< long long,1 > > _5451 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5444)));
    _checked_ptr_1<long long> _ptr__5451(_5451 ? _5451->raw() : nullptr,_5451 ? _5451->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5452 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5444)));
    _checked_ptr_1<long long> _ptr__5452(_5452 ? _5452->raw() : nullptr,_5452 ? _5452->size(0) : 0);
    int _9366 = (int)0;
    int _9367 = (int)((_5429)->size(0));
    for (int _5453 = _9366; _5453 < _9367; ++_5453)
    {
      {
        int _5454 = ((*_5429)(_5453))->inst((int)0,_5451,(int)0,_5452);
        int _9368 = (int)0;
        int _9369 = _5454;
        for (int _5455 = _9368; _5455 < _9369; ++_5455)
        {
          {
            _ptr__5447[safe_add( _ptr__5451[_5455],(int)1 )] += (int)1;
          }
        }
      }
    }
    int _9370 = (int)0;
    int _9371 = _5441;
    for (int _5456 = _9370; _5456 < _9371; ++_5456)
    {
      {
        _ptr__5447[safe_add( _5456,(int)1 )] += _ptr__5447[_5456];
      }
    }
    int _9372 = (int)0;
    int _9373 = (int)((_5429)->size(0));
    for (int _5457 = _9372; _5457 < _9373; ++_5457)
    {
      {
        int _5458 = ((*_5429)(_5457))->inst((int)0,_5451,(int)0,_5452);
        int _9374 = (int)0;
        int _9375 = _5458;
        for (int _5459 = _9374; _5459 < _9375; ++_5459)
        {
          {
            _ptr__5448[_ptr__5447[_ptr__5451[_5459]]] = _ptr__5452[_5459];
            ++ _ptr__5447[_ptr__5451[_5459]];
          }
        }
      }
    }
    int _9376 = (int)0;
    int _9377 = _5441;
    for (int _5460 = _9376; _5460 < _9377; ++_5460)
    {
      {
        _ptr__5447[(_5441 - _5460)] = _ptr__5447[((_5441 - _5460) - (int)1)];
      }
    }
    _ptr__5447[(int)0] = (int)0;
  }
  std::vector<double> _9378;
  for (int _5461 = (int)0, _9379 = _5441; _5461 < _9379 ; ++_5461)
  {
    _9378.push_back(0.0);
  }
  auto _9380 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9378.size()),_9378.begin(),_9378.end()));
  return (::mosek::fusion::p_Expr::_new_Expr(_5447,_5448,_5449,_9380,_5439,nullptr,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add_(monty::rc_ptr< ::mosek::fusion::Expression > _5462,double _5463,monty::rc_ptr< ::mosek::fusion::Expression > _5464,double _5465){
  int _5466 = _5462->getND();
  int _5467 = _5464->getND();
  if ((_5466 == _5467))
  {
    {
      return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5462,_5464,_5463,_5465)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      int _9381;
      bool _9382 = (_5466 > _5467);
      if (_9382)
      {
        _9381 = _5466;
      }
      else
      {
        _9381 = _5467;
      }
      int _5468 = _9381;
      std::shared_ptr< monty::ndarray< int,1 > > _5469 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5468)));
      _checked_ptr_1<int> _ptr__5469(_5469 ? _5469->raw() : nullptr,_5469 ? _5469->size(0) : 0);
      if ((_5466 < _5467))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5470 = _5462->getShape();
          _checked_ptr_1<int> _ptr__5470(_5470 ? _5470->raw() : nullptr,_5470 ? _5470->size(0) : 0);
          int _9383 = (int)0;
          int _9384 = _5466;
          for (int _5471 = _9383; _5471 < _9384; ++_5471)
          {
            {
              _ptr__5469[_5471] = _ptr__5470[_5471];
            }
          }
          int _9385 = _5466;
          int _9386 = _5468;
          for (int _5472 = _9385; _5472 < _9386; ++_5472)
          {
            {
              _ptr__5469[_5472] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5469,_5462)).as<::mosek::fusion::Expression>(),_5464,_5463,_5465)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5473 = _5464->getShape();
          _checked_ptr_1<int> _ptr__5473(_5473 ? _5473->raw() : nullptr,_5473 ? _5473->size(0) : 0);
          int _9387 = (int)0;
          int _9388 = _5467;
          for (int _5474 = _9387; _5474 < _9388; ++_5474)
          {
            {
              _ptr__5469[_5474] = _ptr__5473[_5474];
            }
          }
          int _9389 = _5467;
          int _9390 = _5468;
          for (int _5475 = _9389; _5475 < _9390; ++_5475)
          {
            {
              _ptr__5469[_5475] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5462,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5469,_5464)).as<::mosek::fusion::Expression>(),_5463,_5465)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::transpose  ( monty::rc_ptr< ::mosek::fusion::Expression > _5476) { return mosek::fusion::p_Expr::transpose(_5476); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5476){
  if ((_5476->getND() == (int)0))
  {
    {
      return _5476;
    }
  }
  else if((_5476->getND() == (int)1))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_5476->getDim((int)0))}),_5476)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5476->getND() == (int)2))
  {
    {
      return (::mosek::fusion::p_ExprTranspose::_new_ExprTranspose(_5476)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Incorrect number of dimensions for transpose"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5477,    monty::rc_ptr< ::mosek::fusion::Expression > _5478) { return mosek::fusion::p_Expr::mulElm(_5477,_5478); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5477,monty::rc_ptr< ::mosek::fusion::Expression > _5478){
  return ::mosek::fusion::p_Expr::mulElm_(_5477,_5478);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5479,    monty::rc_ptr< ::mosek::fusion::Expression > _5480) { return mosek::fusion::p_Expr::mulElm(_5479,_5480); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5479,monty::rc_ptr< ::mosek::fusion::Expression > _5480){
  return ::mosek::fusion::p_Expr::mulElm_(_5479,_5480);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,2 > > _5481,    monty::rc_ptr< ::mosek::fusion::Expression > _5482) { return mosek::fusion::p_Expr::mulElm(_5481,_5482); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5481,monty::rc_ptr< ::mosek::fusion::Expression > _5482){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5481),_5482);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,1 > > _5483,    monty::rc_ptr< ::mosek::fusion::Expression > _5484) { return mosek::fusion::p_Expr::mulElm(_5483,_5484); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5483,monty::rc_ptr< ::mosek::fusion::Expression > _5484){
  _checked_ptr_1<double> _ptr__5483(_5483 ? _5483->raw() : nullptr, _5483 ? _5483->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5483,_5484);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5485,    monty::rc_ptr< ::mosek::fusion::Matrix > _5486) { return mosek::fusion::p_Expr::mulElm(_5485,_5486); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5485,monty::rc_ptr< ::mosek::fusion::Matrix > _5486){
  return ::mosek::fusion::p_Expr::mulElm_(_5486,_5485);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5487,    std::shared_ptr< monty::ndarray< double,2 > > _5488) { return mosek::fusion::p_Expr::mulElm(_5487,_5488); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5487,std::shared_ptr< monty::ndarray< double,2 > > _5488){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5488),_5487);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5489,    std::shared_ptr< monty::ndarray< double,1 > > _5490) { return mosek::fusion::p_Expr::mulElm(_5489,_5490); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5489,std::shared_ptr< monty::ndarray< double,1 > > _5490){
  _checked_ptr_1<double> _ptr__5490(_5490 ? _5490->raw() : nullptr, _5490 ? _5490->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5490,_5489);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5491,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5492) { return mosek::fusion::p_Expr::mulElm(_5491,_5492); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5491,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5492){
  return ::mosek::fusion::p_Expr::mulElm_(_5492,_5491);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5493,    monty::rc_ptr< ::mosek::fusion::Expression > _5494) { return mosek::fusion::p_Expr::sub(_5493,_5494); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5493,monty::rc_ptr< ::mosek::fusion::Expression > _5494){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5493),1.0,_5494,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5495,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5496) { return mosek::fusion::p_Expr::sub(_5495,_5496); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5495,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5496){
  return ::mosek::fusion::p_Expr::add_(_5495,1.0,::mosek::fusion::p_Expr::constTerm(_5496),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5497,    monty::rc_ptr< ::mosek::fusion::Expression > _5498) { return mosek::fusion::p_Expr::sub(_5497,_5498); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5497,monty::rc_ptr< ::mosek::fusion::Expression > _5498){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5497),1.0,_5498,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5499,    monty::rc_ptr< ::mosek::fusion::Matrix > _5500) { return mosek::fusion::p_Expr::sub(_5499,_5500); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5499,monty::rc_ptr< ::mosek::fusion::Matrix > _5500){
  return ::mosek::fusion::p_Expr::add_(_5499,1.0,::mosek::fusion::p_Expr::constTerm(_5500),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( double _5501,    monty::rc_ptr< ::mosek::fusion::Expression > _5502) { return mosek::fusion::p_Expr::sub(_5501,_5502); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(double _5501,monty::rc_ptr< ::mosek::fusion::Expression > _5502){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5502->getShape(),_5501),1.0,_5502,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5503,    double _5504) { return mosek::fusion::p_Expr::sub(_5503,_5504); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5503,double _5504){
  return ::mosek::fusion::p_Expr::add_(_5503,1.0,::mosek::fusion::p_Expr::constTerm(_5503->getShape(),_5504),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,2 > > _5505,    monty::rc_ptr< ::mosek::fusion::Expression > _5506) { return mosek::fusion::p_Expr::sub(_5505,_5506); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,2 > > _5505,monty::rc_ptr< ::mosek::fusion::Expression > _5506){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5505),1.0,_5506,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,1 > > _5507,    monty::rc_ptr< ::mosek::fusion::Expression > _5508) { return mosek::fusion::p_Expr::sub(_5507,_5508); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,1 > > _5507,monty::rc_ptr< ::mosek::fusion::Expression > _5508){
  _checked_ptr_1<double> _ptr__5507(_5507 ? _5507->raw() : nullptr, _5507 ? _5507->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5507),1.0,_5508,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5509,    std::shared_ptr< monty::ndarray< double,2 > > _5510) { return mosek::fusion::p_Expr::sub(_5509,_5510); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5509,std::shared_ptr< monty::ndarray< double,2 > > _5510){
  return ::mosek::fusion::p_Expr::add_(_5509,1.0,::mosek::fusion::p_Expr::constTerm(_5510),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5511,    std::shared_ptr< monty::ndarray< double,1 > > _5512) { return mosek::fusion::p_Expr::sub(_5511,_5512); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5511,std::shared_ptr< monty::ndarray< double,1 > > _5512){
  _checked_ptr_1<double> _ptr__5512(_5512 ? _5512->raw() : nullptr, _5512 ? _5512->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5511,1.0,::mosek::fusion::p_Expr::constTerm(_5512),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5513,    monty::rc_ptr< ::mosek::fusion::Expression > _5514) { return mosek::fusion::p_Expr::sub(_5513,_5514); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5513,monty::rc_ptr< ::mosek::fusion::Expression > _5514){
  return ::mosek::fusion::p_Expr::add_(_5513,1.0,_5514,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5515,    monty::rc_ptr< ::mosek::fusion::Expression > _5516) { return mosek::fusion::p_Expr::add(_5515,_5516); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5515,monty::rc_ptr< ::mosek::fusion::Expression > _5516){
  return ::mosek::fusion::p_Expr::add_(_5516,1.0,::mosek::fusion::p_Expr::constTerm(_5515),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5517,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5518) { return mosek::fusion::p_Expr::add(_5517,_5518); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5517,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5518){
  return ::mosek::fusion::p_Expr::add_(_5517,1.0,::mosek::fusion::p_Expr::constTerm(_5518),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5519,    monty::rc_ptr< ::mosek::fusion::Expression > _5520) { return mosek::fusion::p_Expr::add(_5519,_5520); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Matrix > _5519,monty::rc_ptr< ::mosek::fusion::Expression > _5520){
  return ::mosek::fusion::p_Expr::add_(_5520,1.0,::mosek::fusion::p_Expr::constTerm(_5519),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5521,    monty::rc_ptr< ::mosek::fusion::Matrix > _5522) { return mosek::fusion::p_Expr::add(_5521,_5522); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5521,monty::rc_ptr< ::mosek::fusion::Matrix > _5522){
  return ::mosek::fusion::p_Expr::add_(_5521,1.0,::mosek::fusion::p_Expr::constTerm(_5522),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( double _5523,    monty::rc_ptr< ::mosek::fusion::Expression > _5524) { return mosek::fusion::p_Expr::add(_5523,_5524); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(double _5523,monty::rc_ptr< ::mosek::fusion::Expression > _5524){
  return ::mosek::fusion::p_Expr::add_(_5524,1.0,::mosek::fusion::p_Expr::constTerm(_5524->getShape(),_5523),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5525,    double _5526) { return mosek::fusion::p_Expr::add(_5525,_5526); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5525,double _5526){
  return ::mosek::fusion::p_Expr::add_(_5525,1.0,::mosek::fusion::p_Expr::constTerm(_5525->getShape(),_5526),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,2 > > _5527,    monty::rc_ptr< ::mosek::fusion::Expression > _5528) { return mosek::fusion::p_Expr::add(_5527,_5528); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,2 > > _5527,monty::rc_ptr< ::mosek::fusion::Expression > _5528){
  return ::mosek::fusion::p_Expr::add_(_5528,1.0,::mosek::fusion::p_Expr::constTerm(_5527),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,1 > > _5529,    monty::rc_ptr< ::mosek::fusion::Expression > _5530) { return mosek::fusion::p_Expr::add(_5529,_5530); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,1 > > _5529,monty::rc_ptr< ::mosek::fusion::Expression > _5530){
  _checked_ptr_1<double> _ptr__5529(_5529 ? _5529->raw() : nullptr, _5529 ? _5529->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5530,1.0,::mosek::fusion::p_Expr::constTerm(_5529),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5531,    std::shared_ptr< monty::ndarray< double,2 > > _5532) { return mosek::fusion::p_Expr::add(_5531,_5532); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5531,std::shared_ptr< monty::ndarray< double,2 > > _5532){
  return ::mosek::fusion::p_Expr::add_(_5531,1.0,::mosek::fusion::p_Expr::constTerm(_5532),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5533,    std::shared_ptr< monty::ndarray< double,1 > > _5534) { return mosek::fusion::p_Expr::add(_5533,_5534); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5533,std::shared_ptr< monty::ndarray< double,1 > > _5534){
  _checked_ptr_1<double> _ptr__5534(_5534 ? _5534->raw() : nullptr, _5534 ? _5534->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5533,1.0,::mosek::fusion::p_Expr::constTerm(_5534),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5535,    monty::rc_ptr< ::mosek::fusion::Expression > _5536) { return mosek::fusion::p_Expr::add(_5535,_5536); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5535,monty::rc_ptr< ::mosek::fusion::Expression > _5536){
  return ::mosek::fusion::p_Expr::add_(_5535,1.0,_5536,1.0);
}
int mosek::fusion::Expr :: getND() { return mosek::fusion::p_Expr::_get_impl(this)->getND(); }int mosek::fusion::p_Expr::getND(){
  return (int)((shape)->size(0));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Expr :: getShape() { return mosek::fusion::p_Expr::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Expr::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::Expr :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5537,monty::rc_ptr< ::mosek::fusion::WorkStack > _5538,monty::rc_ptr< ::mosek::fusion::WorkStack > _5539) { mosek::fusion::p_Expr::_get_impl(this)->eval(_5537,_5538,_5539); }void mosek::fusion::p_Expr::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5537,monty::rc_ptr< ::mosek::fusion::WorkStack > _5538,monty::rc_ptr< ::mosek::fusion::WorkStack > _5539){
  std::vector<int> _9391;
  for (int _5540 = (int)0, _9392 = (int)((ptrb)->size(0)); _5540 < _9392 ; ++_5540)
  {
    _9391.push_back((int)((*ptrb)(_5540)));
  }
  auto _9393 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9391.size()),_9391.begin(),_9391.end()));
  ::mosek::fusion::p_BaseExpression::storeexpr(_5537,shape,_9393,inst,subj,cof_v,bfix);
}
void mosek::fusion::p_Expr::validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5541,std::shared_ptr< monty::ndarray< long long,1 > > _5542,std::shared_ptr< monty::ndarray< double,1 > > _5543,std::shared_ptr< monty::ndarray< double,1 > > _5544,std::shared_ptr< monty::ndarray< int,1 > > _5545,std::shared_ptr< monty::ndarray< long long,1 > > _5546){
  _checked_ptr_1<long long> _ptr__5541(_5541 ? _5541->raw() : nullptr, _5541 ? _5541->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5542(_5542 ? _5542->raw() : nullptr, _5542 ? _5542->size(0) : 0);
  _checked_ptr_1<double> _ptr__5543(_5543 ? _5543->raw() : nullptr, _5543 ? _5543->size(0) : 0);
  _checked_ptr_1<double> _ptr__5544(_5544 ? _5544->raw() : nullptr, _5544 ? _5544->size(0) : 0);
  _checked_ptr_1<int> _ptr__5545(_5545 ? _5545->raw() : nullptr, _5545 ? _5545->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5546(_5546 ? _5546->raw() : nullptr, _5546 ? _5546->size(0) : 0);
  if ((NULL == _5545.get()))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'shape' in expression is null"));
    }
  }
  {}
  int _5547 = ((int)((_5541)->size(0)) - (int)1);
  long long _5548 = _ptr__5541[((int)((_5541)->size(0)) - (int)1)];
  int _5549 = (int)((_5545)->size(0));
  long long _5550 = (long long)1;
  int _9394 = (int)0;
  int _9395 = _5549;
  for (int _5551 = _9394; _5551 < _9395; ++_5551)
  {
    {
      _5550 *= _ptr__5545[_5551];
    }
  }
  if (((int)((_5541)->size(0)) < (int)1))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong size"));
    }
  }
  {}
  if ((_5548 != (int)((_5542)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'subj' in expression has wrong size"));
    }
  }
  {}
  if ((_5548 != (int)((_5543)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'cof' in expression has wrong size"));
    }
  }
  {}
  if (((NULL == _5544.get()) || (_5547 != (int)((_5544)->size(0)))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'bfix' in expression has wrong length"));
    }
  }
  {}
  if (((NULL != _5546.get()) && ((int)((_5546)->size(0)) < _5550)))
  {
    {
      if (((int)((_5546)->size(0)) != ((int)((_5541)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' in expression has wrong length"));
        }
      }
      {}
      if (((int)((_5546)->size(0)) > (int)0))
      {
        {
          if (((_ptr__5546[(int)0] < (int)0) || (_ptr__5546[(int)0] >= _5550)))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' contains an invalid index"));
            }
          }
          {}
          bool _5552 = true;
          long long _5553 = _5550;
          int _9396 = (int)1;
          int _9397 = (int)((_5546)->size(0));
          for (int _5554 = _9396; _5554 < _9397; ++_5554)
          {
            {
              _5552 = (_5552 && ((_ptr__5546[_5554] >= (int)0) && ((_ptr__5546[_5554] < _5553) && (_ptr__5546[_5554] > _ptr__5546[(_5554 - (int)1)]))));
            }
          }
          if ((!_5552))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Invalid array 'inst'"));
            }
          }
          {}
        }
      }
      {}
    }
  }
  else
  {
    {
      if ((_5550 != ((long long)((_5541)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong length"));
        }
      }
      {}
    }
  }
  bool _5555 = false;
  bool _5556 = false;
  if ((_ptr__5541[(int)0] != (long long)0))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
  bool _5557 = true;
  int _9398 = (int)0;
  int _9399 = _5547;
  for (int _5558 = _9398; _5558 < _9399; ++_5558)
  {
    {
      _5557 = (_5557 && (_ptr__5541[_5558] <= _ptr__5541[safe_add( _5558,(int)1 )]));
    }
  }
  if ((!_5557))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Expr::extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5559){
  monty::rc_ptr< ::mosek::fusion::Model > _9400;
  bool _9401 = ((NULL == _5559.get()) || ((int)((_5559)->size(0)) == (int)0));
  if (_9401)
  {
    _9400 = nullptr;
  }
  else
  {
    _9400 = ((*_5559)((int)0))->__mosek_2fusion_2Variable__getModel();
  }
  return _9400;
}
void mosek::fusion::p_Expr::destroy(){inst.reset();cof_v.reset();subj.reset();ptrb.reset();bfix.reset();shape.reset();}void mosek::fusion::Expr::destroy() { mosek::fusion::p_Expr::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,2 > > _5560) { return __mosek_2fusion_2Expression__pick(_5560); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,1 > > _5561) { return __mosek_2fusion_2Expression__pick(_5561); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(std::shared_ptr< monty::ndarray< int,1 > > _5562) { return __mosek_2fusion_2Expression__index(_5562); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(int _5563) { return __mosek_2fusion_2Expression__index(_5563); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(std::shared_ptr< monty::ndarray< int,1 > > _5564,std::shared_ptr< monty::ndarray< int,1 > > _5565) { return __mosek_2fusion_2Expression__slice(_5564,_5565); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(int _5566,int _5567) { return __mosek_2fusion_2Expression__slice(_5566,_5567); }
monty::rc_ptr< mosek::fusion::FlatExpr > mosek::fusion::Expression::eval() { return __mosek_2fusion_2Expression__eval(); }
mosek::fusion::FlatExpr::FlatExpr(mosek::fusion::p_FlatExpr *_impl) : _impl(_impl) { /*std::cout << "FlatExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::FlatExpr::~FlatExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_FlatExpr::p_FlatExpr  (::mosek::fusion::FlatExpr * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_inst() { return _impl->inst; }
void mosek::fusion::FlatExpr::set_inst(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->inst = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::FlatExpr::get_shape() { return _impl->shape; }
void mosek::fusion::FlatExpr::set_shape(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->shape = _val; }
long long mosek::fusion::FlatExpr::get_nnz() { return _impl->nnz; }
void mosek::fusion::FlatExpr::set_nnz(long long _val) { _impl->nnz = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_cof() { return _impl->cof; }
void mosek::fusion::FlatExpr::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_subj() { return _impl->subj; }
void mosek::fusion::FlatExpr::set_subj(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::FlatExpr::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_bfix() { return _impl->bfix; }
void mosek::fusion::FlatExpr::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5572){ return new mosek::fusion::FlatExpr(_5572); }mosek::fusion::FlatExpr::FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5572) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5572); }void mosek::fusion::p_FlatExpr::_initialize  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5572){monty::rc_reserve __reserve_this(_pubthis);   {
    bfix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5572)->bfix);
    ptrb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5572)->ptrb);
    subj = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5572)->subj);
    cof = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5572)->cof);
    nnz = mosek::fusion::p_FlatExpr::_get_impl(_5572)->nnz;
    shape = mosek::fusion::p_FlatExpr::_get_impl(_5572)->shape;
    inst = mosek::fusion::p_FlatExpr::_get_impl(_5572)->inst;
  }
}mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5573,    std::shared_ptr< monty::ndarray< long long,1 > > _5574,    std::shared_ptr< monty::ndarray< long long,1 > > _5575,    std::shared_ptr< monty::ndarray< double,1 > > _5576,    std::shared_ptr< monty::ndarray< int,1 > > _5577,    std::shared_ptr< monty::ndarray< long long,1 > > _5578){ return new mosek::fusion::FlatExpr(_5573,_5574,_5575,_5576,_5577,_5578); }mosek::fusion::FlatExpr::FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5573,    std::shared_ptr< monty::ndarray< long long,1 > > _5574,    std::shared_ptr< monty::ndarray< long long,1 > > _5575,    std::shared_ptr< monty::ndarray< double,1 > > _5576,    std::shared_ptr< monty::ndarray< int,1 > > _5577,    std::shared_ptr< monty::ndarray< long long,1 > > _5578) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5573,_5574,_5575,_5576,_5577,_5578); }void mosek::fusion::p_FlatExpr::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _5573,    std::shared_ptr< monty::ndarray< long long,1 > > _5574,    std::shared_ptr< monty::ndarray< long long,1 > > _5575,    std::shared_ptr< monty::ndarray< double,1 > > _5576,    std::shared_ptr< monty::ndarray< int,1 > > _5577,    std::shared_ptr< monty::ndarray< long long,1 > > _5578){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5573(_5573 ? _5573->raw() : nullptr, _5573 ? _5573->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5574(_5574 ? _5574->raw() : nullptr, _5574 ? _5574->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5575(_5575 ? _5575->raw() : nullptr, _5575 ? _5575->size(0) : 0);
    _checked_ptr_1<double> _ptr__5576(_5576 ? _5576->raw() : nullptr, _5576 ? _5576->size(0) : 0);
    _checked_ptr_1<int> _ptr__5577(_5577 ? _5577->raw() : nullptr, _5577 ? _5577->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5578(_5578 ? _5578->raw() : nullptr, _5578 ? _5578->size(0) : 0);
    if (((NULL != _5573.get()) && ((int)((_5573)->size(0)) != ((int)((_5574)->size(0)) - (int)1))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of bfix and ptrb"));
      }
    }
    {}
    if (((NULL == _5576.get()) || ((NULL == _5575.get()) || ((int)((_5575)->size(0)) != (int)((_5576)->size(0))))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of subj and cof"));
      }
    }
    {}
    if ((NULL != _5577.get()))
    {
      {
        if ((NULL != _5578.get()))
        {
          {
            if (((int)((_5578)->size(0)) != ((int)((_5574)->size(0)) - (int)1)))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of inst and ptrb"));
              }
            }
            {}
          }
        }
        else if((::mosek::fusion::p_Set::size(_5577) != ((long long)((_5574)->size(0)) - (int)1)))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching shape and ptrb"));
          }
        }
        {}
      }
    }
    {}
    bfix = _5573;
    ptrb = _5574;
    subj = _5575;
    cof = _5576;
    nnz = ((*ptrb)(((int)((ptrb)->size(0)) - (int)1)));
    shape = _5577;
    inst = _5578;
  }
}std::string mosek::fusion::FlatExpr :: toString() { return mosek::fusion::p_FlatExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_FlatExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5579 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5579->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("FlatExpr:"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| ptrb["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((ptrb)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(ptrb)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| subj["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((subj)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(subj)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| cof ["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((cof)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(cof)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| bfix["));
  if ((NULL != bfix.get()))
  {
    {
      _5579->__mosek_2fusion_2Utils_2StringBuffer__a((int)((bfix)->size(0)));
    }
  }
  {}
  _5579->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(bfix)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| inst["));
  if ((NULL != inst.get()))
  {
    {
      _5579->__mosek_2fusion_2Utils_2StringBuffer__a((int)((inst)->size(0)));
    }
  }
  {}
  _5579->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(inst)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"));
  return _5579->toString();
}
int mosek::fusion::FlatExpr :: size() { return mosek::fusion::p_FlatExpr::_get_impl(this)->size(); }int mosek::fusion::p_FlatExpr::size(){
  return ((int)((ptrb)->size(0)) - (int)1);
}
void mosek::fusion::p_FlatExpr::destroy(){inst.reset();shape.reset();cof.reset();subj.reset();ptrb.reset();bfix.reset();}void mosek::fusion::FlatExpr::destroy() { mosek::fusion::p_FlatExpr::_get_impl(this)->destroy(); }mosek::fusion::SymmetricMatrix::SymmetricMatrix(mosek::fusion::p_SymmetricMatrix *_impl) : _impl(_impl) { /*std::cout << "SymmetricMatrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricMatrix::~SymmetricMatrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricMatrix::p_SymmetricMatrix  (::mosek::fusion::SymmetricMatrix * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricMatrix::t mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix  (int _5580,    int _5581,    std::shared_ptr< monty::ndarray< int,1 > > _5582,    std::shared_ptr< monty::ndarray< int,1 > > _5583,    std::shared_ptr< monty::ndarray< double,1 > > _5584,    std::shared_ptr< monty::ndarray< int,1 > > _5585,    std::shared_ptr< monty::ndarray< int,1 > > _5586,    std::shared_ptr< monty::ndarray< double,1 > > _5587,    double _5588){ return new mosek::fusion::SymmetricMatrix(_5580,_5581,_5582,_5583,_5584,_5585,_5586,_5587,_5588); }mosek::fusion::SymmetricMatrix::SymmetricMatrix  (int _5580,    int _5581,    std::shared_ptr< monty::ndarray< int,1 > > _5582,    std::shared_ptr< monty::ndarray< int,1 > > _5583,    std::shared_ptr< monty::ndarray< double,1 > > _5584,    std::shared_ptr< monty::ndarray< int,1 > > _5585,    std::shared_ptr< monty::ndarray< int,1 > > _5586,    std::shared_ptr< monty::ndarray< double,1 > > _5587,    double _5588) :    SymmetricMatrix(new mosek::fusion::p_SymmetricMatrix(this)){ mosek::fusion::p_SymmetricMatrix::_get_impl(this)->_initialize(_5580,_5581,_5582,_5583,_5584,_5585,_5586,_5587,_5588); }void mosek::fusion::p_SymmetricMatrix::_initialize  (int _5580,    int _5581,    std::shared_ptr< monty::ndarray< int,1 > > _5582,    std::shared_ptr< monty::ndarray< int,1 > > _5583,    std::shared_ptr< monty::ndarray< double,1 > > _5584,    std::shared_ptr< monty::ndarray< int,1 > > _5585,    std::shared_ptr< monty::ndarray< int,1 > > _5586,    std::shared_ptr< monty::ndarray< double,1 > > _5587,    double _5588){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5582(_5582 ? _5582->raw() : nullptr, _5582 ? _5582->size(0) : 0);
    _checked_ptr_1<int> _ptr__5583(_5583 ? _5583->raw() : nullptr, _5583 ? _5583->size(0) : 0);
    _checked_ptr_1<double> _ptr__5584(_5584 ? _5584->raw() : nullptr, _5584 ? _5584->size(0) : 0);
    _checked_ptr_1<int> _ptr__5585(_5585 ? _5585->raw() : nullptr, _5585 ? _5585->size(0) : 0);
    _checked_ptr_1<int> _ptr__5586(_5586 ? _5586->raw() : nullptr, _5586 ? _5586->size(0) : 0);
    _checked_ptr_1<double> _ptr__5587(_5587 ? _5587->raw() : nullptr, _5587 ? _5587->size(0) : 0);
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d0 = _5580;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d1 = _5581;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubi = _5582;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubj = _5583;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->uval = _5584;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubi = _5585;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubj = _5586;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vval = _5587;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->scale = _5588;
    nnz = (-(int)1);
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( int _5589,    std::shared_ptr< monty::ndarray< int,1 > > _5590,    std::shared_ptr< monty::ndarray< double,1 > > _5591) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5589,_5590,_5591); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(int _5589,std::shared_ptr< monty::ndarray< int,1 > > _5590,std::shared_ptr< monty::ndarray< double,1 > > _5591){
  _checked_ptr_1<int> _ptr__5590(_5590 ? _5590->raw() : nullptr, _5590 ? _5590->size(0) : 0);
  _checked_ptr_1<double> _ptr__5591(_5591 ? _5591->raw() : nullptr, _5591 ? _5591->size(0) : 0);
  if (((int)((_5590)->size(0)) != (int)((_5591)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching array lengths"));
    }
  }
  {}
  int _9402 = (int)0;
  int _9403 = (int)((_5590)->size(0));
  for (int _5592 = _9402; _5592 < _9403; ++_5592)
  {
    {
      if (((_ptr__5590[_5592] < (int)0) || (_ptr__5590[_5592] >= _5589)))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid index in argument 'sub'"));
        }
      }
      {}
    }
  }
  std::vector<int> _9404;
  for (int _5594 = (int)0, _9405 = (int)((_5590)->size(0)); _5594 < _9405 ; ++_5594)
  {
    _9404.push_back(_ptr__5590[_5594]);
  }
  auto _9406 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9404.size()),_9404.begin(),_9404.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5593 = _9406;
  _checked_ptr_1<int> _ptr__5593(_5593 ? _5593->raw() : nullptr,_5593 ? _5593->size(0) : 0);
  std::vector<int> _9407;
  for (int _5596 = (int)0, _9408 = (int)((_5590)->size(0)); _5596 < _9408 ; ++_5596)
  {
    _9407.push_back((int)1);
  }
  auto _9409 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9407.size()),_9407.begin(),_9407.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5595 = _9409;
  _checked_ptr_1<int> _ptr__5595(_5595 ? _5595->raw() : nullptr,_5595 ? _5595->size(0) : 0);
  std::vector<double> _9410;
  for (int _5598 = (int)0, _9411 = (int)((_5591)->size(0)); _5598 < _9411 ; ++_5598)
  {
    _9410.push_back(_ptr__5591[_5598]);
  }
  auto _9412 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9410.size()),_9410.begin(),_9410.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5597 = _9412;
  _checked_ptr_1<double> _ptr__5597(_5597 ? _5597->raw() : nullptr,_5597 ? _5597->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5589,(int)1,_5593,_5595,_5597,_5593,_5595,_5597,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( std::shared_ptr< monty::ndarray< double,1 > > _5599) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5599); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5599){
  _checked_ptr_1<double> _ptr__5599(_5599 ? _5599->raw() : nullptr, _5599 ? _5599->size(0) : 0);
  int _5600 = (int)((_5599)->size(0));
  std::vector<int> _9413;
  for (int _5602 = (int)0, _9414 = _5600; _5602 < _9414 ; ++_5602)
  {
    _9413.push_back(_5602);
  }
  auto _9415 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9413.size()),_9413.begin(),_9413.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5601 = _9415;
  _checked_ptr_1<int> _ptr__5601(_5601 ? _5601->raw() : nullptr,_5601 ? _5601->size(0) : 0);
  std::vector<int> _9416;
  for (int _5604 = (int)0, _9417 = _5600; _5604 < _9417 ; ++_5604)
  {
    _9416.push_back((int)1);
  }
  auto _9418 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9416.size()),_9416.begin(),_9416.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5603 = _9418;
  _checked_ptr_1<int> _ptr__5603(_5603 ? _5603->raw() : nullptr,_5603 ? _5603->size(0) : 0);
  std::vector<double> _9419;
  for (int _5606 = (int)0, _9420 = _5600; _5606 < _9420 ; ++_5606)
  {
    _9419.push_back(_ptr__5599[_5606]);
  }
  auto _9421 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9419.size()),_9419.begin(),_9419.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5605 = _9421;
  _checked_ptr_1<double> _ptr__5605(_5605 ? _5605->raw() : nullptr,_5605 ? _5605->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5600,(int)1,_5601,_5603,_5605,_5601,_5603,_5605,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::antiDiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5607) { return mosek::fusion::p_SymmetricMatrix::antiDiag(_5607); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5607){
  _checked_ptr_1<double> _ptr__5607(_5607 ? _5607->raw() : nullptr, _5607 ? _5607->size(0) : 0);
  int _5608 = (int)((_5607)->size(0));
  std::vector<int> _9422;
  for (int _5610 = (int)0, _9423 = _5608; _5610 < _9423 ; ++_5610)
  {
    _9422.push_back(_5610);
  }
  auto _9424 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9422.size()),_9422.begin(),_9422.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5609 = _9424;
  _checked_ptr_1<int> _ptr__5609(_5609 ? _5609->raw() : nullptr,_5609 ? _5609->size(0) : 0);
  std::vector<int> _9425;
  for (int _5611 = (int)0, _9426 = _5608; _5611 < _9426 ; ++_5611)
  {
    _9425.push_back((_5608 - _5611));
  }
  auto _9427 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9425.size()),_9425.begin(),_9425.end()));
  std::vector<double> _9428;
  for (int _5612 = (int)0, _9429 = _5608; _5612 < _9429 ; ++_5612)
  {
    _9428.push_back(_ptr__5607[_5612]);
  }
  auto _9430 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9428.size()),_9428.begin(),_9428.end()));
  std::vector<double> _9431;
  for (int _5613 = (int)0, _9432 = _5608; _5613 < _9432 ; ++_5613)
  {
    _9431.push_back(1.0);
  }
  auto _9433 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9431.size()),_9431.begin(),_9431.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5608,_5608,_5609,_9427,_9430,_5609,_5609,_9433,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5614) { return mosek::fusion::p_SymmetricMatrix::diag(_5614); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5614){
  _checked_ptr_1<double> _ptr__5614(_5614 ? _5614->raw() : nullptr, _5614 ? _5614->size(0) : 0);
  int _5615 = (int)((_5614)->size(0));
  std::vector<int> _9434;
  for (int _5617 = (int)0, _9435 = _5615; _5617 < _9435 ; ++_5617)
  {
    _9434.push_back(_5617);
  }
  auto _9436 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9434.size()),_9434.begin(),_9434.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5616 = _9436;
  _checked_ptr_1<int> _ptr__5616(_5616 ? _5616->raw() : nullptr,_5616 ? _5616->size(0) : 0);
  std::vector<double> _9437;
  for (int _5618 = (int)0, _9438 = _5615; _5618 < _9438 ; ++_5618)
  {
    _9437.push_back(_ptr__5614[_5618]);
  }
  auto _9439 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9437.size()),_9437.begin(),_9437.end()));
  std::vector<double> _9440;
  for (int _5619 = (int)0, _9441 = _5615; _5619 < _9441 ; ++_5619)
  {
    _9440.push_back(1.0);
  }
  auto _9442 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9440.size()),_9440.begin(),_9440.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5615,_5615,_5616,_5616,_9439,_5616,_5616,_9442,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5620) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__add(_5620); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5620) { return __mosek_2fusion_2SymmetricMatrix__add(_5620); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5620){
  int _5621 = _pubthis->getdim();
  if ((_5620->getdim() != _5621))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  int _5622 = (int)((usubi)->size(0));
  int _5623 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->usubi)->size(0));
  int _5624 = safe_add( _5622,_5623 );
  int _5625 = (int)((vsubi)->size(0));
  int _5626 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->vsubi)->size(0));
  int _5627 = safe_add( _5625,_5626 );
  std::shared_ptr< monty::ndarray< double,1 > > _5628 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5627)));
  _checked_ptr_1<double> _ptr__5628(_5628 ? _5628->raw() : nullptr,_5628 ? _5628->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5629 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5627)));
  _checked_ptr_1<int> _ptr__5629(_5629 ? _5629->raw() : nullptr,_5629 ? _5629->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5630 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5627)));
  _checked_ptr_1<int> _ptr__5630(_5630 ? _5630->raw() : nullptr,_5630 ? _5630->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5631 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5624)));
  _checked_ptr_1<double> _ptr__5631(_5631 ? _5631->raw() : nullptr,_5631 ? _5631->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5632 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5624)));
  _checked_ptr_1<int> _ptr__5632(_5632 ? _5632->raw() : nullptr,_5632 ? _5632->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5633 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5624)));
  _checked_ptr_1<int> _ptr__5633(_5633 ? _5633->raw() : nullptr,_5633 ? _5633->size(0) : 0);
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5633,(int)0,_5622);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->usubi,(int)0,_5633,_5622,_5623);
  ::mosek::fusion::Utils::Tools::arraycopy(usubj,(int)0,_5632,(int)0,_5622);
  int _9443 = (int)0;
  int _9444 = _5623;
  for (int _5634 = _9443; _5634 < _9444; ++_5634)
  {
    {
      _ptr__5632[safe_add( _5634,_5622 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->usubj)(_5634)),d1 );
    }
  }
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(uval,(int)0,_5631,(int)0,_5622);
    }
  }
  else
  {
    {
      int _9445 = (int)0;
      int _9446 = _5622;
      for (int _5635 = _9445; _5635 < _9446; ++_5635)
      {
        {
          _ptr__5631[_5635] = (scale * ((*uval)(_5635)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->uval,(int)0,_5631,_5622,_5623);
    }
  }
  else
  {
    {
      int _9447 = (int)0;
      int _9448 = _5623;
      for (int _5636 = _9447; _5636 < _9448; ++_5636)
      {
        {
          _ptr__5631[safe_add( _5636,_5622 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->uval)(_5636)));
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5633,(int)0,_5622);
  int _9449 = (int)0;
  int _9450 = _5626;
  for (int _5637 = _9449; _5637 < _9450; ++_5637)
  {
    {
      _ptr__5630[safe_add( _5637,_5625 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->vsubi)(_5637)),mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->d1 );
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(vsubj,(int)0,_5629,(int)0,_5625);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->vsubj,_5625,_5629,_5625,_5626);
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(vval,(int)0,_5628,(int)0,_5625);
    }
  }
  else
  {
    {
      int _9451 = (int)0;
      int _9452 = _5625;
      for (int _5638 = _9451; _5638 < _9452; ++_5638)
      {
        {
          _ptr__5628[_5638] = (scale * ((*vval)(_5638)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->vval,(int)0,_5628,_5625,_5626);
    }
  }
  else
  {
    {
      int _9453 = (int)0;
      int _9454 = _5626;
      for (int _5639 = _9453; _5639 < _9454; ++_5639)
      {
        {
          _ptr__5628[safe_add( _5639,_5625 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->vval)(_5639)));
        }
      }
    }
  }
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,safe_add( d1,mosek::fusion::p_SymmetricMatrix::_get_impl(_5620)->d1 ),_5633,_5632,_5631,_5630,_5629,_5628,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5640) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__sub(_5640); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5640) { return __mosek_2fusion_2SymmetricMatrix__sub(_5640); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5640){
  return _pubthis->__mosek_2fusion_2SymmetricMatrix__add(_5640->__mosek_2fusion_2SymmetricMatrix__mul((-1.0)));
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__mul(double _5641) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__mul(_5641); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::mul(double _5641) { return __mosek_2fusion_2SymmetricMatrix__mul(_5641); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__mul(double _5641){
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,d1,usubi,usubj,uval,vsubi,vsubj,vval,(scale * _5641));
}
int mosek::fusion::SymmetricMatrix :: getdim() { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->getdim(); }int mosek::fusion::p_SymmetricMatrix::getdim(){
  return d0;
}
void mosek::fusion::p_SymmetricMatrix::destroy(){vval.reset();vsubj.reset();vsubi.reset();uval.reset();usubj.reset();usubi.reset();}void mosek::fusion::SymmetricMatrix::destroy() { mosek::fusion::p_SymmetricMatrix::_get_impl(this)->destroy(); }mosek::fusion::NDSparseArray::NDSparseArray(mosek::fusion::p_NDSparseArray *_impl) : _impl(_impl) { /*std::cout << "NDSparseArray() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::NDSparseArray::~NDSparseArray() { delete _impl; _impl = nullptr; }mosek::fusion::p_NDSparseArray::p_NDSparseArray  (::mosek::fusion::NDSparseArray * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5642,    std::shared_ptr< monty::ndarray< int,2 > > _5643,    std::shared_ptr< monty::ndarray< double,1 > > _5644){ return new mosek::fusion::NDSparseArray(_5642,_5643,_5644); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5642,    std::shared_ptr< monty::ndarray< int,2 > > _5643,    std::shared_ptr< monty::ndarray< double,1 > > _5644) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5642,_5643,_5644); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5642,    std::shared_ptr< monty::ndarray< int,2 > > _5643,    std::shared_ptr< monty::ndarray< double,1 > > _5644){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5642(_5642 ? _5642->raw() : nullptr, _5642 ? _5642->size(0) : 0);
    _checked_ptr_1<double> _ptr__5644(_5644 ? _5644->raw() : nullptr, _5644 ? _5644->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5645 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_5643)->size(0)))));
    _checked_ptr_1<long long> _ptr__5645(_5645 ? _5645->raw() : nullptr,_5645 ? _5645->size(0) : 0);
    size = (long long)1;
    int _9455 = (int)0;
    int _9456 = (int)((_5642)->size(0));
    for (int _5646 = _9455; _5646 < _9456; ++_5646)
    {
      {
        size = safe_mul( size,_ptr__5642[_5646] );
      }
    }
    int _5647 = (int)((_5642)->size(0));
    if (((int)((_5643)->size(0)) != (int)((_5644)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    if (((int)((_5643)->size(1)) != _5647))
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index key in sub has wrong length"));
      }
    }
    {}
    int _9457 = (int)0;
    int _9458 = (int)((_5643)->size(0));
    for (int _5648 = _9457; _5648 < _9458; ++_5648)
    {
      {
        int _9459 = (int)0;
        int _9460 = (int)((_5643)->size(1));
        for (int _5649 = _9459; _5649 < _9460; ++_5649)
        {
          {
            if (((((*_5643)(_5648,_5649)) < (int)0) || (((*_5643)(_5648,_5649)) >= _ptr__5642[_5649])))
            {
              {
                throw ::mosek::fusion::IndexError(std::string ("An index in sub is out of bounds"));
              }
            }
            {}
          }
        }
      }
    }
    int _9461 = (int)0;
    int _9462 = (int)((_5643)->size(0));
    for (int _5650 = _9461; _5650 < _9462; ++_5650)
    {
      {
        long long _5651 = (long long)0;
        int _9463 = (int)0;
        int _9464 = (int)((_5643)->size(1));
        for (int _5652 = _9463; _5652 < _9464; ++_5652)
        {
          {
            _5651 = safe_add( safe_mul( _5651,_ptr__5642[((_5647 - _5652) - (int)1)] ),((*_5643)(_5650,_5652)) );
          }
        }
        _ptr__5645[_5650] = _5651;
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5642);
    bool _5653 = true;
    int _9465 = (int)1;
    int _9466 = (int)((_5645)->size(0));
    for (int _5654 = _9465; _5654 < _9466; ++_5654)
    {
      {
        _5653 = (_5653 && (_ptr__5645[_5654] >= _ptr__5645[(_5654 - (int)1)]));
      }
    }
    if (_5653)
    {
      {
        int _5655 = (int)1;
        int _9467 = (int)1;
        int _9468 = (int)((_5645)->size(0));
        for (int _5656 = _9467; _5656 < _9468; ++_5656)
        {
          {
            if ((_ptr__5645[(_5656 - (int)1)] > _ptr__5645[_5656]))
            {
              {
                ++ _5655;
              }
            }
            {}
          }
        }
        if ((_5655 == (int)((_5645)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5645);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5644);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5655)));
            ((*inst)((int)0)) = _ptr__5645[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5655)));
            ((*cof)((int)0)) = _ptr__5644[(int)0];
            int _5657 = (int)0;
            int _9469 = (int)1;
            int _9470 = (int)((_5645)->size(0));
            for (int _5658 = _9469; _5658 < _9470; ++_5658)
            {
              {
                if ((_ptr__5645[_5658] > _ptr__5645[(_5658 - (int)1)]))
                {
                  {
                    ++ _5657;
                    ((*inst)(_5657)) = _ptr__5645[_5658];
                    ((*cof)(_5657)) = _ptr__5644[_5658];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5657)) = (((*cof)(_5657)) + _ptr__5644[_5658]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5659 = ::mosek::fusion::Utils::Tools::range((long long)((_5645)->size(0)));
        _checked_ptr_1<long long> _ptr__5659(_5659 ? _5659->raw() : nullptr,_5659 ? _5659->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5659,_5645,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5645)->size(0)));
        int _5660 = (int)1;
        int _9471 = (int)1;
        int _9472 = (int)((_5645)->size(0));
        for (int _5661 = _9471; _5661 < _9472; ++_5661)
        {
          {
            if ((_ptr__5645[_ptr__5659[(_5661 - (int)1)]] < _ptr__5645[_ptr__5659[_5661]]))
            {
              {
                ++ _5660;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5660)));
        ((*inst)((int)0)) = _ptr__5645[_ptr__5659[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5660)));
        ((*cof)((int)0)) = _ptr__5644[_ptr__5659[(int)0]];
        int _5662 = (int)0;
        int _9473 = (int)1;
        int _9474 = (int)((_5645)->size(0));
        for (int _5663 = _9473; _5663 < _9474; ++_5663)
        {
          {
            if ((_ptr__5645[_ptr__5659[_5663]] > _ptr__5645[_ptr__5659[(_5663 - (int)1)]]))
            {
              {
                ++ _5662;
                ((*inst)(_5662)) = _ptr__5645[_ptr__5659[_5663]];
                ((*cof)(_5662)) = _ptr__5644[_ptr__5659[_5663]];
              }
            }
            else
            {
              {
                ((*cof)(_5662)) = (((*cof)(_5662)) + _ptr__5644[_ptr__5659[_5663]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5664,    std::shared_ptr< monty::ndarray< long long,1 > > _5665,    std::shared_ptr< monty::ndarray< double,1 > > _5666){ return new mosek::fusion::NDSparseArray(_5664,_5665,_5666); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5664,    std::shared_ptr< monty::ndarray< long long,1 > > _5665,    std::shared_ptr< monty::ndarray< double,1 > > _5666) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5664,_5665,_5666); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5664,    std::shared_ptr< monty::ndarray< long long,1 > > _5665,    std::shared_ptr< monty::ndarray< double,1 > > _5666){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5664(_5664 ? _5664->raw() : nullptr, _5664 ? _5664->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5665(_5665 ? _5665->raw() : nullptr, _5665 ? _5665->size(0) : 0);
    _checked_ptr_1<double> _ptr__5666(_5666 ? _5666->raw() : nullptr, _5666 ? _5666->size(0) : 0);
    size = (long long)1;
    int _9475 = (int)0;
    int _9476 = (int)((_5664)->size(0));
    for (int _5667 = _9475; _5667 < _9476; ++_5667)
    {
      {
        size = safe_mul( size,_ptr__5664[_5667] );
      }
    }
    if (((int)((_5665)->size(0)) != (int)((_5666)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    int _9477 = (int)0;
    int _9478 = (int)((_5665)->size(0));
    for (int _5668 = _9477; _5668 < _9478; ++_5668)
    {
      {
        if (((_ptr__5665[_5668] < (int)0) || (_ptr__5665[_5668] >= size)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("An index in inst is out of bounds"));
          }
        }
        {}
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5664);
    bool _5669 = true;
    int _9479 = (int)1;
    int _9480 = (int)((_5665)->size(0));
    for (int _5670 = _9479; _5670 < _9480; ++_5670)
    {
      {
        _5669 = (_5669 && (_ptr__5665[_5670] >= _ptr__5665[(_5670 - (int)1)]));
      }
    }
    if (_5669)
    {
      {
        int _5671 = (int)1;
        int _9481 = (int)1;
        int _9482 = (int)((_5665)->size(0));
        for (int _5672 = _9481; _5672 < _9482; ++_5672)
        {
          {
            if ((_ptr__5665[(_5672 - (int)1)] > _ptr__5665[_5672]))
            {
              {
                ++ _5671;
              }
            }
            {}
          }
        }
        if ((_5671 == (int)((_5665)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5665);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5666);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5671)));
            ((*inst)((int)0)) = _ptr__5665[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5671)));
            ((*cof)((int)0)) = _ptr__5666[(int)0];
            int _5673 = (int)0;
            int _9483 = (int)1;
            int _9484 = (int)((_5665)->size(0));
            for (int _5674 = _9483; _5674 < _9484; ++_5674)
            {
              {
                if ((_ptr__5665[_5674] > _ptr__5665[(_5674 - (int)1)]))
                {
                  {
                    ++ _5673;
                    ((*inst)(_5673)) = _ptr__5665[_5674];
                    ((*cof)(_5673)) = _ptr__5666[_5674];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5673)) = (((*cof)(_5673)) + _ptr__5666[_5674]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5675 = ::mosek::fusion::Utils::Tools::range((long long)((_5665)->size(0)));
        _checked_ptr_1<long long> _ptr__5675(_5675 ? _5675->raw() : nullptr,_5675 ? _5675->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5675,_5665,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5665)->size(0)));
        int _5676 = (int)1;
        int _9485 = (int)1;
        int _9486 = (int)((_5665)->size(0));
        for (int _5677 = _9485; _5677 < _9486; ++_5677)
        {
          {
            if ((_ptr__5665[_ptr__5675[(_5677 - (int)1)]] < _ptr__5665[_ptr__5675[_5677]]))
            {
              {
                ++ _5676;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5676)));
        ((*inst)((int)0)) = _ptr__5665[_ptr__5675[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5676)));
        ((*cof)((int)0)) = _ptr__5666[_ptr__5675[(int)0]];
        int _5678 = (int)0;
        int _9487 = (int)1;
        int _9488 = (int)((_5665)->size(0));
        for (int _5679 = _9487; _5679 < _9488; ++_5679)
        {
          {
            if ((_ptr__5665[_ptr__5675[_5679]] > ((*inst)(_ptr__5675[(_5679 - (int)1)]))))
            {
              {
                ++ _5678;
                ((*inst)(_5678)) = _ptr__5665[_ptr__5675[_5679]];
                ((*cof)(_5678)) = _ptr__5666[_ptr__5675[_5679]];
              }
            }
            else
            {
              {
                ((*cof)(_5678)) = (((*cof)(_5678)) + _ptr__5666[_ptr__5675[_5679]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5680){ return new mosek::fusion::NDSparseArray(_5680); }mosek::fusion::NDSparseArray::NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5680) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5680); }void mosek::fusion::p_NDSparseArray::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5680){monty::rc_reserve __reserve_this(_pubthis);   {
    long long _5681 = _5680->numNonzeros();
    int _5682 = _5680->numColumns();
    int _5683 = _5680->numRows();
    std::shared_ptr< monty::ndarray< double,1 > > _5684 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5681)));
    _checked_ptr_1<double> _ptr__5684(_5684 ? _5684->raw() : nullptr,_5684 ? _5684->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5685 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5681)));
    _checked_ptr_1<int> _ptr__5685(_5685 ? _5685->raw() : nullptr,_5685 ? _5685->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5686 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5681)));
    _checked_ptr_1<int> _ptr__5686(_5686 ? _5686->raw() : nullptr,_5686 ? _5686->size(0) : 0);
    _5680->getDataAsTriplets(_5686,_5685,_5684);
    size = safe_mul( (long long)_5680->numRows(),(long long)_5680->numColumns() );
    dims = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5683),(int)(_5682)});
    std::vector<long long> _9489;
    for (long long _5687 = (long long)0, _9490 = _5681; _5687 < _9490 ; ++_5687)
    {
      _9489.push_back(safe_add( safe_mul( (long long)_ptr__5686[_5687],_5682 ),(long long)_ptr__5685[_5687] ));
    }
    auto _9491 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9489.size()),_9489.begin(),_9489.end()));
    inst = _9491;
    cof = _5684;
  }
}monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5688) { return mosek::fusion::p_NDSparseArray::make(_5688); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(monty::rc_ptr< ::mosek::fusion::Matrix > _5688){
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5688);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5689,    std::shared_ptr< monty::ndarray< long long,1 > > _5690,    std::shared_ptr< monty::ndarray< double,1 > > _5691) { return mosek::fusion::p_NDSparseArray::make(_5689,_5690,_5691); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5689,std::shared_ptr< monty::ndarray< long long,1 > > _5690,std::shared_ptr< monty::ndarray< double,1 > > _5691){
  _checked_ptr_1<int> _ptr__5689(_5689 ? _5689->raw() : nullptr, _5689 ? _5689->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5690(_5690 ? _5690->raw() : nullptr, _5690 ? _5690->size(0) : 0);
  _checked_ptr_1<double> _ptr__5691(_5691 ? _5691->raw() : nullptr, _5691 ? _5691->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5689,_5690,_5691);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5692,    std::shared_ptr< monty::ndarray< int,2 > > _5693,    std::shared_ptr< monty::ndarray< double,1 > > _5694) { return mosek::fusion::p_NDSparseArray::make(_5692,_5693,_5694); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5692,std::shared_ptr< monty::ndarray< int,2 > > _5693,std::shared_ptr< monty::ndarray< double,1 > > _5694){
  _checked_ptr_1<int> _ptr__5692(_5692 ? _5692->raw() : nullptr, _5692 ? _5692->size(0) : 0);
  _checked_ptr_1<double> _ptr__5694(_5694 ? _5694->raw() : nullptr, _5694 ? _5694->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5692,_5693,_5694);
}
void mosek::fusion::p_NDSparseArray::destroy(){cof.reset();inst.reset();dims.reset();}void mosek::fusion::NDSparseArray::destroy() { mosek::fusion::p_NDSparseArray::_get_impl(this)->destroy(); }mosek::fusion::DenseMatrix::DenseMatrix(mosek::fusion::p_DenseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "DenseMatrix()" << this << std::endl; */ }mosek::fusion::DenseMatrix::~DenseMatrix() {  /* std::cout << "~DenseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_DenseMatrix::p_DenseMatrix  (::mosek::fusion::DenseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5695,    int _5696,    std::shared_ptr< monty::ndarray< double,1 > > _5697){ return new mosek::fusion::DenseMatrix(_5695,_5696,_5697); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5695,    int _5696,    std::shared_ptr< monty::ndarray< double,1 > > _5697) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5695,_5696,_5697); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5695,    int _5696,    std::shared_ptr< monty::ndarray< double,1 > > _5697){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5697(_5697 ? _5697->raw() : nullptr, _5697 ? _5697->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5695,_5696);
    nnz = (long long)safe_mul( _5695,_5696 );
    data = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( _5695,_5696 ))));
    ::mosek::fusion::Utils::Tools::arraycopy(_5697,(int)0,data,(int)0,safe_mul( _5695,_5696 ));
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5698){ return new mosek::fusion::DenseMatrix(_5698); }mosek::fusion::DenseMatrix::DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5698) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5698); }void mosek::fusion::p_DenseMatrix::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5698){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(mosek::fusion::p_Matrix::_get_impl(_5698)->dimi,mosek::fusion::p_Matrix::_get_impl(_5698)->dimj);
    monty::rc_ptr< ::mosek::fusion::Matrix > _9492 = _5698;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9492.get()))
    {
      ::mosek::fusion::DenseMatrix::t _5699 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9492.get()));
      {
        data = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_DenseMatrix::_get_impl(_5699)->data);
      }
    }
    else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9492.get()))
    {
      ::mosek::fusion::SparseMatrix::t _5700 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9492.get()));
      {
        data = ::mosek::fusion::Utils::Tools::zeros(safe_mul( mosek::fusion::p_Matrix::_get_impl(_5700)->dimi,mosek::fusion::p_Matrix::_get_impl(_5700)->dimj ));
        long long _9493 = (long long)0;
        long long _9494 = mosek::fusion::p_SparseMatrix::_get_impl(_5700)->nnz;
        for (long long _5702 = _9493; _5702 < _9494; ++_5702)
        {
          {
            ((*data)(safe_add( safe_mul( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5700)->subi)(_5702)),dimj ),((*mosek::fusion::p_SparseMatrix::_get_impl(_5700)->subj)(_5702)) ))) = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5700)->val)(_5702));
          }
        }
      }
    }
    else
    {
      mosek::fusion::Matrix::t _5701 = _9492;
      {
        throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
      }
    }
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5703){ return new mosek::fusion::DenseMatrix(_5703); }mosek::fusion::DenseMatrix::DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5703) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5703); }void mosek::fusion::p_DenseMatrix::_initialize  (std::shared_ptr< monty::ndarray< double,2 > > _5703){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize((int)((_5703)->size(0)),(int)((_5703)->size(1)));
    std::vector<double> _9495;
    for (int _5704 = (int)0, _9496 = dimi; _5704 < _9496 ; ++_5704)
    {
      for (int _5705 = (int)0, _9497 = dimj; _5705 < _9497 ; ++_5705)
      {
        _9495.push_back(((*_5703)(_5704,_5705)));
      }
    }
    auto _9498 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9495.size()),_9495.begin(),_9495.end()));
    data = _9498;
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5706,    int _5707,    double _5708){ return new mosek::fusion::DenseMatrix(_5706,_5707,_5708); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5706,    int _5707,    double _5708) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5706,_5707,_5708); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5706,    int _5707,    double _5708){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(_5706,_5707);
    std::vector<double> _9499;
    for (int _5709 = (int)0, _9500 = _5706; _5709 < _9500 ; ++_5709)
    {
      for (int _5710 = (int)0, _9501 = _5707; _5710 < _9501 ; ++_5710)
      {
        _9499.push_back(_5708);
      }
    }
    auto _9502 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9499.size()),_9499.begin(),_9499.end()));
    data = _9502;
    nnz = (long long)safe_mul( _5706,_5707 );
  }
}std::string mosek::fusion::DenseMatrix :: toString() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_DenseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5711 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5711->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DenseMatrix("));
  _5711->__mosek_2fusion_2Utils_2StringBuffer__a(dimi);
  _5711->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
  _5711->__mosek_2fusion_2Utils_2StringBuffer__a(dimj);
  _5711->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (": "));
  int _5712 = (int)0;
  {
    int _5713 = (int)0;
    for(;(_5713 < dimi);++ _5713)
    {
      {
        if ((_5713 > (int)0))
        {
          {
            _5711->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
          }
        }
        {}
        _5711->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("[ "));
        _5711->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5712)));
        ++ _5712;
        {
          int _5714 = (int)1;
          for(;(_5714 < dimj);++ _5714)
          {
            {
              _5711->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
              _5711->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5712)));
              ++ _5712;
            }
          }
        }
        _5711->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ]"));
      }
    }
  }
  _5711->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _5711->toString();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix :: __mosek_2fusion_2DenseMatrix__transpose() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->__mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_DenseMatrix::__mosek_2fusion_2DenseMatrix__transpose(){
  std::shared_ptr< monty::ndarray< double,1 > > _5715 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5715(_5715 ? _5715->raw() : nullptr,_5715 ? _5715->size(0) : 0);
  int _5716 = (int)0;
  int _5717 = dimi;
  int _9503 = (int)0;
  int _9504 = dimi;
  for (int _5718 = _9503; _5718 < _9504; ++_5718)
  {
    {
      int _5719 = _5718;
      int _9505 = (int)0;
      int _9506 = dimj;
      for (int _5720 = _9505; _5720 < _9506; ++_5720)
      {
        {
          _ptr__5715[_5719] = ((*data)(_5716));
          _5719 = safe_add( _5719,_5717 );
          ++ _5716;
        }
      }
    }
  }
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(dimj,dimi,_5715)).as<::mosek::fusion::Matrix>();
}
bool mosek::fusion::DenseMatrix :: isSparse() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_DenseMatrix::isSparse(){
  return false;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::DenseMatrix :: getDataAsArray() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_DenseMatrix::getDataAsArray(){
  return ::mosek::fusion::Utils::Tools::arraycopy(data);
}
void mosek::fusion::DenseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5721,std::shared_ptr< monty::ndarray< int,1 > > _5722,std::shared_ptr< monty::ndarray< double,1 > > _5723) { mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsTriplets(_5721,_5722,_5723); }void mosek::fusion::p_DenseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5721,std::shared_ptr< monty::ndarray< int,1 > > _5722,std::shared_ptr< monty::ndarray< double,1 > > _5723){
  _checked_ptr_1<int> _ptr__5721(_5721 ? _5721->raw() : nullptr, _5721 ? _5721->size(0) : 0);
  _checked_ptr_1<int> _ptr__5722(_5722 ? _5722->raw() : nullptr, _5722 ? _5722->size(0) : 0);
  _checked_ptr_1<double> _ptr__5723(_5723 ? _5723->raw() : nullptr, _5723 ? _5723->size(0) : 0);
  if ((((int)((_5721)->size(0)) < nnz) || (((int)((_5722)->size(0)) < nnz) || ((int)((_5723)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(data,(int)0,_5723,(int)0,(int)((data)->size(0)));
  int _5724 = (int)0;
  int _9507 = (int)0;
  int _9508 = dimi;
  for (int _5725 = _9507; _5725 < _9508; ++_5725)
  {
    {
      int _9509 = (int)0;
      int _9510 = dimj;
      for (int _5726 = _9509; _5726 < _9510; ++_5726)
      {
        {
          _ptr__5721[_5724] = _5725;
          _ptr__5722[_5724] = _5726;
          ++ _5724;
        }
      }
    }
  }
}
double mosek::fusion::DenseMatrix :: get(int _5727,int _5728) { return mosek::fusion::p_DenseMatrix::_get_impl(this)->get(_5727,_5728); }double mosek::fusion::p_DenseMatrix::get(int _5727,int _5728){
  return ((*data)(safe_add( safe_mul( _5727,dimj ),_5728 )));
}
long long mosek::fusion::DenseMatrix :: numNonzeros() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_DenseMatrix::numNonzeros(){
  return (long long)safe_mul( dimi,dimj );
}
void mosek::fusion::p_DenseMatrix::destroy(){data.reset();}void mosek::fusion::DenseMatrix::destroy() { mosek::fusion::p_DenseMatrix::_get_impl(this)->destroy(); }mosek::fusion::SparseMatrix::SparseMatrix(mosek::fusion::p_SparseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "SparseMatrix()" << this << std::endl; */ }mosek::fusion::SparseMatrix::~SparseMatrix() {  /* std::cout << "~SparseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_SparseMatrix::p_SparseMatrix  (::mosek::fusion::SparseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5729,    int _5730,    std::shared_ptr< monty::ndarray< int,1 > > _5731,    std::shared_ptr< monty::ndarray< int,1 > > _5732,    std::shared_ptr< monty::ndarray< double,1 > > _5733,    long long _5734){ return new mosek::fusion::SparseMatrix(_5729,_5730,_5731,_5732,_5733,_5734); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5729,    int _5730,    std::shared_ptr< monty::ndarray< int,1 > > _5731,    std::shared_ptr< monty::ndarray< int,1 > > _5732,    std::shared_ptr< monty::ndarray< double,1 > > _5733,    long long _5734) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5729,_5730,_5731,_5732,_5733,_5734); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5729,    int _5730,    std::shared_ptr< monty::ndarray< int,1 > > _5731,    std::shared_ptr< monty::ndarray< int,1 > > _5732,    std::shared_ptr< monty::ndarray< double,1 > > _5733,    long long _5734){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5731(_5731 ? _5731->raw() : nullptr, _5731 ? _5731->size(0) : 0);
    _checked_ptr_1<int> _ptr__5732(_5732 ? _5732->raw() : nullptr, _5732 ? _5732->size(0) : 0);
    _checked_ptr_1<double> _ptr__5733(_5733 ? _5733->raw() : nullptr, _5733 ? _5733->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5729,_5730);
    if ((_5734 > (int)0))
    {
      {
        if ((((int)((_5731)->size(0)) < _5734) || (((int)((_5732)->size(0)) < _5734) || ((int)((_5733)->size(0)) < _5734))))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching arrays in sparse data."));
          }
        }
        {}
        long long _9511 = (long long)0;
        long long _9512 = _5734;
        for (long long _5735 = _9511; _5735 < _9512; ++_5735)
        {
          {
            if (((_ptr__5731[_5735] < (int)0) || ((_ptr__5731[_5735] >= dimi) || ((_ptr__5732[_5735] < (int)0) || (_ptr__5732[_5735] >= dimj)))))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Subscript out of bounds."));
              }
            }
            {}
          }
        }
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5736 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5737 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _5738 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 >(monty::shape((int)1)));
        ::mosek::fusion::p_CommonTools::tripletSort(_5731,_5732,_5733,_5736,_5737,_5738,_5734,dimi,dimj);
        subi = ((*_5736)((int)0));
        subj = ((*_5737)((int)0));
        val = ((*_5738)((int)0));
        nnz = (long long)((val)->size(0));
      }
    }
    else
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
        nnz = (long long)0;
      }
    }
  }
}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5739,    int _5740,    std::shared_ptr< monty::ndarray< int,1 > > _5741,    std::shared_ptr< monty::ndarray< int,1 > > _5742,    std::shared_ptr< monty::ndarray< double,1 > > _5743){ return new mosek::fusion::SparseMatrix(_5739,_5740,_5741,_5742,_5743); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5739,    int _5740,    std::shared_ptr< monty::ndarray< int,1 > > _5741,    std::shared_ptr< monty::ndarray< int,1 > > _5742,    std::shared_ptr< monty::ndarray< double,1 > > _5743) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5739,_5740,_5741,_5742,_5743); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5739,    int _5740,    std::shared_ptr< monty::ndarray< int,1 > > _5741,    std::shared_ptr< monty::ndarray< int,1 > > _5742,    std::shared_ptr< monty::ndarray< double,1 > > _5743){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5741(_5741 ? _5741->raw() : nullptr, _5741 ? _5741->size(0) : 0);
    _checked_ptr_1<int> _ptr__5742(_5742 ? _5742->raw() : nullptr, _5742 ? _5742->size(0) : 0);
    _checked_ptr_1<double> _ptr__5743(_5743 ? _5743->raw() : nullptr, _5743 ? _5743->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5739,_5740);
    int _5744 = (int)0;
    int _9513 = (int)0;
    int _9514 = (int)((_5743)->size(0));
    for (int _5745 = _9513; _5745 < _9514; ++_5745)
    {
      {
        if (((_ptr__5743[_5745] > (int)0) || (_ptr__5743[_5745] < (int)0)))
        {
          {
            ++ _5744;
          }
        }
        {}
      }
    }
    if (((_5744 > (int)0) && (_5744 < (int)((_5741)->size(0)))))
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5744)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5744)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5744)));
        nnz = _5744;
        int _5746 = (int)0;
        int _9515 = (int)0;
        int _9516 = (int)((_5743)->size(0));
        for (int _5747 = _9515; _5747 < _9516; ++_5747)
        {
          {
            if (((_ptr__5743[_5747] < (int)0) || (_ptr__5743[_5747] > (int)0)))
            {
              {
                ((*val)(_5746)) = _ptr__5743[_5747];
                ((*subj)(_5746)) = _ptr__5742[_5747];
                ((*subi)(_5746)) = _ptr__5741[_5747];
                ++ _5746;
              }
            }
            {}
          }
        }
      }
    }
    else
    {
      {
        subi = _5741;
        subj = _5742;
        val = _5743;
        if ((NULL == _5741.get()))
        {
          {
            nnz = (long long)0;
          }
        }
        else
        {
          {
            nnz = (long long)((subi)->size(0));
          }
        }
      }
    }
  }
}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SparseMatrix::formPtrb(){
  std::shared_ptr< monty::ndarray< long long,1 > > _5748 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( dimi,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5748(_5748 ? _5748->raw() : nullptr,_5748 ? _5748->size(0) : 0);
  long long _5749 = (long long)0;
  int _9517 = (int)0;
  int _9518 = dimi;
  for (int _5750 = _9517; _5750 < _9518; ++_5750)
  {
    {
      _ptr__5748[_5750] = _5749;
      {
        for(;((_5749 < nnz) && (((*subi)(_5749)) == _5750));++ _5749)
        {
          {
          }
        }
      }
    }
  }
  _ptr__5748[dimi] = _5749;
  return _5748;
}
std::string mosek::fusion::SparseMatrix :: toString() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_SparseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5751 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5751->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SparseMatrix("))->__mosek_2fusion_2Utils_2StringBuffer__a(dimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(dimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (", ["));
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      _5751->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
      int _9519 = (int)1;
      int _9520 = (int)((subi)->size(0));
      for (int _5752 = _9519; _5752 < _9520; ++_5752)
      {
        {
          _5751->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)(_5752)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)(_5752)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)(_5752)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
        }
      }
    }
  }
  {}
  _5751->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ])"));
  return _5751->toString();
}
long long mosek::fusion::SparseMatrix :: numNonzeros() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_SparseMatrix::numNonzeros(){
  return nnz;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix :: __mosek_2fusion_2SparseMatrix__transpose() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->__mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_SparseMatrix::__mosek_2fusion_2SparseMatrix__transpose(){
  return ::mosek::fusion::p_Matrix::sparse(dimj,dimi,subj,subi,val);
}
bool mosek::fusion::SparseMatrix :: isSparse() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_SparseMatrix::isSparse(){
  return true;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SparseMatrix :: getDataAsArray() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_SparseMatrix::getDataAsArray(){
  std::shared_ptr< monty::ndarray< double,1 > > _5753 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5753(_5753 ? _5753->raw() : nullptr,_5753 ? _5753->size(0) : 0);
  int _9521 = (int)0;
  int _9522 = (int)((subi)->size(0));
  for (int _5754 = _9521; _5754 < _9522; ++_5754)
  {
    {
      _ptr__5753[safe_add( safe_mul( ((*subi)(_5754)),dimj ),((*subj)(_5754)) )] = ((*val)(_5754));
    }
  }
  return _5753;
}
void mosek::fusion::SparseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5755,std::shared_ptr< monty::ndarray< int,1 > > _5756,std::shared_ptr< monty::ndarray< double,1 > > _5757) { mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsTriplets(_5755,_5756,_5757); }void mosek::fusion::p_SparseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5755,std::shared_ptr< monty::ndarray< int,1 > > _5756,std::shared_ptr< monty::ndarray< double,1 > > _5757){
  _checked_ptr_1<int> _ptr__5755(_5755 ? _5755->raw() : nullptr, _5755 ? _5755->size(0) : 0);
  _checked_ptr_1<int> _ptr__5756(_5756 ? _5756->raw() : nullptr, _5756 ? _5756->size(0) : 0);
  _checked_ptr_1<double> _ptr__5757(_5757 ? _5757->raw() : nullptr, _5757 ? _5757->size(0) : 0);
  if ((((long long)((_5755)->size(0)) < nnz) || (((long long)((_5756)->size(0)) < nnz) || ((long long)((_5757)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(subi,(long long)0,_5755,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(subj,(long long)0,_5756,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(val,(long long)0,_5757,(long long)0,nnz);
    }
  }
  {}
}
double mosek::fusion::SparseMatrix :: get(int _5758,int _5759) { return mosek::fusion::p_SparseMatrix::_get_impl(this)->get(_5758,_5759); }double mosek::fusion::p_SparseMatrix::get(int _5758,int _5759){
  if (((_5758 < (int)0) || ((_5758 >= dimi) || ((_5759 < (int)0) || (_5759 >= dimj)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index out if bounds"));
    }
  }
  {}
  int _5760 = (int)((subi)->size(0));
  int _5761 = (int)0;
  while ( ((_5760 - _5761) > (int)1) )
  {
    {
      int _5762 = (safe_add( _5761,_5760 ) / (int)2);
      if (((((*subi)(_5762)) < _5758) || ((((*subi)(_5762)) == _5758) && (((*subj)(_5762)) < _5759))))
      {
        {
          _5761 = _5762;
        }
      }
      else if(((((*subi)(_5762)) > _5758) || ((((*subi)(_5762)) == _5758) && (((*subj)(_5762)) > _5759))))
      {
        {
          _5760 = _5762;
        }
      }
      else
      {
        {
          return ((*val)(_5762));
        }
      }
    }
  }
  if (((((*subi)(_5761)) == _5758) && (((*subj)(_5761)) == _5759)))
  {
    {
      return ((*val)(_5761));
    }
  }
  else
  {
    {
      return 0.0;
    }
  }
}
void mosek::fusion::p_SparseMatrix::destroy(){val.reset();subj.reset();subi.reset();}void mosek::fusion::SparseMatrix::destroy() { mosek::fusion::p_SparseMatrix::_get_impl(this)->destroy(); }mosek::fusion::Matrix::Matrix(mosek::fusion::p_Matrix *_impl) : _impl(_impl) { /*std::cout << "Matrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Matrix::~Matrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_Matrix::p_Matrix  (::mosek::fusion::Matrix * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Matrix::_initialize  (int _5763,    int _5764){monty::rc_reserve __reserve_this(_pubthis);   {
    if (((_5763 < (int)0) || (_5764 < (int)0)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimensions"));
      }
    }
    {}
    dimi = _5763;
    dimj = _5764;
  }
}std::string mosek::fusion::Matrix :: toString() { return mosek::fusion::p_Matrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_Matrix::toString(){
  return std::string ("");
}
void mosek::fusion::p_Matrix::switchDims(){
  int _5765 = dimi;
  dimi = dimj;
  dimj = _5765;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5766,    monty::rc_ptr< ::mosek::fusion::Matrix > _5767) { return mosek::fusion::p_Matrix::diag(_5766,_5767); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5766,monty::rc_ptr< ::mosek::fusion::Matrix > _5767){
  std::vector<monty::rc_ptr< ::mosek::fusion::Matrix >> _9523;
  for (int _5768 = (int)0, _9524 = _5766; _5768 < _9524 ; ++_5768)
  {
    _9523.push_back(_5767);
  }
  auto _9525 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 >(monty::shape(_9523.size()),_9523.begin(),_9523.end()));
  return ::mosek::fusion::p_Matrix::diag(_9525);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5769) { return mosek::fusion::p_Matrix::diag(_5769); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5769){
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5770 = _5769;
  long long _5771 = (long long)0;
  int _5772 = (int)0;
  int _5773 = (int)0;
  int _9526 = (int)0;
  int _9527 = (int)((_5769)->size(0));
  for (int _5774 = _9526; _5774 < _9527; ++_5774)
  {
    {
      _5773 = safe_add( _5773,mosek::fusion::p_Matrix::_get_impl(((*_5769)(_5774)))->dimi );
      _5772 = safe_add( _5772,mosek::fusion::p_Matrix::_get_impl(((*_5769)(_5774)))->dimj );
      _5771 = safe_add( _5771,((*_5769)(_5774))->numNonzeros() );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5775 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5771)));
  _checked_ptr_1<int> _ptr__5775(_5775 ? _5775->raw() : nullptr,_5775 ? _5775->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5776 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5771)));
  _checked_ptr_1<int> _ptr__5776(_5776 ? _5776->raw() : nullptr,_5776 ? _5776->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5777 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5771)));
  _checked_ptr_1<double> _ptr__5777(_5777 ? _5777->raw() : nullptr,_5777 ? _5777->size(0) : 0);
  {
    int _5778 = (int)0;
    int _5779 = (int)0;
    long long _5780 = (long long)0;
    int _9528 = (int)0;
    int _9529 = (int)((_5769)->size(0));
    for (int _5781 = _9528; _5781 < _9529; ++_5781)
    {
      {
        long long _5782 = ((*_5769)(_5781))->numNonzeros();
        std::shared_ptr< monty::ndarray< double,1 > > _5783 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5782)));
        _checked_ptr_1<double> _ptr__5783(_5783 ? _5783->raw() : nullptr,_5783 ? _5783->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5784 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5782)));
        _checked_ptr_1<int> _ptr__5784(_5784 ? _5784->raw() : nullptr,_5784 ? _5784->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5785 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5782)));
        _checked_ptr_1<int> _ptr__5785(_5785 ? _5785->raw() : nullptr,_5785 ? _5785->size(0) : 0);
        ((*_5769)(_5781))->getDataAsTriplets(_5785,_5784,_5783);
        ::mosek::fusion::Utils::Tools::arraycopy(_5783,(long long)0,_5777,_5780,_5782);
        long long _9530 = (long long)0;
        long long _9531 = _5782;
        for (long long _5786 = _9530; _5786 < _9531; ++_5786)
        {
          {
            _ptr__5775[safe_add( _5780,_5786 )] = safe_add( _ptr__5785[_5786],_5779 );
            _ptr__5776[safe_add( _5780,_5786 )] = safe_add( _ptr__5785[_5786],_5778 );
          }
        }
        _5780 = safe_add( _5780,_5782 );
        _5779 = safe_add( _5779,mosek::fusion::p_Matrix::_get_impl(((*_5769)(_5781)))->dimi );
        _5778 = safe_add( _5778,mosek::fusion::p_Matrix::_get_impl(((*_5769)(_5781)))->dimj );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5773,_5772,_5775,_5776,_5777)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5787,    double _5788,    int _5789) { return mosek::fusion::p_Matrix::antidiag(_5787,_5788,_5789); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5787,double _5788,int _5789){
  if (((_5789 < _5787) && (_5789 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5788,(_5787 - _5789)),_5789);
    }
  }
  else if(((_5789 > (-_5787)) && (_5789 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5788,safe_add( _5787,_5789 )),_5789);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5790,    double _5791) { return mosek::fusion::p_Matrix::antidiag(_5790,_5791); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5790,double _5791){
  return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5791,_5790),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5792,    double _5793,    int _5794) { return mosek::fusion::p_Matrix::diag(_5792,_5793,_5794); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5792,double _5793,int _5794){
  if (((_5794 < _5792) && (_5794 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5793,(_5792 - _5794)),_5794);
    }
  }
  else if(((_5794 > (-_5792)) && (_5794 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5793,safe_add( _5792,_5794 )),_5794);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5795,    double _5796) { return mosek::fusion::p_Matrix::diag(_5795,_5796); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5795,double _5796){
  return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5796,_5795),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5797,    int _5798) { return mosek::fusion::p_Matrix::antidiag(_5797,_5798); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5797,int _5798){
  _checked_ptr_1<double> _ptr__5797(_5797 ? _5797->raw() : nullptr, _5797 ? _5797->size(0) : 0);
  int _9532;
  bool _9533 = (_5798 > (int)0);
  if (_9533)
  {
    _9532 = _5798;
  }
  else
  {
    _9532 = (-_5798);
  }
  int _5799 = _9532;
  int _5800 = safe_add( (int)((_5797)->size(0)),_5799 );
  int _5801 = (int)((_5797)->size(0));
  if ((_5798 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5802 = ::mosek::fusion::Utils::Tools::range(_5798,safe_add( _5801,_5798 ));
      _checked_ptr_1<int> _ptr__5802(_5802 ? _5802->raw() : nullptr,_5802 ? _5802->size(0) : 0);
      std::vector<int> _9534;
      for (int _5804 = (int)1, _9535 = safe_add( _5801,(int)1 ); _5804 < _9535 ; ++_5804)
      {
        _9534.push_back((safe_add( _5801,_5798 ) - _5804));
      }
      auto _9536 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9534.size()),_9534.begin(),_9534.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5803 = _9536;
      _checked_ptr_1<int> _ptr__5803(_5803 ? _5803->raw() : nullptr,_5803 ? _5803->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5800,_5800,_5802,_5803,_5797)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5805 = ::mosek::fusion::Utils::Tools::range((int)0,_5801);
      _checked_ptr_1<int> _ptr__5805(_5805 ? _5805->raw() : nullptr,_5805 ? _5805->size(0) : 0);
      std::vector<int> _9537;
      for (int _5807 = (int)1, _9538 = safe_add( _5801,(int)1 ); _5807 < _9538 ; ++_5807)
      {
        _9537.push_back((_5801 - _5807));
      }
      auto _9539 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9537.size()),_9537.begin(),_9537.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5806 = _9539;
      _checked_ptr_1<int> _ptr__5806(_5806 ? _5806->raw() : nullptr,_5806 ? _5806->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5800,_5800,_5805,_5806,_5797)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5808) { return mosek::fusion::p_Matrix::antidiag(_5808); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5808){
  _checked_ptr_1<double> _ptr__5808(_5808 ? _5808->raw() : nullptr, _5808 ? _5808->size(0) : 0);
  return ::mosek::fusion::p_Matrix::antidiag(_5808,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5809,    int _5810) { return mosek::fusion::p_Matrix::diag(_5809,_5810); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5809,int _5810){
  _checked_ptr_1<double> _ptr__5809(_5809 ? _5809->raw() : nullptr, _5809 ? _5809->size(0) : 0);
  int _9540;
  bool _9541 = (_5810 > (int)0);
  if (_9541)
  {
    _9540 = _5810;
  }
  else
  {
    _9540 = (-_5810);
  }
  int _5811 = _9540;
  int _5812 = safe_add( (int)((_5809)->size(0)),_5811 );
  int _5813 = (int)((_5809)->size(0));
  if ((_5810 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5814 = ::mosek::fusion::Utils::Tools::range((int)0,_5813);
      _checked_ptr_1<int> _ptr__5814(_5814 ? _5814->raw() : nullptr,_5814 ? _5814->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5815 = ::mosek::fusion::Utils::Tools::range(_5811,safe_add( _5813,_5811 ));
      _checked_ptr_1<int> _ptr__5815(_5815 ? _5815->raw() : nullptr,_5815 ? _5815->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5812,_5812,_5814,_5815,_5809)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5816 = ::mosek::fusion::Utils::Tools::range(_5811,safe_add( _5813,_5811 ));
      _checked_ptr_1<int> _ptr__5816(_5816 ? _5816->raw() : nullptr,_5816 ? _5816->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5817 = ::mosek::fusion::Utils::Tools::range((int)0,_5813);
      _checked_ptr_1<int> _ptr__5817(_5817 ? _5817->raw() : nullptr,_5817 ? _5817->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5812,_5812,_5816,_5817,_5809)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5818) { return mosek::fusion::p_Matrix::diag(_5818); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5818){
  _checked_ptr_1<double> _ptr__5818(_5818 ? _5818->raw() : nullptr, _5818 ? _5818->size(0) : 0);
  return ::mosek::fusion::p_Matrix::diag(_5818,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::ones  ( int _5819,    int _5820) { return mosek::fusion::p_Matrix::ones(_5819,_5820); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::ones(int _5819,int _5820){
  return ::mosek::fusion::p_Matrix::dense(_5819,_5820,1.0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::eye  ( int _5821) { return mosek::fusion::p_Matrix::eye(_5821); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::eye(int _5821){
  std::vector<double> _9542;
  for (int _5822 = (int)0, _9543 = _5821; _5822 < _9543 ; ++_5822)
  {
    _9542.push_back(1.0);
  }
  auto _9544 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9542.size()),_9542.begin(),_9542.end()));
  return ::mosek::fusion::p_Matrix::diag(_9544);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5823) { return mosek::fusion::p_Matrix::dense(_5823); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5823){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5823)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5824,    int _5825,    double _5826) { return mosek::fusion::p_Matrix::dense(_5824,_5825,_5826); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5824,int _5825,double _5826){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5824,_5825,_5826)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5827,    int _5828,    std::shared_ptr< monty::ndarray< double,1 > > _5829) { return mosek::fusion::p_Matrix::dense(_5827,_5828,_5829); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5827,int _5828,std::shared_ptr< monty::ndarray< double,1 > > _5829){
  _checked_ptr_1<double> _ptr__5829(_5829 ? _5829->raw() : nullptr, _5829 ? _5829->size(0) : 0);
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5827,_5828,_5829)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( std::shared_ptr< monty::ndarray< double,2 > > _5830) { return mosek::fusion::p_Matrix::dense(_5830); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(std::shared_ptr< monty::ndarray< double,2 > > _5830){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5830)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5831) { return mosek::fusion::p_Matrix::sparse(_5831); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5831){
  std::shared_ptr< monty::ndarray< int,1 > > _5832 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5831->numNonzeros())));
  _checked_ptr_1<int> _ptr__5832(_5832 ? _5832->raw() : nullptr,_5832 ? _5832->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5833 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5831->numNonzeros())));
  _checked_ptr_1<int> _ptr__5833(_5833 ? _5833->raw() : nullptr,_5833 ? _5833->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5834 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5831->numNonzeros())));
  _checked_ptr_1<double> _ptr__5834(_5834 ? _5834->raw() : nullptr,_5834 ? _5834->size(0) : 0);
  _5831->getDataAsTriplets(_5832,_5833,_5834);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5831->numRows(),_5831->numColumns(),_5832,_5833,_5834)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5835) { return mosek::fusion::p_Matrix::sparse(_5835); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5835){
  int _5836 = (int)((_5835)->size(0));
  int _5837 = (int)((((*_5835)((int)0)))->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _5838 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5836)));
  _checked_ptr_1<int> _ptr__5838(_5838 ? _5838->raw() : nullptr,_5838 ? _5838->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5839 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5837)));
  _checked_ptr_1<int> _ptr__5839(_5839 ? _5839->raw() : nullptr,_5839 ? _5839->size(0) : 0);
  long long _5840 = (long long)0;
  int _5841 = (int)0;
  {
    int _5842 = (int)0;
    for(;(_5842 < _5836);++ _5842)
    {
      {
        {
          int _5843 = (int)0;
          for(;(_5843 < _5837);++ _5843)
          {
            {
              monty::rc_ptr< ::mosek::fusion::Matrix > _5844 = ((*((*_5835)(_5842)))(_5843));
              if ((NULL != _5844.get()))
              {
                {
                  if ((_ptr__5839[_5843] == (int)0))
                  {
                    {
                      _ptr__5839[_5843] = mosek::fusion::p_Matrix::_get_impl(_5844)->dimj;
                    }
                  }
                  else if((_ptr__5839[_5843] != mosek::fusion::p_Matrix::_get_impl(_5844)->dimj))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  if ((_ptr__5838[_5842] == (int)0))
                  {
                    {
                      _ptr__5838[_5842] = mosek::fusion::p_Matrix::_get_impl(_5844)->dimi;
                    }
                  }
                  else if((_ptr__5838[_5842] != mosek::fusion::p_Matrix::_get_impl(_5844)->dimi))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  _5840 = safe_add( _5840,_5844->numNonzeros() );
                }
              }
              {}
              ++ _5841;
            }
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5845 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5840)));
  _checked_ptr_1<double> _ptr__5845(_5845 ? _5845->raw() : nullptr,_5845 ? _5845->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5846 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5840)));
  _checked_ptr_1<int> _ptr__5846(_5846 ? _5846->raw() : nullptr,_5846 ? _5846->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5847 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5840)));
  _checked_ptr_1<int> _ptr__5847(_5847 ? _5847->raw() : nullptr,_5847 ? _5847->size(0) : 0);
  int _5848 = (int)0;
  int _5849 = (int)0;
  {
    int _5850 = (int)0;
    for(;(_5850 < _5836);++ _5850)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _5851 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5837)));
        _checked_ptr_1<int> _ptr__5851(_5851 ? _5851->raw() : nullptr,_5851 ? _5851->size(0) : 0);
        {
          int _5852 = (int)0;
          for(;(_5852 < _ptr__5838[_5850]);++ _5852)
          {
            {
              int _5853 = (int)0;
              {
                int _5854 = (int)0;
                for(;(_5854 < _5837);++ _5854)
                {
                  {
                    monty::rc_ptr< ::mosek::fusion::Matrix > _5855 = ((*((*_5835)(_5850)))(_5854));
                    if ((NULL != _5855.get()))
                    {
                      {
                        monty::rc_ptr< ::mosek::fusion::Matrix > _9545 = _5855;
                        if (false) {}
                        else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9545.get()))
                        {
                          ::mosek::fusion::DenseMatrix::t _5856 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9545.get()));
                          {
                            int _5859 = _ptr__5851[_5854];
                            {
                              int _5860 = (int)0;
                              for(;(_5860 < mosek::fusion::p_Matrix::_get_impl(_5856)->dimj);++ _5860)
                              {
                                {
                                  _ptr__5845[_5848] = ((*mosek::fusion::p_DenseMatrix::_get_impl(_5856)->data)(_5859));
                                  _ptr__5846[_5848] = safe_add( _5849,_5852 );
                                  _ptr__5847[_5848] = safe_add( _5853,_5860 );
                                  ++ _5859;
                                  ++ _5848;
                                }
                              }
                            }
                            _ptr__5851[_5854] = _5859;
                          }
                        }
                        else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9545.get()))
                        {
                          ::mosek::fusion::SparseMatrix::t _5857 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9545.get()));
                          {
                            int _5861;
                            {
                              _5861 = _ptr__5851[_5854];
                              for(;((_5861 < mosek::fusion::p_SparseMatrix::_get_impl(_5857)->nnz) && (((*mosek::fusion::p_SparseMatrix::_get_impl(_5857)->subi)(_5861)) == _5852));++ _5861)
                              {
                                {
                                  _ptr__5845[_5848] = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5857)->val)(_5861));
                                  _ptr__5847[_5848] = safe_add( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5857)->subj)(_5861)),_5853 );
                                  _ptr__5846[_5848] = safe_add( _5849,_5852 );
                                  ++ _5848;
                                }
                              }
                            }
                            _ptr__5851[_5854] = _5861;
                          }
                        }
                        else
                        {
                          mosek::fusion::Matrix::t _5858 = _9545;
                          {
                            throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
                          }
                        }
                      }
                    }
                    {}
                    _5853 = safe_add( _5853,_ptr__5839[_5854] );
                  }
                }
              }
            }
          }
        }
        _5849 = safe_add( _5849,_ptr__5838[_5850] );
      }
    }
  }
  int _5862 = (int)0;
  int _5863 = (int)0;
  {
    int _5864 = (int)0;
    for(;(_5864 < _5836);++ _5864)
    {
      {
        _5862 = safe_add( _5862,_ptr__5838[_5864] );
      }
    }
  }
  {
    int _5865 = (int)0;
    for(;(_5865 < _5837);++ _5865)
    {
      {
        _5863 = safe_add( _5863,_ptr__5839[_5865] );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5862,_5863,_5846,_5847,_5845)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< double,2 > > _5866) { return mosek::fusion::p_Matrix::sparse(_5866); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< double,2 > > _5866){
  int _5867 = (int)((_5866)->size(0));
  int _5868 = (int)((_5866)->size(1));
  long long _5869 = (long long)safe_mul( _5867,_5868 );
  std::vector<int> _9546;
  for (int _5871 = (int)0, _9547 = _5867; _5871 < _9547 ; ++_5871)
  {
    for (int _5872 = (int)0, _9548 = _5868; _5872 < _9548 ; ++_5872)
    {
      _9546.push_back(_5871);
    }
  }
  auto _9549 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9546.size()),_9546.begin(),_9546.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5870 = _9549;
  _checked_ptr_1<int> _ptr__5870(_5870 ? _5870->raw() : nullptr,_5870 ? _5870->size(0) : 0);
  std::vector<int> _9550;
  for (int _5874 = (int)0, _9551 = _5867; _5874 < _9551 ; ++_5874)
  {
    for (int _5875 = (int)0, _9552 = _5868; _5875 < _9552 ; ++_5875)
    {
      _9550.push_back(_5875);
    }
  }
  auto _9553 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9550.size()),_9550.begin(),_9550.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5873 = _9553;
  _checked_ptr_1<int> _ptr__5873(_5873 ? _5873->raw() : nullptr,_5873 ? _5873->size(0) : 0);
  std::vector<double> _9554;
  for (int _5877 = (int)0, _9555 = _5867; _5877 < _9555 ; ++_5877)
  {
    for (int _5878 = (int)0, _9556 = _5868; _5878 < _9556 ; ++_5878)
    {
      _9554.push_back(((*_5866)(_5877,_5878)));
    }
  }
  auto _9557 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9554.size()),_9554.begin(),_9554.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5876 = _9557;
  _checked_ptr_1<double> _ptr__5876(_5876 ? _5876->raw() : nullptr,_5876 ? _5876->size(0) : 0);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5867,_5868,_5870,_5873,_5876)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5879,    int _5880) { return mosek::fusion::p_Matrix::sparse(_5879,_5880); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5879,int _5880){
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5879,_5880,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),(long long)0)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5881,    int _5882,    std::shared_ptr< monty::ndarray< int,1 > > _5883,    std::shared_ptr< monty::ndarray< int,1 > > _5884,    double _5885) { return mosek::fusion::p_Matrix::sparse(_5881,_5882,_5883,_5884,_5885); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5881,int _5882,std::shared_ptr< monty::ndarray< int,1 > > _5883,std::shared_ptr< monty::ndarray< int,1 > > _5884,double _5885){
  _checked_ptr_1<int> _ptr__5883(_5883 ? _5883->raw() : nullptr, _5883 ? _5883->size(0) : 0);
  _checked_ptr_1<int> _ptr__5884(_5884 ? _5884->raw() : nullptr, _5884 ? _5884->size(0) : 0);
  int _5886 = (int)0;
  if ((NULL != _5883.get()))
  {
    {
      _5886 = (int)((_5883)->size(0));
    }
  }
  else if((NULL != _5884.get()))
  {
    {
      _5886 = (int)((_5884)->size(0));
    }
  }
  {}
  return ::mosek::fusion::p_Matrix::sparse(_5881,_5882,_5883,_5884,::mosek::fusion::Utils::Tools::makevector(_5885,_5886));
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5887,    std::shared_ptr< monty::ndarray< int,1 > > _5888,    double _5889) { return mosek::fusion::p_Matrix::sparse(_5887,_5888,_5889); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5887,std::shared_ptr< monty::ndarray< int,1 > > _5888,double _5889){
  _checked_ptr_1<int> _ptr__5887(_5887 ? _5887->raw() : nullptr, _5887 ? _5887->size(0) : 0);
  _checked_ptr_1<int> _ptr__5888(_5888 ? _5888->raw() : nullptr, _5888 ? _5888->size(0) : 0);
  int _5890 = (int)0;
  int _5891 = (int)0;
  int _5892 = (int)((_5887)->size(0));
  if ((_5892 > (int)((_5888)->size(0))))
  {
    {
      _5892 = (int)((_5888)->size(0));
    }
  }
  {}
  int _9558 = (int)0;
  int _9559 = _5892;
  for (int _5893 = _9558; _5893 < _9559; ++_5893)
  {
    {
      if ((_5891 < _ptr__5887[_5893]))
      {
        {
          _5891 = _ptr__5887[_5893];
        }
      }
      {}
      if ((_5890 < _ptr__5888[_5893]))
      {
        {
          _5890 = _ptr__5888[_5893];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5891,(int)1 ),safe_add( _5890,(int)1 ),_5887,_5888,_5889);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5894,    std::shared_ptr< monty::ndarray< int,1 > > _5895,    std::shared_ptr< monty::ndarray< double,1 > > _5896) { return mosek::fusion::p_Matrix::sparse(_5894,_5895,_5896); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5894,std::shared_ptr< monty::ndarray< int,1 > > _5895,std::shared_ptr< monty::ndarray< double,1 > > _5896){
  _checked_ptr_1<int> _ptr__5894(_5894 ? _5894->raw() : nullptr, _5894 ? _5894->size(0) : 0);
  _checked_ptr_1<int> _ptr__5895(_5895 ? _5895->raw() : nullptr, _5895 ? _5895->size(0) : 0);
  _checked_ptr_1<double> _ptr__5896(_5896 ? _5896->raw() : nullptr, _5896 ? _5896->size(0) : 0);
  int _5897 = (int)0;
  int _5898 = (int)0;
  int _5899 = (int)((_5894)->size(0));
  if ((_5899 > (int)((_5895)->size(0))))
  {
    {
      _5899 = (int)((_5895)->size(0));
    }
  }
  {}
  if ((_5899 > (int)((_5896)->size(0))))
  {
    {
      _5899 = (int)((_5896)->size(0));
    }
  }
  {}
  int _9560 = (int)0;
  int _9561 = _5899;
  for (int _5900 = _9560; _5900 < _9561; ++_5900)
  {
    {
      if ((_5898 < _ptr__5894[_5900]))
      {
        {
          _5898 = _ptr__5894[_5900];
        }
      }
      {}
      if ((_5897 < _ptr__5895[_5900]))
      {
        {
          _5897 = _ptr__5895[_5900];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5898,(int)1 ),safe_add( _5897,(int)1 ),_5894,_5895,_5896);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5901,    int _5902,    std::shared_ptr< monty::ndarray< int,1 > > _5903,    std::shared_ptr< monty::ndarray< int,1 > > _5904,    std::shared_ptr< monty::ndarray< double,1 > > _5905) { return mosek::fusion::p_Matrix::sparse(_5901,_5902,_5903,_5904,_5905); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5901,int _5902,std::shared_ptr< monty::ndarray< int,1 > > _5903,std::shared_ptr< monty::ndarray< int,1 > > _5904,std::shared_ptr< monty::ndarray< double,1 > > _5905){
  _checked_ptr_1<int> _ptr__5903(_5903 ? _5903->raw() : nullptr, _5903 ? _5903->size(0) : 0);
  _checked_ptr_1<int> _ptr__5904(_5904 ? _5904->raw() : nullptr, _5904 ? _5904->size(0) : 0);
  _checked_ptr_1<double> _ptr__5905(_5905 ? _5905->raw() : nullptr, _5905 ? _5905->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9562;
  bool _9563 = (NULL != _5905.get());
  if (_9563)
  {
    _9562 = _5905;
  }
  else
  {
    _9562 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5906 = _9562;
  _checked_ptr_1<double> _ptr__5906(_5906 ? _5906->raw() : nullptr,_5906 ? _5906->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9564;
  bool _9565 = (NULL != _5904.get());
  if (_9565)
  {
    _9564 = _5904;
  }
  else
  {
    _9564 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5907 = _9564;
  _checked_ptr_1<int> _ptr__5907(_5907 ? _5907->raw() : nullptr,_5907 ? _5907->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9566;
  bool _9567 = (NULL != _5903.get());
  if (_9567)
  {
    _9566 = _5903;
  }
  else
  {
    _9566 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5908 = _9566;
  _checked_ptr_1<int> _ptr__5908(_5908 ? _5908->raw() : nullptr,_5908 ? _5908->size(0) : 0);
  long long _5909 = (long long)((_5908)->size(0));
  if ((((long long)((_5907)->size(0)) != _5909) || ((long long)((_5906)->size(0)) != _5909)))
  {
    {
      throw ::mosek::fusion::SparseFormatError(std::string ("Arrays defining sparse data have different lengths"));
    }
  }
  {}
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5901,_5902,_5908,_5907,_5906,_5909)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix :: transpose() { return __mosek_2fusion_2Matrix__transpose(); }
int mosek::fusion::Matrix :: numColumns() { return mosek::fusion::p_Matrix::_get_impl(this)->numColumns(); }int mosek::fusion::p_Matrix::numColumns(){
  return dimj;
}
int mosek::fusion::Matrix :: numRows() { return mosek::fusion::p_Matrix::_get_impl(this)->numRows(); }int mosek::fusion::p_Matrix::numRows(){
  return dimi;
}
void mosek::fusion::p_Matrix::destroy(){}void mosek::fusion::Matrix::destroy() { mosek::fusion::p_Matrix::_get_impl(this)->destroy(); }mosek::fusion::UnimplementedError::UnimplementedError  ( const std::string &  _5915) : RuntimeException(_5915)  {
  }
mosek::fusion::FatalError::FatalError  ( const std::string &  _5916) : RuntimeException(_5916)  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( ::mosek::fusion::FusionException _5917) : RuntimeException(_5917.toString())  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( const std::string &  _5918) : RuntimeException(_5918)  {
  }
mosek::fusion::SparseFormatError::SparseFormatError  ( const std::string &  _5919) : mosek::fusion::FusionRuntimeException(_5919)  {
  }
mosek::fusion::SolutionError::SolutionError  ( ) : mosek::fusion::FusionException(std::string ("Solution is invalid or undefined"))  {
  }
mosek::fusion::SolutionError::SolutionError  ( const std::string &  _5920) : mosek::fusion::FusionException(_5920)  {
  }
mosek::fusion::SliceError::SliceError  ( ) : mosek::fusion::FusionRuntimeException(std::string ("Invalid slice range"))  {
  }
mosek::fusion::SliceError::SliceError  ( const std::string &  _5921) : mosek::fusion::FusionRuntimeException(_5921)  {
  }
mosek::fusion::SetDefinitionError::SetDefinitionError  ( const std::string &  _5922) : mosek::fusion::FusionRuntimeException(_5922)  {
  }
mosek::fusion::OptimizeError::OptimizeError  ( const std::string &  _5923) : mosek::fusion::FusionRuntimeException(_5923)  {
  }
mosek::fusion::NameError::NameError  ( const std::string &  _5924) : mosek::fusion::FusionRuntimeException(_5924)  {
  }
mosek::fusion::ModelError::ModelError  ( const std::string &  _5925) : mosek::fusion::FusionRuntimeException(_5925)  {
  }
mosek::fusion::MatrixError::MatrixError  ( const std::string &  _5926) : mosek::fusion::FusionRuntimeException(_5926)  {
  }
mosek::fusion::DimensionError::DimensionError  ( const std::string &  _5927) : mosek::fusion::FusionRuntimeException(_5927)  {
  }
mosek::fusion::LengthError::LengthError  ( const std::string &  _5928) : mosek::fusion::FusionRuntimeException(_5928)  {
  }
mosek::fusion::RangeError::RangeError  ( const std::string &  _5929) : mosek::fusion::FusionRuntimeException(_5929)  {
  }
mosek::fusion::IndexError::IndexError  ( const std::string &  _5930) : mosek::fusion::FusionRuntimeException(_5930)  {
  }
mosek::fusion::DomainError::DomainError  ( const std::string &  _5931) : mosek::fusion::FusionRuntimeException(_5931)  {
  }
mosek::fusion::ValueConversionError::ValueConversionError  ( const std::string &  _5932) : mosek::fusion::FusionRuntimeException(_5932)  {
  }
mosek::fusion::ParameterError::ParameterError  ( const std::string &  _5933) : mosek::fusion::FusionRuntimeException(_5933)  {
  }
mosek::fusion::ExpressionError::ExpressionError  ( const std::string &  _5934) : mosek::fusion::FusionRuntimeException(_5934)  {
  }
mosek::fusion::IOError::IOError  ( const std::string &  _5935) : mosek::fusion::FusionRuntimeException(_5935)  {
  }
mosek::fusion::FusionRuntimeException::FusionRuntimeException  ( const std::string &  _5936) : RuntimeException(_5936)  {
    msg = _5936;
  }
std::string mosek::fusion::FusionRuntimeException::toString(){
  return msg;
}
mosek::fusion::FusionException::FusionException  ( const std::string &  _5937) : Exception(_5937)  {
    msg = _5937;
  }
std::string mosek::fusion::FusionException::toString(){
  return msg;
}
mosek::fusion::LinkedBlocks::LinkedBlocks(mosek::fusion::p_LinkedBlocks *_impl) : _impl(_impl) { /*std::cout << "LinkedBlocks() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedBlocks::~LinkedBlocks() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedBlocks::p_LinkedBlocks  (::mosek::fusion::LinkedBlocks * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (){ return new mosek::fusion::LinkedBlocks(); }mosek::fusion::LinkedBlocks::LinkedBlocks  () :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedBlocks::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedBlocks::_initialize((int)0);
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (int _5938){ return new mosek::fusion::LinkedBlocks(_5938); }mosek::fusion::LinkedBlocks::LinkedBlocks  (int _5938) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_5938); }void mosek::fusion::p_LinkedBlocks::_initialize  (int _5938){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(_5938);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts((int)128);
    bsize = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
    bfirst = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5939){ return new mosek::fusion::LinkedBlocks(_5939); }mosek::fusion::LinkedBlocks::LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5939) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_5939); }void mosek::fusion::p_LinkedBlocks::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5939){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_5939)->ints);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_5939)->blocks);
    bsize = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_5939)->bsize);
    bfirst = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_5939)->bfirst);
  }
}void mosek::fusion::LinkedBlocks :: free(int _5940) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->free(_5940); }void mosek::fusion::p_LinkedBlocks::free(int _5940){
  int _5941 = ((*bfirst)(_5940));
  ints->free(_5940,((*bsize)(_5940)));
  ((*bsize)(_5940)) = (-(int)1);
  ((*bfirst)(_5940)) = (-(int)1);
  blocks->free(_5941,(int)1);
}
int mosek::fusion::LinkedBlocks :: alloc(int _5942) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->alloc(_5942); }int mosek::fusion::p_LinkedBlocks::alloc(int _5942){
  int _9568;
  bool _9569 = (_5942 > (int)0);
  if (_9569)
  {
    _9568 = ints->alloc(_5942);
  }
  else
  {
    _9568 = (-(int)1);
  }
  int _5943 = _9568;
  int _5944 = blocks->alloc();
  if ((blocks->capacity() > (int)((bsize)->size(0))))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5945 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__5945(_5945 ? _5945->raw() : nullptr,_5945 ? _5945->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5946 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__5946(_5946 ? _5946->raw() : nullptr,_5946 ? _5946->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(bsize,(int)0,_5945,(int)0,(int)((bsize)->size(0)));
      ::mosek::fusion::Utils::Tools::arraycopy(bfirst,(int)0,_5946,(int)0,(int)((bfirst)->size(0)));
      bsize = _5945;
      bfirst = _5946;
    }
  }
  {}
  ((*bfirst)(_5944)) = _5943;
  ((*bsize)(_5944)) = _5942;
  return _5944;
}
int mosek::fusion::LinkedBlocks :: maxidx(int _5947) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->maxidx(_5947); }int mosek::fusion::p_LinkedBlocks::maxidx(int _5947){
  return ints->maxidx(((*bfirst)(_5947)),((*bsize)(_5947)));
}
void mosek::fusion::LinkedBlocks :: get(int _5948,std::shared_ptr< monty::ndarray< int,1 > > _5949,int _5950) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->get(_5948,_5949,_5950); }void mosek::fusion::p_LinkedBlocks::get(int _5948,std::shared_ptr< monty::ndarray< int,1 > > _5949,int _5950){
  _checked_ptr_1<int> _ptr__5949(_5949 ? _5949->raw() : nullptr, _5949 ? _5949->size(0) : 0);
  ints->get(((*bfirst)(_5948)),((*bsize)(_5948)),_5949,_5950);
}
int mosek::fusion::LinkedBlocks :: numblocks() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->numblocks(); }int mosek::fusion::p_LinkedBlocks::numblocks(){
  return (int)((bsize)->size(0));
}
int mosek::fusion::LinkedBlocks :: blocksize(int _5951) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->blocksize(_5951); }int mosek::fusion::p_LinkedBlocks::blocksize(int _5951){
  return ((*bsize)(_5951));
}
int mosek::fusion::LinkedBlocks :: capacity() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedBlocks::capacity(){
  return ints->capacity();
}
bool mosek::fusion::LinkedBlocks :: validate() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedBlocks::validate(){
  return (ints->validate() && blocks->validate());
}
void mosek::fusion::p_LinkedBlocks::destroy(){bfirst.reset();bsize.reset();blocks.reset();ints.reset();}void mosek::fusion::LinkedBlocks::destroy() { mosek::fusion::p_LinkedBlocks::_get_impl(this)->destroy(); }mosek::fusion::LinkedInts::LinkedInts(mosek::fusion::p_LinkedInts *_impl) : _impl(_impl) { /*std::cout << "LinkedInts() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedInts::~LinkedInts() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedInts::p_LinkedInts  (::mosek::fusion::LinkedInts * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (int _5952){ return new mosek::fusion::LinkedInts(_5952); }mosek::fusion::LinkedInts::LinkedInts  (int _5952) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_5952); }void mosek::fusion::p_LinkedInts::_initialize  (int _5952){monty::rc_reserve __reserve_this(_pubthis);   {
    int _9570;
    bool _9571 = (_5952 > (int)0);
    if (_9571)
    {
      _9570 = _5952;
    }
    else
    {
      _9570 = (int)128;
    }
    int _5953 = _9570;
    next = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5953)));
    prev = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5953)));
    first_used = (-(int)1);
    first_free = (int)0;
    last_free = (_5953 - (int)1);
    int _9572 = (int)1;
    int _9573 = _5953;
    for (int _5954 = _9572; _5954 < _9573; ++_5954)
    {
      {
        ((*prev)(_5954)) = (_5954 - (int)1);
        ((*next)((_5954 - (int)1))) = _5954;
      }
    }
    ((*prev)((int)0)) = (-(int)1);
    ((*next)((_5953 - (int)1))) = (-(int)1);
    nfree = _5953;
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (){ return new mosek::fusion::LinkedInts(); }mosek::fusion::LinkedInts::LinkedInts  () :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedInts::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedInts::_initialize((int)128);
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5955){ return new mosek::fusion::LinkedInts(_5955); }mosek::fusion::LinkedInts::LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5955) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_5955); }void mosek::fusion::p_LinkedInts::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5955){monty::rc_reserve __reserve_this(_pubthis);   {
    next = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_5955)->next);
    prev = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_5955)->prev);
    first_used = mosek::fusion::p_LinkedInts::_get_impl(_5955)->first_used;
    first_free = mosek::fusion::p_LinkedInts::_get_impl(_5955)->first_free;
    last_free = mosek::fusion::p_LinkedInts::_get_impl(_5955)->last_free;
    nfree = mosek::fusion::p_LinkedInts::_get_impl(_5955)->nfree;
  }
}void mosek::fusion::LinkedInts :: free(int _5956,int _5957) { mosek::fusion::p_LinkedInts::_get_impl(this)->free(_5956,_5957); }void mosek::fusion::p_LinkedInts::free(int _5956,int _5957){
  int _5958 = _5956;
  int _5959 = _5958;
  int _9574 = (int)0;
  int _9575 = (_5957 - (int)1);
  for (int _5960 = _9574; _5960 < _9575; ++_5960)
  {
    {
      _5959 = ((*next)(_5959));
    }
  }
  int _5961 = ((*prev)(_5958));
  int _5962 = ((*next)(_5959));
  if ((_5961 >= (int)0))
  {
    {
      ((*next)(_5961)) = _5962;
    }
  }
  {}
  if ((_5962 >= (int)0))
  {
    {
      ((*prev)(_5962)) = _5961;
    }
  }
  {}
  ((*prev)(_5958)) = (-(int)1);
  ((*next)(_5959)) = first_free;
  if ((first_free >= (int)0))
  {
    {
      ((*prev)(first_free)) = _5959;
    }
  }
  {}
  first_free = _5958;
  nfree += _5957;
}
int mosek::fusion::LinkedInts :: alloc() { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(); }int mosek::fusion::p_LinkedInts::alloc(){
  return allocblock((int)1);
}
int mosek::fusion::LinkedInts :: alloc(int _5963) { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_5963); }int mosek::fusion::p_LinkedInts::alloc(int _5963){
  return allocblock(_5963);
}
void mosek::fusion::LinkedInts :: alloc(int _5964,std::shared_ptr< monty::ndarray< int,1 > > _5965,int _5966) { mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_5964,_5965,_5966); }void mosek::fusion::p_LinkedInts::alloc(int _5964,std::shared_ptr< monty::ndarray< int,1 > > _5965,int _5966){
  _checked_ptr_1<int> _ptr__5965(_5965 ? _5965->raw() : nullptr, _5965 ? _5965->size(0) : 0);
  int _5967 = allocblock(_5964);
  int _9576 = (int)0;
  int _9577 = _5964;
  for (int _5968 = _9576; _5968 < _9577; ++_5968)
  {
    {
      _ptr__5965[safe_add( _5968,_5966 )] = _5967;
      _5967 = ((*next)(_5967));
    }
  }
}
void mosek::fusion::LinkedInts :: get(int _5969,int _5970,std::shared_ptr< monty::ndarray< int,1 > > _5971,int _5972) { mosek::fusion::p_LinkedInts::_get_impl(this)->get(_5969,_5970,_5971,_5972); }void mosek::fusion::p_LinkedInts::get(int _5969,int _5970,std::shared_ptr< monty::ndarray< int,1 > > _5971,int _5972){
  _checked_ptr_1<int> _ptr__5971(_5971 ? _5971->raw() : nullptr, _5971 ? _5971->size(0) : 0);
  int _5973 = _5969;
  int _9578 = (int)0;
  int _9579 = _5970;
  for (int _5974 = _9578; _5974 < _9579; ++_5974)
  {
    {
      _ptr__5971[safe_add( _5974,_5972 )] = _5973;
      _5973 = ((*next)(_5973));
    }
  }
}
int mosek::fusion::LinkedInts :: maxidx(int _5975,int _5976) { return mosek::fusion::p_LinkedInts::_get_impl(this)->maxidx(_5975,_5976); }int mosek::fusion::p_LinkedInts::maxidx(int _5975,int _5976){
  int _5977 = _5975;
  int _5978 = _5975;
  int _9580 = (int)1;
  int _9581 = _5976;
  for (int _5979 = _9580; _5979 < _9581; ++_5979)
  {
    {
      _5978 = ((*next)(_5978));
      if ((_5977 < _5978))
      {
        {
          _5977 = _5978;
        }
      }
      {}
    }
  }
  return _5977;
}
int mosek::fusion::p_LinkedInts::allocblock(int _5980){
  int _5981 = (int)((next)->size(0));
  if ((nfree < _5980))
  {
    {
      int _5982 = (_5980 - nfree);
      if ((_5982 < _5981))
      {
        {
          _5982 = _5981;
        }
      }
      {}
      recap(safe_add( _5982,_5981 ));
    }
  }
  {}
  int _5983 = first_free;
  int _5984 = _5983;
  int _9582 = (int)0;
  int _9583 = (_5980 - (int)1);
  for (int _5985 = _9582; _5985 < _9583; ++_5985)
  {
    {
      _5984 = ((*next)(_5984));
    }
  }
  first_free = ((*next)(_5984));
  if ((first_free < (int)0))
  {
    {
      last_free = (-(int)1);
    }
  }
  else
  {
    {
      ((*prev)(first_free)) = (-(int)1);
    }
  }
  ((*next)(_5984)) = first_used;
  if ((first_used >= (int)0))
  {
    {
      ((*prev)(first_used)) = _5984;
    }
  }
  {}
  first_used = _5983;
  nfree -= _5980;
  return _5983;
}
void mosek::fusion::p_LinkedInts::recap(int _5986){
  int _5987 = (int)((next)->size(0));
  if ((_5986 > _5987))
  {
    {
      next = ::mosek::fusion::p_CommonTools::resize(next,_5986);
      prev = ::mosek::fusion::p_CommonTools::resize(prev,_5986);
      int _9584 = _5987;
      int _9585 = (_5986 - (int)1);
      for (int _5988 = _9584; _5988 < _9585; ++_5988)
      {
        {
          ((*next)(_5988)) = safe_add( _5988,(int)1 );
          ((*prev)(safe_add( _5988,(int)1 ))) = _5988;
        }
      }
      ((*next)((_5986 - (int)1))) = (-(int)1);
      ((*prev)(_5987)) = last_free;
      if ((last_free < (int)0))
      {
        {
          first_free = _5987;
        }
      }
      else
      {
        {
          ((*next)(last_free)) = _5987;
        }
      }
      last_free = (_5986 - (int)1);
      nfree += (_5986 - _5987);
    }
  }
  {}
}
int mosek::fusion::LinkedInts :: capacity() { return mosek::fusion::p_LinkedInts::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedInts::capacity(){
  return (int)((next)->size(0));
}
bool mosek::fusion::LinkedInts :: validate() { return mosek::fusion::p_LinkedInts::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedInts::validate(){
  std::shared_ptr< monty::ndarray< bool,1 > > _5989 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape((int)((next)->size(0)))));
  int _5990 = first_used;
  while ( (_5990 >= (int)0) )
  {
    {
      ((*_5989)(_5990)) = true;
      _5990 = ((*next)(_5990));
      if (((_5990 >= (int)0) && ((*_5989)(_5990))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("used list/next is inconsistent"));
        }
      }
      {}
    }
  }
  _5990 = first_free;
  int _5991 = (int)0;
  while ( (_5990 >= (int)0) )
  {
    {
      ++ _5991;
      ((*_5989)(_5990)) = true;
      _5990 = ((*next)(_5990));
      if (((_5990 >= (int)0) && ((*_5989)(_5990))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("free list/next is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_5991 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free next list did not contain nfree elements"));
    }
  }
  {}
  int _9586 = (int)0;
  int _9587 = (int)((_5989)->size(0));
  for (int _5992 = _9586; _5992 < _9587; ++_5992)
  {
    {
      if ((!((*_5989)(_5990))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("elements missing from used+free list"));
        }
      }
      {}
    }
  }
  int _9588 = (int)0;
  int _9589 = (int)((_5989)->size(0));
  for (int _5993 = _9588; _5993 < _9589; ++_5993)
  {
    {
      ((*_5989)(_5993)) = false;
    }
  }
  _5990 = last_free;
  int _5994 = (int)0;
  while ( (_5990 >= (int)0) )
  {
    {
      ++ _5994;
      ((*_5989)(_5990)) = true;
      _5990 = ((*prev)(_5990));
      if (((_5990 >= (int)0) && ((*_5989)(_5990))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("prev list is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_5994 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free prev list did not contain nfree elements"));
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinkedInts::destroy(){prev.reset();next.reset();}void mosek::fusion::LinkedInts::destroy() { mosek::fusion::p_LinkedInts::_get_impl(this)->destroy(); }mosek::fusion::Parameters::Parameters(mosek::fusion::p_Parameters *_impl) : _impl(_impl) { /*std::cout << "Parameters() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Parameters::~Parameters() { delete _impl; _impl = nullptr; }mosek::fusion::p_Parameters::p_Parameters  (::mosek::fusion::Parameters * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _5995,    const std::string & _5996,    double _5997) { mosek::fusion::p_Parameters::setParameter(_5995,_5996,_5997); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _5995,const std::string & _5996,double _5997){
  if (false)
  {
    {
    }
  }
  else if((_5996 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_5996 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_5996 == std::string ("numThreads")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _5998 = _5997;
          if (((int)0 <= _5998))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_5998);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_5996 == std::string ("mtSpincount")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _5999 = _5997;
          if ((((int)0 <= _5999) && (_5999 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_5999);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_5996 == std::string ("biMaxIterations")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6000 = _5997;
          if (((int)0 <= _6000))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6000);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6001 = _5997;
          if (((int)0 <= _6001))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6001);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logCutSecondOpt")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6002 = _5997;
          if (((int)0 <= _6002))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6002);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logResponse")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6003 = _5997;
          if (((int)0 <= _6003))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6003);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logBi")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6004 = _5997;
          if (((int)0 <= _6004))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6004);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logBiFreq")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6005 = _5997;
          if (((int)0 <= _6005))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6005);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_5996 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_5996 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_5996 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_5996 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_5996 == std::string ("logIntpnt")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6006 = _5997;
          if (((int)0 <= _6006))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6006);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntMaxIterations")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6007 = _5997;
          if (((int)0 <= _6007))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6007);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntOffColTrh")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6008 = _5997;
          if (((int)0 <= _6008))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6008);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  else if((_5996 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_5996 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_5996 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_5996 == std::string ("intpntMaxNumCor")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6009 = _5997;
          if (((-(int)1) <= _6009))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6009);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_5996 == std::string ("presolveLevel")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6010 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6010);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logPresolve")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6011 = _5997;
          if (((int)0 <= _6011))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6011);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_5996 == std::string ("presolveMaxNumPass")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6012 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6012);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6013 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6013);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6014 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6014);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("simPrimalCrash")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6015 = _5997;
          if (((int)0 <= _6015))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6015);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logSim")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6016 = _5997;
          if (((int)0 <= _6016))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6016);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logSimMinor")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6017 = _5997;
          if (((int)0 <= _6017))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6017);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logSimFreq")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6018 = _5997;
          if (((int)0 <= _6018))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6018);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("simPrimalRestrictSelection")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6019 = _5997;
          if ((((int)0 <= _6019) && (_6019 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6019);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_5996 == std::string ("simDualRestrictSelection")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6020 = _5997;
          if ((((int)0 <= _6020) && (_6020 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6020);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_5996 == std::string ("simMaxIterations")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6021 = _5997;
          if (((int)0 <= _6021))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6021);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_5996 == std::string ("simRefactorFreq")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6022 = _5997;
          if (((int)0 <= _6022))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6022);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("simSeed")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6023 = _5997;
          if ((((int)0 <= _6023) && (_6023 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6023);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_5996 == std::string ("logMio")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6024 = _5997;
          if (((int)0 <= _6024))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6024);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logMioFreq")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6025 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6025);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioMaxNumRelaxs")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6026 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6026);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioMaxNumBranches")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6027 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6027);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioMaxNumSolutions")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6028 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6028);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_5996 == std::string ("mioHeuristicLevel")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6029 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6029);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioProbingLevel")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6030 = _5997;
          if ((((-(int)1) <= _6030) && (_6030 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6030);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioCutSelectionLevel")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6031 = _5997;
          if ((((-(int)1) <= _6031) && (_6031 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6031);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioVbDetectionLevel")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6032 = _5997;
          if ((((-(int)1) <= _6032) && (_6032 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6032);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_5996 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_5996 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_5996 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_5996 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_5996 == std::string ("mioSeed")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6033 = _5997;
          if (((int)0 <= _6033))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6033);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_5996 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_5996 == std::string ("writeLpLineWidth")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6034 = _5997;
          if (((int)40 <= _6034))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6034);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("writeLpTermsPerLine")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6035 = _5997;
          if (((int)0 <= _6035))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6035);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_5996 == std::string ("logInfeasAna")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6036 = _5997;
          if (((int)0 <= _6036))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6036);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_5996 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_5996 == std::string ("licensePauseTime")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6037 = _5997;
          if ((((int)0 <= _6037) && (_6037 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6037);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_5996 == std::string ("log")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6038 = _5997;
          if (((int)0 <= _6038))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6038);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logExpand")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6039 = _5997;
          if (((int)0 <= _6039))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6039);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logFile")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6040 = _5997;
          if (((int)0 <= _6040))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6040);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("logOrder")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6041 = _5997;
          if (((int)0 <= _6041))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6041);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_5996 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_5996 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6042 = _5997;
          if ((((int)0 <= _6042) && (_6042 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6042);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("simDualPhaseoneMethod")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6043 = _5997;
          if ((((int)0 <= _6043) && (_6043 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6043);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("simMaxNumSetbacks")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6044 = _5997;
          if (((int)0 <= _6044))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6044);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_5996 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_5996 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_5996 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_5996 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_5996 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_5996 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_5996 == std::string ("simDualCrash")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6045 = _5997;
          if (((int)0 <= _6045))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6045);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_5996 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6046 = _5997;
          if ((((-(int)1) <= _6046) && (_6046 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6046);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_5996 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_5996 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_5996 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_5996 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_5996 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6047 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6047);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6048 = _5997;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6048);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_5996 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_5996 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_5996 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_5996 == std::string ("mioRinsMaxNodes")))
  {
    {
      if (((_5997 - (int)_5997) == 0.0))
      {
        {
          double _6049 = _5997;
          if (((-(int)1) <= _6049))
          {
            {
              mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6049);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("optimizerMaxTime")))
  {
    {
      double _6050 = _5997;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6050);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("lowerObjCut")))
  {
    {
      double _6051 = _5997;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6051);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("upperObjCut")))
  {
    {
      double _6052 = _5997;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6052);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6053 = _5997;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6053);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6054 = _5997;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6054);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolRelGap")))
  {
    {
      double _6055 = _5997;
      if ((1.000000e-14 <= _6055))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6055);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolStepSize")))
  {
    {
      double _6056 = _5997;
      if (((0.000000e+00 <= _6056) && (_6056 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6056);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6057 = _5997;
      if (((1.000000e-06 <= _6057) && (_6057 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6057);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolRelStep")))
  {
    {
      double _6058 = _5997;
      if (((1.000000e-04 <= _6058) && (_6058 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6058);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolPath")))
  {
    {
      double _6059 = _5997;
      if (((0.000000e+00 <= _6059) && (_6059 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6059);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolPfeas")))
  {
    {
      double _6060 = _5997;
      if (((0.000000e+00 <= _6060) && (_6060 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6060);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolDfeas")))
  {
    {
      double _6061 = _5997;
      if (((0.000000e+00 <= _6061) && (_6061 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6061);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolMuRed")))
  {
    {
      double _6062 = _5997;
      if (((0.000000e+00 <= _6062) && (_6062 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6062);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolInfeas")))
  {
    {
      double _6063 = _5997;
      if (((0.000000e+00 <= _6063) && (_6063 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6063);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6064 = _5997;
      if (((0.000000e+00 <= _6064) && (_6064 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6064);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6065 = _5997;
      if (((0.000000e+00 <= _6065) && (_6065 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6065);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6066 = _5997;
      if (((0.000000e+00 <= _6066) && (_6066 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6066);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6067 = _5997;
      if (((0.000000e+00 <= _6067) && (_6067 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6067);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6068 = _5997;
      if ((1.000000e+00 <= _6068))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6068);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6069 = _5997;
      if (((0.000000e+00 <= _6069) && (_6069 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6069);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolPsafe")))
  {
    {
      double _6070 = _5997;
      if ((1.000000e-04 <= _6070))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6070);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("intpntTolDsafe")))
  {
    {
      double _6071 = _5997;
      if ((1.000000e-04 <= _6071))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6071);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioMaxTime")))
  {
    {
      double _6072 = _5997;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6072);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioRelGapConst")))
  {
    {
      double _6073 = _5997;
      if ((1.000000e-15 <= _6073))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6073);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioTolRelGap")))
  {
    {
      double _6074 = _5997;
      if ((0.000000e+00 <= _6074))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6074);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioTolAbsGap")))
  {
    {
      double _6075 = _5997;
      if ((0.000000e+00 <= _6075))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6075);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6076 = _5997;
      if ((1.000000e-09 <= _6076))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6076);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("basisTolX")))
  {
    {
      double _6077 = _5997;
      if ((1.000000e-09 <= _6077))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6077);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("basisTolS")))
  {
    {
      double _6078 = _5997;
      if ((1.000000e-09 <= _6078))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6078);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("basisRelTolS")))
  {
    {
      double _6079 = _5997;
      if ((0.000000e+00 <= _6079))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6079);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("presolveTolX")))
  {
    {
      double _6080 = _5997;
      if ((0.000000e+00 <= _6080))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6080);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("presolveTolS")))
  {
    {
      double _6081 = _5997;
      if ((0.000000e+00 <= _6081))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6081);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("presolveTolAij")))
  {
    {
      double _6082 = _5997;
      if ((1.000000e-15 <= _6082))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6082);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6083 = _5997;
      if ((0.000000e+00 <= _6083))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6083);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6084 = _5997;
      if ((0.000000e+00 <= _6084))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6084);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6085 = _5997;
      if ((1.000000e-12 <= _6085))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6085);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioTolFeas")))
  {
    {
      double _6086 = _5997;
      if (((1.000000e-09 <= _6086) && (_6086 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6086);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("anaSolInfeasTol")))
  {
    {
      double _6087 = _5997;
      if ((0.000000e+00 <= _6087))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_ANA_SOL_INFEAS_TOL"),_6087);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
        }
      }
    }
  }
  {}
  if ((_5996 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6088 = _5997;
      if (((0.000000e+00 <= _6088) && (_6088 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_5995.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6088);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_5996 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_5996 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_5996 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_5996 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_5996 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_5996 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6089,    const std::string & _6090,    int _6091) { mosek::fusion::p_Parameters::setParameter(_6089,_6090,_6091); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6089,const std::string & _6090,int _6091){
  if (false)
  {
    {
    }
  }
  else if((_6090 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6090 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6090 == std::string ("numThreads")))
  {
    {
      int _6092 = _6091;
      if (((int)0 <= _6092))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6092);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6090 == std::string ("mtSpincount")))
  {
    {
      int _6093 = _6091;
      if ((((int)0 <= _6093) && (_6093 <= (int)1000000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6093);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6090 == std::string ("biMaxIterations")))
  {
    {
      int _6094 = _6091;
      if (((int)0 <= _6094))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6094);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      int _6095 = _6091;
      if (((int)0 <= _6095))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6095);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logCutSecondOpt")))
  {
    {
      int _6096 = _6091;
      if (((int)0 <= _6096))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6096);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logResponse")))
  {
    {
      int _6097 = _6091;
      if (((int)0 <= _6097))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6097);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logBi")))
  {
    {
      int _6098 = _6091;
      if (((int)0 <= _6098))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6098);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logBiFreq")))
  {
    {
      int _6099 = _6091;
      if (((int)0 <= _6099))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6099);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6090 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6090 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6090 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6090 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6090 == std::string ("logIntpnt")))
  {
    {
      int _6100 = _6091;
      if (((int)0 <= _6100))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6100);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntMaxIterations")))
  {
    {
      int _6101 = _6091;
      if (((int)0 <= _6101))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6101);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntOffColTrh")))
  {
    {
      int _6102 = _6091;
      if (((int)0 <= _6102))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6102);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  else if((_6090 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6090 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6090 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6090 == std::string ("intpntMaxNumCor")))
  {
    {
      int _6103 = _6091;
      if (((-(int)1) <= _6103))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6103);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6090 == std::string ("presolveLevel")))
  {
    {
      int _6104 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6104);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logPresolve")))
  {
    {
      int _6105 = _6091;
      if (((int)0 <= _6105))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6105);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6090 == std::string ("presolveMaxNumPass")))
  {
    {
      int _6106 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6106);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      int _6107 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6107);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      int _6108 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6108);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("simPrimalCrash")))
  {
    {
      int _6109 = _6091;
      if (((int)0 <= _6109))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6109);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logSim")))
  {
    {
      int _6110 = _6091;
      if (((int)0 <= _6110))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6110);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logSimMinor")))
  {
    {
      int _6111 = _6091;
      if (((int)0 <= _6111))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6111);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logSimFreq")))
  {
    {
      int _6112 = _6091;
      if (((int)0 <= _6112))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6112);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("simPrimalRestrictSelection")))
  {
    {
      int _6113 = _6091;
      if ((((int)0 <= _6113) && (_6113 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6113);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6090 == std::string ("simDualRestrictSelection")))
  {
    {
      int _6114 = _6091;
      if ((((int)0 <= _6114) && (_6114 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6114);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6090 == std::string ("simMaxIterations")))
  {
    {
      int _6115 = _6091;
      if (((int)0 <= _6115))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6115);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6090 == std::string ("simRefactorFreq")))
  {
    {
      int _6116 = _6091;
      if (((int)0 <= _6116))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6116);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("simSeed")))
  {
    {
      int _6117 = _6091;
      if ((((int)0 <= _6117) && (_6117 <= (int)32749)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6117);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6090 == std::string ("logMio")))
  {
    {
      int _6118 = _6091;
      if (((int)0 <= _6118))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6118);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logMioFreq")))
  {
    {
      int _6119 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6119);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioMaxNumRelaxs")))
  {
    {
      int _6120 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6120);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioMaxNumBranches")))
  {
    {
      int _6121 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6121);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioMaxNumSolutions")))
  {
    {
      int _6122 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6122);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6090 == std::string ("mioHeuristicLevel")))
  {
    {
      int _6123 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6123);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioProbingLevel")))
  {
    {
      int _6124 = _6091;
      if ((((-(int)1) <= _6124) && (_6124 <= (int)3)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6124);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioCutSelectionLevel")))
  {
    {
      int _6125 = _6091;
      if ((((-(int)1) <= _6125) && (_6125 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6125);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioVbDetectionLevel")))
  {
    {
      int _6126 = _6091;
      if ((((-(int)1) <= _6126) && (_6126 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6126);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6090 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6090 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6090 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6090 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6090 == std::string ("mioSeed")))
  {
    {
      int _6127 = _6091;
      if (((int)0 <= _6127))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6127);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6090 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6090 == std::string ("writeLpLineWidth")))
  {
    {
      int _6128 = _6091;
      if (((int)40 <= _6128))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6128);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("writeLpTermsPerLine")))
  {
    {
      int _6129 = _6091;
      if (((int)0 <= _6129))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6129);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6090 == std::string ("logInfeasAna")))
  {
    {
      int _6130 = _6091;
      if (((int)0 <= _6130))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6130);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6090 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6090 == std::string ("licensePauseTime")))
  {
    {
      int _6131 = _6091;
      if ((((int)0 <= _6131) && (_6131 <= (int)1000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6131);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6090 == std::string ("log")))
  {
    {
      int _6132 = _6091;
      if (((int)0 <= _6132))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6132);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logExpand")))
  {
    {
      int _6133 = _6091;
      if (((int)0 <= _6133))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6133);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logFile")))
  {
    {
      int _6134 = _6091;
      if (((int)0 <= _6134))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6134);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("logOrder")))
  {
    {
      int _6135 = _6091;
      if (((int)0 <= _6135))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6135);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6090 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6090 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      int _6136 = _6091;
      if ((((int)0 <= _6136) && (_6136 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6136);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("simDualPhaseoneMethod")))
  {
    {
      int _6137 = _6091;
      if ((((int)0 <= _6137) && (_6137 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6137);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("simMaxNumSetbacks")))
  {
    {
      int _6138 = _6091;
      if (((int)0 <= _6138))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6138);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6090 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6090 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6090 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6090 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6090 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6090 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6090 == std::string ("simDualCrash")))
  {
    {
      int _6139 = _6091;
      if (((int)0 <= _6139))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6139);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6090 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      int _6140 = _6091;
      if ((((-(int)1) <= _6140) && (_6140 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6140);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6090 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6090 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6090 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6090 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6090 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      int _6141 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6141);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      int _6142 = _6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6142);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6090 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6090 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6090 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6090 == std::string ("mioRinsMaxNodes")))
  {
    {
      int _6143 = _6091;
      if (((-(int)1) <= _6143))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6143);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("optimizerMaxTime")))
  {
    {
      double _6144 = (double)_6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6144);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("lowerObjCut")))
  {
    {
      double _6145 = (double)_6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6145);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("upperObjCut")))
  {
    {
      double _6146 = (double)_6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6146);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6147 = (double)_6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6147);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6148 = (double)_6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6148);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolRelGap")))
  {
    {
      double _6149 = (double)_6091;
      if ((1.000000e-14 <= _6149))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6149);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolStepSize")))
  {
    {
      double _6150 = (double)_6091;
      if (((0.000000e+00 <= _6150) && (_6150 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6150);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6151 = (double)_6091;
      if (((1.000000e-06 <= _6151) && (_6151 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6151);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolRelStep")))
  {
    {
      double _6152 = (double)_6091;
      if (((1.000000e-04 <= _6152) && (_6152 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6152);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolPath")))
  {
    {
      double _6153 = (double)_6091;
      if (((0.000000e+00 <= _6153) && (_6153 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6153);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolPfeas")))
  {
    {
      double _6154 = (double)_6091;
      if (((0.000000e+00 <= _6154) && (_6154 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6154);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolDfeas")))
  {
    {
      double _6155 = (double)_6091;
      if (((0.000000e+00 <= _6155) && (_6155 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6155);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolMuRed")))
  {
    {
      double _6156 = (double)_6091;
      if (((0.000000e+00 <= _6156) && (_6156 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6156);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolInfeas")))
  {
    {
      double _6157 = (double)_6091;
      if (((0.000000e+00 <= _6157) && (_6157 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6157);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6158 = (double)_6091;
      if (((0.000000e+00 <= _6158) && (_6158 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6158);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6159 = (double)_6091;
      if (((0.000000e+00 <= _6159) && (_6159 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6159);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6160 = (double)_6091;
      if (((0.000000e+00 <= _6160) && (_6160 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6160);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6161 = (double)_6091;
      if (((0.000000e+00 <= _6161) && (_6161 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6161);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6162 = (double)_6091;
      if ((1.000000e+00 <= _6162))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6162);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6163 = (double)_6091;
      if (((0.000000e+00 <= _6163) && (_6163 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6163);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolPsafe")))
  {
    {
      double _6164 = (double)_6091;
      if ((1.000000e-04 <= _6164))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6164);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("intpntTolDsafe")))
  {
    {
      double _6165 = (double)_6091;
      if ((1.000000e-04 <= _6165))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6165);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioMaxTime")))
  {
    {
      double _6166 = (double)_6091;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6166);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioRelGapConst")))
  {
    {
      double _6167 = (double)_6091;
      if ((1.000000e-15 <= _6167))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6167);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioTolRelGap")))
  {
    {
      double _6168 = (double)_6091;
      if ((0.000000e+00 <= _6168))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6168);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioTolAbsGap")))
  {
    {
      double _6169 = (double)_6091;
      if ((0.000000e+00 <= _6169))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6169);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6170 = (double)_6091;
      if ((1.000000e-09 <= _6170))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6170);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("basisTolX")))
  {
    {
      double _6171 = (double)_6091;
      if ((1.000000e-09 <= _6171))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6171);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("basisTolS")))
  {
    {
      double _6172 = (double)_6091;
      if ((1.000000e-09 <= _6172))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6172);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("basisRelTolS")))
  {
    {
      double _6173 = (double)_6091;
      if ((0.000000e+00 <= _6173))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6173);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("presolveTolX")))
  {
    {
      double _6174 = (double)_6091;
      if ((0.000000e+00 <= _6174))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6174);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("presolveTolS")))
  {
    {
      double _6175 = (double)_6091;
      if ((0.000000e+00 <= _6175))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6175);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("presolveTolAij")))
  {
    {
      double _6176 = (double)_6091;
      if ((1.000000e-15 <= _6176))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6176);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6177 = (double)_6091;
      if ((0.000000e+00 <= _6177))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6177);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6178 = (double)_6091;
      if ((0.000000e+00 <= _6178))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6178);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6179 = (double)_6091;
      if ((1.000000e-12 <= _6179))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6179);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioTolFeas")))
  {
    {
      double _6180 = (double)_6091;
      if (((1.000000e-09 <= _6180) && (_6180 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6180);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("anaSolInfeasTol")))
  {
    {
      double _6181 = (double)_6091;
      if ((0.000000e+00 <= _6181))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_ANA_SOL_INFEAS_TOL"),_6181);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
        }
      }
    }
  }
  {}
  if ((_6090 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6182 = (double)_6091;
      if (((0.000000e+00 <= _6182) && (_6182 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6089.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6182);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6090 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6090 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6090 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6090 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6090 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6090 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6183,    const std::string & _6184,    const std::string & _6185) { mosek::fusion::p_Parameters::setParameter(_6183,_6184,_6185); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6183,const std::string & _6184,const std::string & _6185){
  if (false)
  {
    {
    }
  }
  {}
  if ((_6184 == std::string ("autoUpdateSolInfo")))
  {
    {
      int _6186 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6186 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_AUTO_UPDATE_SOL_INFO"),_6186);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("removeUnusedSolutions")))
  {
    {
      int _6187 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6187 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_REMOVE_UNUSED_SOLUTIONS"),_6187);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("numThreads")))
  {
    {
      try
      {
        {
          int _6189 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6189))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6189);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6188)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntMultiThread")))
  {
    {
      int _6190 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6190 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MULTI_THREAD"),_6190);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mtSpincount")))
  {
    {
      try
      {
        {
          int _6192 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((int)0 <= _6192) && (_6192 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6192);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6191)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("optimizer")))
  {
    {
      int _6193 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6185);
      if ((_6193 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_OPTIMIZER"),_6193);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("biMaxIterations")))
  {
    {
      try
      {
        {
          int _6195 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6195))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6195);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6194)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      try
      {
        {
          int _6197 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6197))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6197);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6196)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logCutSecondOpt")))
  {
    {
      try
      {
        {
          int _6199 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6199))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6199);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6198)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logResponse")))
  {
    {
      try
      {
        {
          int _6201 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6201))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6201);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6200)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logBi")))
  {
    {
      try
      {
        {
          int _6203 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6203))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6203);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6202)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logBiFreq")))
  {
    {
      try
      {
        {
          int _6205 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6205))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6205);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6204)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("biCleanOptimizer")))
  {
    {
      int _6206 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6185);
      if ((_6206 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_BI_CLEAN_OPTIMIZER"),_6206);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("intpntStartingPoint")))
  {
    {
      int _6207 = ::mosek::fusion::p_Parameters::string_to_startpointtype_value(_6185);
      if ((_6207 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_STARTING_POINT"),_6207);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("intpntDiffStep")))
  {
    {
      int _6208 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6208 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_DIFF_STEP"),_6208);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("intpntScaling")))
  {
    {
      int _6209 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6185);
      if ((_6209 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SCALING"),_6209);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("intpntSolveForm")))
  {
    {
      int _6210 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6185);
      if ((_6210 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SOLVE_FORM"),_6210);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("logIntpnt")))
  {
    {
      try
      {
        {
          int _6212 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6212))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6212);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6211)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntMaxIterations")))
  {
    {
      try
      {
        {
          int _6214 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6214))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6214);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6213)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntOffColTrh")))
  {
    {
      try
      {
        {
          int _6216 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6216))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6216);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6215)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntOrderMethod")))
  {
    {
      int _6217 = ::mosek::fusion::p_Parameters::string_to_orderingtype_value(_6185);
      if ((_6217 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_METHOD"),_6217);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("intpntBasis")))
  {
    {
      int _6218 = ::mosek::fusion::p_Parameters::string_to_basindtype_value(_6185);
      if ((_6218 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_BASIS"),_6218);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("biIgnoreMaxIter")))
  {
    {
      int _6219 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6219 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_MAX_ITER"),_6219);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("biIgnoreNumError")))
  {
    {
      int _6220 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6220 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_NUM_ERROR"),_6220);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("intpntMaxNumCor")))
  {
    {
      try
      {
        {
          int _6222 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((-(int)1) <= _6222))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6222);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6221)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveUse")))
  {
    {
      int _6223 = ::mosek::fusion::p_Parameters::string_to_presolvemode_value(_6185);
      if ((_6223 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_USE"),_6223);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("presolveLevel")))
  {
    {
      try
      {
        {
          int _6225 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6225);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6224)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logPresolve")))
  {
    {
      try
      {
        {
          int _6227 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6227))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6227);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6226)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveLindepUse")))
  {
    {
      int _6228 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6228 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_USE"),_6228);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("presolveMaxNumPass")))
  {
    {
      try
      {
        {
          int _6230 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6230);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6229)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      try
      {
        {
          int _6232 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6232);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6231)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      try
      {
        {
          int _6234 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6234);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6233)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simPrimalCrash")))
  {
    {
      try
      {
        {
          int _6236 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6236))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6236);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6235)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logSim")))
  {
    {
      try
      {
        {
          int _6238 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6238))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6238);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6237)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logSimMinor")))
  {
    {
      try
      {
        {
          int _6240 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6240))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6240);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6239)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logSimFreq")))
  {
    {
      try
      {
        {
          int _6242 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6242))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6242);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6241)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simPrimalRestrictSelection")))
  {
    {
      try
      {
        {
          int _6244 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((int)0 <= _6244) && (_6244 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6244);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6243)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simPrimalSelection")))
  {
    {
      int _6245 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6185);
      if ((_6245 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_SELECTION"),_6245);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simDualRestrictSelection")))
  {
    {
      try
      {
        {
          int _6247 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((int)0 <= _6247) && (_6247 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6247);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6246)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simDualSelection")))
  {
    {
      int _6248 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6185);
      if ((_6248 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_SELECTION"),_6248);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simMaxIterations")))
  {
    {
      try
      {
        {
          int _6250 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6250))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6250);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6249)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simHotstartLu")))
  {
    {
      int _6251 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6251 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART_LU"),_6251);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simRefactorFreq")))
  {
    {
      try
      {
        {
          int _6253 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6253))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6253);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6252)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simSeed")))
  {
    {
      try
      {
        {
          int _6255 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((int)0 <= _6255) && (_6255 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6255);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6254)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioMode")))
  {
    {
      int _6256 = ::mosek::fusion::p_Parameters::string_to_miomode_value(_6185);
      if ((_6256 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_MODE"),_6256);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("logMio")))
  {
    {
      try
      {
        {
          int _6258 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6258))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6258);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6257)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logMioFreq")))
  {
    {
      try
      {
        {
          int _6260 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6260);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6259)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioMaxNumRelaxs")))
  {
    {
      try
      {
        {
          int _6262 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6262);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6261)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioMaxNumBranches")))
  {
    {
      try
      {
        {
          int _6264 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6264);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6263)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioMaxNumSolutions")))
  {
    {
      try
      {
        {
          int _6266 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6266);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6265)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioNodeSelection")))
  {
    {
      int _6267 = ::mosek::fusion::p_Parameters::string_to_mionodeseltype_value(_6185);
      if ((_6267 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_SELECTION"),_6267);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioHeuristicLevel")))
  {
    {
      try
      {
        {
          int _6269 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6269);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6268)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioProbingLevel")))
  {
    {
      try
      {
        {
          int _6271 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((-(int)1) <= _6271) && (_6271 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6271);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6270)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioCutSelectionLevel")))
  {
    {
      try
      {
        {
          int _6273 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((-(int)1) <= _6273) && (_6273 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6273);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6272)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioVbDetectionLevel")))
  {
    {
      try
      {
        {
          int _6275 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((-(int)1) <= _6275) && (_6275 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6275);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6274)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioBranchDir")))
  {
    {
      int _6276 = ::mosek::fusion::p_Parameters::string_to_branchdir_value(_6185);
      if ((_6276 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_BRANCH_DIR"),_6276);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioRootOptimizer")))
  {
    {
      int _6277 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6185);
      if ((_6277 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_OPTIMIZER"),_6277);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioNodeOptimizer")))
  {
    {
      int _6278 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6185);
      if ((_6278 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_OPTIMIZER"),_6278);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioPerspectiveReformulate")))
  {
    {
      int _6279 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6279 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_PERSPECTIVE_REFORMULATE"),_6279);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      int _6280 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6280 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROPAGATE_OBJECTIVE_CONSTRAINT"),_6280);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioSeed")))
  {
    {
      try
      {
        {
          int _6282 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6282))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6282);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6281)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioConicOuterApproximation")))
  {
    {
      int _6283 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6283 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_CONIC_OUTER_APPROXIMATION"),_6283);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("writeLpQuotedNames")))
  {
    {
      int _6284 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6284 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_QUOTED_NAMES"),_6284);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("writeLpLineWidth")))
  {
    {
      try
      {
        {
          int _6286 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)40 <= _6286))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6286);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6285)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("writeLpTermsPerLine")))
  {
    {
      try
      {
        {
          int _6288 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6288))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6288);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6287)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("writeLpFullObj")))
  {
    {
      int _6289 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6289 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_FULL_OBJ"),_6289);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("logInfeasAna")))
  {
    {
      try
      {
        {
          int _6291 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6291))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6291);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6290)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("licenseWait")))
  {
    {
      int _6292 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6292 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_WAIT"),_6292);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      int _6293 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6293 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_SUPPRESS_EXPIRE_WRNS"),_6293);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("licensePauseTime")))
  {
    {
      try
      {
        {
          int _6295 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((int)0 <= _6295) && (_6295 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6295);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6294)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("licenseDebug")))
  {
    {
      int _6296 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6296 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_DEBUG"),_6296);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("log")))
  {
    {
      try
      {
        {
          int _6298 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6298))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6298);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6297)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logExpand")))
  {
    {
      try
      {
        {
          int _6300 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6300))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6300);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6299)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logFile")))
  {
    {
      try
      {
        {
          int _6302 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6302))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6302);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6301)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("logOrder")))
  {
    {
      try
      {
        {
          int _6304 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6304))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6304);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6303)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simScaling")))
  {
    {
      int _6305 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6185);
      if ((_6305 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING"),_6305);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simScalingMethod")))
  {
    {
      int _6306 = ::mosek::fusion::p_Parameters::string_to_scalingmethod_value(_6185);
      if ((_6306 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING_METHOD"),_6306);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6308 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((int)0 <= _6308) && (_6308 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6308);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6307)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simDualPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6310 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((int)0 <= _6310) && (_6310 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6310);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6309)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simMaxNumSetbacks")))
  {
    {
      try
      {
        {
          int _6312 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6312))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6312);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6311)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simHotstart")))
  {
    {
      int _6313 = ::mosek::fusion::p_Parameters::string_to_simhotstart_value(_6185);
      if ((_6313 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART"),_6313);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simBasisFactorUse")))
  {
    {
      int _6314 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6314 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_BASIS_FACTOR_USE"),_6314);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simDegen")))
  {
    {
      int _6315 = ::mosek::fusion::p_Parameters::string_to_simdegen_value(_6185);
      if ((_6315 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_DEGEN"),_6315);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simReformulation")))
  {
    {
      int _6316 = ::mosek::fusion::p_Parameters::string_to_simreform_value(_6185);
      if ((_6316 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFORMULATION"),_6316);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simExploitDupvec")))
  {
    {
      int _6317 = ::mosek::fusion::p_Parameters::string_to_simdupvec_value(_6185);
      if ((_6317 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_EXPLOIT_DUPVEC"),_6317);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simSaveLu")))
  {
    {
      int _6318 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6318 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_SAVE_LU"),_6318);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simNonSingular")))
  {
    {
      int _6319 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6319 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_NON_SINGULAR"),_6319);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simDualCrash")))
  {
    {
      try
      {
        {
          int _6321 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((int)0 <= _6321))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6321);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6320)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("infeasPreferPrimal")))
  {
    {
      int _6322 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6322 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INFEAS_PREFER_PRIMAL"),_6322);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      try
      {
        {
          int _6324 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if ((((-(int)1) <= _6324) && (_6324 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6324);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6323)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioCutCmir")))
  {
    {
      int _6325 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6325 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CMIR"),_6325);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioCutClique")))
  {
    {
      int _6326 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6326 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CLIQUE"),_6326);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioCutImpliedBound")))
  {
    {
      int _6327 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6327 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_IMPLIED_BOUND"),_6327);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioCutKnapsackCover")))
  {
    {
      int _6328 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6328 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_KNAPSACK_COVER"),_6328);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioCutGmi")))
  {
    {
      int _6329 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6329 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_GMI"),_6329);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      try
      {
        {
          int _6331 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6331);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6330)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      try
      {
        {
          int _6333 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6333);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6332)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("cacheLicense")))
  {
    {
      int _6334 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6334 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_CACHE_LICENSE"),_6334);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("intpntRegularizationUse")))
  {
    {
      int _6335 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6335 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_REGULARIZATION_USE"),_6335);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simSolveForm")))
  {
    {
      int _6336 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6185);
      if ((_6336 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_SOLVE_FORM"),_6336);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("simSwitchOptimizer")))
  {
    {
      int _6337 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6185);
      if ((_6337 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_SIM_SWITCH_OPTIMIZER"),_6337);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("mioRinsMaxNodes")))
  {
    {
      try
      {
        {
          int _6339 = ::mosek::fusion::Utils::Tools::toInt(_6185);
          if (((-(int)1) <= _6339))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6339);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6338)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("optimizerMaxTime")))
  {
    {
      try
      {
        {
          double _6341 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6341);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6340)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("lowerObjCut")))
  {
    {
      try
      {
        {
          double _6343 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6343);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6342)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("upperObjCut")))
  {
    {
      try
      {
        {
          double _6345 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6345);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6344)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6347 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6347);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6346)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6349 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6349);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6348)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolRelGap")))
  {
    {
      try
      {
        {
          double _6351 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e-14 <= _6351))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6351);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6350)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolStepSize")))
  {
    {
      try
      {
        {
          double _6353 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6353) && (_6353 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6353);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6352)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simLuTolRelPiv")))
  {
    {
      try
      {
        {
          double _6355 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((1.000000e-06 <= _6355) && (_6355 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6355);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6354)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolRelStep")))
  {
    {
      try
      {
        {
          double _6357 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((1.000000e-04 <= _6357) && (_6357 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6357);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6356)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolPath")))
  {
    {
      try
      {
        {
          double _6359 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6359) && (_6359 <= 9.999000e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6359);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6358)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolPfeas")))
  {
    {
      try
      {
        {
          double _6361 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6361) && (_6361 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6361);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6360)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolDfeas")))
  {
    {
      try
      {
        {
          double _6363 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6363) && (_6363 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6363);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6362)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolMuRed")))
  {
    {
      try
      {
        {
          double _6365 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6365) && (_6365 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6365);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6364)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolInfeas")))
  {
    {
      try
      {
        {
          double _6367 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6367) && (_6367 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6367);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6366)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntCoTolRelGap")))
  {
    {
      try
      {
        {
          double _6369 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6369) && (_6369 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6369);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6368)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntCoTolPfeas")))
  {
    {
      try
      {
        {
          double _6371 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6371) && (_6371 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6371);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6370)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntCoTolDfeas")))
  {
    {
      try
      {
        {
          double _6373 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6373) && (_6373 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6373);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6372)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntCoTolMuRed")))
  {
    {
      try
      {
        {
          double _6375 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6375) && (_6375 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6375);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6374)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntCoTolNearRel")))
  {
    {
      try
      {
        {
          double _6377 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e+00 <= _6377))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6377);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6376)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntCoTolInfeas")))
  {
    {
      try
      {
        {
          double _6379 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6379) && (_6379 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6379);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6378)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolPsafe")))
  {
    {
      try
      {
        {
          double _6381 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e-04 <= _6381))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6381);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6380)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("intpntTolDsafe")))
  {
    {
      try
      {
        {
          double _6383 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e-04 <= _6383))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6383);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6382)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioMaxTime")))
  {
    {
      try
      {
        {
          double _6385 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6385);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6384)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioRelGapConst")))
  {
    {
      try
      {
        {
          double _6387 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e-15 <= _6387))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6387);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6386)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioTolRelGap")))
  {
    {
      try
      {
        {
          double _6389 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((0.000000e+00 <= _6389))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6389);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6388)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioTolAbsGap")))
  {
    {
      try
      {
        {
          double _6391 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((0.000000e+00 <= _6391))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6391);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6390)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      try
      {
        {
          double _6393 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e-09 <= _6393))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6393);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6392)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("basisTolX")))
  {
    {
      try
      {
        {
          double _6395 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e-09 <= _6395))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6395);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6394)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("basisTolS")))
  {
    {
      try
      {
        {
          double _6397 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e-09 <= _6397))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6397);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6396)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("basisRelTolS")))
  {
    {
      try
      {
        {
          double _6399 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((0.000000e+00 <= _6399))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6399);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6398)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveTolX")))
  {
    {
      try
      {
        {
          double _6401 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((0.000000e+00 <= _6401))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6401);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6400)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveTolS")))
  {
    {
      try
      {
        {
          double _6403 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((0.000000e+00 <= _6403))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6403);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6402)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveTolAij")))
  {
    {
      try
      {
        {
          double _6405 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e-15 <= _6405))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6405);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6404)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveTolAbsLindep")))
  {
    {
      try
      {
        {
          double _6407 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((0.000000e+00 <= _6407))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6407);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6406)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("presolveTolRelLindep")))
  {
    {
      try
      {
        {
          double _6409 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((0.000000e+00 <= _6409))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6409);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6408)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("simplexAbsTolPiv")))
  {
    {
      try
      {
        {
          double _6411 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((1.000000e-12 <= _6411))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6411);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6410)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioTolFeas")))
  {
    {
      try
      {
        {
          double _6413 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((1.000000e-09 <= _6413) && (_6413 <= 1.000000e-03)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6413);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6412)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("anaSolInfeasTol")))
  {
    {
      try
      {
        {
          double _6415 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if ((0.000000e+00 <= _6415))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_ANA_SOL_INFEAS_TOL"),_6415);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6414)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      try
      {
        {
          double _6417 = ::mosek::fusion::Utils::Tools::toDouble(_6185);
          if (((0.000000e+00 <= _6417) && (_6417 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6417);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6416)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  {}
  if ((_6184 == std::string ("dataFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_SPAR_DATA_FILE_NAME"),_6185);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("basSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_SPAR_BAS_SOL_FILE_NAME"),_6185);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("itrSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_SPAR_ITR_SOL_FILE_NAME"),_6185);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("intSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_SPAR_INT_SOL_FILE_NAME"),_6185);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("writeLpGenVarName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_SPAR_WRITE_LP_GEN_VAR_NAME"),_6185);
      return;
    }
  }
  {}
  if ((_6184 == std::string ("remoteAccessToken")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6183.get())->task_put_param(std::string ("MSK_SPAR_REMOTE_ACCESS_TOKEN"),_6185);
      return;
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
int mosek::fusion::p_Parameters::string_to_variabletype_value(const std::string & _6418){
  if ((_6418 == std::string ("typeCont")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6418 == std::string ("typeInt")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_value_value(const std::string & _6419){
  if ((_6419 == std::string ("maxStrLen")))
  {
    {
      return (int)1024;
    }
  }
  {}
  if ((_6419 == std::string ("licenseBufferLength")))
  {
    {
      return (int)21;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_streamtype_value(const std::string & _6420){
  if ((_6420 == std::string ("log")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6420 == std::string ("msg")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6420 == std::string ("err")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6420 == std::string ("wrn")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_startpointtype_value(const std::string & _6421){
  if ((_6421 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6421 == std::string ("guess")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6421 == std::string ("constant")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6421 == std::string ("satisfyBounds")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_stakey_value(const std::string & _6422){
  if ((_6422 == std::string ("unk")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6422 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6422 == std::string ("supbas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6422 == std::string ("low")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6422 == std::string ("upr")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6422 == std::string ("fix")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6422 == std::string ("inf")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sparam_value(const std::string & _6423){
  if ((_6423 == std::string ("dataFileName")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6423 == std::string ("paramReadFileName")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6423 == std::string ("paramWriteFileName")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6423 == std::string ("paramCommentSign")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6423 == std::string ("debugFileName")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6423 == std::string ("basSolFileName")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6423 == std::string ("itrSolFileName")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6423 == std::string ("intSolFileName")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6423 == std::string ("solFilterXcLow")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6423 == std::string ("solFilterXcUpr")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6423 == std::string ("solFilterXxLow")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6423 == std::string ("solFilterXxUpr")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6423 == std::string ("readMpsObjName")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6423 == std::string ("readMpsRanName")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6423 == std::string ("readMpsRhsName")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6423 == std::string ("readMpsBouName")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6423 == std::string ("statFileName")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6423 == std::string ("statName")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6423 == std::string ("statKey")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6423 == std::string ("writeLpGenVarName")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6423 == std::string ("sensitivityResFileName")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6423 == std::string ("sensitivityFileName")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6423 == std::string ("mioDebugString")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6423 == std::string ("remoteAccessToken")))
  {
    {
      return (int)13;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solveform_value(const std::string & _6424){
  if ((_6424 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6424 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6424 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_soltype_value(const std::string & _6425){
  if ((_6425 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6425 == std::string ("itr")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6425 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solsta_value(const std::string & _6426){
  if ((_6426 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6426 == std::string ("optimal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6426 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6426 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6426 == std::string ("primAndDualFeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6426 == std::string ("primInfeasCer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6426 == std::string ("dualInfeasCer")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6426 == std::string ("primIllposedCer")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6426 == std::string ("dualIllposedCer")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6426 == std::string ("integerOptimal")))
  {
    {
      return (int)9;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solitem_value(const std::string & _6427){
  if ((_6427 == std::string ("xc")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6427 == std::string ("xx")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6427 == std::string ("y")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6427 == std::string ("slc")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6427 == std::string ("suc")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6427 == std::string ("slx")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6427 == std::string ("sux")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6427 == std::string ("snx")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simseltype_value(const std::string & _6428){
  if ((_6428 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6428 == std::string ("full")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6428 == std::string ("ase")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6428 == std::string ("devex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6428 == std::string ("se")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6428 == std::string ("partial")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sensitivitytype_value(const std::string & _6429){
  if ((_6429 == std::string ("basis")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingmethod_value(const std::string & _6430){
  if ((_6430 == std::string ("pow2")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6430 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingtype_value(const std::string & _6431){
  if ((_6431 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6431 == std::string ("none")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6431 == std::string ("moderate")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6431 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescodetype_value(const std::string & _6432){
  if ((_6432 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6432 == std::string ("wrn")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6432 == std::string ("trm")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6432 == std::string ("err")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6432 == std::string ("unk")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescode_value(const std::string & _6433){
  if ((_6433 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6433 == std::string ("wrnOpenParamFile")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLargeBound")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLargeLoBound")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLargeUpBound")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLargeConFx")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLargeCj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLargeAij")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6433 == std::string ("wrnZeroAij")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6433 == std::string ("wrnNameMaxLen")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6433 == std::string ("wrnSparMaxLen")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6433 == std::string ("wrnMpsSplitRhsVector")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6433 == std::string ("wrnMpsSplitRanVector")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6433 == std::string ("wrnMpsSplitBouVector")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLpOldQuadFormat")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLpDropVariable")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6433 == std::string ("wrnNzInUprTri")))
  {
    {
      return (int)200;
    }
  }
  {}
  if ((_6433 == std::string ("wrnDroppedNzQobj")))
  {
    {
      return (int)201;
    }
  }
  {}
  if ((_6433 == std::string ("wrnIgnoreInteger")))
  {
    {
      return (int)250;
    }
  }
  {}
  if ((_6433 == std::string ("wrnNoGlobalOptimizer")))
  {
    {
      return (int)251;
    }
  }
  {}
  if ((_6433 == std::string ("wrnMioInfeasibleFinal")))
  {
    {
      return (int)270;
    }
  }
  {}
  if ((_6433 == std::string ("wrnSolFilter")))
  {
    {
      return (int)300;
    }
  }
  {}
  if ((_6433 == std::string ("wrnUndefSolFileName")))
  {
    {
      return (int)350;
    }
  }
  {}
  if ((_6433 == std::string ("wrnSolFileIgnoredCon")))
  {
    {
      return (int)351;
    }
  }
  {}
  if ((_6433 == std::string ("wrnSolFileIgnoredVar")))
  {
    {
      return (int)352;
    }
  }
  {}
  if ((_6433 == std::string ("wrnTooFewBasisVars")))
  {
    {
      return (int)400;
    }
  }
  {}
  if ((_6433 == std::string ("wrnTooManyBasisVars")))
  {
    {
      return (int)405;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLicenseExpire")))
  {
    {
      return (int)500;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLicenseServer")))
  {
    {
      return (int)501;
    }
  }
  {}
  if ((_6433 == std::string ("wrnEmptyName")))
  {
    {
      return (int)502;
    }
  }
  {}
  if ((_6433 == std::string ("wrnUsingGenericNames")))
  {
    {
      return (int)503;
    }
  }
  {}
  if ((_6433 == std::string ("wrnLicenseFeatureExpire")))
  {
    {
      return (int)505;
    }
  }
  {}
  if ((_6433 == std::string ("wrnParamNameDou")))
  {
    {
      return (int)510;
    }
  }
  {}
  if ((_6433 == std::string ("wrnParamNameInt")))
  {
    {
      return (int)511;
    }
  }
  {}
  if ((_6433 == std::string ("wrnParamNameStr")))
  {
    {
      return (int)512;
    }
  }
  {}
  if ((_6433 == std::string ("wrnParamStrValue")))
  {
    {
      return (int)515;
    }
  }
  {}
  if ((_6433 == std::string ("wrnParamIgnoredCmio")))
  {
    {
      return (int)516;
    }
  }
  {}
  if ((_6433 == std::string ("wrnZerosInSparseRow")))
  {
    {
      return (int)705;
    }
  }
  {}
  if ((_6433 == std::string ("wrnZerosInSparseCol")))
  {
    {
      return (int)710;
    }
  }
  {}
  if ((_6433 == std::string ("wrnIncompleteLinearDependencyCheck")))
  {
    {
      return (int)800;
    }
  }
  {}
  if ((_6433 == std::string ("wrnEliminatorSpace")))
  {
    {
      return (int)801;
    }
  }
  {}
  if ((_6433 == std::string ("wrnPresolveOutofspace")))
  {
    {
      return (int)802;
    }
  }
  {}
  if ((_6433 == std::string ("wrnWriteChangedNames")))
  {
    {
      return (int)803;
    }
  }
  {}
  if ((_6433 == std::string ("wrnWriteDiscardedCfix")))
  {
    {
      return (int)804;
    }
  }
  {}
  if ((_6433 == std::string ("wrnDuplicateConstraintNames")))
  {
    {
      return (int)850;
    }
  }
  {}
  if ((_6433 == std::string ("wrnDuplicateVariableNames")))
  {
    {
      return (int)851;
    }
  }
  {}
  if ((_6433 == std::string ("wrnDuplicateBarvariableNames")))
  {
    {
      return (int)852;
    }
  }
  {}
  if ((_6433 == std::string ("wrnDuplicateConeNames")))
  {
    {
      return (int)853;
    }
  }
  {}
  if ((_6433 == std::string ("wrnAnaLargeBounds")))
  {
    {
      return (int)900;
    }
  }
  {}
  if ((_6433 == std::string ("wrnAnaCZero")))
  {
    {
      return (int)901;
    }
  }
  {}
  if ((_6433 == std::string ("wrnAnaEmptyCols")))
  {
    {
      return (int)902;
    }
  }
  {}
  if ((_6433 == std::string ("wrnAnaCloseBounds")))
  {
    {
      return (int)903;
    }
  }
  {}
  if ((_6433 == std::string ("wrnAnaAlmostIntBounds")))
  {
    {
      return (int)904;
    }
  }
  {}
  if ((_6433 == std::string ("wrnQuadConesWithRootFixedAtZero")))
  {
    {
      return (int)930;
    }
  }
  {}
  if ((_6433 == std::string ("wrnRquadConesWithRootFixedAtZero")))
  {
    {
      return (int)931;
    }
  }
  {}
  if ((_6433 == std::string ("wrnExpConesWithVariablesFixedAtZero")))
  {
    {
      return (int)932;
    }
  }
  {}
  if ((_6433 == std::string ("wrnPowConesWithRootFixedAtZero")))
  {
    {
      return (int)933;
    }
  }
  {}
  if ((_6433 == std::string ("wrnNoDualizer")))
  {
    {
      return (int)950;
    }
  }
  {}
  if ((_6433 == std::string ("wrnSymMatLarge")))
  {
    {
      return (int)960;
    }
  }
  {}
  if ((_6433 == std::string ("errLicense")))
  {
    {
      return (int)1000;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseExpired")))
  {
    {
      return (int)1001;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseVersion")))
  {
    {
      return (int)1002;
    }
  }
  {}
  if ((_6433 == std::string ("errSizeLicense")))
  {
    {
      return (int)1005;
    }
  }
  {}
  if ((_6433 == std::string ("errProbLicense")))
  {
    {
      return (int)1006;
    }
  }
  {}
  if ((_6433 == std::string ("errFileLicense")))
  {
    {
      return (int)1007;
    }
  }
  {}
  if ((_6433 == std::string ("errMissingLicenseFile")))
  {
    {
      return (int)1008;
    }
  }
  {}
  if ((_6433 == std::string ("errSizeLicenseCon")))
  {
    {
      return (int)1010;
    }
  }
  {}
  if ((_6433 == std::string ("errSizeLicenseVar")))
  {
    {
      return (int)1011;
    }
  }
  {}
  if ((_6433 == std::string ("errSizeLicenseIntvar")))
  {
    {
      return (int)1012;
    }
  }
  {}
  if ((_6433 == std::string ("errOptimizerLicense")))
  {
    {
      return (int)1013;
    }
  }
  {}
  if ((_6433 == std::string ("errFlexlm")))
  {
    {
      return (int)1014;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseServer")))
  {
    {
      return (int)1015;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseMax")))
  {
    {
      return (int)1016;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseMoseklmDaemon")))
  {
    {
      return (int)1017;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseFeature")))
  {
    {
      return (int)1018;
    }
  }
  {}
  if ((_6433 == std::string ("errPlatformNotLicensed")))
  {
    {
      return (int)1019;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseCannotAllocate")))
  {
    {
      return (int)1020;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseCannotConnect")))
  {
    {
      return (int)1021;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseInvalidHostid")))
  {
    {
      return (int)1025;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseServerVersion")))
  {
    {
      return (int)1026;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseNoServerSupport")))
  {
    {
      return (int)1027;
    }
  }
  {}
  if ((_6433 == std::string ("errLicenseNoServerLine")))
  {
    {
      return (int)1028;
    }
  }
  {}
  if ((_6433 == std::string ("errOlderDll")))
  {
    {
      return (int)1035;
    }
  }
  {}
  if ((_6433 == std::string ("errNewerDll")))
  {
    {
      return (int)1036;
    }
  }
  {}
  if ((_6433 == std::string ("errLinkFileDll")))
  {
    {
      return (int)1040;
    }
  }
  {}
  if ((_6433 == std::string ("errThreadMutexInit")))
  {
    {
      return (int)1045;
    }
  }
  {}
  if ((_6433 == std::string ("errThreadMutexLock")))
  {
    {
      return (int)1046;
    }
  }
  {}
  if ((_6433 == std::string ("errThreadMutexUnlock")))
  {
    {
      return (int)1047;
    }
  }
  {}
  if ((_6433 == std::string ("errThreadCreate")))
  {
    {
      return (int)1048;
    }
  }
  {}
  if ((_6433 == std::string ("errThreadCondInit")))
  {
    {
      return (int)1049;
    }
  }
  {}
  if ((_6433 == std::string ("errUnknown")))
  {
    {
      return (int)1050;
    }
  }
  {}
  if ((_6433 == std::string ("errSpace")))
  {
    {
      return (int)1051;
    }
  }
  {}
  if ((_6433 == std::string ("errFileOpen")))
  {
    {
      return (int)1052;
    }
  }
  {}
  if ((_6433 == std::string ("errFileRead")))
  {
    {
      return (int)1053;
    }
  }
  {}
  if ((_6433 == std::string ("errFileWrite")))
  {
    {
      return (int)1054;
    }
  }
  {}
  if ((_6433 == std::string ("errDataFileExt")))
  {
    {
      return (int)1055;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidFileName")))
  {
    {
      return (int)1056;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidSolFileName")))
  {
    {
      return (int)1057;
    }
  }
  {}
  if ((_6433 == std::string ("errEndOfFile")))
  {
    {
      return (int)1059;
    }
  }
  {}
  if ((_6433 == std::string ("errNullEnv")))
  {
    {
      return (int)1060;
    }
  }
  {}
  if ((_6433 == std::string ("errNullTask")))
  {
    {
      return (int)1061;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidStream")))
  {
    {
      return (int)1062;
    }
  }
  {}
  if ((_6433 == std::string ("errNoInitEnv")))
  {
    {
      return (int)1063;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidTask")))
  {
    {
      return (int)1064;
    }
  }
  {}
  if ((_6433 == std::string ("errNullPointer")))
  {
    {
      return (int)1065;
    }
  }
  {}
  if ((_6433 == std::string ("errLivingTasks")))
  {
    {
      return (int)1066;
    }
  }
  {}
  if ((_6433 == std::string ("errBlankName")))
  {
    {
      return (int)1070;
    }
  }
  {}
  if ((_6433 == std::string ("errDupName")))
  {
    {
      return (int)1071;
    }
  }
  {}
  if ((_6433 == std::string ("errFormatString")))
  {
    {
      return (int)1072;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidObjName")))
  {
    {
      return (int)1075;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidConName")))
  {
    {
      return (int)1076;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidVarName")))
  {
    {
      return (int)1077;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidConeName")))
  {
    {
      return (int)1078;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidBarvarName")))
  {
    {
      return (int)1079;
    }
  }
  {}
  if ((_6433 == std::string ("errSpaceLeaking")))
  {
    {
      return (int)1080;
    }
  }
  {}
  if ((_6433 == std::string ("errSpaceNoInfo")))
  {
    {
      return (int)1081;
    }
  }
  {}
  if ((_6433 == std::string ("errReadFormat")))
  {
    {
      return (int)1090;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsFile")))
  {
    {
      return (int)1100;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsInvField")))
  {
    {
      return (int)1101;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsInvMarker")))
  {
    {
      return (int)1102;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsNullConName")))
  {
    {
      return (int)1103;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsNullVarName")))
  {
    {
      return (int)1104;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsUndefConName")))
  {
    {
      return (int)1105;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsUndefVarName")))
  {
    {
      return (int)1106;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsInvConKey")))
  {
    {
      return (int)1107;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsInvBoundKey")))
  {
    {
      return (int)1108;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsInvSecName")))
  {
    {
      return (int)1109;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsNoObjective")))
  {
    {
      return (int)1110;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsSplittedVar")))
  {
    {
      return (int)1111;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsMulConName")))
  {
    {
      return (int)1112;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsMulQsec")))
  {
    {
      return (int)1113;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsMulQobj")))
  {
    {
      return (int)1114;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsInvSecOrder")))
  {
    {
      return (int)1115;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsMulCsec")))
  {
    {
      return (int)1116;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsConeType")))
  {
    {
      return (int)1117;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsConeOverlap")))
  {
    {
      return (int)1118;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsConeRepeat")))
  {
    {
      return (int)1119;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsNonSymmetricQ")))
  {
    {
      return (int)1120;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsDuplicateQElement")))
  {
    {
      return (int)1121;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsInvalidObjsense")))
  {
    {
      return (int)1122;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsTabInField2")))
  {
    {
      return (int)1125;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsTabInField3")))
  {
    {
      return (int)1126;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsTabInField5")))
  {
    {
      return (int)1127;
    }
  }
  {}
  if ((_6433 == std::string ("errMpsInvalidObjName")))
  {
    {
      return (int)1128;
    }
  }
  {}
  if ((_6433 == std::string ("errLpIncompatible")))
  {
    {
      return (int)1150;
    }
  }
  {}
  if ((_6433 == std::string ("errLpEmpty")))
  {
    {
      return (int)1151;
    }
  }
  {}
  if ((_6433 == std::string ("errLpDupSlackName")))
  {
    {
      return (int)1152;
    }
  }
  {}
  if ((_6433 == std::string ("errWriteMpsInvalidName")))
  {
    {
      return (int)1153;
    }
  }
  {}
  if ((_6433 == std::string ("errLpInvalidVarName")))
  {
    {
      return (int)1154;
    }
  }
  {}
  if ((_6433 == std::string ("errLpFreeConstraint")))
  {
    {
      return (int)1155;
    }
  }
  {}
  if ((_6433 == std::string ("errWriteOpfInvalidVarName")))
  {
    {
      return (int)1156;
    }
  }
  {}
  if ((_6433 == std::string ("errLpFileFormat")))
  {
    {
      return (int)1157;
    }
  }
  {}
  if ((_6433 == std::string ("errWriteLpFormat")))
  {
    {
      return (int)1158;
    }
  }
  {}
  if ((_6433 == std::string ("errReadLpMissingEndTag")))
  {
    {
      return (int)1159;
    }
  }
  {}
  if ((_6433 == std::string ("errLpFormat")))
  {
    {
      return (int)1160;
    }
  }
  {}
  if ((_6433 == std::string ("errWriteLpNonUniqueName")))
  {
    {
      return (int)1161;
    }
  }
  {}
  if ((_6433 == std::string ("errReadLpNonexistingName")))
  {
    {
      return (int)1162;
    }
  }
  {}
  if ((_6433 == std::string ("errLpWriteConicProblem")))
  {
    {
      return (int)1163;
    }
  }
  {}
  if ((_6433 == std::string ("errLpWriteGecoProblem")))
  {
    {
      return (int)1164;
    }
  }
  {}
  if ((_6433 == std::string ("errWritingFile")))
  {
    {
      return (int)1166;
    }
  }
  {}
  if ((_6433 == std::string ("errPtfFormat")))
  {
    {
      return (int)1167;
    }
  }
  {}
  if ((_6433 == std::string ("errOpfFormat")))
  {
    {
      return (int)1168;
    }
  }
  {}
  if ((_6433 == std::string ("errOpfNewVariable")))
  {
    {
      return (int)1169;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidNameInSolFile")))
  {
    {
      return (int)1170;
    }
  }
  {}
  if ((_6433 == std::string ("errLpInvalidConName")))
  {
    {
      return (int)1171;
    }
  }
  {}
  if ((_6433 == std::string ("errOpfPrematureEof")))
  {
    {
      return (int)1172;
    }
  }
  {}
  if ((_6433 == std::string ("errJsonSyntax")))
  {
    {
      return (int)1175;
    }
  }
  {}
  if ((_6433 == std::string ("errJsonString")))
  {
    {
      return (int)1176;
    }
  }
  {}
  if ((_6433 == std::string ("errJsonNumberOverflow")))
  {
    {
      return (int)1177;
    }
  }
  {}
  if ((_6433 == std::string ("errJsonFormat")))
  {
    {
      return (int)1178;
    }
  }
  {}
  if ((_6433 == std::string ("errJsonData")))
  {
    {
      return (int)1179;
    }
  }
  {}
  if ((_6433 == std::string ("errJsonMissingData")))
  {
    {
      return (int)1180;
    }
  }
  {}
  if ((_6433 == std::string ("errArgumentLenneq")))
  {
    {
      return (int)1197;
    }
  }
  {}
  if ((_6433 == std::string ("errArgumentType")))
  {
    {
      return (int)1198;
    }
  }
  {}
  if ((_6433 == std::string ("errNumArguments")))
  {
    {
      return (int)1199;
    }
  }
  {}
  if ((_6433 == std::string ("errInArgument")))
  {
    {
      return (int)1200;
    }
  }
  {}
  if ((_6433 == std::string ("errArgumentDimension")))
  {
    {
      return (int)1201;
    }
  }
  {}
  if ((_6433 == std::string ("errShapeIsTooLarge")))
  {
    {
      return (int)1202;
    }
  }
  {}
  if ((_6433 == std::string ("errIndexIsTooSmall")))
  {
    {
      return (int)1203;
    }
  }
  {}
  if ((_6433 == std::string ("errIndexIsTooLarge")))
  {
    {
      return (int)1204;
    }
  }
  {}
  if ((_6433 == std::string ("errParamName")))
  {
    {
      return (int)1205;
    }
  }
  {}
  if ((_6433 == std::string ("errParamNameDou")))
  {
    {
      return (int)1206;
    }
  }
  {}
  if ((_6433 == std::string ("errParamNameInt")))
  {
    {
      return (int)1207;
    }
  }
  {}
  if ((_6433 == std::string ("errParamNameStr")))
  {
    {
      return (int)1208;
    }
  }
  {}
  if ((_6433 == std::string ("errParamIndex")))
  {
    {
      return (int)1210;
    }
  }
  {}
  if ((_6433 == std::string ("errParamIsTooLarge")))
  {
    {
      return (int)1215;
    }
  }
  {}
  if ((_6433 == std::string ("errParamIsTooSmall")))
  {
    {
      return (int)1216;
    }
  }
  {}
  if ((_6433 == std::string ("errParamValueStr")))
  {
    {
      return (int)1217;
    }
  }
  {}
  if ((_6433 == std::string ("errParamType")))
  {
    {
      return (int)1218;
    }
  }
  {}
  if ((_6433 == std::string ("errInfDouIndex")))
  {
    {
      return (int)1219;
    }
  }
  {}
  if ((_6433 == std::string ("errInfIntIndex")))
  {
    {
      return (int)1220;
    }
  }
  {}
  if ((_6433 == std::string ("errIndexArrIsTooSmall")))
  {
    {
      return (int)1221;
    }
  }
  {}
  if ((_6433 == std::string ("errIndexArrIsTooLarge")))
  {
    {
      return (int)1222;
    }
  }
  {}
  if ((_6433 == std::string ("errInfLintIndex")))
  {
    {
      return (int)1225;
    }
  }
  {}
  if ((_6433 == std::string ("errArgIsTooSmall")))
  {
    {
      return (int)1226;
    }
  }
  {}
  if ((_6433 == std::string ("errArgIsTooLarge")))
  {
    {
      return (int)1227;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidWhichsol")))
  {
    {
      return (int)1228;
    }
  }
  {}
  if ((_6433 == std::string ("errInfDouName")))
  {
    {
      return (int)1230;
    }
  }
  {}
  if ((_6433 == std::string ("errInfIntName")))
  {
    {
      return (int)1231;
    }
  }
  {}
  if ((_6433 == std::string ("errInfType")))
  {
    {
      return (int)1232;
    }
  }
  {}
  if ((_6433 == std::string ("errInfLintName")))
  {
    {
      return (int)1234;
    }
  }
  {}
  if ((_6433 == std::string ("errIndex")))
  {
    {
      return (int)1235;
    }
  }
  {}
  if ((_6433 == std::string ("errWhichsol")))
  {
    {
      return (int)1236;
    }
  }
  {}
  if ((_6433 == std::string ("errSolitem")))
  {
    {
      return (int)1237;
    }
  }
  {}
  if ((_6433 == std::string ("errWhichitemNotAllowed")))
  {
    {
      return (int)1238;
    }
  }
  {}
  if ((_6433 == std::string ("errMaxnumcon")))
  {
    {
      return (int)1240;
    }
  }
  {}
  if ((_6433 == std::string ("errMaxnumvar")))
  {
    {
      return (int)1241;
    }
  }
  {}
  if ((_6433 == std::string ("errMaxnumbarvar")))
  {
    {
      return (int)1242;
    }
  }
  {}
  if ((_6433 == std::string ("errMaxnumqnz")))
  {
    {
      return (int)1243;
    }
  }
  {}
  if ((_6433 == std::string ("errTooSmallMaxNumNz")))
  {
    {
      return (int)1245;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidIdx")))
  {
    {
      return (int)1246;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidMaxNum")))
  {
    {
      return (int)1247;
    }
  }
  {}
  if ((_6433 == std::string ("errNumconlim")))
  {
    {
      return (int)1250;
    }
  }
  {}
  if ((_6433 == std::string ("errNumvarlim")))
  {
    {
      return (int)1251;
    }
  }
  {}
  if ((_6433 == std::string ("errTooSmallMaxnumanz")))
  {
    {
      return (int)1252;
    }
  }
  {}
  if ((_6433 == std::string ("errInvAptre")))
  {
    {
      return (int)1253;
    }
  }
  {}
  if ((_6433 == std::string ("errMulAElement")))
  {
    {
      return (int)1254;
    }
  }
  {}
  if ((_6433 == std::string ("errInvBk")))
  {
    {
      return (int)1255;
    }
  }
  {}
  if ((_6433 == std::string ("errInvBkc")))
  {
    {
      return (int)1256;
    }
  }
  {}
  if ((_6433 == std::string ("errInvBkx")))
  {
    {
      return (int)1257;
    }
  }
  {}
  if ((_6433 == std::string ("errInvVarType")))
  {
    {
      return (int)1258;
    }
  }
  {}
  if ((_6433 == std::string ("errSolverProbtype")))
  {
    {
      return (int)1259;
    }
  }
  {}
  if ((_6433 == std::string ("errObjectiveRange")))
  {
    {
      return (int)1260;
    }
  }
  {}
  if ((_6433 == std::string ("errUndefSolution")))
  {
    {
      return (int)1265;
    }
  }
  {}
  if ((_6433 == std::string ("errBasis")))
  {
    {
      return (int)1266;
    }
  }
  {}
  if ((_6433 == std::string ("errInvSkc")))
  {
    {
      return (int)1267;
    }
  }
  {}
  if ((_6433 == std::string ("errInvSkx")))
  {
    {
      return (int)1268;
    }
  }
  {}
  if ((_6433 == std::string ("errInvSkn")))
  {
    {
      return (int)1274;
    }
  }
  {}
  if ((_6433 == std::string ("errInvSkStr")))
  {
    {
      return (int)1269;
    }
  }
  {}
  if ((_6433 == std::string ("errInvSk")))
  {
    {
      return (int)1270;
    }
  }
  {}
  if ((_6433 == std::string ("errInvConeTypeStr")))
  {
    {
      return (int)1271;
    }
  }
  {}
  if ((_6433 == std::string ("errInvConeType")))
  {
    {
      return (int)1272;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidSurplus")))
  {
    {
      return (int)1275;
    }
  }
  {}
  if ((_6433 == std::string ("errInvNameItem")))
  {
    {
      return (int)1280;
    }
  }
  {}
  if ((_6433 == std::string ("errProItem")))
  {
    {
      return (int)1281;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidFormatType")))
  {
    {
      return (int)1283;
    }
  }
  {}
  if ((_6433 == std::string ("errFirsti")))
  {
    {
      return (int)1285;
    }
  }
  {}
  if ((_6433 == std::string ("errLasti")))
  {
    {
      return (int)1286;
    }
  }
  {}
  if ((_6433 == std::string ("errFirstj")))
  {
    {
      return (int)1287;
    }
  }
  {}
  if ((_6433 == std::string ("errLastj")))
  {
    {
      return (int)1288;
    }
  }
  {}
  if ((_6433 == std::string ("errMaxLenIsTooSmall")))
  {
    {
      return (int)1289;
    }
  }
  {}
  if ((_6433 == std::string ("errNonlinearEquality")))
  {
    {
      return (int)1290;
    }
  }
  {}
  if ((_6433 == std::string ("errNonconvex")))
  {
    {
      return (int)1291;
    }
  }
  {}
  if ((_6433 == std::string ("errNonlinearRanged")))
  {
    {
      return (int)1292;
    }
  }
  {}
  if ((_6433 == std::string ("errConQNotPsd")))
  {
    {
      return (int)1293;
    }
  }
  {}
  if ((_6433 == std::string ("errConQNotNsd")))
  {
    {
      return (int)1294;
    }
  }
  {}
  if ((_6433 == std::string ("errObjQNotPsd")))
  {
    {
      return (int)1295;
    }
  }
  {}
  if ((_6433 == std::string ("errObjQNotNsd")))
  {
    {
      return (int)1296;
    }
  }
  {}
  if ((_6433 == std::string ("errArgumentPermArray")))
  {
    {
      return (int)1299;
    }
  }
  {}
  if ((_6433 == std::string ("errConeIndex")))
  {
    {
      return (int)1300;
    }
  }
  {}
  if ((_6433 == std::string ("errConeSize")))
  {
    {
      return (int)1301;
    }
  }
  {}
  if ((_6433 == std::string ("errConeOverlap")))
  {
    {
      return (int)1302;
    }
  }
  {}
  if ((_6433 == std::string ("errConeRepVar")))
  {
    {
      return (int)1303;
    }
  }
  {}
  if ((_6433 == std::string ("errMaxnumcone")))
  {
    {
      return (int)1304;
    }
  }
  {}
  if ((_6433 == std::string ("errConeType")))
  {
    {
      return (int)1305;
    }
  }
  {}
  if ((_6433 == std::string ("errConeTypeStr")))
  {
    {
      return (int)1306;
    }
  }
  {}
  if ((_6433 == std::string ("errConeOverlapAppend")))
  {
    {
      return (int)1307;
    }
  }
  {}
  if ((_6433 == std::string ("errRemoveConeVariable")))
  {
    {
      return (int)1310;
    }
  }
  {}
  if ((_6433 == std::string ("errAppendingTooBigCone")))
  {
    {
      return (int)1311;
    }
  }
  {}
  if ((_6433 == std::string ("errConeParameter")))
  {
    {
      return (int)1320;
    }
  }
  {}
  if ((_6433 == std::string ("errSolFileInvalidNumber")))
  {
    {
      return (int)1350;
    }
  }
  {}
  if ((_6433 == std::string ("errHugeC")))
  {
    {
      return (int)1375;
    }
  }
  {}
  if ((_6433 == std::string ("errHugeAij")))
  {
    {
      return (int)1380;
    }
  }
  {}
  if ((_6433 == std::string ("errDuplicateAij")))
  {
    {
      return (int)1385;
    }
  }
  {}
  if ((_6433 == std::string ("errLowerBoundIsANan")))
  {
    {
      return (int)1390;
    }
  }
  {}
  if ((_6433 == std::string ("errUpperBoundIsANan")))
  {
    {
      return (int)1391;
    }
  }
  {}
  if ((_6433 == std::string ("errInfiniteBound")))
  {
    {
      return (int)1400;
    }
  }
  {}
  if ((_6433 == std::string ("errInvQobjSubi")))
  {
    {
      return (int)1401;
    }
  }
  {}
  if ((_6433 == std::string ("errInvQobjSubj")))
  {
    {
      return (int)1402;
    }
  }
  {}
  if ((_6433 == std::string ("errInvQobjVal")))
  {
    {
      return (int)1403;
    }
  }
  {}
  if ((_6433 == std::string ("errInvQconSubk")))
  {
    {
      return (int)1404;
    }
  }
  {}
  if ((_6433 == std::string ("errInvQconSubi")))
  {
    {
      return (int)1405;
    }
  }
  {}
  if ((_6433 == std::string ("errInvQconSubj")))
  {
    {
      return (int)1406;
    }
  }
  {}
  if ((_6433 == std::string ("errInvQconVal")))
  {
    {
      return (int)1407;
    }
  }
  {}
  if ((_6433 == std::string ("errQconSubiTooSmall")))
  {
    {
      return (int)1408;
    }
  }
  {}
  if ((_6433 == std::string ("errQconSubiTooLarge")))
  {
    {
      return (int)1409;
    }
  }
  {}
  if ((_6433 == std::string ("errQobjUpperTriangle")))
  {
    {
      return (int)1415;
    }
  }
  {}
  if ((_6433 == std::string ("errQconUpperTriangle")))
  {
    {
      return (int)1417;
    }
  }
  {}
  if ((_6433 == std::string ("errFixedBoundValues")))
  {
    {
      return (int)1420;
    }
  }
  {}
  if ((_6433 == std::string ("errTooSmallATruncationValue")))
  {
    {
      return (int)1421;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidObjectiveSense")))
  {
    {
      return (int)1445;
    }
  }
  {}
  if ((_6433 == std::string ("errUndefinedObjectiveSense")))
  {
    {
      return (int)1446;
    }
  }
  {}
  if ((_6433 == std::string ("errYIsUndefined")))
  {
    {
      return (int)1449;
    }
  }
  {}
  if ((_6433 == std::string ("errNanInDoubleData")))
  {
    {
      return (int)1450;
    }
  }
  {}
  if ((_6433 == std::string ("errNanInBlc")))
  {
    {
      return (int)1461;
    }
  }
  {}
  if ((_6433 == std::string ("errNanInBuc")))
  {
    {
      return (int)1462;
    }
  }
  {}
  if ((_6433 == std::string ("errNanInC")))
  {
    {
      return (int)1470;
    }
  }
  {}
  if ((_6433 == std::string ("errNanInBlx")))
  {
    {
      return (int)1471;
    }
  }
  {}
  if ((_6433 == std::string ("errNanInBux")))
  {
    {
      return (int)1472;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidAij")))
  {
    {
      return (int)1473;
    }
  }
  {}
  if ((_6433 == std::string ("errSymMatInvalid")))
  {
    {
      return (int)1480;
    }
  }
  {}
  if ((_6433 == std::string ("errSymMatHuge")))
  {
    {
      return (int)1482;
    }
  }
  {}
  if ((_6433 == std::string ("errInvProblem")))
  {
    {
      return (int)1500;
    }
  }
  {}
  if ((_6433 == std::string ("errMixedConicAndNl")))
  {
    {
      return (int)1501;
    }
  }
  {}
  if ((_6433 == std::string ("errGlobalInvConicProblem")))
  {
    {
      return (int)1503;
    }
  }
  {}
  if ((_6433 == std::string ("errInvOptimizer")))
  {
    {
      return (int)1550;
    }
  }
  {}
  if ((_6433 == std::string ("errMioNoOptimizer")))
  {
    {
      return (int)1551;
    }
  }
  {}
  if ((_6433 == std::string ("errNoOptimizerVarType")))
  {
    {
      return (int)1552;
    }
  }
  {}
  if ((_6433 == std::string ("errFinalSolution")))
  {
    {
      return (int)1560;
    }
  }
  {}
  if ((_6433 == std::string ("errFirst")))
  {
    {
      return (int)1570;
    }
  }
  {}
  if ((_6433 == std::string ("errLast")))
  {
    {
      return (int)1571;
    }
  }
  {}
  if ((_6433 == std::string ("errSliceSize")))
  {
    {
      return (int)1572;
    }
  }
  {}
  if ((_6433 == std::string ("errNegativeSurplus")))
  {
    {
      return (int)1573;
    }
  }
  {}
  if ((_6433 == std::string ("errNegativeAppend")))
  {
    {
      return (int)1578;
    }
  }
  {}
  if ((_6433 == std::string ("errPostsolve")))
  {
    {
      return (int)1580;
    }
  }
  {}
  if ((_6433 == std::string ("errOverflow")))
  {
    {
      return (int)1590;
    }
  }
  {}
  if ((_6433 == std::string ("errNoBasisSol")))
  {
    {
      return (int)1600;
    }
  }
  {}
  if ((_6433 == std::string ("errBasisFactor")))
  {
    {
      return (int)1610;
    }
  }
  {}
  if ((_6433 == std::string ("errBasisSingular")))
  {
    {
      return (int)1615;
    }
  }
  {}
  if ((_6433 == std::string ("errFactor")))
  {
    {
      return (int)1650;
    }
  }
  {}
  if ((_6433 == std::string ("errFeasrepairCannotRelax")))
  {
    {
      return (int)1700;
    }
  }
  {}
  if ((_6433 == std::string ("errFeasrepairSolvingRelaxed")))
  {
    {
      return (int)1701;
    }
  }
  {}
  if ((_6433 == std::string ("errFeasrepairInconsistentBound")))
  {
    {
      return (int)1702;
    }
  }
  {}
  if ((_6433 == std::string ("errRepairInvalidProblem")))
  {
    {
      return (int)1710;
    }
  }
  {}
  if ((_6433 == std::string ("errRepairOptimizationFailed")))
  {
    {
      return (int)1711;
    }
  }
  {}
  if ((_6433 == std::string ("errNameMaxLen")))
  {
    {
      return (int)1750;
    }
  }
  {}
  if ((_6433 == std::string ("errNameIsNull")))
  {
    {
      return (int)1760;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidCompression")))
  {
    {
      return (int)1800;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidIomode")))
  {
    {
      return (int)1801;
    }
  }
  {}
  if ((_6433 == std::string ("errNoPrimalInfeasCer")))
  {
    {
      return (int)2000;
    }
  }
  {}
  if ((_6433 == std::string ("errNoDualInfeasCer")))
  {
    {
      return (int)2001;
    }
  }
  {}
  if ((_6433 == std::string ("errNoSolutionInCallback")))
  {
    {
      return (int)2500;
    }
  }
  {}
  if ((_6433 == std::string ("errInvMarki")))
  {
    {
      return (int)2501;
    }
  }
  {}
  if ((_6433 == std::string ("errInvMarkj")))
  {
    {
      return (int)2502;
    }
  }
  {}
  if ((_6433 == std::string ("errInvNumi")))
  {
    {
      return (int)2503;
    }
  }
  {}
  if ((_6433 == std::string ("errInvNumj")))
  {
    {
      return (int)2504;
    }
  }
  {}
  if ((_6433 == std::string ("errTaskIncompatible")))
  {
    {
      return (int)2560;
    }
  }
  {}
  if ((_6433 == std::string ("errTaskInvalid")))
  {
    {
      return (int)2561;
    }
  }
  {}
  if ((_6433 == std::string ("errTaskWrite")))
  {
    {
      return (int)2562;
    }
  }
  {}
  if ((_6433 == std::string ("errLuMaxNumTries")))
  {
    {
      return (int)2800;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidUtf8")))
  {
    {
      return (int)2900;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidWchar")))
  {
    {
      return (int)2901;
    }
  }
  {}
  if ((_6433 == std::string ("errNoDualForItgSol")))
  {
    {
      return (int)2950;
    }
  }
  {}
  if ((_6433 == std::string ("errNoSnxForBasSol")))
  {
    {
      return (int)2953;
    }
  }
  {}
  if ((_6433 == std::string ("errInternal")))
  {
    {
      return (int)3000;
    }
  }
  {}
  if ((_6433 == std::string ("errApiArrayTooSmall")))
  {
    {
      return (int)3001;
    }
  }
  {}
  if ((_6433 == std::string ("errApiCbConnect")))
  {
    {
      return (int)3002;
    }
  }
  {}
  if ((_6433 == std::string ("errApiFatalError")))
  {
    {
      return (int)3005;
    }
  }
  {}
  if ((_6433 == std::string ("errApiInternal")))
  {
    {
      return (int)3999;
    }
  }
  {}
  if ((_6433 == std::string ("errSenFormat")))
  {
    {
      return (int)3050;
    }
  }
  {}
  if ((_6433 == std::string ("errSenUndefName")))
  {
    {
      return (int)3051;
    }
  }
  {}
  if ((_6433 == std::string ("errSenIndexRange")))
  {
    {
      return (int)3052;
    }
  }
  {}
  if ((_6433 == std::string ("errSenBoundInvalidUp")))
  {
    {
      return (int)3053;
    }
  }
  {}
  if ((_6433 == std::string ("errSenBoundInvalidLo")))
  {
    {
      return (int)3054;
    }
  }
  {}
  if ((_6433 == std::string ("errSenIndexInvalid")))
  {
    {
      return (int)3055;
    }
  }
  {}
  if ((_6433 == std::string ("errSenInvalidRegexp")))
  {
    {
      return (int)3056;
    }
  }
  {}
  if ((_6433 == std::string ("errSenSolutionStatus")))
  {
    {
      return (int)3057;
    }
  }
  {}
  if ((_6433 == std::string ("errSenNumerical")))
  {
    {
      return (int)3058;
    }
  }
  {}
  if ((_6433 == std::string ("errSenUnhandledProblemType")))
  {
    {
      return (int)3080;
    }
  }
  {}
  if ((_6433 == std::string ("errUnbStepSize")))
  {
    {
      return (int)3100;
    }
  }
  {}
  if ((_6433 == std::string ("errIdenticalTasks")))
  {
    {
      return (int)3101;
    }
  }
  {}
  if ((_6433 == std::string ("errAdInvalidCodelist")))
  {
    {
      return (int)3102;
    }
  }
  {}
  if ((_6433 == std::string ("errInternalTestFailed")))
  {
    {
      return (int)3500;
    }
  }
  {}
  if ((_6433 == std::string ("errXmlInvalidProblemType")))
  {
    {
      return (int)3600;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidAmplStub")))
  {
    {
      return (int)3700;
    }
  }
  {}
  if ((_6433 == std::string ("errInt64ToInt32Cast")))
  {
    {
      return (int)3800;
    }
  }
  {}
  if ((_6433 == std::string ("errSizeLicenseNumcores")))
  {
    {
      return (int)3900;
    }
  }
  {}
  if ((_6433 == std::string ("errInfeasUndefined")))
  {
    {
      return (int)3910;
    }
  }
  {}
  if ((_6433 == std::string ("errNoBarxForSolution")))
  {
    {
      return (int)3915;
    }
  }
  {}
  if ((_6433 == std::string ("errNoBarsForSolution")))
  {
    {
      return (int)3916;
    }
  }
  {}
  if ((_6433 == std::string ("errBarVarDim")))
  {
    {
      return (int)3920;
    }
  }
  {}
  if ((_6433 == std::string ("errSymMatInvalidRowIndex")))
  {
    {
      return (int)3940;
    }
  }
  {}
  if ((_6433 == std::string ("errSymMatInvalidColIndex")))
  {
    {
      return (int)3941;
    }
  }
  {}
  if ((_6433 == std::string ("errSymMatNotLowerTringular")))
  {
    {
      return (int)3942;
    }
  }
  {}
  if ((_6433 == std::string ("errSymMatInvalidValue")))
  {
    {
      return (int)3943;
    }
  }
  {}
  if ((_6433 == std::string ("errSymMatDuplicate")))
  {
    {
      return (int)3944;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidSymMatDim")))
  {
    {
      return (int)3950;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidFileFormatForSymMat")))
  {
    {
      return (int)4000;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidFileFormatForCfix")))
  {
    {
      return (int)4001;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidFileFormatForRangedConstraints")))
  {
    {
      return (int)4002;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidFileFormatForFreeConstraints")))
  {
    {
      return (int)4003;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidFileFormatForCones")))
  {
    {
      return (int)4005;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidFileFormatForNonlinear")))
  {
    {
      return (int)4010;
    }
  }
  {}
  if ((_6433 == std::string ("errDuplicateConstraintNames")))
  {
    {
      return (int)4500;
    }
  }
  {}
  if ((_6433 == std::string ("errDuplicateVariableNames")))
  {
    {
      return (int)4501;
    }
  }
  {}
  if ((_6433 == std::string ("errDuplicateBarvariableNames")))
  {
    {
      return (int)4502;
    }
  }
  {}
  if ((_6433 == std::string ("errDuplicateConeNames")))
  {
    {
      return (int)4503;
    }
  }
  {}
  if ((_6433 == std::string ("errNonUniqueArray")))
  {
    {
      return (int)5000;
    }
  }
  {}
  if ((_6433 == std::string ("errArgumentIsTooLarge")))
  {
    {
      return (int)5005;
    }
  }
  {}
  if ((_6433 == std::string ("errMioInternal")))
  {
    {
      return (int)5010;
    }
  }
  {}
  if ((_6433 == std::string ("errInvalidProblemType")))
  {
    {
      return (int)6000;
    }
  }
  {}
  if ((_6433 == std::string ("errUnhandledSolutionStatus")))
  {
    {
      return (int)6010;
    }
  }
  {}
  if ((_6433 == std::string ("errUpperTriangle")))
  {
    {
      return (int)6020;
    }
  }
  {}
  if ((_6433 == std::string ("errLauSingularMatrix")))
  {
    {
      return (int)7000;
    }
  }
  {}
  if ((_6433 == std::string ("errLauNotPositiveDefinite")))
  {
    {
      return (int)7001;
    }
  }
  {}
  if ((_6433 == std::string ("errLauInvalidLowerTriangularMatrix")))
  {
    {
      return (int)7002;
    }
  }
  {}
  if ((_6433 == std::string ("errLauUnknown")))
  {
    {
      return (int)7005;
    }
  }
  {}
  if ((_6433 == std::string ("errLauArgM")))
  {
    {
      return (int)7010;
    }
  }
  {}
  if ((_6433 == std::string ("errLauArgN")))
  {
    {
      return (int)7011;
    }
  }
  {}
  if ((_6433 == std::string ("errLauArgK")))
  {
    {
      return (int)7012;
    }
  }
  {}
  if ((_6433 == std::string ("errLauArgTransa")))
  {
    {
      return (int)7015;
    }
  }
  {}
  if ((_6433 == std::string ("errLauArgTransb")))
  {
    {
      return (int)7016;
    }
  }
  {}
  if ((_6433 == std::string ("errLauArgUplo")))
  {
    {
      return (int)7017;
    }
  }
  {}
  if ((_6433 == std::string ("errLauArgTrans")))
  {
    {
      return (int)7018;
    }
  }
  {}
  if ((_6433 == std::string ("errLauInvalidSparseSymmetricMatrix")))
  {
    {
      return (int)7019;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfParse")))
  {
    {
      return (int)7100;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfObjSense")))
  {
    {
      return (int)7101;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfNoVariables")))
  {
    {
      return (int)7102;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfTooManyConstraints")))
  {
    {
      return (int)7103;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfTooManyVariables")))
  {
    {
      return (int)7104;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfNoVersionSpecified")))
  {
    {
      return (int)7105;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfSyntax")))
  {
    {
      return (int)7106;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicateObj")))
  {
    {
      return (int)7107;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicateCon")))
  {
    {
      return (int)7108;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicateVar")))
  {
    {
      return (int)7109;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicateInt")))
  {
    {
      return (int)7110;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidVarType")))
  {
    {
      return (int)7111;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidConType")))
  {
    {
      return (int)7112;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidDomainDimension")))
  {
    {
      return (int)7113;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicateObjacoord")))
  {
    {
      return (int)7114;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicateBcoord")))
  {
    {
      return (int)7115;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicateAcoord")))
  {
    {
      return (int)7116;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfTooFewVariables")))
  {
    {
      return (int)7117;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfTooFewConstraints")))
  {
    {
      return (int)7118;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfTooFewInts")))
  {
    {
      return (int)7119;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfTooManyInts")))
  {
    {
      return (int)7120;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidIntIndex")))
  {
    {
      return (int)7121;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfUnsupported")))
  {
    {
      return (int)7122;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicatePsdvar")))
  {
    {
      return (int)7123;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidPsdvarDimension")))
  {
    {
      return (int)7124;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfTooFewPsdvar")))
  {
    {
      return (int)7125;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidExpDimension")))
  {
    {
      return (int)7126;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicatePowCones")))
  {
    {
      return (int)7130;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfDuplicatePowStarCones")))
  {
    {
      return (int)7131;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidPower")))
  {
    {
      return (int)7132;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfPowerConeIsTooLong")))
  {
    {
      return (int)7133;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidPowerConeIndex")))
  {
    {
      return (int)7134;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidPowerStarConeIndex")))
  {
    {
      return (int)7135;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfUnhandledPowerConeType")))
  {
    {
      return (int)7136;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfUnhandledPowerStarConeType")))
  {
    {
      return (int)7137;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfPowerConeMismatch")))
  {
    {
      return (int)7138;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfPowerStarConeMismatch")))
  {
    {
      return (int)7139;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidNumberOfCones")))
  {
    {
      return (int)7740;
    }
  }
  {}
  if ((_6433 == std::string ("errCbfInvalidDimensionOfCones")))
  {
    {
      return (int)7741;
    }
  }
  {}
  if ((_6433 == std::string ("errMioInvalidRootOptimizer")))
  {
    {
      return (int)7700;
    }
  }
  {}
  if ((_6433 == std::string ("errMioInvalidNodeOptimizer")))
  {
    {
      return (int)7701;
    }
  }
  {}
  if ((_6433 == std::string ("errToconicConstrQNotPsd")))
  {
    {
      return (int)7800;
    }
  }
  {}
  if ((_6433 == std::string ("errToconicConstraintFx")))
  {
    {
      return (int)7801;
    }
  }
  {}
  if ((_6433 == std::string ("errToconicConstraintRa")))
  {
    {
      return (int)7802;
    }
  }
  {}
  if ((_6433 == std::string ("errToconicConstrNotConic")))
  {
    {
      return (int)7803;
    }
  }
  {}
  if ((_6433 == std::string ("errToconicObjectiveNotPsd")))
  {
    {
      return (int)7804;
    }
  }
  {}
  if ((_6433 == std::string ("errServerConnect")))
  {
    {
      return (int)8000;
    }
  }
  {}
  if ((_6433 == std::string ("errServerProtocol")))
  {
    {
      return (int)8001;
    }
  }
  {}
  if ((_6433 == std::string ("errServerStatus")))
  {
    {
      return (int)8002;
    }
  }
  {}
  if ((_6433 == std::string ("errServerToken")))
  {
    {
      return (int)8003;
    }
  }
  {}
  if ((_6433 == std::string ("trmMaxIterations")))
  {
    {
      return (int)10000;
    }
  }
  {}
  if ((_6433 == std::string ("trmMaxTime")))
  {
    {
      return (int)10001;
    }
  }
  {}
  if ((_6433 == std::string ("trmObjectiveRange")))
  {
    {
      return (int)10002;
    }
  }
  {}
  if ((_6433 == std::string ("trmMioNumRelaxs")))
  {
    {
      return (int)10008;
    }
  }
  {}
  if ((_6433 == std::string ("trmMioNumBranches")))
  {
    {
      return (int)10009;
    }
  }
  {}
  if ((_6433 == std::string ("trmNumMaxNumIntSolutions")))
  {
    {
      return (int)10015;
    }
  }
  {}
  if ((_6433 == std::string ("trmStall")))
  {
    {
      return (int)10006;
    }
  }
  {}
  if ((_6433 == std::string ("trmUserCallback")))
  {
    {
      return (int)10007;
    }
  }
  {}
  if ((_6433 == std::string ("trmMaxNumSetbacks")))
  {
    {
      return (int)10020;
    }
  }
  {}
  if ((_6433 == std::string ("trmNumericalProblem")))
  {
    {
      return (int)10025;
    }
  }
  {}
  if ((_6433 == std::string ("trmInternal")))
  {
    {
      return (int)10030;
    }
  }
  {}
  if ((_6433 == std::string ("trmInternalStop")))
  {
    {
      return (int)10031;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_xmlwriteroutputtype_value(const std::string & _6434){
  if ((_6434 == std::string ("row")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6434 == std::string ("col")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_prosta_value(const std::string & _6435){
  if ((_6435 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6435 == std::string ("primAndDualFeas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6435 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6435 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6435 == std::string ("primInfeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6435 == std::string ("dualInfeas")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6435 == std::string ("primAndDualInfeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6435 == std::string ("illPosed")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6435 == std::string ("primInfeasOrUnbounded")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemtype_value(const std::string & _6436){
  if ((_6436 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6436 == std::string ("qo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6436 == std::string ("qcqo")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6436 == std::string ("conic")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6436 == std::string ("mixed")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemitem_value(const std::string & _6437){
  if ((_6437 == std::string ("var")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6437 == std::string ("con")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6437 == std::string ("cone")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_parametertype_value(const std::string & _6438){
  if ((_6438 == std::string ("invalidType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6438 == std::string ("douType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6438 == std::string ("intType")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6438 == std::string ("strType")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_presolvemode_value(const std::string & _6439){
  if ((_6439 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6439 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6439 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_orderingtype_value(const std::string & _6440){
  if ((_6440 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6440 == std::string ("appminloc")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6440 == std::string ("experimental")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6440 == std::string ("tryGraphpar")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6440 == std::string ("forceGraphpar")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6440 == std::string ("none")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_optimizertype_value(const std::string & _6441){
  if ((_6441 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6441 == std::string ("intpnt")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6441 == std::string ("conic")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6441 == std::string ("primalSimplex")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6441 == std::string ("dualSimplex")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6441 == std::string ("freeSimplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6441 == std::string ("mixedInt")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_onoffkey_value(const std::string & _6442){
  if ((_6442 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6442 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_objsense_value(const std::string & _6443){
  if ((_6443 == std::string ("minimize")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6443 == std::string ("maximize")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mpsformat_value(const std::string & _6444){
  if ((_6444 == std::string ("strict")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6444 == std::string ("relaxed")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6444 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6444 == std::string ("cplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mionodeseltype_value(const std::string & _6445){
  if ((_6445 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6445 == std::string ("first")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6445 == std::string ("best")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6445 == std::string ("pseudo")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miomode_value(const std::string & _6446){
  if ((_6446 == std::string ("ignored")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6446 == std::string ("satisfied")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miocontsoltype_value(const std::string & _6447){
  if ((_6447 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6447 == std::string ("root")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6447 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6447 == std::string ("itgRel")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_branchdir_value(const std::string & _6448){
  if ((_6448 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6448 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6448 == std::string ("down")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6448 == std::string ("near")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6448 == std::string ("far")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6448 == std::string ("rootLp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6448 == std::string ("guided")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6448 == std::string ("pseudocost")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iparam_value(const std::string & _6449){
  if ((_6449 == std::string ("autoUpdateSolInfo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6449 == std::string ("removeUnusedSolutions")))
  {
    {
      return (int)112;
    }
  }
  {}
  if ((_6449 == std::string ("intpntHotstart")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6449 == std::string ("intpntPurify")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6449 == std::string ("numThreads")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6449 == std::string ("intpntMultiThread")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6449 == std::string ("timingLevel")))
  {
    {
      return (int)146;
    }
  }
  {}
  if ((_6449 == std::string ("mtSpincount")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6449 == std::string ("maxNumWarnings")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6449 == std::string ("optimizer")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6449 == std::string ("biMaxIterations")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6449 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6449 == std::string ("logCutSecondOpt")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6449 == std::string ("logAnaPro")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6449 == std::string ("logResponse")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6449 == std::string ("logBi")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6449 == std::string ("logBiFreq")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6449 == std::string ("biCleanOptimizer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6449 == std::string ("intpntMaxNumRefinementSteps")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6449 == std::string ("intpntStartingPoint")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6449 == std::string ("intpntDiffStep")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6449 == std::string ("intpntScaling")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6449 == std::string ("intpntSolveForm")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6449 == std::string ("logIntpnt")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6449 == std::string ("intpntMaxIterations")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6449 == std::string ("intpntOffColTrh")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6449 == std::string ("intpntOrderMethod")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6449 == std::string ("intpntBasis")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6449 == std::string ("biIgnoreMaxIter")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6449 == std::string ("biIgnoreNumError")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6449 == std::string ("intpntMaxNumCor")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6449 == std::string ("presolveUse")))
  {
    {
      return (int)103;
    }
  }
  {}
  if ((_6449 == std::string ("presolveLevel")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6449 == std::string ("logPresolve")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6449 == std::string ("presolveLindepUse")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6449 == std::string ("presolveMaxNumPass")))
  {
    {
      return (int)101;
    }
  }
  {}
  if ((_6449 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6449 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6449 == std::string ("presolveMaxNumReductions")))
  {
    {
      return (int)102;
    }
  }
  {}
  if ((_6449 == std::string ("simStabilityPriority")))
  {
    {
      return (int)139;
    }
  }
  {}
  if ((_6449 == std::string ("simPrimalCrash")))
  {
    {
      return (int)128;
    }
  }
  {}
  if ((_6449 == std::string ("logSim")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6449 == std::string ("logSimMinor")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6449 == std::string ("logSimFreq")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6449 == std::string ("simPrimalRestrictSelection")))
  {
    {
      return (int)130;
    }
  }
  {}
  if ((_6449 == std::string ("simPrimalSelection")))
  {
    {
      return (int)131;
    }
  }
  {}
  if ((_6449 == std::string ("simDualRestrictSelection")))
  {
    {
      return (int)120;
    }
  }
  {}
  if ((_6449 == std::string ("simDualSelection")))
  {
    {
      return (int)121;
    }
  }
  {}
  if ((_6449 == std::string ("simMaxIterations")))
  {
    {
      return (int)125;
    }
  }
  {}
  if ((_6449 == std::string ("simHotstartLu")))
  {
    {
      return (int)124;
    }
  }
  {}
  if ((_6449 == std::string ("simRefactorFreq")))
  {
    {
      return (int)132;
    }
  }
  {}
  if ((_6449 == std::string ("simSeed")))
  {
    {
      return (int)137;
    }
  }
  {}
  if ((_6449 == std::string ("mioMode")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6449 == std::string ("logMio")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6449 == std::string ("logMioFreq")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6449 == std::string ("mioMaxNumRelaxs")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6449 == std::string ("mioMaxNumBranches")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6449 == std::string ("mioMaxNumSolutions")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6449 == std::string ("mioNodeSelection")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6449 == std::string ("mioHeuristicLevel")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6449 == std::string ("mioProbingLevel")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6449 == std::string ("mioCutSelectionLevel")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6449 == std::string ("mioVbDetectionLevel")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6449 == std::string ("mioBranchDir")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6449 == std::string ("mioRootOptimizer")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6449 == std::string ("mioNodeOptimizer")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6449 == std::string ("mioPerspectiveReformulate")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6449 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6449 == std::string ("mioSeed")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6449 == std::string ("mioConicOuterApproximation")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6449 == std::string ("readKeepFreeCon")))
  {
    {
      return (int)106;
    }
  }
  {}
  if ((_6449 == std::string ("readMpsFormat")))
  {
    {
      return (int)109;
    }
  }
  {}
  if ((_6449 == std::string ("writeMpsFormat")))
  {
    {
      return (int)164;
    }
  }
  {}
  if ((_6449 == std::string ("readMpsWidth")))
  {
    {
      return (int)110;
    }
  }
  {}
  if ((_6449 == std::string ("readDebug")))
  {
    {
      return (int)105;
    }
  }
  {}
  if ((_6449 == std::string ("readLpQuotedNames")))
  {
    {
      return (int)108;
    }
  }
  {}
  if ((_6449 == std::string ("writeDataParam")))
  {
    {
      return (int)151;
    }
  }
  {}
  if ((_6449 == std::string ("writeFreeCon")))
  {
    {
      return (int)152;
    }
  }
  {}
  if ((_6449 == std::string ("writeGenericNames")))
  {
    {
      return (int)153;
    }
  }
  {}
  if ((_6449 == std::string ("writeGenericNamesIo")))
  {
    {
      return (int)154;
    }
  }
  {}
  if ((_6449 == std::string ("writeCompression")))
  {
    {
      return (int)150;
    }
  }
  {}
  if ((_6449 == std::string ("writeMpsInt")))
  {
    {
      return (int)165;
    }
  }
  {}
  if ((_6449 == std::string ("writeLpStrictFormat")))
  {
    {
      return (int)162;
    }
  }
  {}
  if ((_6449 == std::string ("writeLpQuotedNames")))
  {
    {
      return (int)161;
    }
  }
  {}
  if ((_6449 == std::string ("writeLpLineWidth")))
  {
    {
      return (int)160;
    }
  }
  {}
  if ((_6449 == std::string ("writeLpTermsPerLine")))
  {
    {
      return (int)163;
    }
  }
  {}
  if ((_6449 == std::string ("writeLpFullObj")))
  {
    {
      return (int)159;
    }
  }
  {}
  if ((_6449 == std::string ("writePrecision")))
  {
    {
      return (int)166;
    }
  }
  {}
  if ((_6449 == std::string ("writeSolIgnoreInvalidNames")))
  {
    {
      return (int)170;
    }
  }
  {}
  if ((_6449 == std::string ("writeSolHead")))
  {
    {
      return (int)169;
    }
  }
  {}
  if ((_6449 == std::string ("writeSolConstraints")))
  {
    {
      return (int)168;
    }
  }
  {}
  if ((_6449 == std::string ("writeSolVariables")))
  {
    {
      return (int)171;
    }
  }
  {}
  if ((_6449 == std::string ("writeSolBarvariables")))
  {
    {
      return (int)167;
    }
  }
  {}
  if ((_6449 == std::string ("writeBasHead")))
  {
    {
      return (int)148;
    }
  }
  {}
  if ((_6449 == std::string ("writeBasConstraints")))
  {
    {
      return (int)147;
    }
  }
  {}
  if ((_6449 == std::string ("writeBasVariables")))
  {
    {
      return (int)149;
    }
  }
  {}
  if ((_6449 == std::string ("writeIntHead")))
  {
    {
      return (int)157;
    }
  }
  {}
  if ((_6449 == std::string ("writeIntConstraints")))
  {
    {
      return (int)156;
    }
  }
  {}
  if ((_6449 == std::string ("writeIntVariables")))
  {
    {
      return (int)158;
    }
  }
  {}
  if ((_6449 == std::string ("solReadNameWidth")))
  {
    {
      return (int)143;
    }
  }
  {}
  if ((_6449 == std::string ("solReadWidth")))
  {
    {
      return (int)144;
    }
  }
  {}
  if ((_6449 == std::string ("infeasReportAuto")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6449 == std::string ("infeasReportLevel")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6449 == std::string ("infeasGenericNames")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6449 == std::string ("logInfeasAna")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6449 == std::string ("licenseWait")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6449 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6449 == std::string ("licensePauseTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6449 == std::string ("licenseDebug")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6449 == std::string ("solFilterKeepBasic")))
  {
    {
      return (int)141;
    }
  }
  {}
  if ((_6449 == std::string ("solFilterKeepRanged")))
  {
    {
      return (int)142;
    }
  }
  {}
  if ((_6449 == std::string ("log")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6449 == std::string ("logExpand")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6449 == std::string ("logFile")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6449 == std::string ("logOrder")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6449 == std::string ("logSensitivity")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6449 == std::string ("logSensitivityOpt")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6449 == std::string ("readTaskIgnoreParam")))
  {
    {
      return (int)111;
    }
  }
  {}
  if ((_6449 == std::string ("writeTaskIncSol")))
  {
    {
      return (int)172;
    }
  }
  {}
  if ((_6449 == std::string ("paramReadCaseName")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6449 == std::string ("paramReadIgnError")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6449 == std::string ("solutionCallback")))
  {
    {
      return (int)145;
    }
  }
  {}
  if ((_6449 == std::string ("simScaling")))
  {
    {
      return (int)135;
    }
  }
  {}
  if ((_6449 == std::string ("simScalingMethod")))
  {
    {
      return (int)136;
    }
  }
  {}
  if ((_6449 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      return (int)129;
    }
  }
  {}
  if ((_6449 == std::string ("simDualPhaseoneMethod")))
  {
    {
      return (int)119;
    }
  }
  {}
  if ((_6449 == std::string ("simMaxNumSetbacks")))
  {
    {
      return (int)126;
    }
  }
  {}
  if ((_6449 == std::string ("simHotstart")))
  {
    {
      return (int)123;
    }
  }
  {}
  if ((_6449 == std::string ("simBasisFactorUse")))
  {
    {
      return (int)116;
    }
  }
  {}
  if ((_6449 == std::string ("simDegen")))
  {
    {
      return (int)117;
    }
  }
  {}
  if ((_6449 == std::string ("simReformulation")))
  {
    {
      return (int)133;
    }
  }
  {}
  if ((_6449 == std::string ("simExploitDupvec")))
  {
    {
      return (int)122;
    }
  }
  {}
  if ((_6449 == std::string ("simSaveLu")))
  {
    {
      return (int)134;
    }
  }
  {}
  if ((_6449 == std::string ("simNonSingular")))
  {
    {
      return (int)127;
    }
  }
  {}
  if ((_6449 == std::string ("simDualCrash")))
  {
    {
      return (int)118;
    }
  }
  {}
  if ((_6449 == std::string ("logStorage")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6449 == std::string ("infeasPreferPrimal")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6449 == std::string ("readLpDropNewVarsInBou")))
  {
    {
      return (int)107;
    }
  }
  {}
  if ((_6449 == std::string ("opfWriteLineLength")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6449 == std::string ("opfWriteHints")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6449 == std::string ("opfWriteParameters")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6449 == std::string ("opfWriteProblem")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6449 == std::string ("opfWriteHeader")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6449 == std::string ("opfWriteSolutions")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6449 == std::string ("opfWriteSolBas")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6449 == std::string ("opfWriteSolItg")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6449 == std::string ("opfWriteSolItr")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6449 == std::string ("primalRepairOptimizer")))
  {
    {
      return (int)104;
    }
  }
  {}
  if ((_6449 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6449 == std::string ("mioCutCmir")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6449 == std::string ("mioCutClique")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6449 == std::string ("mioCutImpliedBound")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6449 == std::string ("mioCutKnapsackCover")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6449 == std::string ("mioCutGmi")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6449 == std::string ("sensitivityType")))
  {
    {
      return (int)115;
    }
  }
  {}
  if ((_6449 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6449 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6449 == std::string ("sensitivityAll")))
  {
    {
      return (int)113;
    }
  }
  {}
  if ((_6449 == std::string ("logFeasRepair")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6449 == std::string ("cacheLicense")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6449 == std::string ("intpntRegularizationUse")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6449 == std::string ("simSolveForm")))
  {
    {
      return (int)138;
    }
  }
  {}
  if ((_6449 == std::string ("simSwitchOptimizer")))
  {
    {
      return (int)140;
    }
  }
  {}
  if ((_6449 == std::string ("writeIgnoreIncompatibleItems")))
  {
    {
      return (int)155;
    }
  }
  {}
  if ((_6449 == std::string ("checkConvexity")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6449 == std::string ("logCheckConvexity")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6449 == std::string ("autoSortABeforeOpt")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6449 == std::string ("sensitivityOptimizer")))
  {
    {
      return (int)114;
    }
  }
  {}
  if ((_6449 == std::string ("writeXmlMode")))
  {
    {
      return (int)173;
    }
  }
  {}
  if ((_6449 == std::string ("anaSolBasis")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6449 == std::string ("anaSolPrintViolated")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6449 == std::string ("basisSolveUsePlusOne")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6449 == std::string ("compressStatfile")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6449 == std::string ("mioRinsMaxNodes")))
  {
    {
      return (int)76;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iomode_value(const std::string & _6450){
  if ((_6450 == std::string ("read")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6450 == std::string ("write")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6450 == std::string ("readwrite")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_iinf_value(const std::string & _6451){
  if ((_6451 == std::string ("versionMajor")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6451 == std::string ("versionMinor")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6451 == std::string ("versionRevision")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6451 == std::string ("presolveLindepWork")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6451 == std::string ("presolveLindepPivots")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6451 == std::string ("presolveLindepSkipped")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6451 == std::string ("presolveOutofspace")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6451 == std::string ("presolveBadPrecision")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6451 == std::string ("optObjectiveSense")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6451 == std::string ("optimizer")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6451 == std::string ("intpntFirRefIter")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumRefSteps")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6451 == std::string ("intpntFactorDim")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6451 == std::string ("intpntFactorSchurNumSingular")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6451 == std::string ("intpntFactorNumDenseA")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6451 == std::string ("intpntFactorNumDenseADup")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6451 == std::string ("intpntFactorNumDenseW")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumcon")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumvar")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumbarvar")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumblo")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumbup")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumbfr")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumbfx")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumcone")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumconevar")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumbndcone")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumrqcones")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumqcones")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumpexpcones")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6451 == std::string ("intpntNumppowcones")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6451 == std::string ("intpntMinconedim")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6451 == std::string ("intpntMaxconedim")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6451 == std::string ("intpntMaxbarvardim")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumcfr")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumcfx")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumclo")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumcup")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumcra")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumcnl")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumvfr")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumvfx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumvlo")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumvup")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumvra")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumvnl")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumnza")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumcon")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumcfr")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumcfx")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumclo")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumcup")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumcra")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumcnl")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumvar")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumvfr")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumvfx")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumvlo")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumvup")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumvra")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumvnl")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6451 == std::string ("presolveFnumnza")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumElimns")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6451 == std::string ("presolveEliNumTries")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6451 == std::string ("presolveEliNumFreedCon")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6451 == std::string ("presolveEliNumFreedConTotal")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6451 == std::string ("presolveLindepNumTries")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6451 == std::string ("presolveLindepNum")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6451 == std::string ("presolveForceConNum")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6451 == std::string ("presolveForceConNumVar")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6451 == std::string ("presolveForceVarNum")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6451 == std::string ("presolveForceVarNumCon")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6451 == std::string ("presolvePivOnConNum")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumDouBlocks")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumSimplifiedDouBlocks")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6451 == std::string ("presolveSizeSimplifiedDouBlocks")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6451 == std::string ("presolveNumQuadConeOrthoTrans")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6451 == std::string ("intpntFactorNum")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6451 == std::string ("intpntFactorNumSolve")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6451 == std::string ("simPrimalHotstartNumBasics")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6451 == std::string ("simPrimalHotstartBasisRank")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6451 == std::string ("simDualHotstartNumBasics")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6451 == std::string ("simDualHotstartBasisRank")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6451 == std::string ("intpntGpOrderEmployed")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6451 == std::string ("numLuFactorizations")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6451 == std::string ("simPrimalTrust")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6451 == std::string ("simDualTrust")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6451 == std::string ("simPrimalNumSetbacks")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6451 == std::string ("simDualNumSetbacks")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6451 == std::string ("simNumDupvec")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6451 == std::string ("simNumPrimalBoundswaps")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6451 == std::string ("simNumDualBoundswaps")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6451 == std::string ("simNumDualIntegerPivots")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6451 == std::string ("biPrimalInfo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6451 == std::string ("biDualInfo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6451 == std::string ("presolveLindepNumTruncTries")))
  {
    {
      return (int)57;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_dinf_value(const std::string & _6452){
  if ((_6452 == std::string ("sensitivityPrimalTime")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6452 == std::string ("sensitivityDualTime")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6452 == std::string ("intpntGfeas")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6452 == std::string ("intpntMu")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6452 == std::string ("intpntInitIterTime")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorTime")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6452 == std::string ("intpntInitSearchTime")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFormSearchTime")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6452 == std::string ("intpntUpdateTime")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSetupTime")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSchurTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorHatSchurTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorHatSchurPushTime")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorHatSchurPullTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorBarSchurTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorBarSchurDeTabTime")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorBarSchurSpTabTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSparseLTime")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSparseLUpdateLastTime")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSparseLFactorLastTime")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseLTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseTime")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotaTime")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotaSolveTime")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotatdotaTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotlInitTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotlFactorTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6452 == std::string ("intpntIterNonCorrectorFlops")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6452 == std::string ("intpntIterOneCorrectorFlops")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6452 == std::string ("intpntSolveTime")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6452 == std::string ("intpntIterRefTime")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6452 == std::string ("intpntSolveSparseLTime")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6452 == std::string ("intpntSolveDenseLTime")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSetupFlops")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSetupHatSchurFlops")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSchurFlops")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorHatSchurFlops")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorHatSchurPushFlops")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorHatSchurPullFlops")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorBarSchurFlops")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSparseLFlops")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorMlOrderSparseLFlops")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorGpOrderSparseLFlops")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSparseLUpdateLastFlops")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSparseLFactorLastFlops")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseLFlops")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseFlops")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotaFlops")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotatdotaFlops")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotlFactor_initFlops")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotlFactorFlops")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotl11FactorFlops")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotl21FactorFlops")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorDenseDotl22FactorFlops")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6452 == std::string ("presolveAcoltTime")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6452 == std::string ("presolveSetupTime")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6452 == std::string ("presolveCheckproTime")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6452 == std::string ("presolveDupconTime")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6452 == std::string ("presolveDupvarTime")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6452 == std::string ("presolveFinalTime")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6452 == std::string ("presolveSubDomvarTime")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6452 == std::string ("presolveSubRelaxTime")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6452 == std::string ("primalSimplexInftime")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6452 == std::string ("dualSimplexInftime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6452 == std::string ("intpntGpOrderSavedFlops")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSetupDetectDenseTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSetupMlOrderTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6452 == std::string ("intpntFactorSetupGpOrderTime")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6452 == std::string ("biCrashTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6452 == std::string ("biCrashLuTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6452 == std::string ("biFactorTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6452 == std::string ("biFactorWork")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6452 == std::string ("biPrimalDone")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6452 == std::string ("biDualDone")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6452 == std::string ("simPrimalObj")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6452 == std::string ("simPrimalFeas")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6452 == std::string ("simDualObj")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6452 == std::string ("simDualFeas")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6452 == std::string ("biPrimalObj")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6452 == std::string ("biDualObj")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6452 == std::string ("biPrimalFeas")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6452 == std::string ("biDualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6452 == std::string ("intpntPurifyTime")))
  {
    {
      return (int)63;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_inftype_value(const std::string & _6453){
  if ((_6453 == std::string ("douType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6453 == std::string ("intType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6453 == std::string ("lintType")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iinfitem_value(const std::string & _6454){
  if ((_6454 == std::string ("anaProNumCon")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumConLo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumConUp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumConRa")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumConEq")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumConFr")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumVar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumVarLo")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumVarUp")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumVarRa")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumVarEq")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumVarFr")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumVarCont")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumVarBin")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6454 == std::string ("anaProNumVarInt")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6454 == std::string ("optimizeResponse")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6454 == std::string ("intpntIter")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6454 == std::string ("intpntFactorDimDense")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6454 == std::string ("intpntSolveDual")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6454 == std::string ("mioNodeDepth")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumvar")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumbin")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumint")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumcont")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumcon")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumcone")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumqcones")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumrqcones")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumpexpcones")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumconevar")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumbinconevar")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumintconevar")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumcontconevar")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumvar")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumbin")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumint")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumcont")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumcon")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumcone")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumqcones")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumrqcones")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumpexpcones")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumconevar")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumbinconevar")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumintconevar")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6454 == std::string ("mioPresolvedNumcontconevar")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6454 == std::string ("mioCliqueTableSize")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6454 == std::string ("mioConstructSolution")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6454 == std::string ("mioConstructNumRoundings")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumIntSolutions")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6454 == std::string ("mioObjBoundDefined")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumActiveNodes")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumRelax")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumBranch")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6454 == std::string ("mioTotalNumCuts")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumCmirCuts")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumCliqueCuts")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumImpliedBoundCuts")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumKnapsackCoverCuts")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumGomoryCuts")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6454 == std::string ("mioNumRepeatedPresolve")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6454 == std::string ("mioInitialSolution")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6454 == std::string ("mioUserObjCut")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6454 == std::string ("mioRelgapSatisfied")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6454 == std::string ("mioAbsgapSatisfied")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6454 == std::string ("rdProtype")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6454 == std::string ("rdNumcon")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6454 == std::string ("rdNumvar")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6454 == std::string ("rdNumbarvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6454 == std::string ("rdNumintvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6454 == std::string ("rdNumq")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6454 == std::string ("simDualDegIter")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6454 == std::string ("simDualInfIter")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6454 == std::string ("simDualHotstartLu")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6454 == std::string ("simPrimalIter")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6454 == std::string ("simDualIter")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6454 == std::string ("intpntNumThreads")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6454 == std::string ("simPrimalInfIter")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6454 == std::string ("simPrimalDegIter")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6454 == std::string ("simPrimalHotstart")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6454 == std::string ("simPrimalHotstartLu")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6454 == std::string ("simDualHotstart")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6454 == std::string ("solItrProsta")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6454 == std::string ("solItrSolsta")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6454 == std::string ("solBasProsta")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6454 == std::string ("solBasSolsta")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6454 == std::string ("solItgProsta")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6454 == std::string ("solItgSolsta")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6454 == std::string ("simNumcon")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6454 == std::string ("simNumvar")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6454 == std::string ("optNumcon")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6454 == std::string ("optNumvar")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6454 == std::string ("stoNumARealloc")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6454 == std::string ("rdNumcone")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6454 == std::string ("simSolveDual")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6454 == std::string ("purifyPrimalSuccess")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6454 == std::string ("purifyDualSuccess")))
  {
    {
      return (int)68;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_liinf_value(const std::string & _6455){
  if ((_6455 == std::string ("intpntLenbarvar")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorNumNzBefore")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorMlOrderSparseLNz")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorGpOrderSparseLNz")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6455 == std::string ("presolveStackSize")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorVNz")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6455 == std::string ("intpntFactorUpdatedVNz")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_liinfitem_value(const std::string & _6456){
  if ((_6456 == std::string ("mioAnz")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6456 == std::string ("mioPresolvedAnz")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6456 == std::string ("mioSimplexIter")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6456 == std::string ("mioIntpntIter")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6456 == std::string ("biPrimalIter")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6456 == std::string ("biDualIter")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6456 == std::string ("biCleanPrimalIter")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6456 == std::string ("biCleanDualIter")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6456 == std::string ("biCleanPrimalDegIter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6456 == std::string ("biCleanDualDegIter")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6456 == std::string ("intpntFactorNumNz")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6456 == std::string ("rdNumanz")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6456 == std::string ("rdNumqnz")))
  {
    {
      return (int)12;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dparam_value(const std::string & _6457){
  if ((_6457 == std::string ("dataTolCjLarge")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6457 == std::string ("dataTolCHuge")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6457 == std::string ("dataTolAijLarge")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6457 == std::string ("dataTolAijHuge")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6457 == std::string ("dataSymMatTol")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6457 == std::string ("dataSymMatTolLarge")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6457 == std::string ("dataSymMatTolHuge")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6457 == std::string ("dataTolBoundInf")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6457 == std::string ("dataTolBoundWrn")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6457 == std::string ("dataTolQij")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6457 == std::string ("dataTolX")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6457 == std::string ("semidefiniteTolApprox")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6457 == std::string ("optimizerMaxTime")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6457 == std::string ("lowerObjCut")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6457 == std::string ("upperObjCut")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6457 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6457 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolRelGap")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolStepSize")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6457 == std::string ("simLuTolRelPiv")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolRelStep")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolPath")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolPfeas")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolDfeas")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolMuRed")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolInfeas")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6457 == std::string ("intpntCoTolRelGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6457 == std::string ("intpntCoTolPfeas")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6457 == std::string ("intpntCoTolDfeas")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6457 == std::string ("intpntCoTolMuRed")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6457 == std::string ("intpntCoTolNearRel")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6457 == std::string ("intpntCoTolInfeas")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6457 == std::string ("intpntQoTolRelGap")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6457 == std::string ("intpntQoTolPfeas")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6457 == std::string ("intpntQoTolDfeas")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6457 == std::string ("intpntQoTolMuRed")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6457 == std::string ("intpntQoTolNearRel")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6457 == std::string ("intpntQoTolInfeas")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolPsafe")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6457 == std::string ("intpntTolDsafe")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6457 == std::string ("mioMaxTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6457 == std::string ("mioRelGapConst")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6457 == std::string ("mioTolRelGap")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6457 == std::string ("mioTolAbsGap")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6457 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6457 == std::string ("basisTolX")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6457 == std::string ("basisTolS")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6457 == std::string ("basisRelTolS")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6457 == std::string ("presolveTolX")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6457 == std::string ("presolveTolS")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6457 == std::string ("presolveTolAij")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6457 == std::string ("presolveTolAbsLindep")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6457 == std::string ("presolveTolRelLindep")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6457 == std::string ("simplexAbsTolPiv")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6457 == std::string ("mioTolFeas")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6457 == std::string ("anaSolInfeasTol")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6457 == std::string ("checkConvexityRelTol")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6457 == std::string ("qcqoReformulateRelDropTol")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6457 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      return (int)45;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_feature_value(const std::string & _6458){
  if ((_6458 == std::string ("pts")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6458 == std::string ("pton")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dinfitem_value(const std::string & _6459){
  if ((_6459 == std::string ("biTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6459 == std::string ("biPrimalTime")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6459 == std::string ("biDualTime")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6459 == std::string ("biCleanTime")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6459 == std::string ("biCleanPrimalTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6459 == std::string ("biCleanDualTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6459 == std::string ("intpntTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6459 == std::string ("intpntOrderTime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6459 == std::string ("intpntPrimalObj")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6459 == std::string ("intpntDualObj")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6459 == std::string ("intpntPrimalFeas")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6459 == std::string ("intpntDualFeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6459 == std::string ("intpntOptStatus")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6459 == std::string ("simTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6459 == std::string ("simPrimalTime")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6459 == std::string ("simDualTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6459 == std::string ("simObj")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6459 == std::string ("simFeas")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6459 == std::string ("mioTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6459 == std::string ("mioRootPresolveTime")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6459 == std::string ("mioRootOptimizerTime")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6459 == std::string ("toConicTime")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6459 == std::string ("mioConstructSolutionObj")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6459 == std::string ("mioObjInt")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6459 == std::string ("mioObjBound")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6459 == std::string ("mioObjRelGap")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6459 == std::string ("mioObjAbsGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6459 == std::string ("mioUserObjCut")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6459 == std::string ("mioCmirSeparationTime")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6459 == std::string ("mioCliqueSeparationTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6459 == std::string ("mioKnapsackCoverSeparationTime")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6459 == std::string ("mioGmiSeparationTime")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6459 == std::string ("mioImpliedBoundTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6459 == std::string ("mioRootCutgenTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6459 == std::string ("mioProbingTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6459 == std::string ("optimizerTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6459 == std::string ("presolveTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6459 == std::string ("mioDualBoundAfterPresolve")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6459 == std::string ("presolveEliTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6459 == std::string ("presolveLindepTime")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6459 == std::string ("rdTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6459 == std::string ("solItrPrimalObj")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6459 == std::string ("solItrPviolcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6459 == std::string ("solItrPviolvar")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6459 == std::string ("solItrPviolbarvar")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6459 == std::string ("solItrPviolcones")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6459 == std::string ("solItrDualObj")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6459 == std::string ("solItrDviolcon")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6459 == std::string ("solItrDviolvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6459 == std::string ("solItrDviolbarvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6459 == std::string ("solItrDviolcones")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmXc")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmXx")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmBarx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmY")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmSlc")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmSuc")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmSlx")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmSux")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmSnx")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6459 == std::string ("solItrNrmBars")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6459 == std::string ("solBasPrimalObj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6459 == std::string ("solBasPviolcon")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6459 == std::string ("solBasPviolvar")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6459 == std::string ("solBasDualObj")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6459 == std::string ("solBasDviolcon")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6459 == std::string ("solBasDviolvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6459 == std::string ("solBasNrmXc")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6459 == std::string ("solBasNrmXx")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6459 == std::string ("solBasNrmBarx")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6459 == std::string ("solBasNrmY")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6459 == std::string ("solBasNrmSlc")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6459 == std::string ("solBasNrmSuc")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6459 == std::string ("solBasNrmSlx")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6459 == std::string ("solBasNrmSux")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6459 == std::string ("solItgPrimalObj")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6459 == std::string ("solItgPviolcon")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6459 == std::string ("solItgPviolvar")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6459 == std::string ("solItgPviolbarvar")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6459 == std::string ("solItgPviolcones")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6459 == std::string ("solItgPviolitg")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6459 == std::string ("solItgNrmXc")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6459 == std::string ("solItgNrmXx")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6459 == std::string ("solItgNrmBarx")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6459 == std::string ("intpntFactorNumFlops")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6459 == std::string ("qcqoReformulateTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6459 == std::string ("qcqoReformulateMaxPerturbation")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6459 == std::string ("qcqoReformulateWorstCholeskyDiagScaling")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6459 == std::string ("qcqoReformulateWorstCholeskyColumnScaling")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6459 == std::string ("primalRepairPenaltyObj")))
  {
    {
      return (int)35;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dataformat_value(const std::string & _6460){
  if ((_6460 == std::string ("extension")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6460 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6460 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6460 == std::string ("op")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6460 == std::string ("freeMps")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6460 == std::string ("task")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6460 == std::string ("ptf")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6460 == std::string ("cb")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6460 == std::string ("jsonTask")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_symmattype_value(const std::string & _6461){
  if ((_6461 == std::string ("sparse")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scopr_value(const std::string & _6462){
  if ((_6462 == std::string ("ent")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6462 == std::string ("exp")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6462 == std::string ("log")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6462 == std::string ("pow")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6462 == std::string ("sqrt")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_nametype_value(const std::string & _6463){
  if ((_6463 == std::string ("gen")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6463 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6463 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_conetype_value(const std::string & _6464){
  if ((_6464 == std::string ("quad")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6464 == std::string ("rquad")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6464 == std::string ("pexp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6464 == std::string ("dexp")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6464 == std::string ("ppow")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6464 == std::string ("dpow")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6464 == std::string ("zero")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_compresstype_value(const std::string & _6465){
  if ((_6465 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6465 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6465 == std::string ("gzip")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6465 == std::string ("zstd")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_checkconvexitytype_value(const std::string & _6466){
  if ((_6466 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6466 == std::string ("simple")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6466 == std::string ("full")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_callbackcode_value(const std::string & _6467){
  if ((_6467 == std::string ("beginRootCutgen")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6467 == std::string ("imRootCutgen")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6467 == std::string ("endRootCutgen")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6467 == std::string ("beginOptimizer")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6467 == std::string ("endOptimizer")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6467 == std::string ("beginPresolve")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6467 == std::string ("updatePresolve")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6467 == std::string ("imPresolve")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6467 == std::string ("endPresolve")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6467 == std::string ("beginIntpnt")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6467 == std::string ("intpnt")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6467 == std::string ("imIntpnt")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6467 == std::string ("endIntpnt")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6467 == std::string ("beginConic")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6467 == std::string ("conic")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6467 == std::string ("imConic")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6467 == std::string ("endConic")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6467 == std::string ("primalSimplex")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6467 == std::string ("dualSimplex")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6467 == std::string ("beginBi")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6467 == std::string ("imBi")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6467 == std::string ("endBi")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6467 == std::string ("beginPrimalBi")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6467 == std::string ("imPrimalBi")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6467 == std::string ("updatePrimalBi")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6467 == std::string ("endPrimalBi")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6467 == std::string ("beginDualBi")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6467 == std::string ("imDualBi")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6467 == std::string ("updateDualBi")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6467 == std::string ("endDualBi")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6467 == std::string ("beginSimplexBi")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6467 == std::string ("imSimplexBi")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6467 == std::string ("beginPrimalSimplexBi")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6467 == std::string ("updatePrimalSimplexBi")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6467 == std::string ("endPrimalSimplexBi")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6467 == std::string ("beginDualSimplexBi")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6467 == std::string ("updateDualSimplexBi")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6467 == std::string ("endDualSimplexBi")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6467 == std::string ("endSimplexBi")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6467 == std::string ("beginMio")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6467 == std::string ("imMio")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6467 == std::string ("newIntMio")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6467 == std::string ("endMio")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6467 == std::string ("beginSimplex")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6467 == std::string ("beginDualSimplex")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6467 == std::string ("imDualSimplex")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6467 == std::string ("updateDualSimplex")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6467 == std::string ("endDualSimplex")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6467 == std::string ("beginPrimalSimplex")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6467 == std::string ("imPrimalSimplex")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6467 == std::string ("updatePrimalSimplex")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6467 == std::string ("endPrimalSimplex")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6467 == std::string ("endSimplex")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6467 == std::string ("beginInfeasAna")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6467 == std::string ("endInfeasAna")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6467 == std::string ("imPrimalSensivity")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6467 == std::string ("imDualSensivity")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6467 == std::string ("imMioIntpnt")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6467 == std::string ("imMioPrimalSimplex")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6467 == std::string ("imMioDualSimplex")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6467 == std::string ("beginPrimalSetupBi")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6467 == std::string ("endPrimalSetupBi")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6467 == std::string ("beginDualSetupBi")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6467 == std::string ("endDualSetupBi")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6467 == std::string ("beginPrimalSensitivity")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6467 == std::string ("endPrimalSensitivity")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6467 == std::string ("beginDualSensitivity")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6467 == std::string ("endDualSensitivity")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6467 == std::string ("beginLicenseWait")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6467 == std::string ("endLicenseWait")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6467 == std::string ("imLicenseWait")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6467 == std::string ("beginQcqoReformulate")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6467 == std::string ("endQcqoReformulate")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6467 == std::string ("imQoReformulate")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6467 == std::string ("beginToConic")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6467 == std::string ("endToConic")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6467 == std::string ("beginFullConvexityCheck")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6467 == std::string ("endFullConvexityCheck")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6467 == std::string ("imFullConvexityCheck")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6467 == std::string ("beginPrimalRepair")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6467 == std::string ("endPrimalRepair")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6467 == std::string ("beginRead")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6467 == std::string ("imRead")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6467 == std::string ("endRead")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6467 == std::string ("beginWrite")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6467 == std::string ("endWrite")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6467 == std::string ("readOpfSection")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6467 == std::string ("imLu")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6467 == std::string ("imOrder")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6467 == std::string ("imSimplex")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6467 == std::string ("readOpf")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6467 == std::string ("writeOpf")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6467 == std::string ("solvingRemote")))
  {
    {
      return (int)84;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_purify_value(const std::string & _6468){
  if ((_6468 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6468 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6468 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6468 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6468 == std::string ("auto")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_intpnthotstart_value(const std::string & _6469){
  if ((_6469 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6469 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6469 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6469 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simhotstart_value(const std::string & _6470){
  if ((_6470 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6470 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6470 == std::string ("statusKeys")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdupvec_value(const std::string & _6471){
  if ((_6471 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6471 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6471 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simreform_value(const std::string & _6472){
  if ((_6472 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6472 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6472 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6472 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_uplo_value(const std::string & _6473){
  if ((_6473 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6473 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_transpose_value(const std::string & _6474){
  if ((_6474 == std::string ("no")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6474 == std::string ("yes")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdegen_value(const std::string & _6475){
  if ((_6475 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6475 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6475 == std::string ("aggressive")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6475 == std::string ("moderate")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6475 == std::string ("minimum")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mark_value(const std::string & _6476){
  if ((_6476 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6476 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_boundkey_value(const std::string & _6477){
  if ((_6477 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6477 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6477 == std::string ("fx")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6477 == std::string ("fr")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6477 == std::string ("ra")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_basindtype_value(const std::string & _6478){
  if ((_6478 == std::string ("never")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6478 == std::string ("always")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6478 == std::string ("noError")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6478 == std::string ("ifFeasible")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6478 == std::string ("reservered")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_language_value(const std::string & _6479){
  if ((_6479 == std::string ("eng")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6479 == std::string ("dan")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
void mosek::fusion::p_Parameters::destroy(){}void mosek::fusion::Parameters::destroy() { mosek::fusion::p_Parameters::_get_impl(this)->destroy(); }